Class: Stripe::AccountCreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2207
2208
2209
2210
2211
2212
# File 'lib/stripe/params/account_create_params.rb', line 2207

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2199
2200
2201
# File 'lib/stripe/params/account_create_params.rb', line 2199

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2201
2202
2203
# File 'lib/stripe/params/account_create_params.rb', line 2201

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2203
2204
2205
# File 'lib/stripe/params/account_create_params.rb', line 2203

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2205
2206
2207
# File 'lib/stripe/params/account_create_params.rb', line 2205

def secondary_color
  @secondary_color
end