Class: Stripe::AccountCreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2156
2157
2158
2159
2160
2161
# File 'lib/stripe/params/account_create_params.rb', line 2156

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2148
2149
2150
# File 'lib/stripe/params/account_create_params.rb', line 2148

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2150
2151
2152
# File 'lib/stripe/params/account_create_params.rb', line 2150

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2152
2153
2154
# File 'lib/stripe/params/account_create_params.rb', line 2152

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2154
2155
2156
# File 'lib/stripe/params/account_create_params.rb', line 2154

def secondary_color
  @secondary_color
end