Class: Stripe::AccountCreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2181
2182
2183
2184
2185
2186
# File 'lib/stripe/params/account_create_params.rb', line 2181

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2173
2174
2175
# File 'lib/stripe/params/account_create_params.rb', line 2173

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2175
2176
2177
# File 'lib/stripe/params/account_create_params.rb', line 2175

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2177
2178
2179
# File 'lib/stripe/params/account_create_params.rb', line 2177

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2179
2180
2181
# File 'lib/stripe/params/account_create_params.rb', line 2179

def secondary_color
  @secondary_color
end