Class: Stripe::AccountCreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2130
2131
2132
2133
2134
2135
# File 'lib/stripe/params/account_create_params.rb', line 2130

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2122
2123
2124
# File 'lib/stripe/params/account_create_params.rb', line 2122

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2124
2125
2126
# File 'lib/stripe/params/account_create_params.rb', line 2124

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2126
2127
2128
# File 'lib/stripe/params/account_create_params.rb', line 2126

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2128
2129
2130
# File 'lib/stripe/params/account_create_params.rb', line 2128

def secondary_color
  @secondary_color
end