Class: Stripe::AccountCreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



1838
1839
1840
1841
1842
1843
# File 'lib/stripe/params/account_create_params.rb', line 1838

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



1830
1831
1832
# File 'lib/stripe/params/account_create_params.rb', line 1830

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



1832
1833
1834
# File 'lib/stripe/params/account_create_params.rb', line 1832

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



1834
1835
1836
# File 'lib/stripe/params/account_create_params.rb', line 1834

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



1836
1837
1838
# File 'lib/stripe/params/account_create_params.rb', line 1836

def secondary_color
  @secondary_color
end