Class: Stripe::AccountCreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2065
2066
2067
2068
2069
2070
# File 'lib/stripe/params/account_create_params.rb', line 2065

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2057
2058
2059
# File 'lib/stripe/params/account_create_params.rb', line 2057

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2059
2060
2061
# File 'lib/stripe/params/account_create_params.rb', line 2059

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2061
2062
2063
# File 'lib/stripe/params/account_create_params.rb', line 2061

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2063
2064
2065
# File 'lib/stripe/params/account_create_params.rb', line 2063

def secondary_color
  @secondary_color
end