Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2271
2272
2273
2274
2275
# File 'lib/stripe/params/account_create_params.rb', line 2271

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2265
2266
2267
# File 'lib/stripe/params/account_create_params.rb', line 2265

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2267
2268
2269
# File 'lib/stripe/params/account_create_params.rb', line 2267

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2269
2270
2271
# File 'lib/stripe/params/account_create_params.rb', line 2269

def user_agent
  @user_agent
end