Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2185
2186
2187
2188
2189
# File 'lib/stripe/params/account_create_params.rb', line 2185

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2179
2180
2181
# File 'lib/stripe/params/account_create_params.rb', line 2179

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2181
2182
2183
# File 'lib/stripe/params/account_create_params.rb', line 2181

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2183
2184
2185
# File 'lib/stripe/params/account_create_params.rb', line 2183

def user_agent
  @user_agent
end