Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1920
1921
1922
1923
1924
# File 'lib/stripe/params/account_create_params.rb', line 1920

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1914
1915
1916
# File 'lib/stripe/params/account_create_params.rb', line 1914

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1916
1917
1918
# File 'lib/stripe/params/account_create_params.rb', line 1916

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1918
1919
1920
# File 'lib/stripe/params/account_create_params.rb', line 1918

def user_agent
  @user_agent
end