Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2210
2211
2212
2213
2214
# File 'lib/stripe/params/account_create_params.rb', line 2210

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2204
2205
2206
# File 'lib/stripe/params/account_create_params.rb', line 2204

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2206
2207
2208
# File 'lib/stripe/params/account_create_params.rb', line 2206

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2208
2209
2210
# File 'lib/stripe/params/account_create_params.rb', line 2208

def user_agent
  @user_agent
end