Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2152 2153 2154 2155 2156 |
# File 'lib/stripe/params/account_create_params.rb', line 2152 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
2146 2147 2148 |
# File 'lib/stripe/params/account_create_params.rb', line 2146 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
2148 2149 2150 |
# File 'lib/stripe/params/account_create_params.rb', line 2148 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
2150 2151 2152 |
# File 'lib/stripe/params/account_create_params.rb', line 2150 def user_agent @user_agent end |