Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2120
2121
2122
2123
2124
# File 'lib/stripe/params/account_create_params.rb', line 2120

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2114
2115
2116
# File 'lib/stripe/params/account_create_params.rb', line 2114

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2116
2117
2118
# File 'lib/stripe/params/account_create_params.rb', line 2116

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2118
2119
2120
# File 'lib/stripe/params/account_create_params.rb', line 2118

def user_agent
  @user_agent
end