Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2130
2131
2132
2133
2134
# File 'lib/stripe/params/account_create_params.rb', line 2130

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2124
2125
2126
# File 'lib/stripe/params/account_create_params.rb', line 2124

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2126
2127
2128
# File 'lib/stripe/params/account_create_params.rb', line 2126

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2128
2129
2130
# File 'lib/stripe/params/account_create_params.rb', line 2128

def user_agent
  @user_agent
end