Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2075
2076
2077
2078
2079
# File 'lib/stripe/params/account_create_params.rb', line 2075

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2069
2070
2071
# File 'lib/stripe/params/account_create_params.rb', line 2069

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2071
2072
2073
# File 'lib/stripe/params/account_create_params.rb', line 2071

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2073
2074
2075
# File 'lib/stripe/params/account_create_params.rb', line 2073

def user_agent
  @user_agent
end