Class: Stripe::AccountCreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1801
1802
1803
1804
1805
# File 'lib/stripe/params/account_create_params.rb', line 1801

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1795
1796
1797
# File 'lib/stripe/params/account_create_params.rb', line 1795

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1797
1798
1799
# File 'lib/stripe/params/account_create_params.rb', line 1797

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1799
1800
1801
# File 'lib/stripe/params/account_create_params.rb', line 1799

def user_agent
  @user_agent
end