Class: Stripe::AccountCreateParams::Settings::CardPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::CardPayments
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: DeclineOn
Instance Attribute Summary collapse
-
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
-
#statement_descriptor_prefix ⇒ Object
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_prefix_kana ⇒ Object
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only).
-
#statement_descriptor_prefix_kanji ⇒ Object
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only).
Instance Method Summary collapse
-
#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments
constructor
A new instance of CardPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments
Returns a new instance of CardPayments.
2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 |
# File 'lib/stripe/params/account_create_params.rb', line 2129 def initialize( decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil ) @decline_on = decline_on @statement_descriptor_prefix = statement_descriptor_prefix @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji end |
Instance Attribute Details
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
2121 2122 2123 |
# File 'lib/stripe/params/account_create_params.rb', line 2121 def decline_on @decline_on end |
#statement_descriptor_prefix ⇒ Object
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.
2123 2124 2125 |
# File 'lib/stripe/params/account_create_params.rb', line 2123 def statement_descriptor_prefix @statement_descriptor_prefix end |
#statement_descriptor_prefix_kana ⇒ Object
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.
2125 2126 2127 |
# File 'lib/stripe/params/account_create_params.rb', line 2125 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.
2127 2128 2129 |
# File 'lib/stripe/params/account_create_params.rb', line 2127 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |