Class: Stripe::AccountCreateParams::Settings::CardPayments::DeclineOn
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::CardPayments::DeclineOn
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#avs_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect ZIP or postal code.
-
#cvc_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect CVC.
Instance Method Summary collapse
-
#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn
constructor
A new instance of DeclineOn.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn
Returns a new instance of DeclineOn.
2180 2181 2182 2183 |
# File 'lib/stripe/params/account_create_params.rb', line 2180 def initialize(avs_failure: nil, cvc_failure: nil) @avs_failure = avs_failure @cvc_failure = cvc_failure end |
Instance Attribute Details
#avs_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.
2176 2177 2178 |
# File 'lib/stripe/params/account_create_params.rb', line 2176 def avs_failure @avs_failure end |
#cvc_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.
2178 2179 2180 |
# File 'lib/stripe/params/account_create_params.rb', line 2178 def cvc_failure @cvc_failure end |