Class: Stripe::AccountCreateParams::Settings::Invoices
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::Invoices
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#hosted_payment_method_save ⇒ Object
Whether payment methods should be saved when a payment is completed for a one-time invoices on a hosted invoice page.
Instance Method Summary collapse
-
#initialize(hosted_payment_method_save: nil) ⇒ Invoices
constructor
A new instance of Invoices.
Methods inherited from RequestParams
Constructor Details
#initialize(hosted_payment_method_save: nil) ⇒ Invoices
Returns a new instance of Invoices.
1853 1854 1855 |
# File 'lib/stripe/params/account_create_params.rb', line 1853 def initialize(hosted_payment_method_save: nil) @hosted_payment_method_save = hosted_payment_method_save end |
Instance Attribute Details
#hosted_payment_method_save ⇒ Object
Whether payment methods should be saved when a payment is completed for a one-time invoices on a hosted invoice page.
1851 1852 1853 |
# File 'lib/stripe/params/account_create_params.rb', line 1851 def hosted_payment_method_save @hosted_payment_method_save end |