Class: Stripe::AccountCreateParams::Settings::Payments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments

Returns a new instance of Payments.



2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
# File 'lib/stripe/params/account_create_params.rb', line 2386

def initialize(
  email_customers_on_successful_payment: nil,
  statement_descriptor: nil,
  statement_descriptor_kana: nil,
  statement_descriptor_kanji: nil
)
  @email_customers_on_successful_payment = email_customers_on_successful_payment
  @statement_descriptor = statement_descriptor
  @statement_descriptor_kana = statement_descriptor_kana
  @statement_descriptor_kanji = statement_descriptor_kanji
end

Instance Attribute Details

#email_customers_on_successful_paymentObject

When you enable this parameter, the customer of this Account receives an email receipt when their payment succeeds. If this parameter isn't set, the default value is false.



2378
2379
2380
# File 'lib/stripe/params/account_create_params.rb', line 2378

def email_customers_on_successful_payment
  @email_customers_on_successful_payment
end

#statement_descriptorObject

The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don't set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the account settings documentation.



2380
2381
2382
# File 'lib/stripe/params/account_create_params.rb', line 2380

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_kanaObject

The Kana variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements.



2382
2383
2384
# File 'lib/stripe/params/account_create_params.rb', line 2382

def statement_descriptor_kana
  @statement_descriptor_kana
end

#statement_descriptor_kanjiObject

The Kanji variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements.



2384
2385
2386
# File 'lib/stripe/params/account_create_params.rb', line 2384

def statement_descriptor_kanji
  @statement_descriptor_kanji
end