Class: Stripe::AccountCreateParams::Settings::Payments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments

Returns a new instance of Payments.



2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
# File 'lib/stripe/params/account_create_params.rb', line 2300

def initialize(
  email_customers_on_successful_payment: nil,
  statement_descriptor: nil,
  statement_descriptor_kana: nil,
  statement_descriptor_kanji: nil
)
  @email_customers_on_successful_payment = email_customers_on_successful_payment
  @statement_descriptor = statement_descriptor
  @statement_descriptor_kana = statement_descriptor_kana
  @statement_descriptor_kanji = statement_descriptor_kanji
end

Instance Attribute Details

#email_customers_on_successful_paymentObject

When you enable this parameter, the customer of this Account receives an email receipt when their payment succeeds. If this parameter isn't set, the default value is false.



2292
2293
2294
# File 'lib/stripe/params/account_create_params.rb', line 2292

def email_customers_on_successful_payment
  @email_customers_on_successful_payment
end

#statement_descriptorObject

The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don't set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the account settings documentation.



2294
2295
2296
# File 'lib/stripe/params/account_create_params.rb', line 2294

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_kanaObject

The Kana variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements.



2296
2297
2298
# File 'lib/stripe/params/account_create_params.rb', line 2296

def statement_descriptor_kana
  @statement_descriptor_kana
end

#statement_descriptor_kanjiObject

The Kanji variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have special requirements.



2298
2299
2300
# File 'lib/stripe/params/account_create_params.rb', line 2298

def statement_descriptor_kanji
  @statement_descriptor_kanji
end