Class: Stripe::AccountCreateParams::Settings::Payments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments

Returns a new instance of Payments.



2140
2141
2142
2143
2144
2145
2146
2147
2148
# File 'lib/stripe/params/account_create_params.rb', line 2140

def initialize(
  statement_descriptor: nil,
  statement_descriptor_kana: nil,
  statement_descriptor_kanji: nil
)
  @statement_descriptor = statement_descriptor
  @statement_descriptor_kana = statement_descriptor_kana
  @statement_descriptor_kanji = statement_descriptor_kanji
end

Instance Attribute Details

#statement_descriptorObject

The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a ‘statement_descriptor_prefix`, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the `statement_descriptor` text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the [account settings documentation](docs.stripe.com/get-started/account/statement-descriptors).



2134
2135
2136
# File 'lib/stripe/params/account_create_params.rb', line 2134

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_kanaObject

The Kana variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).



2136
2137
2138
# File 'lib/stripe/params/account_create_params.rb', line 2136

def statement_descriptor_kana
  @statement_descriptor_kana
end

#statement_descriptor_kanjiObject

The Kanji variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).



2138
2139
2140
# File 'lib/stripe/params/account_create_params.rb', line 2138

def statement_descriptor_kanji
  @statement_descriptor_kanji
end