Class: Stripe::AccountCreateParams::Settings::Payouts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::Payouts
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Schedule
Instance Attribute Summary collapse
-
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account.
-
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account.
-
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts.
Instance Method Summary collapse
-
#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
constructor
A new instance of Payouts.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
Returns a new instance of Payouts.
2082 2083 2084 2085 2086 |
# File 'lib/stripe/params/account_create_params.rb', line 2082 def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) @debit_negative_balances = debit_negative_balances @schedule = schedule @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see Understanding Connect Account Balances.
2076 2077 2078 |
# File 'lib/stripe/params/account_create_params.rb', line 2076 def debit_negative_balances @debit_negative_balances end |
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account. For details, see our Setting Bank and Debit Card Payouts documentation.
2078 2079 2080 |
# File 'lib/stripe/params/account_create_params.rb', line 2078 def schedule @schedule end |
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard.
2080 2081 2082 |
# File 'lib/stripe/params/account_create_params.rb', line 2080 def statement_descriptor @statement_descriptor end |