Class: Stripe::AccountCreateParams::Settings::Payouts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::Payouts
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Schedule
Instance Attribute Summary collapse
-
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account.
-
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account.
-
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts.
Instance Method Summary collapse
-
#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
constructor
A new instance of Payouts.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
Returns a new instance of Payouts.
2351 2352 2353 2354 2355 |
# File 'lib/stripe/params/account_create_params.rb', line 2351 def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) @debit_negative_balances = debit_negative_balances @schedule = schedule @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see Understanding Connect Account Balances.
2345 2346 2347 |
# File 'lib/stripe/params/account_create_params.rb', line 2345 def debit_negative_balances @debit_negative_balances end |
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account. For details, see our Setting Bank and Debit Card Payouts documentation.
2347 2348 2349 |
# File 'lib/stripe/params/account_create_params.rb', line 2347 def schedule @schedule end |
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard.
2349 2350 2351 |
# File 'lib/stripe/params/account_create_params.rb', line 2349 def statement_descriptor @statement_descriptor end |