Class: Stripe::AccountCreateParams::Settings::Payouts::Schedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::Payouts::Schedule
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
The number of days charge funds are held before being paid out.
-
#interval ⇒ Object
How frequently available funds are paid out.
-
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31.
-
#monthly_payout_days ⇒ Object
The days of the month when available funds are paid out, specified as an array of numbers between 1–31.
-
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc.
-
#weekly_payout_days ⇒ Object
The days of the week when available funds are paid out, specified as an array, e.g., [‘monday`, `tuesday`].
Instance Method Summary collapse
-
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule
constructor
A new instance of Schedule.
Methods inherited from RequestParams
Constructor Details
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule
Returns a new instance of Schedule.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 |
# File 'lib/stripe/params/account_create_params.rb', line 2221 def initialize( delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil ) @delay_days = delay_days @interval = interval @monthly_anchor = monthly_anchor @monthly_payout_days = monthly_payout_days @weekly_anchor = weekly_anchor @weekly_payout_days = weekly_payout_days end |
Instance Attribute Details
#delay_days ⇒ Object
The number of days charge funds are held before being paid out. May also be set to ‘minimum`, representing the lowest available value for the account country. Default is `minimum`. The `delay_days` parameter remains at the last configured value if `interval` is `manual`. [Learn more about controlling payout delay days](/connect/manage-payout-schedule).
2209 2210 2211 |
# File 'lib/stripe/params/account_create_params.rb', line 2209 def delay_days @delay_days end |
#interval ⇒ Object
How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.
2211 2212 2213 |
# File 'lib/stripe/params/account_create_params.rb', line 2211 def interval @interval end |
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.
2213 2214 2215 |
# File 'lib/stripe/params/account_create_params.rb', line 2213 def monthly_anchor @monthly_anchor end |
#monthly_payout_days ⇒ Object
The days of the month when available funds are paid out, specified as an array of numbers between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly` and `monthly_anchor` is not set.
2215 2216 2217 |
# File 'lib/stripe/params/account_create_params.rb', line 2215 def monthly_payout_days @monthly_payout_days end |
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc. Required and applicable only if `interval` is `weekly`.
2217 2218 2219 |
# File 'lib/stripe/params/account_create_params.rb', line 2217 def weekly_anchor @weekly_anchor end |
#weekly_payout_days ⇒ Object
The days of the week when available funds are paid out, specified as an array, e.g., [‘monday`, `tuesday`]. Required and applicable only if `interval` is `weekly`.
2219 2220 2221 |
# File 'lib/stripe/params/account_create_params.rb', line 2219 def weekly_payout_days @weekly_payout_days end |