Class: Stripe::AccountCreateParams::Settings::PaypayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::PaypayPayments
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Site
Instance Attribute Summary collapse
-
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
-
#goods_type ⇒ Object
Whether your business sells digital content or not.
-
#site ⇒ Object
Details regarding your business’s website.
Instance Method Summary collapse
-
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
constructor
A new instance of PaypayPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
Returns a new instance of PaypayPayments.
2288 2289 2290 2291 2292 |
# File 'lib/stripe/params/account_create_params.rb', line 2288 def initialize(additional_files: nil, goods_type: nil, site: nil) @additional_files = additional_files @goods_type = goods_type @site = site end |
Instance Attribute Details
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
2282 2283 2284 |
# File 'lib/stripe/params/account_create_params.rb', line 2282 def additional_files @additional_files end |
#goods_type ⇒ Object
Whether your business sells digital content or not.
2284 2285 2286 |
# File 'lib/stripe/params/account_create_params.rb', line 2284 def goods_type @goods_type end |
#site ⇒ Object
Details regarding your business’s website.
2286 2287 2288 |
# File 'lib/stripe/params/account_create_params.rb', line 2286 def site @site end |