Class: Stripe::AccountCreateParams::Settings::PaypayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::Settings::PaypayPayments
- Defined in:
- lib/stripe/params/account_create_params.rb
Defined Under Namespace
Classes: Site
Instance Attribute Summary collapse
-
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
-
#goods_type ⇒ Object
Whether your business sells digital content or not.
-
#site ⇒ Object
Details regarding your business’s website.
Instance Method Summary collapse
-
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
constructor
A new instance of PaypayPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
Returns a new instance of PaypayPayments.
2320 2321 2322 2323 2324 |
# File 'lib/stripe/params/account_create_params.rb', line 2320 def initialize(additional_files: nil, goods_type: nil, site: nil) @additional_files = additional_files @goods_type = goods_type @site = site end |
Instance Attribute Details
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
2314 2315 2316 |
# File 'lib/stripe/params/account_create_params.rb', line 2314 def additional_files @additional_files end |
#goods_type ⇒ Object
Whether your business sells digital content or not.
2316 2317 2318 |
# File 'lib/stripe/params/account_create_params.rb', line 2316 def goods_type @goods_type end |
#site ⇒ Object
Details regarding your business’s website.
2318 2319 2320 |
# File 'lib/stripe/params/account_create_params.rb', line 2318 def site @site end |