Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2050
2051
2052
2053
2054
# File 'lib/stripe/params/account_create_params.rb', line 2050

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2044
2045
2046
# File 'lib/stripe/params/account_create_params.rb', line 2044

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2046
2047
2048
# File 'lib/stripe/params/account_create_params.rb', line 2046

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2048
2049
2050
# File 'lib/stripe/params/account_create_params.rb', line 2048

def user_agent
  @user_agent
end