Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2424
2425
2426
2427
2428
# File 'lib/stripe/params/account_create_params.rb', line 2424

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2418
2419
2420
# File 'lib/stripe/params/account_create_params.rb', line 2418

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2420
2421
2422
# File 'lib/stripe/params/account_create_params.rb', line 2420

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2422
2423
2424
# File 'lib/stripe/params/account_create_params.rb', line 2422

def user_agent
  @user_agent
end