Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2373
2374
2375
2376
2377
# File 'lib/stripe/params/account_create_params.rb', line 2373

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2367
2368
2369
# File 'lib/stripe/params/account_create_params.rb', line 2367

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2369
2370
2371
# File 'lib/stripe/params/account_create_params.rb', line 2369

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2371
2372
2373
# File 'lib/stripe/params/account_create_params.rb', line 2371

def user_agent
  @user_agent
end