Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1998
1999
2000
2001
2002
# File 'lib/stripe/params/account_create_params.rb', line 1998

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1992
1993
1994
# File 'lib/stripe/params/account_create_params.rb', line 1992

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1994
1995
1996
# File 'lib/stripe/params/account_create_params.rb', line 1994

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1996
1997
1998
# File 'lib/stripe/params/account_create_params.rb', line 1996

def user_agent
  @user_agent
end