Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2366
2367
2368
2369
2370
# File 'lib/stripe/params/account_create_params.rb', line 2366

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2360
2361
2362
# File 'lib/stripe/params/account_create_params.rb', line 2360

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2362
2363
2364
# File 'lib/stripe/params/account_create_params.rb', line 2362

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2364
2365
2366
# File 'lib/stripe/params/account_create_params.rb', line 2364

def user_agent
  @user_agent
end