Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2345
2346
2347
2348
2349
# File 'lib/stripe/params/account_create_params.rb', line 2345

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2339
2340
2341
# File 'lib/stripe/params/account_create_params.rb', line 2339

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2341
2342
2343
# File 'lib/stripe/params/account_create_params.rb', line 2341

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2343
2344
2345
# File 'lib/stripe/params/account_create_params.rb', line 2343

def user_agent
  @user_agent
end