Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2313
2314
2315
2316
2317
# File 'lib/stripe/params/account_create_params.rb', line 2313

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2307
2308
2309
# File 'lib/stripe/params/account_create_params.rb', line 2307

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2309
2310
2311
# File 'lib/stripe/params/account_create_params.rb', line 2309

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2311
2312
2313
# File 'lib/stripe/params/account_create_params.rb', line 2311

def user_agent
  @user_agent
end