Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2278
2279
2280
2281
2282
# File 'lib/stripe/params/account_create_params.rb', line 2278

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2272
2273
2274
# File 'lib/stripe/params/account_create_params.rb', line 2272

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2274
2275
2276
# File 'lib/stripe/params/account_create_params.rb', line 2274

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2276
2277
2278
# File 'lib/stripe/params/account_create_params.rb', line 2276

def user_agent
  @user_agent
end