Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2233
2234
2235
2236
2237
# File 'lib/stripe/params/account_create_params.rb', line 2233

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2227
2228
2229
# File 'lib/stripe/params/account_create_params.rb', line 2227

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2229
2230
2231
# File 'lib/stripe/params/account_create_params.rb', line 2229

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2231
2232
2233
# File 'lib/stripe/params/account_create_params.rb', line 2231

def user_agent
  @user_agent
end