Class: Stripe::AccountCreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1931
1932
1933
1934
1935
# File 'lib/stripe/params/account_create_params.rb', line 1931

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1925
1926
1927
# File 'lib/stripe/params/account_create_params.rb', line 1925

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1927
1928
1929
# File 'lib/stripe/params/account_create_params.rb', line 1927

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1929
1930
1931
# File 'lib/stripe/params/account_create_params.rb', line 1929

def user_agent
  @user_agent
end