Class: Stripe::AccountCreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user's service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2627 2628 2629 2630 2631 2632 |
# File 'lib/stripe/params/account_create_params.rb', line 2627 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2619 2620 2621 |
# File 'lib/stripe/params/account_create_params.rb', line 2619 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2621 2622 2623 |
# File 'lib/stripe/params/account_create_params.rb', line 2621 def ip @ip end |
#service_agreement ⇒ Object
The user's service agreement type.
2623 2624 2625 |
# File 'lib/stripe/params/account_create_params.rb', line 2623 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2625 2626 2627 |
# File 'lib/stripe/params/account_create_params.rb', line 2625 def user_agent @user_agent end |