Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2614
2615
2616
2617
2618
2619
# File 'lib/stripe/params/account_create_params.rb', line 2614

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2606
2607
2608
# File 'lib/stripe/params/account_create_params.rb', line 2606

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2608
2609
2610
# File 'lib/stripe/params/account_create_params.rb', line 2608

def ip
  @ip
end

#service_agreementObject

The user's service agreement type.



2610
2611
2612
# File 'lib/stripe/params/account_create_params.rb', line 2610

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2612
2613
2614
# File 'lib/stripe/params/account_create_params.rb', line 2612

def user_agent
  @user_agent
end