Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2566
2567
2568
2569
2570
2571
# File 'lib/stripe/params/account_create_params.rb', line 2566

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2558
2559
2560
# File 'lib/stripe/params/account_create_params.rb', line 2558

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2560
2561
2562
# File 'lib/stripe/params/account_create_params.rb', line 2560

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2562
2563
2564
# File 'lib/stripe/params/account_create_params.rb', line 2562

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2564
2565
2566
# File 'lib/stripe/params/account_create_params.rb', line 2564

def user_agent
  @user_agent
end