Class: Stripe::AccountCreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2566 2567 2568 2569 2570 2571 |
# File 'lib/stripe/params/account_create_params.rb', line 2566 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2558 2559 2560 |
# File 'lib/stripe/params/account_create_params.rb', line 2558 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2560 2561 2562 |
# File 'lib/stripe/params/account_create_params.rb', line 2560 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2562 2563 2564 |
# File 'lib/stripe/params/account_create_params.rb', line 2562 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2564 2565 2566 |
# File 'lib/stripe/params/account_create_params.rb', line 2564 def user_agent @user_agent end |