Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2480
2481
2482
2483
2484
2485
# File 'lib/stripe/params/account_create_params.rb', line 2480

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2472
2473
2474
# File 'lib/stripe/params/account_create_params.rb', line 2472

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2474
2475
2476
# File 'lib/stripe/params/account_create_params.rb', line 2474

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2476
2477
2478
# File 'lib/stripe/params/account_create_params.rb', line 2476

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2478
2479
2480
# File 'lib/stripe/params/account_create_params.rb', line 2478

def user_agent
  @user_agent
end