Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2111
2112
2113
2114
2115
2116
# File 'lib/stripe/params/account_create_params.rb', line 2111

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2103
2104
2105
# File 'lib/stripe/params/account_create_params.rb', line 2103

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2105
2106
2107
# File 'lib/stripe/params/account_create_params.rb', line 2105

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2107
2108
2109
# File 'lib/stripe/params/account_create_params.rb', line 2107

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2109
2110
2111
# File 'lib/stripe/params/account_create_params.rb', line 2109

def user_agent
  @user_agent
end