Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2460
2461
2462
2463
2464
2465
# File 'lib/stripe/params/account_create_params.rb', line 2460

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2452
2453
2454
# File 'lib/stripe/params/account_create_params.rb', line 2452

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2454
2455
2456
# File 'lib/stripe/params/account_create_params.rb', line 2454

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2456
2457
2458
# File 'lib/stripe/params/account_create_params.rb', line 2456

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2458
2459
2460
# File 'lib/stripe/params/account_create_params.rb', line 2458

def user_agent
  @user_agent
end