Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2447
2448
2449
2450
2451
2452
# File 'lib/stripe/params/account_create_params.rb', line 2447

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2439
2440
2441
# File 'lib/stripe/params/account_create_params.rb', line 2439

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2441
2442
2443
# File 'lib/stripe/params/account_create_params.rb', line 2441

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2443
2444
2445
# File 'lib/stripe/params/account_create_params.rb', line 2443

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2445
2446
2447
# File 'lib/stripe/params/account_create_params.rb', line 2445

def user_agent
  @user_agent
end