Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2422
2423
2424
2425
2426
2427
# File 'lib/stripe/params/account_create_params.rb', line 2422

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2414
2415
2416
# File 'lib/stripe/params/account_create_params.rb', line 2414

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2416
2417
2418
# File 'lib/stripe/params/account_create_params.rb', line 2416

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2418
2419
2420
# File 'lib/stripe/params/account_create_params.rb', line 2418

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2420
2421
2422
# File 'lib/stripe/params/account_create_params.rb', line 2420

def user_agent
  @user_agent
end