Class: Stripe::AccountCreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2422 2423 2424 2425 2426 2427 |
# File 'lib/stripe/params/account_create_params.rb', line 2422 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2414 2415 2416 |
# File 'lib/stripe/params/account_create_params.rb', line 2414 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2416 2417 2418 |
# File 'lib/stripe/params/account_create_params.rb', line 2416 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2418 2419 2420 |
# File 'lib/stripe/params/account_create_params.rb', line 2418 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2420 2421 2422 |
# File 'lib/stripe/params/account_create_params.rb', line 2420 def user_agent @user_agent end |