Class: Stripe::AccountCreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountCreateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_create_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2390 2391 2392 2393 2394 2395 |
# File 'lib/stripe/params/account_create_params.rb', line 2390 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2382 2383 2384 |
# File 'lib/stripe/params/account_create_params.rb', line 2382 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2384 2385 2386 |
# File 'lib/stripe/params/account_create_params.rb', line 2384 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2386 2387 2388 |
# File 'lib/stripe/params/account_create_params.rb', line 2386 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2388 2389 2390 |
# File 'lib/stripe/params/account_create_params.rb', line 2388 def user_agent @user_agent end |