Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2287
2288
2289
2290
2291
2292
# File 'lib/stripe/params/account_create_params.rb', line 2287

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2279
2280
2281
# File 'lib/stripe/params/account_create_params.rb', line 2279

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2281
2282
2283
# File 'lib/stripe/params/account_create_params.rb', line 2281

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2283
2284
2285
# File 'lib/stripe/params/account_create_params.rb', line 2283

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2285
2286
2287
# File 'lib/stripe/params/account_create_params.rb', line 2285

def user_agent
  @user_agent
end