Class: Stripe::AccountCreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1992
1993
1994
1995
1996
1997
# File 'lib/stripe/params/account_create_params.rb', line 1992

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



1984
1985
1986
# File 'lib/stripe/params/account_create_params.rb', line 1984

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



1986
1987
1988
# File 'lib/stripe/params/account_create_params.rb', line 1986

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



1988
1989
1990
# File 'lib/stripe/params/account_create_params.rb', line 1988

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



1990
1991
1992
# File 'lib/stripe/params/account_create_params.rb', line 1990

def user_agent
  @user_agent
end