Class: Stripe::AccountExternalAccountService::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_external_account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/stripe/services/account_external_account_service.rb', line 168

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



151
152
153
# File 'lib/stripe/services/account_external_account_service.rb', line 151

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



154
155
156
# File 'lib/stripe/services/account_external_account_service.rb', line 154

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



157
158
159
# File 'lib/stripe/services/account_external_account_service.rb', line 157

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



160
161
162
# File 'lib/stripe/services/account_external_account_service.rb', line 160

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



163
164
165
# File 'lib/stripe/services/account_external_account_service.rb', line 163

def currency
  @currency
end

#objectObject

Attribute for param field object



148
149
150
# File 'lib/stripe/services/account_external_account_service.rb', line 148

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



166
167
168
# File 'lib/stripe/services/account_external_account_service.rb', line 166

def routing_number
  @routing_number
end