Class: Stripe::AccountExternalAccountService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_external_account_service.rb

Defined Under Namespace

Classes: Documents

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_holder_type: nil, account_type: nil, address_city: nil, address_country: nil, address_line1: nil, address_line2: nil, address_state: nil, address_zip: nil, default_for_currency: nil, documents: nil, exp_month: nil, exp_year: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/stripe/services/account_external_account_service.rb', line 83

def initialize(
  account_holder_name: nil,
  account_holder_type: nil,
  account_type: nil,
  address_city: nil,
  address_country: nil,
  address_line1: nil,
  address_line2: nil,
  address_state: nil,
  address_zip: nil,
  default_for_currency: nil,
  documents: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  metadata: nil,
  name: nil
)
  @account_holder_name = 
  @account_holder_type = 
  @account_type = 
  @address_city = address_city
  @address_country = address_country
  @address_line1 = address_line1
  @address_line2 = address_line2
  @address_state = address_state
  @address_zip = address_zip
  @default_for_currency = default_for_currency
  @documents = documents
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @metadata = 
  @name = name
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.



36
37
38
# File 'lib/stripe/services/account_external_account_service.rb', line 36

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. This can be either ‘individual` or `company`.



39
40
41
# File 'lib/stripe/services/account_external_account_service.rb', line 39

def 
  @account_holder_type
end

#account_typeObject

The bank account type. This can only be ‘checking` or `savings` in most countries. In Japan, this can only be `futsu` or `toza`.



42
43
44
# File 'lib/stripe/services/account_external_account_service.rb', line 42

def 
  @account_type
end

#address_cityObject

City/District/Suburb/Town/Village.



45
46
47
# File 'lib/stripe/services/account_external_account_service.rb', line 45

def address_city
  @address_city
end

#address_countryObject

Billing address country, if provided when creating card.



48
49
50
# File 'lib/stripe/services/account_external_account_service.rb', line 48

def address_country
  @address_country
end

#address_line1Object

Address line 1 (Street address/PO Box/Company name).



51
52
53
# File 'lib/stripe/services/account_external_account_service.rb', line 51

def address_line1
  @address_line1
end

#address_line2Object

Address line 2 (Apartment/Suite/Unit/Building).



54
55
56
# File 'lib/stripe/services/account_external_account_service.rb', line 54

def address_line2
  @address_line2
end

#address_stateObject

State/County/Province/Region.



57
58
59
# File 'lib/stripe/services/account_external_account_service.rb', line 57

def address_state
  @address_state
end

#address_zipObject

ZIP or postal code.



60
61
62
# File 'lib/stripe/services/account_external_account_service.rb', line 60

def address_zip
  @address_zip
end

#default_for_currencyObject

When set to true, this becomes the default external account for its currency.



63
64
65
# File 'lib/stripe/services/account_external_account_service.rb', line 63

def default_for_currency
  @default_for_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



66
67
68
# File 'lib/stripe/services/account_external_account_service.rb', line 66

def documents
  @documents
end

#exp_monthObject

Two digit number representing the card’s expiration month.



69
70
71
# File 'lib/stripe/services/account_external_account_service.rb', line 69

def exp_month
  @exp_month
end

#exp_yearObject

Four digit number representing the card’s expiration year.



72
73
74
# File 'lib/stripe/services/account_external_account_service.rb', line 72

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



75
76
77
# File 'lib/stripe/services/account_external_account_service.rb', line 75

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



78
79
80
# File 'lib/stripe/services/account_external_account_service.rb', line 78

def 
  @metadata
end

#nameObject

Cardholder name.



81
82
83
# File 'lib/stripe/services/account_external_account_service.rb', line 81

def name
  @name
end