Method: Stripe::AccountExternalAccountService#update
- Defined in:
- lib/stripe/services/account_external_account_service.rb
#update(account, id, params = {}, opts = {}) ⇒ Object
Updates the metadata, account holder name, account holder type of a bank account belonging to a connected account and optionally sets it as the default for its currency. Other bank account details are not editable by design.
You can only update bank accounts when [account.controller.requirement_collection is application, which includes <a href=“/connect/custom-accounts”>Custom accounts](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection).
You can re-enable a disabled bank account by performing an update call without providing any arguments or changes.
58 59 60 61 62 63 64 65 66 |
# File 'lib/stripe/services/account_external_account_service.rb', line 58 def update(account, id, params = {}, opts = {}) request( method: :post, path: format("/v1/accounts/%<account>s/external_accounts/%<id>s", { account: CGI.escape(account), id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |