Class: Stripe::AccountNotice::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountNotice::UpdateParams
- Defined in:
- lib/stripe/resources/account_notice.rb
Defined Under Namespace
Classes: Email
Instance Attribute Summary collapse
-
#email ⇒ Object
Information about the email you sent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#sent_at ⇒ Object
Date when you sent the notice.
Instance Method Summary collapse
-
#initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
102 103 104 105 106 107 |
# File 'lib/stripe/resources/account_notice.rb', line 102 def initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) @email = email @expand = @metadata = @sent_at = sent_at end |
Instance Attribute Details
#email ⇒ Object
Information about the email you sent.
91 92 93 |
# File 'lib/stripe/resources/account_notice.rb', line 91 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
94 95 96 |
# File 'lib/stripe/resources/account_notice.rb', line 94 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
97 98 99 |
# File 'lib/stripe/resources/account_notice.rb', line 97 def @metadata end |
#sent_at ⇒ Object
Date when you sent the notice.
100 101 102 |
# File 'lib/stripe/resources/account_notice.rb', line 100 def sent_at @sent_at end |