Class: Stripe::AccountNoticeService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_notice_service.rb

Defined Under Namespace

Classes: Email

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



60
61
62
63
64
65
# File 'lib/stripe/services/account_notice_service.rb', line 60

def initialize(email: nil, expand: nil, metadata: nil, sent_at: nil)
  @email = email
  @expand = expand
  @metadata = 
  @sent_at = sent_at
end

Instance Attribute Details

#emailObject

Information about the email you sent.



52
53
54
# File 'lib/stripe/services/account_notice_service.rb', line 52

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



54
55
56
# File 'lib/stripe/services/account_notice_service.rb', line 54

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



56
57
58
# File 'lib/stripe/services/account_notice_service.rb', line 56

def 
  @metadata
end

#sent_atObject

Date when you sent the notice.



58
59
60
# File 'lib/stripe/services/account_notice_service.rb', line 58

def sent_at
  @sent_at
end