Class: Stripe::AccountNoticeService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_notice_service.rb

Defined Under Namespace

Classes: Email

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



69
70
71
72
73
74
# File 'lib/stripe/services/account_notice_service.rb', line 69

def initialize(email: nil, expand: nil, metadata: nil, sent_at: nil)
  @email = email
  @expand = expand
  @metadata = 
  @sent_at = sent_at
end

Instance Attribute Details

#emailObject

Information about the email you sent.



58
59
60
# File 'lib/stripe/services/account_notice_service.rb', line 58

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



61
62
63
# File 'lib/stripe/services/account_notice_service.rb', line 61

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



64
65
66
# File 'lib/stripe/services/account_notice_service.rb', line 64

def 
  @metadata
end

#sent_atObject

Date when you sent the notice.



67
68
69
# File 'lib/stripe/services/account_notice_service.rb', line 67

def sent_at
  @sent_at
end