Class: Stripe::AccountNoticeUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountNoticeUpdateParams
- Defined in:
- lib/stripe/params/account_notice_update_params.rb
Defined Under Namespace
Classes: Email
Instance Attribute Summary collapse
-
#email ⇒ Object
Information about the email you sent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#sent_at ⇒ Object
Date when you sent the notice.
Instance Method Summary collapse
-
#initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) ⇒ AccountNoticeUpdateParams
constructor
A new instance of AccountNoticeUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) ⇒ AccountNoticeUpdateParams
Returns a new instance of AccountNoticeUpdateParams.
29 30 31 32 33 34 |
# File 'lib/stripe/params/account_notice_update_params.rb', line 29 def initialize(email: nil, expand: nil, metadata: nil, sent_at: nil) @email = email @expand = @metadata = @sent_at = sent_at end |
Instance Attribute Details
#email ⇒ Object
Information about the email you sent.
21 22 23 |
# File 'lib/stripe/params/account_notice_update_params.rb', line 21 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
23 24 25 |
# File 'lib/stripe/params/account_notice_update_params.rb', line 23 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
25 26 27 |
# File 'lib/stripe/params/account_notice_update_params.rb', line 25 def @metadata end |
#sent_at ⇒ Object
Date when you sent the notice.
27 28 29 |
# File 'lib/stripe/params/account_notice_update_params.rb', line 27 def sent_at @sent_at end |