Class: Stripe::AccountPersonCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountPersonCreateParams
- Defined in:
- lib/stripe/params/account_person_create_params.rb
Defined Under Namespace
Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, SelfReportedIncome, SelfReportedMonthlyHousingPayment, UsCfpbData, Verification
Instance Attribute Summary collapse
-
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
-
#address ⇒ Object
The person’s address.
-
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
-
#dob ⇒ Object
The person’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The person’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#first_name ⇒ Object
The person’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
-
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
-
#id_number ⇒ Object
The person’s ID number, as appropriate for their country.
-
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The person’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
-
#maiden_name ⇒ Object
The person’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#nationality ⇒ Object
The country where the person is a national.
-
#person_token ⇒ Object
A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.
-
#phone ⇒ Object
The person’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The person’s registered address.
-
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
-
#self_reported_income ⇒ Object
The credit applicant’s self-reported yearly income in minor units.
-
#self_reported_monthly_housing_payment ⇒ Object
The credit applicant’s self-reported monthly housing payment in minor units.
-
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
-
#us_cfpb_data ⇒ Object
Demographic data related to the person.
-
#verification ⇒ Object
The person’s verification status.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil) ⇒ AccountPersonCreateParams
Returns a new instance of AccountPersonCreateParams.
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/stripe/params/account_person_create_params.rb', line 401 def initialize( additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, self_reported_income: nil, self_reported_monthly_housing_payment: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil ) @additional_tos_acceptances = additional_tos_acceptances @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @documents = documents @email = email @expand = @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @nationality = nationality @person_token = person_token @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @self_reported_income = self_reported_income @self_reported_monthly_housing_payment = self_reported_monthly_housing_payment @ssn_last_4 = ssn_last_4 @us_cfpb_data = us_cfpb_data @verification = verification end |
Instance Attribute Details
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
339 340 341 |
# File 'lib/stripe/params/account_person_create_params.rb', line 339 def additional_tos_acceptances @additional_tos_acceptances end |
#address ⇒ Object
The person’s address.
341 342 343 |
# File 'lib/stripe/params/account_person_create_params.rb', line 341 def address @address end |
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
343 344 345 |
# File 'lib/stripe/params/account_person_create_params.rb', line 343 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
345 346 347 |
# File 'lib/stripe/params/account_person_create_params.rb', line 345 def address_kanji @address_kanji end |
#dob ⇒ Object
The person’s date of birth.
347 348 349 |
# File 'lib/stripe/params/account_person_create_params.rb', line 347 def dob @dob end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
349 350 351 |
# File 'lib/stripe/params/account_person_create_params.rb', line 349 def documents @documents end |
#email ⇒ Object
The person’s email address.
351 352 353 |
# File 'lib/stripe/params/account_person_create_params.rb', line 351 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
353 354 355 |
# File 'lib/stripe/params/account_person_create_params.rb', line 353 def @expand end |
#first_name ⇒ Object
The person’s first name.
355 356 357 |
# File 'lib/stripe/params/account_person_create_params.rb', line 355 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
357 358 359 |
# File 'lib/stripe/params/account_person_create_params.rb', line 357 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
359 360 361 |
# File 'lib/stripe/params/account_person_create_params.rb', line 359 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
361 362 363 |
# File 'lib/stripe/params/account_person_create_params.rb', line 361 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
363 364 365 |
# File 'lib/stripe/params/account_person_create_params.rb', line 363 def gender @gender end |
#id_number ⇒ Object
The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
365 366 367 |
# File 'lib/stripe/params/account_person_create_params.rb', line 365 def id_number @id_number end |
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
367 368 369 |
# File 'lib/stripe/params/account_person_create_params.rb', line 367 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The person’s last name.
369 370 371 |
# File 'lib/stripe/params/account_person_create_params.rb', line 369 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
371 372 373 |
# File 'lib/stripe/params/account_person_create_params.rb', line 371 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
373 374 375 |
# File 'lib/stripe/params/account_person_create_params.rb', line 373 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The person’s maiden name.
375 376 377 |
# File 'lib/stripe/params/account_person_create_params.rb', line 375 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
377 378 379 |
# File 'lib/stripe/params/account_person_create_params.rb', line 377 def @metadata end |
#nationality ⇒ Object
The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.
379 380 381 |
# File 'lib/stripe/params/account_person_create_params.rb', line 379 def nationality @nationality end |
#person_token ⇒ Object
A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.
381 382 383 |
# File 'lib/stripe/params/account_person_create_params.rb', line 381 def person_token @person_token end |
#phone ⇒ Object
The person’s phone number.
383 384 385 |
# File 'lib/stripe/params/account_person_create_params.rb', line 383 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
385 386 387 |
# File 'lib/stripe/params/account_person_create_params.rb', line 385 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The person’s registered address.
387 388 389 |
# File 'lib/stripe/params/account_person_create_params.rb', line 387 def registered_address @registered_address end |
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
389 390 391 |
# File 'lib/stripe/params/account_person_create_params.rb', line 389 def relationship @relationship end |
#self_reported_income ⇒ Object
The credit applicant’s self-reported yearly income in minor units.
391 392 393 |
# File 'lib/stripe/params/account_person_create_params.rb', line 391 def self_reported_income @self_reported_income end |
#self_reported_monthly_housing_payment ⇒ Object
The credit applicant’s self-reported monthly housing payment in minor units.
393 394 395 |
# File 'lib/stripe/params/account_person_create_params.rb', line 393 def self_reported_monthly_housing_payment @self_reported_monthly_housing_payment end |
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
395 396 397 |
# File 'lib/stripe/params/account_person_create_params.rb', line 395 def ssn_last_4 @ssn_last_4 end |
#us_cfpb_data ⇒ Object
Demographic data related to the person.
397 398 399 |
# File 'lib/stripe/params/account_person_create_params.rb', line 397 def us_cfpb_data @us_cfpb_data end |
#verification ⇒ Object
The person’s verification status.
399 400 401 |
# File 'lib/stripe/params/account_person_create_params.rb', line 399 def verification @verification end |