Class: Stripe::AccountPersonService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::AccountPersonService
- Defined in:
- lib/stripe/services/account_person_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(account, params = {}, opts = {}) ⇒ Object
Creates a new person.
-
#delete(account, person, params = {}, opts = {}) ⇒ Object
Deletes an existing person’s relationship to the account’s legal entity.
-
#list(account, params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account’s legal entity.
-
#retrieve(account, person, params = {}, opts = {}) ⇒ Object
Retrieves an existing person.
-
#update(account, person, params = {}, opts = {}) ⇒ Object
Updates an existing person.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(account, params = {}, opts = {}) ⇒ Object
Creates a new person.
965 966 967 968 969 970 971 972 973 |
# File 'lib/stripe/services/account_person_service.rb', line 965 def create(account, params = {}, opts = {}) request( method: :post, path: format("/v1/accounts/%<account>s/persons", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |
#delete(account, person, params = {}, opts = {}) ⇒ Object
Deletes an existing person’s relationship to the account’s legal entity. Any person with a relationship for an account can be deleted through the API, except if the person is the account_opener. If your integration is using the executive parameter, you cannot delete the only verified executive on file.
976 977 978 979 980 981 982 983 984 |
# File 'lib/stripe/services/account_person_service.rb', line 976 def delete(account, person, params = {}, opts = {}) request( method: :delete, path: format("/v1/accounts/%<account>s/persons/%<person>s", { account: CGI.escape(account), person: CGI.escape(person) }), params: params, opts: opts, base_address: :api ) end |
#list(account, params = {}, opts = {}) ⇒ Object
Returns a list of people associated with the account’s legal entity. The people are returned sorted by creation date, with the most recent people appearing first.
987 988 989 990 991 992 993 994 995 |
# File 'lib/stripe/services/account_person_service.rb', line 987 def list(account, params = {}, opts = {}) request( method: :get, path: format("/v1/accounts/%<account>s/persons", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(account, person, params = {}, opts = {}) ⇒ Object
Retrieves an existing person.
998 999 1000 1001 1002 1003 1004 1005 1006 |
# File 'lib/stripe/services/account_person_service.rb', line 998 def retrieve(account, person, params = {}, opts = {}) request( method: :get, path: format("/v1/accounts/%<account>s/persons/%<person>s", { account: CGI.escape(account), person: CGI.escape(person) }), params: params, opts: opts, base_address: :api ) end |
#update(account, person, params = {}, opts = {}) ⇒ Object
Updates an existing person.
1009 1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/stripe/services/account_person_service.rb', line 1009 def update(account, person, params = {}, opts = {}) request( method: :post, path: format("/v1/accounts/%<account>s/persons/%<person>s", { account: CGI.escape(account), person: CGI.escape(person) }), params: params, opts: opts, base_address: :api ) end |