Class: Stripe::AccountPersonService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountPersonService::CreateParams
- Defined in:
- lib/stripe/services/account_person_service.rb
Defined Under Namespace
Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, UsCfpbData, Verification
Instance Attribute Summary collapse
-
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
-
#address ⇒ Object
The person’s address.
-
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
-
#dob ⇒ Object
The person’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The person’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#first_name ⇒ Object
The person’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
-
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
-
#id_number ⇒ Object
The person’s ID number, as appropriate for their country.
-
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The person’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
-
#maiden_name ⇒ Object
The person’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nationality ⇒ Object
The country where the person is a national.
-
#person_token ⇒ Object
A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.
-
#phone ⇒ Object
The person’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The person’s registered address.
-
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
-
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
-
#us_cfpb_data ⇒ Object
Demographic data related to the person.
-
#verification ⇒ Object
The person’s verification status.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 |
# File 'lib/stripe/services/account_person_service.rb', line 902 def initialize( additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil ) @additional_tos_acceptances = additional_tos_acceptances @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @documents = documents @email = email @expand = @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @nationality = nationality @person_token = person_token @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @us_cfpb_data = us_cfpb_data @verification = verification end |
Instance Attribute Details
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
844 845 846 |
# File 'lib/stripe/services/account_person_service.rb', line 844 def additional_tos_acceptances @additional_tos_acceptances end |
#address ⇒ Object
The person’s address.
846 847 848 |
# File 'lib/stripe/services/account_person_service.rb', line 846 def address @address end |
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
848 849 850 |
# File 'lib/stripe/services/account_person_service.rb', line 848 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
850 851 852 |
# File 'lib/stripe/services/account_person_service.rb', line 850 def address_kanji @address_kanji end |
#dob ⇒ Object
The person’s date of birth.
852 853 854 |
# File 'lib/stripe/services/account_person_service.rb', line 852 def dob @dob end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
854 855 856 |
# File 'lib/stripe/services/account_person_service.rb', line 854 def documents @documents end |
#email ⇒ Object
The person’s email address.
856 857 858 |
# File 'lib/stripe/services/account_person_service.rb', line 856 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
858 859 860 |
# File 'lib/stripe/services/account_person_service.rb', line 858 def @expand end |
#first_name ⇒ Object
The person’s first name.
860 861 862 |
# File 'lib/stripe/services/account_person_service.rb', line 860 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
862 863 864 |
# File 'lib/stripe/services/account_person_service.rb', line 862 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
864 865 866 |
# File 'lib/stripe/services/account_person_service.rb', line 864 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
866 867 868 |
# File 'lib/stripe/services/account_person_service.rb', line 866 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
868 869 870 |
# File 'lib/stripe/services/account_person_service.rb', line 868 def gender @gender end |
#id_number ⇒ Object
The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
870 871 872 |
# File 'lib/stripe/services/account_person_service.rb', line 870 def id_number @id_number end |
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
872 873 874 |
# File 'lib/stripe/services/account_person_service.rb', line 872 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The person’s last name.
874 875 876 |
# File 'lib/stripe/services/account_person_service.rb', line 874 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
876 877 878 |
# File 'lib/stripe/services/account_person_service.rb', line 876 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
878 879 880 |
# File 'lib/stripe/services/account_person_service.rb', line 878 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The person’s maiden name.
880 881 882 |
# File 'lib/stripe/services/account_person_service.rb', line 880 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
882 883 884 |
# File 'lib/stripe/services/account_person_service.rb', line 882 def @metadata end |
#nationality ⇒ Object
The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.
884 885 886 |
# File 'lib/stripe/services/account_person_service.rb', line 884 def nationality @nationality end |
#person_token ⇒ Object
A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.
886 887 888 |
# File 'lib/stripe/services/account_person_service.rb', line 886 def person_token @person_token end |
#phone ⇒ Object
The person’s phone number.
888 889 890 |
# File 'lib/stripe/services/account_person_service.rb', line 888 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
890 891 892 |
# File 'lib/stripe/services/account_person_service.rb', line 890 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The person’s registered address.
892 893 894 |
# File 'lib/stripe/services/account_person_service.rb', line 892 def registered_address @registered_address end |
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
894 895 896 |
# File 'lib/stripe/services/account_person_service.rb', line 894 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
896 897 898 |
# File 'lib/stripe/services/account_person_service.rb', line 896 def ssn_last_4 @ssn_last_4 end |
#us_cfpb_data ⇒ Object
Demographic data related to the person.
898 899 900 |
# File 'lib/stripe/services/account_person_service.rb', line 898 def us_cfpb_data @us_cfpb_data end |
#verification ⇒ Object
The person’s verification status.
900 901 902 |
# File 'lib/stripe/services/account_person_service.rb', line 900 def verification @verification end |