Class: Stripe::AccountPersonService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountPersonService::CreateParams
- Defined in:
- lib/stripe/services/account_person_service.rb
Defined Under Namespace
Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
-
#address ⇒ Object
The person’s address.
-
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
-
#dob ⇒ Object
The person’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The person’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#first_name ⇒ Object
The person’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
-
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
-
#id_number ⇒ Object
The person’s ID number, as appropriate for their country.
-
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The person’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
-
#maiden_name ⇒ Object
The person’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nationality ⇒ Object
The country where the person is a national.
-
#person_token ⇒ Object
A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.
-
#phone ⇒ Object
The person’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The person’s registered address.
-
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
-
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
-
#verification ⇒ Object
The person’s verification status.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 |
# File 'lib/stripe/services/account_person_service.rb', line 820 def initialize( additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @additional_tos_acceptances = additional_tos_acceptances @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @documents = documents @email = email @expand = @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @nationality = nationality @person_token = person_token @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
764 765 766 |
# File 'lib/stripe/services/account_person_service.rb', line 764 def additional_tos_acceptances @additional_tos_acceptances end |
#address ⇒ Object
The person’s address.
766 767 768 |
# File 'lib/stripe/services/account_person_service.rb', line 766 def address @address end |
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
768 769 770 |
# File 'lib/stripe/services/account_person_service.rb', line 768 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
770 771 772 |
# File 'lib/stripe/services/account_person_service.rb', line 770 def address_kanji @address_kanji end |
#dob ⇒ Object
The person’s date of birth.
772 773 774 |
# File 'lib/stripe/services/account_person_service.rb', line 772 def dob @dob end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
774 775 776 |
# File 'lib/stripe/services/account_person_service.rb', line 774 def documents @documents end |
#email ⇒ Object
The person’s email address.
776 777 778 |
# File 'lib/stripe/services/account_person_service.rb', line 776 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
778 779 780 |
# File 'lib/stripe/services/account_person_service.rb', line 778 def @expand end |
#first_name ⇒ Object
The person’s first name.
780 781 782 |
# File 'lib/stripe/services/account_person_service.rb', line 780 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
782 783 784 |
# File 'lib/stripe/services/account_person_service.rb', line 782 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
784 785 786 |
# File 'lib/stripe/services/account_person_service.rb', line 784 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
786 787 788 |
# File 'lib/stripe/services/account_person_service.rb', line 786 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
788 789 790 |
# File 'lib/stripe/services/account_person_service.rb', line 788 def gender @gender end |
#id_number ⇒ Object
The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
790 791 792 |
# File 'lib/stripe/services/account_person_service.rb', line 790 def id_number @id_number end |
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
792 793 794 |
# File 'lib/stripe/services/account_person_service.rb', line 792 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The person’s last name.
794 795 796 |
# File 'lib/stripe/services/account_person_service.rb', line 794 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
796 797 798 |
# File 'lib/stripe/services/account_person_service.rb', line 796 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
798 799 800 |
# File 'lib/stripe/services/account_person_service.rb', line 798 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The person’s maiden name.
800 801 802 |
# File 'lib/stripe/services/account_person_service.rb', line 800 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
802 803 804 |
# File 'lib/stripe/services/account_person_service.rb', line 802 def @metadata end |
#nationality ⇒ Object
The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.
804 805 806 |
# File 'lib/stripe/services/account_person_service.rb', line 804 def nationality @nationality end |
#person_token ⇒ Object
A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.
806 807 808 |
# File 'lib/stripe/services/account_person_service.rb', line 806 def person_token @person_token end |
#phone ⇒ Object
The person’s phone number.
808 809 810 |
# File 'lib/stripe/services/account_person_service.rb', line 808 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
810 811 812 |
# File 'lib/stripe/services/account_person_service.rb', line 810 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The person’s registered address.
812 813 814 |
# File 'lib/stripe/services/account_person_service.rb', line 812 def registered_address @registered_address end |
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
814 815 816 |
# File 'lib/stripe/services/account_person_service.rb', line 814 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
816 817 818 |
# File 'lib/stripe/services/account_person_service.rb', line 816 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The person’s verification status.
818 819 820 |
# File 'lib/stripe/services/account_person_service.rb', line 818 def verification @verification end |