Class: Stripe::AccountPersonService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountPersonService::CreateParams
- Defined in:
- lib/stripe/services/account_person_service.rb
Defined Under Namespace
Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
-
#address ⇒ Object
The person’s address.
-
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
-
#dob ⇒ Object
The person’s date of birth.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The person’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#first_name ⇒ Object
The person’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
-
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
-
#id_number ⇒ Object
The person’s ID number, as appropriate for their country.
-
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The person’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
-
#maiden_name ⇒ Object
The person’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#nationality ⇒ Object
The country where the person is a national.
-
#person_token ⇒ Object
A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.
-
#phone ⇒ Object
The person’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The person’s registered address.
-
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
-
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
-
#verification ⇒ Object
The person’s verification status.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/stripe/services/account_person_service.rb', line 959 def initialize( additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @additional_tos_acceptances = additional_tos_acceptances @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @documents = documents @email = email @expand = @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @nationality = nationality @person_token = person_token @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#additional_tos_acceptances ⇒ Object
Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.
876 877 878 |
# File 'lib/stripe/services/account_person_service.rb', line 876 def additional_tos_acceptances @additional_tos_acceptances end |
#address ⇒ Object
The person’s address.
879 880 881 |
# File 'lib/stripe/services/account_person_service.rb', line 879 def address @address end |
#address_kana ⇒ Object
The Kana variation of the person’s address (Japan only).
882 883 884 |
# File 'lib/stripe/services/account_person_service.rb', line 882 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the person’s address (Japan only).
885 886 887 |
# File 'lib/stripe/services/account_person_service.rb', line 885 def address_kanji @address_kanji end |
#dob ⇒ Object
The person’s date of birth.
888 889 890 |
# File 'lib/stripe/services/account_person_service.rb', line 888 def dob @dob end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
891 892 893 |
# File 'lib/stripe/services/account_person_service.rb', line 891 def documents @documents end |
#email ⇒ Object
The person’s email address.
894 895 896 |
# File 'lib/stripe/services/account_person_service.rb', line 894 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
897 898 899 |
# File 'lib/stripe/services/account_person_service.rb', line 897 def @expand end |
#first_name ⇒ Object
The person’s first name.
900 901 902 |
# File 'lib/stripe/services/account_person_service.rb', line 900 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the person’s first name (Japan only).
903 904 905 |
# File 'lib/stripe/services/account_person_service.rb', line 903 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the person’s first name (Japan only).
906 907 908 |
# File 'lib/stripe/services/account_person_service.rb', line 906 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the person is known by.
909 910 911 |
# File 'lib/stripe/services/account_person_service.rb', line 909 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The person’s gender (International regulations require either “male” or “female”).
912 913 914 |
# File 'lib/stripe/services/account_person_service.rb', line 912 def gender @gender end |
#id_number ⇒ Object
The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
915 916 917 |
# File 'lib/stripe/services/account_person_service.rb', line 915 def id_number @id_number end |
#id_number_secondary ⇒ Object
The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).
918 919 920 |
# File 'lib/stripe/services/account_person_service.rb', line 918 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The person’s last name.
921 922 923 |
# File 'lib/stripe/services/account_person_service.rb', line 921 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the person’s last name (Japan only).
924 925 926 |
# File 'lib/stripe/services/account_person_service.rb', line 924 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the person’s last name (Japan only).
927 928 929 |
# File 'lib/stripe/services/account_person_service.rb', line 927 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The person’s maiden name.
930 931 932 |
# File 'lib/stripe/services/account_person_service.rb', line 930 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
933 934 935 |
# File 'lib/stripe/services/account_person_service.rb', line 933 def @metadata end |
#nationality ⇒ Object
The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.
936 937 938 |
# File 'lib/stripe/services/account_person_service.rb', line 936 def nationality @nationality end |
#person_token ⇒ Object
A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.
939 940 941 |
# File 'lib/stripe/services/account_person_service.rb', line 939 def person_token @person_token end |
#phone ⇒ Object
The person’s phone number.
942 943 944 |
# File 'lib/stripe/services/account_person_service.rb', line 942 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
945 946 947 |
# File 'lib/stripe/services/account_person_service.rb', line 945 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The person’s registered address.
948 949 950 |
# File 'lib/stripe/services/account_person_service.rb', line 948 def registered_address @registered_address end |
#relationship ⇒ Object
The relationship that this person has with the account’s legal entity.
951 952 953 |
# File 'lib/stripe/services/account_person_service.rb', line 951 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the person’s Social Security number (U.S. only).
954 955 956 |
# File 'lib/stripe/services/account_person_service.rb', line 954 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The person’s verification status.
957 958 959 |
# File 'lib/stripe/services/account_person_service.rb', line 957 def verification @verification end |