Class: Stripe::AccountPersonService::CreateParams::AdditionalTosAcceptances::Account
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountPersonService::CreateParams::AdditionalTosAcceptances::Account
- Defined in:
- lib/stripe/services/account_person_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
constructor
A new instance of Account.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account
Returns a new instance of Account.
529 530 531 532 533 |
# File 'lib/stripe/services/account_person_service.rb', line 529 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
523 524 525 |
# File 'lib/stripe/services/account_person_service.rb', line 523 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
525 526 527 |
# File 'lib/stripe/services/account_person_service.rb', line 525 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
527 528 529 |
# File 'lib/stripe/services/account_person_service.rb', line 527 def user_agent @user_agent end |