Class: Stripe::AccountPersonService::CreateParams::AdditionalTosAcceptances::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account

Returns a new instance of Account.



530
531
532
533
534
# File 'lib/stripe/services/account_person_service.rb', line 530

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



524
525
526
# File 'lib/stripe/services/account_person_service.rb', line 524

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



526
527
528
# File 'lib/stripe/services/account_person_service.rb', line 526

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



528
529
530
# File 'lib/stripe/services/account_person_service.rb', line 528

def user_agent
  @user_agent
end