Class: Stripe::AccountPersonService::CreateParams::AdditionalTosAcceptances::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account

Returns a new instance of Account.



488
489
490
491
492
# File 'lib/stripe/services/account_person_service.rb', line 488

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



482
483
484
# File 'lib/stripe/services/account_person_service.rb', line 482

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



484
485
486
# File 'lib/stripe/services/account_person_service.rb', line 484

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



486
487
488
# File 'lib/stripe/services/account_person_service.rb', line 486

def user_agent
  @user_agent
end