Class: Stripe::AccountPersonService::CreateParams::AdditionalTosAcceptances::Account

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ Account

Returns a new instance of Account.



564
565
566
567
568
# File 'lib/stripe/services/account_person_service.rb', line 564

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



556
557
558
# File 'lib/stripe/services/account_person_service.rb', line 556

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



559
560
561
# File 'lib/stripe/services/account_person_service.rb', line 559

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



562
563
564
# File 'lib/stripe/services/account_person_service.rb', line 562

def user_agent
  @user_agent
end