Class: Stripe::AccountPersonService::CreateParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
# File 'lib/stripe/services/account_person_service.rb', line 708

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



692
693
694
# File 'lib/stripe/services/account_person_service.rb', line 692

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



694
695
696
# File 'lib/stripe/services/account_person_service.rb', line 694

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



696
697
698
# File 'lib/stripe/services/account_person_service.rb', line 696

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



698
699
700
# File 'lib/stripe/services/account_person_service.rb', line 698

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



700
701
702
# File 'lib/stripe/services/account_person_service.rb', line 700

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



702
703
704
# File 'lib/stripe/services/account_person_service.rb', line 702

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



704
705
706
# File 'lib/stripe/services/account_person_service.rb', line 704

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



706
707
708
# File 'lib/stripe/services/account_person_service.rb', line 706

def title
  @title
end