Class: Stripe::AccountPersonService::CreateParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
# File 'lib/stripe/services/account_person_service.rb', line 817

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



794
795
796
# File 'lib/stripe/services/account_person_service.rb', line 794

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



797
798
799
# File 'lib/stripe/services/account_person_service.rb', line 797

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



800
801
802
# File 'lib/stripe/services/account_person_service.rb', line 800

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



803
804
805
# File 'lib/stripe/services/account_person_service.rb', line 803

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



806
807
808
# File 'lib/stripe/services/account_person_service.rb', line 806

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



809
810
811
# File 'lib/stripe/services/account_person_service.rb', line 809

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



812
813
814
# File 'lib/stripe/services/account_person_service.rb', line 812

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



815
816
817
# File 'lib/stripe/services/account_person_service.rb', line 815

def title
  @title
end