Class: Stripe::AccountPersonService::ListParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/stripe/services/account_person_service.rb', line 436

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



424
425
426
# File 'lib/stripe/services/account_person_service.rb', line 424

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



426
427
428
# File 'lib/stripe/services/account_person_service.rb', line 426

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



428
429
430
# File 'lib/stripe/services/account_person_service.rb', line 428

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



430
431
432
# File 'lib/stripe/services/account_person_service.rb', line 430

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



432
433
434
# File 'lib/stripe/services/account_person_service.rb', line 432

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



434
435
436
# File 'lib/stripe/services/account_person_service.rb', line 434

def representative
  @representative
end