Class: Stripe::AccountPersonService::ListParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, representative: nil) ⇒ Relationship

Returns a new instance of Relationship.



506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/stripe/services/account_person_service.rb', line 506

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  representative: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @representative = representative
end

Instance Attribute Details

#authorizerObject

A filter on the list of people returned based on whether these people are authorizers of the account’s representative.



489
490
491
# File 'lib/stripe/services/account_person_service.rb', line 489

def authorizer
  @authorizer
end

#directorObject

A filter on the list of people returned based on whether these people are directors of the account’s company.



492
493
494
# File 'lib/stripe/services/account_person_service.rb', line 492

def director
  @director
end

#executiveObject

A filter on the list of people returned based on whether these people are executives of the account’s company.



495
496
497
# File 'lib/stripe/services/account_person_service.rb', line 495

def executive
  @executive
end

A filter on the list of people returned based on whether these people are legal guardians of the account’s representative.



498
499
500
# File 'lib/stripe/services/account_person_service.rb', line 498

def legal_guardian
  @legal_guardian
end

#ownerObject

A filter on the list of people returned based on whether these people are owners of the account’s company.



501
502
503
# File 'lib/stripe/services/account_person_service.rb', line 501

def owner
  @owner
end

#representativeObject

A filter on the list of people returned based on whether these people are the representative of the account’s company.



504
505
506
# File 'lib/stripe/services/account_person_service.rb', line 504

def representative
  @representative
end