Class: Stripe::AccountPersonService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Defined Under Namespace

Classes: AdditionalTosAcceptances, Address, AddressKana, AddressKanji, Dob, Documents, RegisteredAddress, Relationship, UsCfpbData, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(additional_tos_acceptances: nil, address: nil, address_kana: nil, address_kanji: nil, dob: nil, documents: nil, email: nil, expand: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, nationality: nil, person_token: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, us_cfpb_data: nil, verification: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/stripe/services/account_person_service.rb', line 400

def initialize(
  additional_tos_acceptances: nil,
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  documents: nil,
  email: nil,
  expand: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  nationality: nil,
  person_token: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  us_cfpb_data: nil,
  verification: nil
)
  @additional_tos_acceptances = additional_tos_acceptances
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @documents = documents
  @email = email
  @expand = expand
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @nationality = nationality
  @person_token = person_token
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @us_cfpb_data = us_cfpb_data
  @verification = verification
end

Instance Attribute Details

#additional_tos_acceptancesObject

Details on the legal guardian’s or authorizer’s acceptance of the required Stripe agreements.



342
343
344
# File 'lib/stripe/services/account_person_service.rb', line 342

def additional_tos_acceptances
  @additional_tos_acceptances
end

#addressObject

The person’s address.



344
345
346
# File 'lib/stripe/services/account_person_service.rb', line 344

def address
  @address
end

#address_kanaObject

The Kana variation of the person’s address (Japan only).



346
347
348
# File 'lib/stripe/services/account_person_service.rb', line 346

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the person’s address (Japan only).



348
349
350
# File 'lib/stripe/services/account_person_service.rb', line 348

def address_kanji
  @address_kanji
end

#dobObject

The person’s date of birth.



350
351
352
# File 'lib/stripe/services/account_person_service.rb', line 350

def dob
  @dob
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



352
353
354
# File 'lib/stripe/services/account_person_service.rb', line 352

def documents
  @documents
end

#emailObject

The person’s email address.



354
355
356
# File 'lib/stripe/services/account_person_service.rb', line 354

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



356
357
358
# File 'lib/stripe/services/account_person_service.rb', line 356

def expand
  @expand
end

#first_nameObject

The person’s first name.



358
359
360
# File 'lib/stripe/services/account_person_service.rb', line 358

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the person’s first name (Japan only).



360
361
362
# File 'lib/stripe/services/account_person_service.rb', line 360

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the person’s first name (Japan only).



362
363
364
# File 'lib/stripe/services/account_person_service.rb', line 362

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the person is known by.



364
365
366
# File 'lib/stripe/services/account_person_service.rb', line 364

def full_name_aliases
  @full_name_aliases
end

#genderObject

The person’s gender (International regulations require either “male” or “female”).



366
367
368
# File 'lib/stripe/services/account_person_service.rb', line 366

def gender
  @gender
end

#id_numberObject

The person’s ID number, as appropriate for their country. For example, a social security number in the U.S., social insurance number in Canada, etc. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



368
369
370
# File 'lib/stripe/services/account_person_service.rb', line 368

def id_number
  @id_number
end

#id_number_secondaryObject

The person’s secondary ID number, as appropriate for their country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token provided by Stripe.js](docs.stripe.com/js/tokens/create_token?type=pii).



370
371
372
# File 'lib/stripe/services/account_person_service.rb', line 370

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The person’s last name.



372
373
374
# File 'lib/stripe/services/account_person_service.rb', line 372

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the person’s last name (Japan only).



374
375
376
# File 'lib/stripe/services/account_person_service.rb', line 374

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the person’s last name (Japan only).



376
377
378
# File 'lib/stripe/services/account_person_service.rb', line 376

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The person’s maiden name.



378
379
380
# File 'lib/stripe/services/account_person_service.rb', line 378

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



380
381
382
# File 'lib/stripe/services/account_person_service.rb', line 380

def 
  @metadata
end

#nationalityObject

The country where the person is a national. Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)), or “XX” if unavailable.



382
383
384
# File 'lib/stripe/services/account_person_service.rb', line 382

def nationality
  @nationality
end

#person_tokenObject

A [person token](docs.stripe.com/connect/account-tokens), used to securely provide details to the person.



384
385
386
# File 'lib/stripe/services/account_person_service.rb', line 384

def person_token
  @person_token
end

#phoneObject

The person’s phone number.



386
387
388
# File 'lib/stripe/services/account_person_service.rb', line 386

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



388
389
390
# File 'lib/stripe/services/account_person_service.rb', line 388

def political_exposure
  @political_exposure
end

#registered_addressObject

The person’s registered address.



390
391
392
# File 'lib/stripe/services/account_person_service.rb', line 390

def registered_address
  @registered_address
end

#relationshipObject

The relationship that this person has with the account’s legal entity.



392
393
394
# File 'lib/stripe/services/account_person_service.rb', line 392

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the person’s Social Security number (U.S. only).



394
395
396
# File 'lib/stripe/services/account_person_service.rb', line 394

def ssn_last_4
  @ssn_last_4
end

#us_cfpb_dataObject

Demographic data related to the person.



396
397
398
# File 'lib/stripe/services/account_person_service.rb', line 396

def us_cfpb_data
  @us_cfpb_data
end

#verificationObject

The person’s verification status.



398
399
400
# File 'lib/stripe/services/account_person_service.rb', line 398

def verification
  @verification
end