Class: Stripe::AccountPersonService::UpdateParams::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Defined Under Namespace

Classes: CompanyAuthorization, Passport, Visa

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(company_authorization: nil, passport: nil, visa: nil) ⇒ Documents

Returns a new instance of Documents.



215
216
217
218
219
# File 'lib/stripe/services/account_person_service.rb', line 215

def initialize(company_authorization: nil, passport: nil, visa: nil)
  @company_authorization = company_authorization
  @passport = passport
  @visa = visa
end

Instance Attribute Details

#company_authorizationObject

One or more documents that demonstrate proof that this person is authorized to represent the company.



207
208
209
# File 'lib/stripe/services/account_person_service.rb', line 207

def company_authorization
  @company_authorization
end

#passportObject

One or more documents showing the person’s passport page with photo and personal data.



210
211
212
# File 'lib/stripe/services/account_person_service.rb', line 210

def passport
  @passport
end

#visaObject

One or more documents showing the person’s visa required for living in the country where they are residing.



213
214
215
# File 'lib/stripe/services/account_person_service.rb', line 213

def visa
  @visa
end