Class: Stripe::AccountPersonService::UpdateParams::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_person_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(authorizer: nil, director: nil, executive: nil, legal_guardian: nil, owner: nil, percent_ownership: nil, representative: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/stripe/services/account_person_service.rb', line 283

def initialize(
  authorizer: nil,
  director: nil,
  executive: nil,
  legal_guardian: nil,
  owner: nil,
  percent_ownership: nil,
  representative: nil,
  title: nil
)
  @authorizer = authorizer
  @director = director
  @executive = executive
  @legal_guardian = legal_guardian
  @owner = owner
  @percent_ownership = percent_ownership
  @representative = representative
  @title = title
end

Instance Attribute Details

#authorizerObject

Whether the person is the authorizer of the account’s representative.



260
261
262
# File 'lib/stripe/services/account_person_service.rb', line 260

def authorizer
  @authorizer
end

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



263
264
265
# File 'lib/stripe/services/account_person_service.rb', line 263

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



266
267
268
# File 'lib/stripe/services/account_person_service.rb', line 266

def executive
  @executive
end

Whether the person is the legal guardian of the account’s representative.



269
270
271
# File 'lib/stripe/services/account_person_service.rb', line 269

def legal_guardian
  @legal_guardian
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



272
273
274
# File 'lib/stripe/services/account_person_service.rb', line 272

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



275
276
277
# File 'lib/stripe/services/account_person_service.rb', line 275

def percent_ownership
  @percent_ownership
end

#representativeObject

Whether the person is authorized as the primary representative of the account. This is the person nominated by the business to provide information about themselves, and general information about the account. There can only be one representative at any given time. At the time the account is created, this person should be set to the person responsible for opening the account.



278
279
280
# File 'lib/stripe/services/account_person_service.rb', line 278

def representative
  @representative
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



281
282
283
# File 'lib/stripe/services/account_person_service.rb', line 281

def title
  @title
end