Class: Stripe::AccountService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: CreateParams, DeleteParams, ListParams, RejectParams, RetrieveCurrentParams, RetrieveParams, UpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from StripeService

#request, #request_stream

Constructor Details

#initialize(requestor) ⇒ AccountService

Returns a new instance of AccountService.



8
9
10
11
12
13
14
# File 'lib/stripe/services/account_service.rb', line 8

def initialize(requestor)
  super
  @capabilities = Stripe::AccountCapabilityService.new(@requestor)
  @external_accounts = Stripe::AccountExternalAccountService.new(@requestor)
  @login_links = Stripe::AccountLoginLinkService.new(@requestor)
  @persons = Stripe::AccountPersonService.new(@requestor)
end

Instance Attribute Details

#capabilitiesObject (readonly)

Returns the value of attribute capabilities.



6
7
8
# File 'lib/stripe/services/account_service.rb', line 6

def capabilities
  @capabilities
end

#external_accountsObject (readonly)

Returns the value of attribute external_accounts.



6
7
8
# File 'lib/stripe/services/account_service.rb', line 6

def external_accounts
  @external_accounts
end

Returns the value of attribute login_links.



6
7
8
# File 'lib/stripe/services/account_service.rb', line 6

def 
  @login_links
end

#personsObject (readonly)

Returns the value of attribute persons.



6
7
8
# File 'lib/stripe/services/account_service.rb', line 6

def persons
  @persons
end

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

With [Connect](docs.stripe.com/docs/connect), you can create Stripe accounts for your users. To do this, you’ll first need to [register your platform](dashboard.stripe.com/account/applications/settings).

If you’ve already collected information for your connected accounts, you [can prefill that information](docs.stripe.com/docs/connect/best-practices#onboarding) when creating the account. Connect Onboarding won’t ask for the prefilled information during account onboarding. You can prefill any information on the account.



4732
4733
4734
# File 'lib/stripe/services/account_service.rb', line 4732

def create(params = {}, opts = {})
  request(method: :post, path: "/v1/accounts", params: params, opts: opts, base_address: :api)
end

#delete(account, params = {}, opts = {}) ⇒ Object

With [Connect](docs.stripe.com/connect), you can delete accounts you manage.

Test-mode accounts can be deleted at any time.

Live-mode accounts that have access to the standard dashboard and Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. All other Live-mode accounts, can be deleted when all [balances](docs.stripe.com/api/balance/balance_object) are zero.

If you want to delete your own account, use the [account information tab in your account settings](dashboard.stripe.com/settings/account) instead.



4743
4744
4745
4746
4747
4748
4749
4750
4751
# File 'lib/stripe/services/account_service.rb', line 4743

def delete(, params = {}, opts = {})
  request(
    method: :delete,
    path: format("/v1/accounts/%<account>s", { account: CGI.escape() }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of accounts connected to your platform via [Connect](docs.stripe.com/docs/connect). If you’re not a platform, the list is empty.



4754
4755
4756
# File 'lib/stripe/services/account_service.rb', line 4754

def list(params = {}, opts = {})
  request(method: :get, path: "/v1/accounts", params: params, opts: opts, base_address: :api)
end

#reject(account, params = {}, opts = {}) ⇒ Object

With [Connect](docs.stripe.com/connect), you can reject accounts that you have flagged as suspicious.

Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.



4761
4762
4763
4764
4765
4766
4767
4768
4769
# File 'lib/stripe/services/account_service.rb', line 4761

def reject(, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape() }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(account, params = {}, opts = {}) ⇒ Object

Retrieves the details of an account.



4772
4773
4774
4775
4776
4777
4778
4779
4780
# File 'lib/stripe/services/account_service.rb', line 4772

def retrieve(, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/accounts/%<account>s", { account: CGI.escape() }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve_current(params = {}, opts = {}) ⇒ Object

Retrieves the details of an account.



4783
4784
4785
# File 'lib/stripe/services/account_service.rb', line 4783

def retrieve_current(params = {}, opts = {})
  request(method: :get, path: "/v1/account", params: params, opts: opts, base_address: :api)
end

#update(account, params = {}, opts = {}) ⇒ Object

Updates a [connected account](docs.stripe.com/connect/accounts) by setting the values of the parameters passed. Any parameters not provided are left unchanged.

For accounts where [controller.requirement_collection](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, you can update any information on the account.

For accounts where [controller.requirement_collection](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection) is stripe, which includes Standard and Express accounts, you can update all information until you create an [Account Link or <a href=“/api/account_sessions”>Account Session](docs.stripe.com/api/account_links) to start Connect onboarding, after which some properties can no longer be updated.

To update your own account, use the [Dashboard](dashboard.stripe.com/settings/account). Refer to our [Connect](docs.stripe.com/docs/connect/updating-accounts) documentation to learn more about updating accounts.



4800
4801
4802
4803
4804
4805
4806
4807
4808
# File 'lib/stripe/services/account_service.rb', line 4800

def update(, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/accounts/%<account>s", { account: CGI.escape() }),
    params: params,
    opts: opts,
    base_address: :api
  )
end