Class: Stripe::AccountService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::AccountService
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RejectParams, RetrieveCurrentParams, RetrieveParams, UpdateParams
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
readonly
Returns the value of attribute capabilities.
-
#external_accounts ⇒ Object
readonly
Returns the value of attribute external_accounts.
-
#login_links ⇒ Object
readonly
Returns the value of attribute login_links.
-
#persons ⇒ Object
readonly
Returns the value of attribute persons.
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/docs/connect), you can create Stripe accounts for your users.
-
#delete(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can delete accounts you manage.
-
#initialize(requestor) ⇒ AccountService
constructor
A new instance of AccountService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of accounts connected to your platform via [Connect](stripe.com/docs/connect).
-
#reject(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can reject accounts that you have flagged as suspicious.
-
#retrieve(account, params = {}, opts = {}) ⇒ Object
Retrieves the details of an account.
-
#retrieve_current(params = {}, opts = {}) ⇒ Object
Retrieves the details of an account.
-
#update(account, params = {}, opts = {}) ⇒ Object
Updates a [connected account](stripe.com/connect/accounts) by setting the values of the parameters passed.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ AccountService
Returns a new instance of AccountService.
8 9 10 11 12 13 14 |
# File 'lib/stripe/services/account_service.rb', line 8 def initialize(requestor) super(requestor) @capabilities = Stripe::AccountCapabilityService.new(@requestor) @external_accounts = Stripe::AccountExternalAccountService.new(@requestor) @login_links = Stripe::AccountLoginLinkService.new(@requestor) @persons = Stripe::AccountPersonService.new(@requestor) end |
Instance Attribute Details
#capabilities ⇒ Object (readonly)
Returns the value of attribute capabilities.
6 7 8 |
# File 'lib/stripe/services/account_service.rb', line 6 def capabilities @capabilities end |
#external_accounts ⇒ Object (readonly)
Returns the value of attribute external_accounts.
6 7 8 |
# File 'lib/stripe/services/account_service.rb', line 6 def external_accounts @external_accounts end |
#login_links ⇒ Object (readonly)
Returns the value of attribute login_links.
6 7 8 |
# File 'lib/stripe/services/account_service.rb', line 6 def login_links @login_links end |
#persons ⇒ Object (readonly)
Returns the value of attribute persons.
6 7 8 |
# File 'lib/stripe/services/account_service.rb', line 6 def persons @persons end |
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/docs/connect), you can create Stripe accounts for your users. To do this, you’ll first need to [register your platform](dashboard.stripe.com/account/applications/settings).
If you’ve already collected information for your connected accounts, you [can prefill that information](stripe.com/docs/connect/best-practices#onboarding) when creating the account. Connect Onboarding won’t ask for the prefilled information during account onboarding. You can prefill any information on the account.
4884 4885 4886 |
# File 'lib/stripe/services/account_service.rb', line 4884 def create(params = {}, opts = {}) request(method: :post, path: "/v1/accounts", params: params, opts: opts, base_address: :api) end |
#delete(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can delete accounts you manage.
Test-mode accounts can be deleted at any time.
Live-mode accounts where Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. Live-mode accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be deleted when all [balances](stripe.com/api/balance/balance_object) are zero.
If you want to delete your own account, use the [account information tab in your account settings](dashboard.stripe.com/settings/account) instead.
4895 4896 4897 4898 4899 4900 4901 4902 4903 |
# File 'lib/stripe/services/account_service.rb', line 4895 def delete(account, params = {}, opts = {}) request( method: :delete, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of accounts connected to your platform via [Connect](stripe.com/docs/connect). If you’re not a platform, the list is empty.
4906 4907 4908 |
# File 'lib/stripe/services/account_service.rb', line 4906 def list(params = {}, opts = {}) request(method: :get, path: "/v1/accounts", params: params, opts: opts, base_address: :api) end |
#reject(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can reject accounts that you have flagged as suspicious.
Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.
4913 4914 4915 4916 4917 4918 4919 4920 4921 |
# File 'lib/stripe/services/account_service.rb', line 4913 def reject(account, params = {}, opts = {}) request( method: :post, path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(account, params = {}, opts = {}) ⇒ Object
Retrieves the details of an account.
4924 4925 4926 4927 4928 4929 4930 4931 4932 |
# File 'lib/stripe/services/account_service.rb', line 4924 def retrieve(account, params = {}, opts = {}) request( method: :get, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |
#retrieve_current(params = {}, opts = {}) ⇒ Object
Retrieves the details of an account.
4935 4936 4937 |
# File 'lib/stripe/services/account_service.rb', line 4935 def retrieve_current(params = {}, opts = {}) request(method: :get, path: "/v1/account", params: params, opts: opts, base_address: :api) end |
#update(account, params = {}, opts = {}) ⇒ Object
Updates a [connected account](stripe.com/connect/accounts) by setting the values of the parameters passed. Any parameters not provided are left unchanged.
For accounts where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, you can update any information on the account.
For accounts where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is stripe, which includes Standard and Express accounts, you can update all information until you create an [Account Link or <a href=“/api/account_sessions”>Account Session](stripe.com/api/account_links) to start Connect onboarding, after which some properties can no longer be updated.
To update your own account, use the [Dashboard](dashboard.stripe.com/settings/account). Refer to our [Connect](stripe.com/docs/connect/updating-accounts) documentation to learn more about updating accounts.
4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/stripe/services/account_service.rb', line 4952 def update(account, params = {}, opts = {}) request( method: :post, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |