Class: Stripe::AccountService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::AccountService
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RejectParams, RetrieveCurrentParams, RetrieveParams, UpdateParams
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
readonly
Returns the value of attribute capabilities.
-
#external_accounts ⇒ Object
readonly
Returns the value of attribute external_accounts.
-
#login_links ⇒ Object
readonly
Returns the value of attribute login_links.
-
#persons ⇒ Object
readonly
Returns the value of attribute persons.
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/docs/connect), you can create Stripe accounts for your users.
-
#delete(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can delete accounts you manage.
-
#initialize(requestor) ⇒ AccountService
constructor
A new instance of AccountService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of accounts connected to your platform via [Connect](stripe.com/docs/connect).
-
#reject(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can reject accounts that you have flagged as suspicious.
-
#retrieve(account, params = {}, opts = {}) ⇒ Object
Retrieves the details of an account.
-
#retrieve_current(params = {}, opts = {}) ⇒ Object
Retrieves the details of an account.
-
#update(account, params = {}, opts = {}) ⇒ Object
Updates a [connected account](stripe.com/connect/accounts) by setting the values of the parameters passed.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ AccountService
Returns a new instance of AccountService.
8 9 10 11 12 13 14 |
# File 'lib/stripe/services/account_service.rb', line 8 def initialize(requestor) super(requestor) @capabilities = Stripe::AccountCapabilityService.new(@requestor) @external_accounts = Stripe::AccountExternalAccountService.new(@requestor) @login_links = Stripe::AccountLoginLinkService.new(@requestor) @persons = Stripe::AccountPersonService.new(@requestor) end |
Instance Attribute Details
#capabilities ⇒ Object (readonly)
Returns the value of attribute capabilities.
6 7 8 |
# File 'lib/stripe/services/account_service.rb', line 6 def capabilities @capabilities end |
#external_accounts ⇒ Object (readonly)
Returns the value of attribute external_accounts.
6 7 8 |
# File 'lib/stripe/services/account_service.rb', line 6 def external_accounts @external_accounts end |
#login_links ⇒ Object (readonly)
Returns the value of attribute login_links.
6 7 8 |
# File 'lib/stripe/services/account_service.rb', line 6 def login_links @login_links end |
#persons ⇒ Object (readonly)
Returns the value of attribute persons.
6 7 8 |
# File 'lib/stripe/services/account_service.rb', line 6 def persons @persons end |
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/docs/connect), you can create Stripe accounts for your users. To do this, you’ll first need to [register your platform](dashboard.stripe.com/account/applications/settings).
If you’ve already collected information for your connected accounts, you [can prefill that information](stripe.com/docs/connect/best-practices#onboarding) when creating the account. Connect Onboarding won’t ask for the prefilled information during account onboarding. You can prefill any information on the account.
4463 4464 4465 |
# File 'lib/stripe/services/account_service.rb', line 4463 def create(params = {}, opts = {}) request(method: :post, path: "/v1/accounts", params: params, opts: opts, base_address: :api) end |
#delete(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can delete accounts you manage.
Test-mode accounts can be deleted at any time.
Live-mode accounts where Stripe is responsible for negative account balances cannot be deleted, which includes Standard accounts. Live-mode accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be deleted when all [balances](stripe.com/api/balance/balance_object) are zero.
If you want to delete your own account, use the [account information tab in your account settings](dashboard.stripe.com/settings/account) instead.
4474 4475 4476 4477 4478 4479 4480 4481 4482 |
# File 'lib/stripe/services/account_service.rb', line 4474 def delete(account, params = {}, opts = {}) request( method: :delete, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of accounts connected to your platform via [Connect](stripe.com/docs/connect). If you’re not a platform, the list is empty.
4485 4486 4487 |
# File 'lib/stripe/services/account_service.rb', line 4485 def list(params = {}, opts = {}) request(method: :get, path: "/v1/accounts", params: params, opts: opts, base_address: :api) end |
#reject(account, params = {}, opts = {}) ⇒ Object
With [Connect](stripe.com/connect), you can reject accounts that you have flagged as suspicious.
Only accounts where your platform is liable for negative account balances, which includes Custom and Express accounts, can be rejected. Test-mode accounts can be rejected at any time. Live-mode accounts can only be rejected after all balances are zero.
4492 4493 4494 4495 4496 4497 4498 4499 4500 |
# File 'lib/stripe/services/account_service.rb', line 4492 def reject(account, params = {}, opts = {}) request( method: :post, path: format("/v1/accounts/%<account>s/reject", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(account, params = {}, opts = {}) ⇒ Object
Retrieves the details of an account.
4503 4504 4505 4506 4507 4508 4509 4510 4511 |
# File 'lib/stripe/services/account_service.rb', line 4503 def retrieve(account, params = {}, opts = {}) request( method: :get, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |
#retrieve_current(params = {}, opts = {}) ⇒ Object
Retrieves the details of an account.
4514 4515 4516 |
# File 'lib/stripe/services/account_service.rb', line 4514 def retrieve_current(params = {}, opts = {}) request(method: :get, path: "/v1/account", params: params, opts: opts, base_address: :api) end |
#update(account, params = {}, opts = {}) ⇒ Object
Updates a [connected account](stripe.com/connect/accounts) by setting the values of the parameters passed. Any parameters not provided are left unchanged.
For accounts where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is application, which includes Custom accounts, you can update any information on the account.
For accounts where [controller.requirement_collection](stripe.com/api/accounts/object#account_object-controller-requirement_collection) is stripe, which includes Standard and Express accounts, you can update all information until you create an [Account Link or <a href=“/api/account_sessions”>Account Session](stripe.com/api/account_links) to start Connect onboarding, after which some properties can no longer be updated.
To update your own account, use the [Dashboard](dashboard.stripe.com/settings/account). Refer to our [Connect](stripe.com/docs/connect/updating-accounts) documentation to learn more about updating accounts.
4531 4532 4533 4534 4535 4536 4537 4538 4539 |
# File 'lib/stripe/services/account_service.rb', line 4531 def update(account, params = {}, opts = {}) request( method: :post, path: format("/v1/accounts/%<account>s", { account: CGI.escape(account) }), params: params, opts: opts, base_address: :api ) end |