Class: Stripe::AccountService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Controller, Documents, Groups, Individual, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, controller: nil, country: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, settings: nil, tos_acceptance: nil, type: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



4112
4113
4114
4115
4116
4117
4118
4119
4120
4121
4122
4123
4124
4125
4126
4127
4128
4129
4130
4131
4132
4133
4134
4135
4136
4137
4138
4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
# File 'lib/stripe/services/account_service.rb', line 4112

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  controller: nil,
  country: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  settings: nil,
  tos_acceptance: nil,
  type: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @controller = controller
  @country = country
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
  @external_account = 
  @groups = groups
  @individual = individual
  @metadata = 
  @settings = settings
  @tos_acceptance = tos_acceptance
  @type = type
end

Instance Attribute Details

#account_tokenObject

An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.



4069
4070
4071
# File 'lib/stripe/services/account_service.rb', line 4069

def 
  @account_token
end

#business_profileObject

Business information about the account.



4071
4072
4073
# File 'lib/stripe/services/account_service.rb', line 4071

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.



4073
4074
4075
# File 'lib/stripe/services/account_service.rb', line 4073

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is ‘none`, which includes Custom accounts.



4082
4083
4084
# File 'lib/stripe/services/account_service.rb', line 4082

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any ‘business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



4084
4085
4086
# File 'lib/stripe/services/account_service.rb', line 4084

def company
  @company
end

#controllerObject

A hash of configuration describing the account controller’s attributes.



4086
4087
4088
# File 'lib/stripe/services/account_service.rb', line 4086

def controller
  @controller
end

#countryObject

The country in which the account holder resides, or in which the business is legally established. This should be an ISO 3166-1 alpha-2 country code. For example, if you are in the United States and the business for which you’re creating an account is legally represented in Canada, you would use ‘CA` as the country for the account being created. Available countries include [Stripe’s global markets](stripe.com/global) as well as countries where [cross-border payouts](stripe.com/docs/connect/cross-border-payouts) are supported.



4088
4089
4090
# File 'lib/stripe/services/account_service.rb', line 4088

def country
  @country
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).



4090
4091
4092
# File 'lib/stripe/services/account_service.rb', line 4090

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



4092
4093
4094
# File 'lib/stripe/services/account_service.rb', line 4092

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, Stripe doesn’t email the account without your consent.



4094
4095
4096
# File 'lib/stripe/services/account_service.rb', line 4094

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



4096
4097
4098
# File 'lib/stripe/services/account_service.rb', line 4096

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the ‘external_account` parameter for [bank account](/api#account_create_bank_account) creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



4098
4099
4100
# File 'lib/stripe/services/account_service.rb', line 4098

def 
  @external_account
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



4100
4101
4102
# File 'lib/stripe/services/account_service.rb', line 4100

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless ‘business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.



4102
4103
4104
# File 'lib/stripe/services/account_service.rb', line 4102

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4104
4105
4106
# File 'lib/stripe/services/account_service.rb', line 4104

def 
  @metadata
end

#settingsObject

Options for customizing how the account functions within Stripe.



4106
4107
4108
# File 'lib/stripe/services/account_service.rb', line 4106

def settings
  @settings
end

#tos_acceptanceObject

Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. This property defaults to a `full` service agreement when empty.



4108
4109
4110
# File 'lib/stripe/services/account_service.rb', line 4108

def tos_acceptance
  @tos_acceptance
end

#typeObject

The type of Stripe account to create. May be one of ‘custom`, `express` or `standard`.



4110
4111
4112
# File 'lib/stripe/services/account_service.rb', line 4110

def type
  @type
end