Class: Stripe::AccountService::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
# File 'lib/stripe/services/account_service.rb', line 2104

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2092
2093
2094
# File 'lib/stripe/services/account_service.rb', line 2092

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2094
2095
2096
# File 'lib/stripe/services/account_service.rb', line 2094

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2096
2097
2098
# File 'lib/stripe/services/account_service.rb', line 2096

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2098
2099
2100
# File 'lib/stripe/services/account_service.rb', line 2098

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2100
2101
2102
# File 'lib/stripe/services/account_service.rb', line 2100

def currency
  @currency
end

#objectObject

Attribute for param field object



2090
2091
2092
# File 'lib/stripe/services/account_service.rb', line 2090

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



2102
2103
2104
# File 'lib/stripe/services/account_service.rb', line 2102

def routing_number
  @routing_number
end