Class: Stripe::AccountService::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
# File 'lib/stripe/services/account_service.rb', line 2065

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2053
2054
2055
# File 'lib/stripe/services/account_service.rb', line 2053

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2055
2056
2057
# File 'lib/stripe/services/account_service.rb', line 2055

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2057
2058
2059
# File 'lib/stripe/services/account_service.rb', line 2057

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2059
2060
2061
# File 'lib/stripe/services/account_service.rb', line 2059

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2061
2062
2063
# File 'lib/stripe/services/account_service.rb', line 2061

def currency
  @currency
end

#objectObject

Attribute for param field object



2051
2052
2053
# File 'lib/stripe/services/account_service.rb', line 2051

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriate institution number for the bank account. For US bank accounts, this is required and should be the ACH routing number, not the wire routing number. If you are providing an IBAN for ‘account_number`, this field is not required.



2063
2064
2065
# File 'lib/stripe/services/account_service.rb', line 2063

def routing_number
  @routing_number
end