Class: Stripe::AccountService::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
# File 'lib/stripe/services/account_service.rb', line 2237

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2225
2226
2227
# File 'lib/stripe/services/account_service.rb', line 2225

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2227
2228
2229
# File 'lib/stripe/services/account_service.rb', line 2227

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2229
2230
2231
# File 'lib/stripe/services/account_service.rb', line 2229

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2231
2232
2233
# File 'lib/stripe/services/account_service.rb', line 2231

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2233
2234
2235
# File 'lib/stripe/services/account_service.rb', line 2233

def currency
  @currency
end

#objectObject

Attribute for param field object



2223
2224
2225
# File 'lib/stripe/services/account_service.rb', line 2223

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



2235
2236
2237
# File 'lib/stripe/services/account_service.rb', line 2235

def routing_number
  @routing_number
end