Class: Stripe::AccountService::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
# File 'lib/stripe/services/account_service.rb', line 2452

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2435
2436
2437
# File 'lib/stripe/services/account_service.rb', line 2435

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2438
2439
2440
# File 'lib/stripe/services/account_service.rb', line 2438

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2441
2442
2443
# File 'lib/stripe/services/account_service.rb', line 2441

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2444
2445
2446
# File 'lib/stripe/services/account_service.rb', line 2444

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2447
2448
2449
# File 'lib/stripe/services/account_service.rb', line 2447

def currency
  @currency
end

#objectObject

Attribute for param field object



2432
2433
2434
# File 'lib/stripe/services/account_service.rb', line 2432

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



2450
2451
2452
# File 'lib/stripe/services/account_service.rb', line 2450

def routing_number
  @routing_number
end