Class: Stripe::AccountService::CreateParams::BankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(object: nil, account_holder_name: nil, account_holder_type: nil, account_number: nil, country: nil, currency: nil, routing_number: nil) ⇒ BankAccount

Returns a new instance of BankAccount.



2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
# File 'lib/stripe/services/account_service.rb', line 2192

def initialize(
  object: nil,
  account_holder_name: nil,
  account_holder_type: nil,
  account_number: nil,
  country: nil,
  currency: nil,
  routing_number: nil
)
  @object = object
  @account_holder_name = 
  @account_holder_type = 
  @account_number = 
  @country = country
  @currency = currency
  @routing_number = routing_number
end

Instance Attribute Details

#account_holder_nameObject

The name of the person or business that owns the bank account.This field is required when attaching the bank account to a ‘Customer` object.



2180
2181
2182
# File 'lib/stripe/services/account_service.rb', line 2180

def 
  @account_holder_name
end

#account_holder_typeObject

The type of entity that holds the account. It can be ‘company` or `individual`. This field is required when attaching the bank account to a `Customer` object.



2182
2183
2184
# File 'lib/stripe/services/account_service.rb', line 2182

def 
  @account_holder_type
end

#account_numberObject

The account number for the bank account, in string form. Must be a checking account.



2184
2185
2186
# File 'lib/stripe/services/account_service.rb', line 2184

def 
  @account_number
end

#countryObject

The country in which the bank account is located.



2186
2187
2188
# File 'lib/stripe/services/account_service.rb', line 2186

def country
  @country
end

#currencyObject

The currency the bank account is in. This must be a country/currency pairing that [Stripe supports.](docs/payouts)



2188
2189
2190
# File 'lib/stripe/services/account_service.rb', line 2188

def currency
  @currency
end

#objectObject

Attribute for param field object



2178
2179
2180
# File 'lib/stripe/services/account_service.rb', line 2178

def object
  @object
end

#routing_numberObject

The routing number, sort code, or other country-appropriateinstitution number for the bank account. For US bank accounts, this is required and should bethe ACH routing number, not the wire routing number. If you are providing an IBAN for`account_number`, this field is not required.



2190
2191
2192
# File 'lib/stripe/services/account_service.rb', line 2190

def routing_number
  @routing_number
end