Class: Stripe::AccountService::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
# File 'lib/stripe/services/account_service.rb', line 2206

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2182
2183
2184
# File 'lib/stripe/services/account_service.rb', line 2182

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2184
2185
2186
# File 'lib/stripe/services/account_service.rb', line 2184

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2186
2187
2188
# File 'lib/stripe/services/account_service.rb', line 2186

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



2188
2189
2190
# File 'lib/stripe/services/account_service.rb', line 2188

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2190
2191
2192
# File 'lib/stripe/services/account_service.rb', line 2190

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2192
2193
2194
# File 'lib/stripe/services/account_service.rb', line 2192

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2194
2195
2196
# File 'lib/stripe/services/account_service.rb', line 2194

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2196
2197
2198
# File 'lib/stripe/services/account_service.rb', line 2196

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2198
2199
2200
# File 'lib/stripe/services/account_service.rb', line 2198

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2200
2201
2202
# File 'lib/stripe/services/account_service.rb', line 2200

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2202
2203
2204
# File 'lib/stripe/services/account_service.rb', line 2202

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2204
2205
2206
# File 'lib/stripe/services/account_service.rb', line 2204

def url
  @url
end