Class: Stripe::AccountService::CreateParams::BusinessProfile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::BusinessProfile
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress
Instance Attribute Summary collapse
-
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc).
-
#minority_owned_business_designation ⇒ Object
Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#name ⇒ Object
The customer-facing business name.
-
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business.
-
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#support_email ⇒ Object
A publicly available email address for sending support issues to.
-
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
-
#support_url ⇒ Object
A publicly available website for handling support issues.
-
#url ⇒ Object
The business’s publicly available website.
Instance Method Summary collapse
-
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
constructor
A new instance of BusinessProfile.
Methods inherited from RequestParams
Constructor Details
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
Returns a new instance of BusinessProfile.
2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 |
# File 'lib/stripe/services/account_service.rb', line 2429 def initialize( annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil ) @annual_revenue = annual_revenue @estimated_worker_count = estimated_worker_count @mcc = mcc @minority_owned_business_designation = minority_owned_business_designation @monthly_estimated_revenue = monthly_estimated_revenue @name = name @product_description = product_description @support_address = support_address @support_email = support_email @support_phone = support_phone @support_url = support_url @url = url end |
Instance Attribute Details
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
2405 2406 2407 |
# File 'lib/stripe/services/account_service.rb', line 2405 def annual_revenue @annual_revenue end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
2407 2408 2409 |
# File 'lib/stripe/services/account_service.rb', line 2407 def estimated_worker_count @estimated_worker_count end |
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.
2409 2410 2411 |
# File 'lib/stripe/services/account_service.rb', line 2409 def mcc @mcc end |
#minority_owned_business_designation ⇒ Object
Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.
2411 2412 2413 |
# File 'lib/stripe/services/account_service.rb', line 2411 def minority_owned_business_designation @minority_owned_business_designation end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
2413 2414 2415 |
# File 'lib/stripe/services/account_service.rb', line 2413 def monthly_estimated_revenue @monthly_estimated_revenue end |
#name ⇒ Object
The customer-facing business name.
2415 2416 2417 |
# File 'lib/stripe/services/account_service.rb', line 2415 def name @name end |
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.
2417 2418 2419 |
# File 'lib/stripe/services/account_service.rb', line 2417 def product_description @product_description end |
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
2419 2420 2421 |
# File 'lib/stripe/services/account_service.rb', line 2419 def support_address @support_address end |
#support_email ⇒ Object
A publicly available email address for sending support issues to.
2421 2422 2423 |
# File 'lib/stripe/services/account_service.rb', line 2421 def support_email @support_email end |
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
2423 2424 2425 |
# File 'lib/stripe/services/account_service.rb', line 2423 def support_phone @support_phone end |
#support_url ⇒ Object
A publicly available website for handling support issues.
2425 2426 2427 |
# File 'lib/stripe/services/account_service.rb', line 2425 def support_url @support_url end |
#url ⇒ Object
The business’s publicly available website.
2427 2428 2429 |
# File 'lib/stripe/services/account_service.rb', line 2427 def url @url end |