Class: Stripe::AccountService::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
# File 'lib/stripe/services/account_service.rb', line 2155

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2131
2132
2133
# File 'lib/stripe/services/account_service.rb', line 2131

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2133
2134
2135
# File 'lib/stripe/services/account_service.rb', line 2133

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2135
2136
2137
# File 'lib/stripe/services/account_service.rb', line 2135

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



2137
2138
2139
# File 'lib/stripe/services/account_service.rb', line 2137

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2139
2140
2141
# File 'lib/stripe/services/account_service.rb', line 2139

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2141
2142
2143
# File 'lib/stripe/services/account_service.rb', line 2141

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2143
2144
2145
# File 'lib/stripe/services/account_service.rb', line 2143

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2145
2146
2147
# File 'lib/stripe/services/account_service.rb', line 2145

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2147
2148
2149
# File 'lib/stripe/services/account_service.rb', line 2147

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2149
2150
2151
# File 'lib/stripe/services/account_service.rb', line 2149

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2151
2152
2153
# File 'lib/stripe/services/account_service.rb', line 2151

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2153
2154
2155
# File 'lib/stripe/services/account_service.rb', line 2153

def url
  @url
end