Class: Stripe::AccountService::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
2424
# File 'lib/stripe/services/account_service.rb', line 2398

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2374
2375
2376
# File 'lib/stripe/services/account_service.rb', line 2374

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2376
2377
2378
# File 'lib/stripe/services/account_service.rb', line 2376

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2378
2379
2380
# File 'lib/stripe/services/account_service.rb', line 2378

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



2380
2381
2382
# File 'lib/stripe/services/account_service.rb', line 2380

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2382
2383
2384
# File 'lib/stripe/services/account_service.rb', line 2382

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2384
2385
2386
# File 'lib/stripe/services/account_service.rb', line 2384

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2386
2387
2388
# File 'lib/stripe/services/account_service.rb', line 2386

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2388
2389
2390
# File 'lib/stripe/services/account_service.rb', line 2388

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2390
2391
2392
# File 'lib/stripe/services/account_service.rb', line 2390

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2392
2393
2394
# File 'lib/stripe/services/account_service.rb', line 2392

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2394
2395
2396
# File 'lib/stripe/services/account_service.rb', line 2394

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2396
2397
2398
# File 'lib/stripe/services/account_service.rb', line 2396

def url
  @url
end