Class: Stripe::AccountService::CreateParams::BusinessProfile
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::BusinessProfile
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress
Instance Attribute Summary collapse
-
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
-
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc.
-
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc).
-
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business.
-
#name ⇒ Object
The customer-facing business name.
-
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business.
-
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
-
#support_email ⇒ Object
A publicly available email address for sending support issues to.
-
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
-
#support_url ⇒ Object
A publicly available website for handling support issues.
-
#url ⇒ Object
The business’s publicly available website.
Instance Method Summary collapse
-
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
constructor
A new instance of BusinessProfile.
Methods inherited from RequestParams
Constructor Details
#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile
Returns a new instance of BusinessProfile.
2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 |
# File 'lib/stripe/services/account_service.rb', line 2392 def initialize( annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil ) @annual_revenue = annual_revenue @estimated_worker_count = estimated_worker_count @mcc = mcc @monthly_estimated_revenue = monthly_estimated_revenue @name = name @product_description = product_description @support_address = support_address @support_email = support_email @support_phone = support_phone @support_url = support_url @url = url end |
Instance Attribute Details
#annual_revenue ⇒ Object
The applicant’s gross annual revenue for its preceding fiscal year.
2370 2371 2372 |
# File 'lib/stripe/services/account_service.rb', line 2370 def annual_revenue @annual_revenue end |
#estimated_worker_count ⇒ Object
An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.
2372 2373 2374 |
# File 'lib/stripe/services/account_service.rb', line 2372 def estimated_worker_count @estimated_worker_count end |
#mcc ⇒ Object
[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.
2374 2375 2376 |
# File 'lib/stripe/services/account_service.rb', line 2374 def mcc @mcc end |
#monthly_estimated_revenue ⇒ Object
An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.
2376 2377 2378 |
# File 'lib/stripe/services/account_service.rb', line 2376 def monthly_estimated_revenue @monthly_estimated_revenue end |
#name ⇒ Object
The customer-facing business name.
2378 2379 2380 |
# File 'lib/stripe/services/account_service.rb', line 2378 def name @name end |
#product_description ⇒ Object
Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.
2380 2381 2382 |
# File 'lib/stripe/services/account_service.rb', line 2380 def product_description @product_description end |
#support_address ⇒ Object
A publicly available mailing address for sending support issues to.
2382 2383 2384 |
# File 'lib/stripe/services/account_service.rb', line 2382 def support_address @support_address end |
#support_email ⇒ Object
A publicly available email address for sending support issues to.
2384 2385 2386 |
# File 'lib/stripe/services/account_service.rb', line 2384 def support_email @support_email end |
#support_phone ⇒ Object
A publicly available phone number to call with support issues.
2386 2387 2388 |
# File 'lib/stripe/services/account_service.rb', line 2386 def support_phone @support_phone end |
#support_url ⇒ Object
A publicly available website for handling support issues.
2388 2389 2390 |
# File 'lib/stripe/services/account_service.rb', line 2388 def support_url @support_url end |
#url ⇒ Object
The business’s publicly available website.
2390 2391 2392 |
# File 'lib/stripe/services/account_service.rb', line 2390 def url @url end |