Class: Stripe::AccountService::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
# File 'lib/stripe/services/account_service.rb', line 2337

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2315
2316
2317
# File 'lib/stripe/services/account_service.rb', line 2315

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2317
2318
2319
# File 'lib/stripe/services/account_service.rb', line 2317

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2319
2320
2321
# File 'lib/stripe/services/account_service.rb', line 2319

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2321
2322
2323
# File 'lib/stripe/services/account_service.rb', line 2321

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2323
2324
2325
# File 'lib/stripe/services/account_service.rb', line 2323

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2325
2326
2327
# File 'lib/stripe/services/account_service.rb', line 2325

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2327
2328
2329
# File 'lib/stripe/services/account_service.rb', line 2327

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2329
2330
2331
# File 'lib/stripe/services/account_service.rb', line 2329

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2331
2332
2333
# File 'lib/stripe/services/account_service.rb', line 2331

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2333
2334
2335
# File 'lib/stripe/services/account_service.rb', line 2333

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2335
2336
2337
# File 'lib/stripe/services/account_service.rb', line 2335

def url
  @url
end