Class: Stripe::AccountService::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
# File 'lib/stripe/services/account_service.rb', line 2292

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2270
2271
2272
# File 'lib/stripe/services/account_service.rb', line 2270

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2272
2273
2274
# File 'lib/stripe/services/account_service.rb', line 2272

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2274
2275
2276
# File 'lib/stripe/services/account_service.rb', line 2274

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2276
2277
2278
# File 'lib/stripe/services/account_service.rb', line 2276

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2278
2279
2280
# File 'lib/stripe/services/account_service.rb', line 2278

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2280
2281
2282
# File 'lib/stripe/services/account_service.rb', line 2280

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2282
2283
2284
# File 'lib/stripe/services/account_service.rb', line 2282

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2284
2285
2286
# File 'lib/stripe/services/account_service.rb', line 2284

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2286
2287
2288
# File 'lib/stripe/services/account_service.rb', line 2286

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2288
2289
2290
# File 'lib/stripe/services/account_service.rb', line 2288

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2290
2291
2292
# File 'lib/stripe/services/account_service.rb', line 2290

def url
  @url
end