Class: Stripe::AccountService::CreateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



2570
2571
2572
2573
2574
2575
2576
2577
2578
2579
2580
2581
2582
2583
2584
2585
2586
2587
2588
2589
2590
2591
2592
2593
2594
# File 'lib/stripe/services/account_service.rb', line 2570

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



2538
2539
2540
# File 'lib/stripe/services/account_service.rb', line 2538

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



2541
2542
2543
# File 'lib/stripe/services/account_service.rb', line 2541

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



2544
2545
2546
# File 'lib/stripe/services/account_service.rb', line 2544

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



2547
2548
2549
# File 'lib/stripe/services/account_service.rb', line 2547

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



2550
2551
2552
# File 'lib/stripe/services/account_service.rb', line 2550

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



2553
2554
2555
# File 'lib/stripe/services/account_service.rb', line 2553

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



2556
2557
2558
# File 'lib/stripe/services/account_service.rb', line 2556

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



2559
2560
2561
# File 'lib/stripe/services/account_service.rb', line 2559

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



2562
2563
2564
# File 'lib/stripe/services/account_service.rb', line 2562

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



2565
2566
2567
# File 'lib/stripe/services/account_service.rb', line 2565

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



2568
2569
2570
# File 'lib/stripe/services/account_service.rb', line 2568

def url
  @url
end