Class: Stripe::AccountService::CreateParams::BusinessProfile::AnnualRevenue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::BusinessProfile::AnnualRevenue
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer representing the amount in the [smallest currency unit](/currencies#zero-decimal).
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
constructor
A new instance of AnnualRevenue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, fiscal_year_end: nil) ⇒ AnnualRevenue
Returns a new instance of AnnualRevenue.
2220 2221 2222 2223 2224 |
# File 'lib/stripe/services/account_service.rb', line 2220 def initialize(amount: nil, currency: nil, fiscal_year_end: nil) @amount = amount @currency = currency @fiscal_year_end = fiscal_year_end end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer representing the amount in the [smallest currency unit](/currencies#zero-decimal).
2214 2215 2216 |
# File 'lib/stripe/services/account_service.rb', line 2214 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2216 2217 2218 |
# File 'lib/stripe/services/account_service.rb', line 2216 def currency @currency end |
#fiscal_year_end ⇒ Object
The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
2218 2219 2220 |
# File 'lib/stripe/services/account_service.rb', line 2218 def fiscal_year_end @fiscal_year_end end |