Class: Stripe::AccountService::CreateParams::Capabilities::IdBankTransferPaymentsBca
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Capabilities::IdBankTransferPaymentsBca
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested.
Instance Method Summary collapse
-
#initialize(requested: nil) ⇒ IdBankTransferPaymentsBca
constructor
A new instance of IdBankTransferPaymentsBca.
Methods inherited from RequestParams
Constructor Details
#initialize(requested: nil) ⇒ IdBankTransferPaymentsBca
Returns a new instance of IdBankTransferPaymentsBca.
2640 2641 2642 |
# File 'lib/stripe/services/account_service.rb', line 2640 def initialize(requested: nil) @requested = requested end |
Instance Attribute Details
#requested ⇒ Object
Passing true requests the capability for the account, if it is not already requested. A requested capability may not immediately become active. Any requirements to activate the capability are returned in the ‘requirements` arrays.
2638 2639 2640 |
# File 'lib/stripe/services/account_service.rb', line 2638 def requested @requested end |