Class: Stripe::AccountService::CreateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
3274
3275
3276
3277
3278
3279
3280
3281
3282
3283
3284
3285
3286
3287
3288
3289
3290
3291
3292
3293
3294
3295
# File 'lib/stripe/services/account_service.rb', line 3249

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



3205
3206
3207
# File 'lib/stripe/services/account_service.rb', line 3205

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



3207
3208
3209
# File 'lib/stripe/services/account_service.rb', line 3207

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



3209
3210
3211
# File 'lib/stripe/services/account_service.rb', line 3209

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



3211
3212
3213
# File 'lib/stripe/services/account_service.rb', line 3211

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3213
3214
3215
# File 'lib/stripe/services/account_service.rb', line 3213

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



3215
3216
3217
# File 'lib/stripe/services/account_service.rb', line 3215

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



3217
3218
3219
# File 'lib/stripe/services/account_service.rb', line 3217

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



3219
3220
3221
# File 'lib/stripe/services/account_service.rb', line 3219

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



3221
3222
3223
# File 'lib/stripe/services/account_service.rb', line 3221

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



3223
3224
3225
# File 'lib/stripe/services/account_service.rb', line 3223

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



3225
3226
3227
# File 'lib/stripe/services/account_service.rb', line 3225

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



3227
3228
3229
# File 'lib/stripe/services/account_service.rb', line 3227

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3229
3230
3231
# File 'lib/stripe/services/account_service.rb', line 3229

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



3231
3232
3233
# File 'lib/stripe/services/account_service.rb', line 3231

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



3233
3234
3235
# File 'lib/stripe/services/account_service.rb', line 3233

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



3235
3236
3237
# File 'lib/stripe/services/account_service.rb', line 3235

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



3237
3238
3239
# File 'lib/stripe/services/account_service.rb', line 3237

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



3239
3240
3241
# File 'lib/stripe/services/account_service.rb', line 3239

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



3241
3242
3243
# File 'lib/stripe/services/account_service.rb', line 3241

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



3243
3244
3245
# File 'lib/stripe/services/account_service.rb', line 3243

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



3245
3246
3247
# File 'lib/stripe/services/account_service.rb', line 3245

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



3247
3248
3249
# File 'lib/stripe/services/account_service.rb', line 3247

def verification
  @verification
end