Class: Stripe::AccountService::CreateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
3265
3266
3267
3268
3269
3270
# File 'lib/stripe/services/account_service.rb', line 3224

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



3180
3181
3182
# File 'lib/stripe/services/account_service.rb', line 3180

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



3182
3183
3184
# File 'lib/stripe/services/account_service.rb', line 3182

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



3184
3185
3186
# File 'lib/stripe/services/account_service.rb', line 3184

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



3186
3187
3188
# File 'lib/stripe/services/account_service.rb', line 3186

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3188
3189
3190
# File 'lib/stripe/services/account_service.rb', line 3188

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



3190
3191
3192
# File 'lib/stripe/services/account_service.rb', line 3190

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



3192
3193
3194
# File 'lib/stripe/services/account_service.rb', line 3192

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



3194
3195
3196
# File 'lib/stripe/services/account_service.rb', line 3194

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



3196
3197
3198
# File 'lib/stripe/services/account_service.rb', line 3196

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



3198
3199
3200
# File 'lib/stripe/services/account_service.rb', line 3198

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



3200
3201
3202
# File 'lib/stripe/services/account_service.rb', line 3200

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



3202
3203
3204
# File 'lib/stripe/services/account_service.rb', line 3202

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3204
3205
3206
# File 'lib/stripe/services/account_service.rb', line 3204

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



3206
3207
3208
# File 'lib/stripe/services/account_service.rb', line 3206

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



3208
3209
3210
# File 'lib/stripe/services/account_service.rb', line 3208

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



3210
3211
3212
# File 'lib/stripe/services/account_service.rb', line 3210

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



3212
3213
3214
# File 'lib/stripe/services/account_service.rb', line 3212

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



3214
3215
3216
# File 'lib/stripe/services/account_service.rb', line 3214

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



3216
3217
3218
# File 'lib/stripe/services/account_service.rb', line 3216

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



3218
3219
3220
# File 'lib/stripe/services/account_service.rb', line 3218

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



3220
3221
3222
# File 'lib/stripe/services/account_service.rb', line 3220

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



3222
3223
3224
# File 'lib/stripe/services/account_service.rb', line 3222

def verification
  @verification
end