Class: Stripe::AccountService::CreateParams::Company
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Company
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The company’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
-
#directors_provided ⇒ Object
Whether the company’s directors have been provided.
-
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
-
#executives_provided ⇒ Object
Whether the company’s executives have been provided.
-
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
-
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
-
#name ⇒ Object
The company’s legal name.
-
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
-
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
-
#owners_provided ⇒ Object
Whether the company’s owners have been provided.
-
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
-
#ownership_exemption_reason ⇒ Object
This value is used to determine if a business is exempt from providing ultimate beneficial owners.
-
#phone ⇒ Object
The company’s phone number (used for verification).
-
#registration_date ⇒ Object
Attribute for param field registration_date.
-
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes.
-
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity.
-
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country.
-
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
-
#vat_id ⇒ Object
The VAT number of the company.
-
#verification ⇒ Object
Information on the verification state of the company.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company
Returns a new instance of Company.
3668 3669 3670 3671 3672 3673 3674 3675 3676 3677 3678 3679 3680 3681 3682 3683 3684 3685 3686 3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 3711 3712 3713 3714 |
# File 'lib/stripe/services/account_service.rb', line 3668 def initialize( address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @directors_provided = directors_provided @directorship_declaration = directorship_declaration @executives_provided = executives_provided @export_license_id = export_license_id @export_purpose_code = export_purpose_code @name = name @name_kana = name_kana @name_kanji = name_kanji @owners_provided = owners_provided @ownership_declaration = ownership_declaration @ownership_exemption_reason = ownership_exemption_reason @phone = phone @registration_date = registration_date @registration_number = registration_number @structure = structure @tax_id = tax_id @tax_id_registrar = tax_id_registrar @vat_id = vat_id @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The company’s primary address.
3624 3625 3626 |
# File 'lib/stripe/services/account_service.rb', line 3624 def address @address end |
#address_kana ⇒ Object
The Kana variation of the company’s primary address (Japan only).
3626 3627 3628 |
# File 'lib/stripe/services/account_service.rb', line 3626 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the company’s primary address (Japan only).
3628 3629 3630 |
# File 'lib/stripe/services/account_service.rb', line 3628 def address_kanji @address_kanji end |
#directors_provided ⇒ Object
Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.
3630 3631 3632 |
# File 'lib/stripe/services/account_service.rb', line 3630 def directors_provided @directors_provided end |
#directorship_declaration ⇒ Object
This hash is used to attest that the directors information provided to Stripe is both current and correct.
3632 3633 3634 |
# File 'lib/stripe/services/account_service.rb', line 3632 def directorship_declaration @directorship_declaration end |
#executives_provided ⇒ Object
Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.
3634 3635 3636 |
# File 'lib/stripe/services/account_service.rb', line 3634 def executives_provided @executives_provided end |
#export_license_id ⇒ Object
The export license ID number of the company, also referred as Import Export Code (India only).
3636 3637 3638 |
# File 'lib/stripe/services/account_service.rb', line 3636 def export_license_id @export_license_id end |
#export_purpose_code ⇒ Object
The purpose code to use for export transactions (India only).
3638 3639 3640 |
# File 'lib/stripe/services/account_service.rb', line 3638 def export_purpose_code @export_purpose_code end |
#name ⇒ Object
The company’s legal name.
3640 3641 3642 |
# File 'lib/stripe/services/account_service.rb', line 3640 def name @name end |
#name_kana ⇒ Object
The Kana variation of the company’s legal name (Japan only).
3642 3643 3644 |
# File 'lib/stripe/services/account_service.rb', line 3642 def name_kana @name_kana end |
#name_kanji ⇒ Object
The Kanji variation of the company’s legal name (Japan only).
3644 3645 3646 |
# File 'lib/stripe/services/account_service.rb', line 3644 def name_kanji @name_kanji end |
#owners_provided ⇒ Object
Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.
3646 3647 3648 |
# File 'lib/stripe/services/account_service.rb', line 3646 def owners_provided @owners_provided end |
#ownership_declaration ⇒ Object
This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
3648 3649 3650 |
# File 'lib/stripe/services/account_service.rb', line 3648 def ownership_declaration @ownership_declaration end |
#ownership_exemption_reason ⇒ Object
This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.
3650 3651 3652 |
# File 'lib/stripe/services/account_service.rb', line 3650 def ownership_exemption_reason @ownership_exemption_reason end |
#phone ⇒ Object
The company’s phone number (used for verification).
3652 3653 3654 |
# File 'lib/stripe/services/account_service.rb', line 3652 def phone @phone end |
#registration_date ⇒ Object
Attribute for param field registration_date
3654 3655 3656 |
# File 'lib/stripe/services/account_service.rb', line 3654 def registration_date @registration_date end |
#registration_number ⇒ Object
The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).
3656 3657 3658 |
# File 'lib/stripe/services/account_service.rb', line 3656 def registration_number @registration_number end |
#structure ⇒ Object
The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.
3658 3659 3660 |
# File 'lib/stripe/services/account_service.rb', line 3658 def structure @structure end |
#tax_id ⇒ Object
The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)
3660 3661 3662 |
# File 'lib/stripe/services/account_service.rb', line 3660 def tax_id @tax_id end |
#tax_id_registrar ⇒ Object
The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).
3662 3663 3664 |
# File 'lib/stripe/services/account_service.rb', line 3662 def tax_id_registrar @tax_id_registrar end |
#vat_id ⇒ Object
The VAT number of the company.
3664 3665 3666 |
# File 'lib/stripe/services/account_service.rb', line 3664 def vat_id @vat_id end |
#verification ⇒ Object
Information on the verification state of the company.
3666 3667 3668 |
# File 'lib/stripe/services/account_service.rb', line 3666 def verification @verification end |