Class: Stripe::AccountService::CreateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
# File 'lib/stripe/services/account_service.rb', line 3517

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



3475
3476
3477
# File 'lib/stripe/services/account_service.rb', line 3475

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



3477
3478
3479
# File 'lib/stripe/services/account_service.rb', line 3477

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



3479
3480
3481
# File 'lib/stripe/services/account_service.rb', line 3479

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



3481
3482
3483
# File 'lib/stripe/services/account_service.rb', line 3481

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



3483
3484
3485
# File 'lib/stripe/services/account_service.rb', line 3483

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



3485
3486
3487
# File 'lib/stripe/services/account_service.rb', line 3485

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



3487
3488
3489
# File 'lib/stripe/services/account_service.rb', line 3487

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



3489
3490
3491
# File 'lib/stripe/services/account_service.rb', line 3489

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



3491
3492
3493
# File 'lib/stripe/services/account_service.rb', line 3491

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



3493
3494
3495
# File 'lib/stripe/services/account_service.rb', line 3493

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



3495
3496
3497
# File 'lib/stripe/services/account_service.rb', line 3495

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



3497
3498
3499
# File 'lib/stripe/services/account_service.rb', line 3497

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3499
3500
3501
# File 'lib/stripe/services/account_service.rb', line 3499

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

Attribute for param field ownership_exemption_reason



3501
3502
3503
# File 'lib/stripe/services/account_service.rb', line 3501

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



3503
3504
3505
# File 'lib/stripe/services/account_service.rb', line 3503

def phone
  @phone
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



3505
3506
3507
# File 'lib/stripe/services/account_service.rb', line 3505

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



3507
3508
3509
# File 'lib/stripe/services/account_service.rb', line 3507

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



3509
3510
3511
# File 'lib/stripe/services/account_service.rb', line 3509

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



3511
3512
3513
# File 'lib/stripe/services/account_service.rb', line 3511

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



3513
3514
3515
# File 'lib/stripe/services/account_service.rb', line 3513

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



3515
3516
3517
# File 'lib/stripe/services/account_service.rb', line 3515

def verification
  @verification
end