Class: Stripe::AccountService::CreateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, OwnershipDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



3442
3443
3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
3471
3472
3473
3474
3475
3476
3477
3478
3479
3480
3481
3482
3483
3484
# File 'lib/stripe/services/account_service.rb', line 3442

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



3402
3403
3404
# File 'lib/stripe/services/account_service.rb', line 3402

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



3404
3405
3406
# File 'lib/stripe/services/account_service.rb', line 3404

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



3406
3407
3408
# File 'lib/stripe/services/account_service.rb', line 3406

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



3408
3409
3410
# File 'lib/stripe/services/account_service.rb', line 3408

def directors_provided
  @directors_provided
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



3410
3411
3412
# File 'lib/stripe/services/account_service.rb', line 3410

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



3412
3413
3414
# File 'lib/stripe/services/account_service.rb', line 3412

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



3414
3415
3416
# File 'lib/stripe/services/account_service.rb', line 3414

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



3416
3417
3418
# File 'lib/stripe/services/account_service.rb', line 3416

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



3418
3419
3420
# File 'lib/stripe/services/account_service.rb', line 3418

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



3420
3421
3422
# File 'lib/stripe/services/account_service.rb', line 3420

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



3422
3423
3424
# File 'lib/stripe/services/account_service.rb', line 3422

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3424
3425
3426
# File 'lib/stripe/services/account_service.rb', line 3424

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

Attribute for param field ownership_exemption_reason



3426
3427
3428
# File 'lib/stripe/services/account_service.rb', line 3426

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



3428
3429
3430
# File 'lib/stripe/services/account_service.rb', line 3428

def phone
  @phone
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



3430
3431
3432
# File 'lib/stripe/services/account_service.rb', line 3430

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



3432
3433
3434
# File 'lib/stripe/services/account_service.rb', line 3432

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



3434
3435
3436
# File 'lib/stripe/services/account_service.rb', line 3434

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



3436
3437
3438
# File 'lib/stripe/services/account_service.rb', line 3436

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



3438
3439
3440
# File 'lib/stripe/services/account_service.rb', line 3438

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



3440
3441
3442
# File 'lib/stripe/services/account_service.rb', line 3440

def verification
  @verification
end