Class: Stripe::AccountService::CreateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, OwnershipDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
3855
3856
3857
3858
3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
3871
3872
3873
3874
3875
3876
3877
# File 'lib/stripe/services/account_service.rb', line 3837

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  phone: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @phone = phone
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



3781
3782
3783
# File 'lib/stripe/services/account_service.rb', line 3781

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



3784
3785
3786
# File 'lib/stripe/services/account_service.rb', line 3784

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



3787
3788
3789
# File 'lib/stripe/services/account_service.rb', line 3787

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



3790
3791
3792
# File 'lib/stripe/services/account_service.rb', line 3790

def directors_provided
  @directors_provided
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



3793
3794
3795
# File 'lib/stripe/services/account_service.rb', line 3793

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



3796
3797
3798
# File 'lib/stripe/services/account_service.rb', line 3796

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



3799
3800
3801
# File 'lib/stripe/services/account_service.rb', line 3799

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



3802
3803
3804
# File 'lib/stripe/services/account_service.rb', line 3802

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



3805
3806
3807
# File 'lib/stripe/services/account_service.rb', line 3805

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



3808
3809
3810
# File 'lib/stripe/services/account_service.rb', line 3808

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



3811
3812
3813
# File 'lib/stripe/services/account_service.rb', line 3811

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



3814
3815
3816
# File 'lib/stripe/services/account_service.rb', line 3814

def ownership_declaration
  @ownership_declaration
end

#phoneObject

The company’s phone number (used for verification).



3817
3818
3819
# File 'lib/stripe/services/account_service.rb', line 3817

def phone
  @phone
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



3820
3821
3822
# File 'lib/stripe/services/account_service.rb', line 3820

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



3823
3824
3825
# File 'lib/stripe/services/account_service.rb', line 3823

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



3826
3827
3828
# File 'lib/stripe/services/account_service.rb', line 3826

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



3829
3830
3831
# File 'lib/stripe/services/account_service.rb', line 3829

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



3832
3833
3834
# File 'lib/stripe/services/account_service.rb', line 3832

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



3835
3836
3837
# File 'lib/stripe/services/account_service.rb', line 3835

def verification
  @verification
end