Class: Stripe::AccountService::CreateParams::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
3548 3549 3550 3551 3552 |
# File 'lib/stripe/services/account_service.rb', line 3548 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
3542 3543 3544 |
# File 'lib/stripe/services/account_service.rb', line 3542 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
3544 3545 3546 |
# File 'lib/stripe/services/account_service.rb', line 3544 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
3546 3547 3548 |
# File 'lib/stripe/services/account_service.rb', line 3546 def user_agent @user_agent end |