Class: Stripe::AccountService::CreateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



3540
3541
3542
3543
3544
# File 'lib/stripe/services/account_service.rb', line 3540

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



3534
3535
3536
# File 'lib/stripe/services/account_service.rb', line 3534

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



3536
3537
3538
# File 'lib/stripe/services/account_service.rb', line 3536

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



3538
3539
3540
# File 'lib/stripe/services/account_service.rb', line 3538

def user_agent
  @user_agent
end