Class: Stripe::AccountService::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3138
3139
3140
3141
3142
# File 'lib/stripe/services/account_service.rb', line 3138

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



3132
3133
3134
# File 'lib/stripe/services/account_service.rb', line 3132

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3134
3135
3136
# File 'lib/stripe/services/account_service.rb', line 3134

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3136
3137
3138
# File 'lib/stripe/services/account_service.rb', line 3136

def user_agent
  @user_agent
end