Class: Stripe::AccountService::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3582
3583
3584
3585
3586
# File 'lib/stripe/services/account_service.rb', line 3582

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



3576
3577
3578
# File 'lib/stripe/services/account_service.rb', line 3576

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3578
3579
3580
# File 'lib/stripe/services/account_service.rb', line 3578

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3580
3581
3582
# File 'lib/stripe/services/account_service.rb', line 3580

def user_agent
  @user_agent
end