Class: Stripe::AccountService::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3111
3112
3113
3114
3115
# File 'lib/stripe/services/account_service.rb', line 3111

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



3105
3106
3107
# File 'lib/stripe/services/account_service.rb', line 3105

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3107
3108
3109
# File 'lib/stripe/services/account_service.rb', line 3107

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3109
3110
3111
# File 'lib/stripe/services/account_service.rb', line 3109

def user_agent
  @user_agent
end