Class: Stripe::AccountService::CreateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



3448
3449
3450
3451
3452
# File 'lib/stripe/services/account_service.rb', line 3448

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



3442
3443
3444
# File 'lib/stripe/services/account_service.rb', line 3442

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



3444
3445
3446
# File 'lib/stripe/services/account_service.rb', line 3444

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



3446
3447
3448
# File 'lib/stripe/services/account_service.rb', line 3446

def user_agent
  @user_agent
end