Class: Stripe::AccountService::CreateParams::Company::OwnershipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Company::OwnershipDeclaration
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
constructor
A new instance of OwnershipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
Returns a new instance of OwnershipDeclaration.
3448 3449 3450 3451 3452 |
# File 'lib/stripe/services/account_service.rb', line 3448 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
3442 3443 3444 |
# File 'lib/stripe/services/account_service.rb', line 3442 def date @date end |
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
3444 3445 3446 |
# File 'lib/stripe/services/account_service.rb', line 3444 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
3446 3447 3448 |
# File 'lib/stripe/services/account_service.rb', line 3446 def user_agent @user_agent end |