Class: Stripe::AccountService::CreateParams::Company::OwnershipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Company::OwnershipDeclaration
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
constructor
A new instance of OwnershipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
Returns a new instance of OwnershipDeclaration.
3375 3376 3377 3378 3379 |
# File 'lib/stripe/services/account_service.rb', line 3375 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
3369 3370 3371 |
# File 'lib/stripe/services/account_service.rb', line 3369 def date @date end |
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
3371 3372 3373 |
# File 'lib/stripe/services/account_service.rb', line 3371 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
3373 3374 3375 |
# File 'lib/stripe/services/account_service.rb', line 3373 def user_agent @user_agent end |