Class: Stripe::AccountService::CreateParams::Controller

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



3806
3807
3808
3809
3810
3811
3812
3813
3814
3815
3816
3817
3818
3819
3820
# File 'lib/stripe/services/account_service.rb', line 3806

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



3794
3795
3796
# File 'lib/stripe/services/account_service.rb', line 3794

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



3796
3797
3798
# File 'lib/stripe/services/account_service.rb', line 3796

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



3798
3799
3800
# File 'lib/stripe/services/account_service.rb', line 3798

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



3800
3801
3802
# File 'lib/stripe/services/account_service.rb', line 3800

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



3802
3803
3804
# File 'lib/stripe/services/account_service.rb', line 3802

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



3804
3805
3806
# File 'lib/stripe/services/account_service.rb', line 3804

def stripe_dashboard
  @stripe_dashboard
end