Class: Stripe::AccountService::CreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Controller
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
Constructor Details
#initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
3309 3310 3311 3312 3313 3314 |
# File 'lib/stripe/services/account_service.rb', line 3309 def initialize(fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
3301 3302 3303 |
# File 'lib/stripe/services/account_service.rb', line 3301 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
3303 3304 3305 |
# File 'lib/stripe/services/account_service.rb', line 3303 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
3305 3306 3307 |
# File 'lib/stripe/services/account_service.rb', line 3305 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
3307 3308 3309 |
# File 'lib/stripe/services/account_service.rb', line 3307 def stripe_dashboard @stripe_dashboard end |