Class: Stripe::AccountService::CreateParams::Controller

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



3781
3782
3783
3784
3785
3786
3787
3788
3789
3790
3791
3792
3793
3794
3795
# File 'lib/stripe/services/account_service.rb', line 3781

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



3769
3770
3771
# File 'lib/stripe/services/account_service.rb', line 3769

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



3771
3772
3773
# File 'lib/stripe/services/account_service.rb', line 3771

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



3773
3774
3775
# File 'lib/stripe/services/account_service.rb', line 3773

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



3775
3776
3777
# File 'lib/stripe/services/account_service.rb', line 3775

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



3777
3778
3779
# File 'lib/stripe/services/account_service.rb', line 3777

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



3779
3780
3781
# File 'lib/stripe/services/account_service.rb', line 3779

def stripe_dashboard
  @stripe_dashboard
end