Class: Stripe::AccountService::CreateParams::Controller
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Controller
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Application, Dashboard, Fees, Losses, StripeDashboard
Instance Attribute Summary collapse
-
#application ⇒ Object
A hash of configuration describing the Connect application that controls the account.
-
#dashboard ⇒ Object
Properties of the account’s dashboard.
-
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
-
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
-
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change.
-
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
Instance Method Summary collapse
-
#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
constructor
A new instance of Controller.
Methods inherited from RequestParams
Constructor Details
#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller
Returns a new instance of Controller.
3743 3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 |
# File 'lib/stripe/services/account_service.rb', line 3743 def initialize( application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil ) @application = application @dashboard = dashboard @fees = fees @losses = losses @requirement_collection = requirement_collection @stripe_dashboard = stripe_dashboard end |
Instance Attribute Details
#application ⇒ Object
A hash of configuration describing the Connect application that controls the account.
3731 3732 3733 |
# File 'lib/stripe/services/account_service.rb', line 3731 def application @application end |
#dashboard ⇒ Object
Properties of the account’s dashboard.
3733 3734 3735 |
# File 'lib/stripe/services/account_service.rb', line 3733 def dashboard @dashboard end |
#fees ⇒ Object
A hash of configuration for who pays Stripe fees for product usage on this account.
3735 3736 3737 |
# File 'lib/stripe/services/account_service.rb', line 3735 def fees @fees end |
#losses ⇒ Object
A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.
3737 3738 3739 |
# File 'lib/stripe/services/account_service.rb', line 3737 def losses @losses end |
#requirement_collection ⇒ Object
A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.
3739 3740 3741 |
# File 'lib/stripe/services/account_service.rb', line 3739 def requirement_collection @requirement_collection end |
#stripe_dashboard ⇒ Object
A hash of configuration for Stripe-hosted dashboards.
3741 3742 3743 |
# File 'lib/stripe/services/account_service.rb', line 3741 def stripe_dashboard @stripe_dashboard end |