Class: Stripe::AccountService::CreateParams::Controller

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'lib/stripe/services/account_service.rb', line 3551

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



3539
3540
3541
# File 'lib/stripe/services/account_service.rb', line 3539

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



3541
3542
3543
# File 'lib/stripe/services/account_service.rb', line 3541

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



3543
3544
3545
# File 'lib/stripe/services/account_service.rb', line 3543

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



3545
3546
3547
# File 'lib/stripe/services/account_service.rb', line 3545

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



3547
3548
3549
# File 'lib/stripe/services/account_service.rb', line 3547

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



3549
3550
3551
# File 'lib/stripe/services/account_service.rb', line 3549

def stripe_dashboard
  @stripe_dashboard
end