Class: Stripe::AccountService::CreateParams::Controller

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Application, Dashboard, Fees, Losses, StripeDashboard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, dashboard: nil, fees: nil, losses: nil, requirement_collection: nil, stripe_dashboard: nil) ⇒ Controller

Returns a new instance of Controller.



3628
3629
3630
3631
3632
3633
3634
3635
3636
3637
3638
3639
3640
3641
3642
# File 'lib/stripe/services/account_service.rb', line 3628

def initialize(
  application: nil,
  dashboard: nil,
  fees: nil,
  losses: nil,
  requirement_collection: nil,
  stripe_dashboard: nil
)
  @application = application
  @dashboard = dashboard
  @fees = fees
  @losses = losses
  @requirement_collection = requirement_collection
  @stripe_dashboard = stripe_dashboard
end

Instance Attribute Details

#applicationObject

A hash of configuration describing the Connect application that controls the account.



3616
3617
3618
# File 'lib/stripe/services/account_service.rb', line 3616

def application
  @application
end

#dashboardObject

Properties of the account’s dashboard.



3618
3619
3620
# File 'lib/stripe/services/account_service.rb', line 3618

def dashboard
  @dashboard
end

#feesObject

A hash of configuration for who pays Stripe fees for product usage on this account.



3620
3621
3622
# File 'lib/stripe/services/account_service.rb', line 3620

def fees
  @fees
end

#lossesObject

A hash of configuration for products that have negative balance liability, and whether Stripe or a Connect application is responsible for them.



3622
3623
3624
# File 'lib/stripe/services/account_service.rb', line 3622

def losses
  @losses
end

#requirement_collectionObject

A value indicating responsibility for collecting updated information when requirements on the account are due or change. Defaults to ‘stripe`.



3624
3625
3626
# File 'lib/stripe/services/account_service.rb', line 3624

def requirement_collection
  @requirement_collection
end

#stripe_dashboardObject

A hash of configuration for Stripe-hosted dashboards.



3626
3627
3628
# File 'lib/stripe/services/account_service.rb', line 3626

def stripe_dashboard
  @stripe_dashboard
end