Class: Stripe::AccountService::CreateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Individual
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 3827 3828 3829 3830 |
# File 'lib/stripe/services/account_service.rb', line 3782 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
3736 3737 3738 |
# File 'lib/stripe/services/account_service.rb', line 3736 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
3738 3739 3740 |
# File 'lib/stripe/services/account_service.rb', line 3738 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
3740 3741 3742 |
# File 'lib/stripe/services/account_service.rb', line 3740 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
3742 3743 3744 |
# File 'lib/stripe/services/account_service.rb', line 3742 def dob @dob end |
#email ⇒ Object
The individual’s email address.
3744 3745 3746 |
# File 'lib/stripe/services/account_service.rb', line 3744 def email @email end |
#first_name ⇒ Object
The individual’s first name.
3746 3747 3748 |
# File 'lib/stripe/services/account_service.rb', line 3746 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
3748 3749 3750 |
# File 'lib/stripe/services/account_service.rb', line 3748 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
3750 3751 3752 |
# File 'lib/stripe/services/account_service.rb', line 3750 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
3752 3753 3754 |
# File 'lib/stripe/services/account_service.rb', line 3752 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
3754 3755 3756 |
# File 'lib/stripe/services/account_service.rb', line 3754 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
3756 3757 3758 |
# File 'lib/stripe/services/account_service.rb', line 3756 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
3758 3759 3760 |
# File 'lib/stripe/services/account_service.rb', line 3758 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
3760 3761 3762 |
# File 'lib/stripe/services/account_service.rb', line 3760 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
3762 3763 3764 |
# File 'lib/stripe/services/account_service.rb', line 3762 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
3764 3765 3766 |
# File 'lib/stripe/services/account_service.rb', line 3764 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
3766 3767 3768 |
# File 'lib/stripe/services/account_service.rb', line 3766 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3768 3769 3770 |
# File 'lib/stripe/services/account_service.rb', line 3768 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
3770 3771 3772 |
# File 'lib/stripe/services/account_service.rb', line 3770 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
3772 3773 3774 |
# File 'lib/stripe/services/account_service.rb', line 3772 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
3774 3775 3776 |
# File 'lib/stripe/services/account_service.rb', line 3774 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
3776 3777 3778 |
# File 'lib/stripe/services/account_service.rb', line 3776 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
3778 3779 3780 |
# File 'lib/stripe/services/account_service.rb', line 3778 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
3780 3781 3782 |
# File 'lib/stripe/services/account_service.rb', line 3780 def verification @verification end |