Class: Stripe::AccountService::CreateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
4281
4282
4283
4284
4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
4303
4304
4305
4306
4307
4308
4309
4310
4311
# File 'lib/stripe/services/account_service.rb', line 4263

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



4217
4218
4219
# File 'lib/stripe/services/account_service.rb', line 4217

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



4219
4220
4221
# File 'lib/stripe/services/account_service.rb', line 4219

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



4221
4222
4223
# File 'lib/stripe/services/account_service.rb', line 4221

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



4223
4224
4225
# File 'lib/stripe/services/account_service.rb', line 4223

def dob
  @dob
end

#emailObject

The individual’s email address.



4225
4226
4227
# File 'lib/stripe/services/account_service.rb', line 4225

def email
  @email
end

#first_nameObject

The individual’s first name.



4227
4228
4229
# File 'lib/stripe/services/account_service.rb', line 4227

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



4229
4230
4231
# File 'lib/stripe/services/account_service.rb', line 4229

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



4231
4232
4233
# File 'lib/stripe/services/account_service.rb', line 4231

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



4233
4234
4235
# File 'lib/stripe/services/account_service.rb', line 4233

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



4235
4236
4237
# File 'lib/stripe/services/account_service.rb', line 4235

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4237
4238
4239
# File 'lib/stripe/services/account_service.rb', line 4237

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4239
4240
4241
# File 'lib/stripe/services/account_service.rb', line 4239

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



4241
4242
4243
# File 'lib/stripe/services/account_service.rb', line 4241

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4243
4244
4245
# File 'lib/stripe/services/account_service.rb', line 4243

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4245
4246
4247
# File 'lib/stripe/services/account_service.rb', line 4245

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4247
4248
4249
# File 'lib/stripe/services/account_service.rb', line 4247

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4249
4250
4251
# File 'lib/stripe/services/account_service.rb', line 4249

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4251
4252
4253
# File 'lib/stripe/services/account_service.rb', line 4251

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4253
4254
4255
# File 'lib/stripe/services/account_service.rb', line 4253

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4255
4256
4257
# File 'lib/stripe/services/account_service.rb', line 4255

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4257
4258
4259
# File 'lib/stripe/services/account_service.rb', line 4257

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4259
4260
4261
# File 'lib/stripe/services/account_service.rb', line 4259

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4261
4262
4263
# File 'lib/stripe/services/account_service.rb', line 4261

def verification
  @verification
end