Class: Stripe::AccountService::CreateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
4212
4213
4214
4215
4216
4217
4218
4219
4220
4221
4222
4223
4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
# File 'lib/stripe/services/account_service.rb', line 4198

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



4152
4153
4154
# File 'lib/stripe/services/account_service.rb', line 4152

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



4154
4155
4156
# File 'lib/stripe/services/account_service.rb', line 4154

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



4156
4157
4158
# File 'lib/stripe/services/account_service.rb', line 4156

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



4158
4159
4160
# File 'lib/stripe/services/account_service.rb', line 4158

def dob
  @dob
end

#emailObject

The individual’s email address.



4160
4161
4162
# File 'lib/stripe/services/account_service.rb', line 4160

def email
  @email
end

#first_nameObject

The individual’s first name.



4162
4163
4164
# File 'lib/stripe/services/account_service.rb', line 4162

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



4164
4165
4166
# File 'lib/stripe/services/account_service.rb', line 4164

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



4166
4167
4168
# File 'lib/stripe/services/account_service.rb', line 4166

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



4168
4169
4170
# File 'lib/stripe/services/account_service.rb', line 4168

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



4170
4171
4172
# File 'lib/stripe/services/account_service.rb', line 4170

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4172
4173
4174
# File 'lib/stripe/services/account_service.rb', line 4172

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4174
4175
4176
# File 'lib/stripe/services/account_service.rb', line 4174

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



4176
4177
4178
# File 'lib/stripe/services/account_service.rb', line 4176

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4178
4179
4180
# File 'lib/stripe/services/account_service.rb', line 4178

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4180
4181
4182
# File 'lib/stripe/services/account_service.rb', line 4180

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4182
4183
4184
# File 'lib/stripe/services/account_service.rb', line 4182

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4184
4185
4186
# File 'lib/stripe/services/account_service.rb', line 4184

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4186
4187
4188
# File 'lib/stripe/services/account_service.rb', line 4186

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4188
4189
4190
# File 'lib/stripe/services/account_service.rb', line 4188

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4190
4191
4192
# File 'lib/stripe/services/account_service.rb', line 4190

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4192
4193
4194
# File 'lib/stripe/services/account_service.rb', line 4192

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4194
4195
4196
# File 'lib/stripe/services/account_service.rb', line 4194

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4196
4197
4198
# File 'lib/stripe/services/account_service.rb', line 4196

def verification
  @verification
end