Class: Stripe::AccountService::CreateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Individual
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
3717 3718 3719 3720 3721 3722 3723 3724 3725 3726 3727 3728 3729 3730 3731 3732 3733 3734 3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 3750 3751 3752 3753 3754 3755 3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/stripe/services/account_service.rb', line 3717 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
3671 3672 3673 |
# File 'lib/stripe/services/account_service.rb', line 3671 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
3673 3674 3675 |
# File 'lib/stripe/services/account_service.rb', line 3673 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
3675 3676 3677 |
# File 'lib/stripe/services/account_service.rb', line 3675 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
3677 3678 3679 |
# File 'lib/stripe/services/account_service.rb', line 3677 def dob @dob end |
#email ⇒ Object
The individual’s email address.
3679 3680 3681 |
# File 'lib/stripe/services/account_service.rb', line 3679 def email @email end |
#first_name ⇒ Object
The individual’s first name.
3681 3682 3683 |
# File 'lib/stripe/services/account_service.rb', line 3681 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
3683 3684 3685 |
# File 'lib/stripe/services/account_service.rb', line 3683 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
3685 3686 3687 |
# File 'lib/stripe/services/account_service.rb', line 3685 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
3687 3688 3689 |
# File 'lib/stripe/services/account_service.rb', line 3687 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
3689 3690 3691 |
# File 'lib/stripe/services/account_service.rb', line 3689 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
3691 3692 3693 |
# File 'lib/stripe/services/account_service.rb', line 3691 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
3693 3694 3695 |
# File 'lib/stripe/services/account_service.rb', line 3693 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
3695 3696 3697 |
# File 'lib/stripe/services/account_service.rb', line 3695 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
3697 3698 3699 |
# File 'lib/stripe/services/account_service.rb', line 3697 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
3699 3700 3701 |
# File 'lib/stripe/services/account_service.rb', line 3699 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
3701 3702 3703 |
# File 'lib/stripe/services/account_service.rb', line 3701 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3703 3704 3705 |
# File 'lib/stripe/services/account_service.rb', line 3703 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
3705 3706 3707 |
# File 'lib/stripe/services/account_service.rb', line 3705 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
3707 3708 3709 |
# File 'lib/stripe/services/account_service.rb', line 3707 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
3709 3710 3711 |
# File 'lib/stripe/services/account_service.rb', line 3709 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
3711 3712 3713 |
# File 'lib/stripe/services/account_service.rb', line 3711 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
3713 3714 3715 |
# File 'lib/stripe/services/account_service.rb', line 3713 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
3715 3716 3717 |
# File 'lib/stripe/services/account_service.rb', line 3715 def verification @verification end |