Class: Stripe::AccountService::CreateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
3707
3708
3709
3710
3711
3712
3713
3714
3715
3716
3717
3718
3719
3720
3721
3722
3723
3724
3725
3726
3727
3728
3729
3730
3731
3732
3733
3734
3735
3736
3737
3738
3739
3740
# File 'lib/stripe/services/account_service.rb', line 3692

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



3646
3647
3648
# File 'lib/stripe/services/account_service.rb', line 3646

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



3648
3649
3650
# File 'lib/stripe/services/account_service.rb', line 3648

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



3650
3651
3652
# File 'lib/stripe/services/account_service.rb', line 3650

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



3652
3653
3654
# File 'lib/stripe/services/account_service.rb', line 3652

def dob
  @dob
end

#emailObject

The individual’s email address.



3654
3655
3656
# File 'lib/stripe/services/account_service.rb', line 3654

def email
  @email
end

#first_nameObject

The individual’s first name.



3656
3657
3658
# File 'lib/stripe/services/account_service.rb', line 3656

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



3658
3659
3660
# File 'lib/stripe/services/account_service.rb', line 3658

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



3660
3661
3662
# File 'lib/stripe/services/account_service.rb', line 3660

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



3662
3663
3664
# File 'lib/stripe/services/account_service.rb', line 3662

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



3664
3665
3666
# File 'lib/stripe/services/account_service.rb', line 3664

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



3666
3667
3668
# File 'lib/stripe/services/account_service.rb', line 3666

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



3668
3669
3670
# File 'lib/stripe/services/account_service.rb', line 3668

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



3670
3671
3672
# File 'lib/stripe/services/account_service.rb', line 3670

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



3672
3673
3674
# File 'lib/stripe/services/account_service.rb', line 3672

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



3674
3675
3676
# File 'lib/stripe/services/account_service.rb', line 3674

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



3676
3677
3678
# File 'lib/stripe/services/account_service.rb', line 3676

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3678
3679
3680
# File 'lib/stripe/services/account_service.rb', line 3678

def 
  @metadata
end

#phoneObject

The individual’s phone number.



3680
3681
3682
# File 'lib/stripe/services/account_service.rb', line 3680

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



3682
3683
3684
# File 'lib/stripe/services/account_service.rb', line 3682

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



3684
3685
3686
# File 'lib/stripe/services/account_service.rb', line 3684

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



3686
3687
3688
# File 'lib/stripe/services/account_service.rb', line 3686

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



3688
3689
3690
# File 'lib/stripe/services/account_service.rb', line 3688

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



3690
3691
3692
# File 'lib/stripe/services/account_service.rb', line 3690

def verification
  @verification
end