Class: Stripe::AccountService::CreateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4127
4128
4129
4130
4131
4132
4133
4134
4135
4136
4137
4138
4139
4140
4141
4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
4174
4175
# File 'lib/stripe/services/account_service.rb', line 4127

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



4081
4082
4083
# File 'lib/stripe/services/account_service.rb', line 4081

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



4083
4084
4085
# File 'lib/stripe/services/account_service.rb', line 4083

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



4085
4086
4087
# File 'lib/stripe/services/account_service.rb', line 4085

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



4087
4088
4089
# File 'lib/stripe/services/account_service.rb', line 4087

def dob
  @dob
end

#emailObject

The individual’s email address.



4089
4090
4091
# File 'lib/stripe/services/account_service.rb', line 4089

def email
  @email
end

#first_nameObject

The individual’s first name.



4091
4092
4093
# File 'lib/stripe/services/account_service.rb', line 4091

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



4093
4094
4095
# File 'lib/stripe/services/account_service.rb', line 4093

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



4095
4096
4097
# File 'lib/stripe/services/account_service.rb', line 4095

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



4097
4098
4099
# File 'lib/stripe/services/account_service.rb', line 4097

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



4099
4100
4101
# File 'lib/stripe/services/account_service.rb', line 4099

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4101
4102
4103
# File 'lib/stripe/services/account_service.rb', line 4101

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4103
4104
4105
# File 'lib/stripe/services/account_service.rb', line 4103

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



4105
4106
4107
# File 'lib/stripe/services/account_service.rb', line 4105

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4107
4108
4109
# File 'lib/stripe/services/account_service.rb', line 4107

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4109
4110
4111
# File 'lib/stripe/services/account_service.rb', line 4109

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4111
4112
4113
# File 'lib/stripe/services/account_service.rb', line 4111

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4113
4114
4115
# File 'lib/stripe/services/account_service.rb', line 4113

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4115
4116
4117
# File 'lib/stripe/services/account_service.rb', line 4115

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4117
4118
4119
# File 'lib/stripe/services/account_service.rb', line 4117

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4119
4120
4121
# File 'lib/stripe/services/account_service.rb', line 4119

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4121
4122
4123
# File 'lib/stripe/services/account_service.rb', line 4121

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4123
4124
4125
# File 'lib/stripe/services/account_service.rb', line 4123

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4125
4126
4127
# File 'lib/stripe/services/account_service.rb', line 4125

def verification
  @verification
end