Class: Stripe::AccountService::CreateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
4040
4041
4042
4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
# File 'lib/stripe/services/account_service.rb', line 4020

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



3974
3975
3976
# File 'lib/stripe/services/account_service.rb', line 3974

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



3976
3977
3978
# File 'lib/stripe/services/account_service.rb', line 3976

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



3978
3979
3980
# File 'lib/stripe/services/account_service.rb', line 3978

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



3980
3981
3982
# File 'lib/stripe/services/account_service.rb', line 3980

def dob
  @dob
end

#emailObject

The individual’s email address.



3982
3983
3984
# File 'lib/stripe/services/account_service.rb', line 3982

def email
  @email
end

#first_nameObject

The individual’s first name.



3984
3985
3986
# File 'lib/stripe/services/account_service.rb', line 3984

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



3986
3987
3988
# File 'lib/stripe/services/account_service.rb', line 3986

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



3988
3989
3990
# File 'lib/stripe/services/account_service.rb', line 3988

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



3990
3991
3992
# File 'lib/stripe/services/account_service.rb', line 3990

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



3992
3993
3994
# File 'lib/stripe/services/account_service.rb', line 3992

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



3994
3995
3996
# File 'lib/stripe/services/account_service.rb', line 3994

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



3996
3997
3998
# File 'lib/stripe/services/account_service.rb', line 3996

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



3998
3999
4000
# File 'lib/stripe/services/account_service.rb', line 3998

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4000
4001
4002
# File 'lib/stripe/services/account_service.rb', line 4000

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4002
4003
4004
# File 'lib/stripe/services/account_service.rb', line 4002

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4004
4005
4006
# File 'lib/stripe/services/account_service.rb', line 4004

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4006
4007
4008
# File 'lib/stripe/services/account_service.rb', line 4006

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4008
4009
4010
# File 'lib/stripe/services/account_service.rb', line 4008

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4010
4011
4012
# File 'lib/stripe/services/account_service.rb', line 4010

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4012
4013
4014
# File 'lib/stripe/services/account_service.rb', line 4012

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4014
4015
4016
# File 'lib/stripe/services/account_service.rb', line 4014

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4016
4017
4018
# File 'lib/stripe/services/account_service.rb', line 4016

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4018
4019
4020
# File 'lib/stripe/services/account_service.rb', line 4018

def verification
  @verification
end