Class: Stripe::AccountService::CreateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
3950
3951
3952
3953
3954
3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
3967
3968
3969
3970
3971
3972
3973
3974
3975
3976
3977
3978
# File 'lib/stripe/services/account_service.rb', line 3930

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



3884
3885
3886
# File 'lib/stripe/services/account_service.rb', line 3884

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



3886
3887
3888
# File 'lib/stripe/services/account_service.rb', line 3886

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



3888
3889
3890
# File 'lib/stripe/services/account_service.rb', line 3888

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



3890
3891
3892
# File 'lib/stripe/services/account_service.rb', line 3890

def dob
  @dob
end

#emailObject

The individual’s email address.



3892
3893
3894
# File 'lib/stripe/services/account_service.rb', line 3892

def email
  @email
end

#first_nameObject

The individual’s first name.



3894
3895
3896
# File 'lib/stripe/services/account_service.rb', line 3894

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



3896
3897
3898
# File 'lib/stripe/services/account_service.rb', line 3896

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



3898
3899
3900
# File 'lib/stripe/services/account_service.rb', line 3898

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



3900
3901
3902
# File 'lib/stripe/services/account_service.rb', line 3900

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



3902
3903
3904
# File 'lib/stripe/services/account_service.rb', line 3902

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



3904
3905
3906
# File 'lib/stripe/services/account_service.rb', line 3904

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



3906
3907
3908
# File 'lib/stripe/services/account_service.rb', line 3906

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



3908
3909
3910
# File 'lib/stripe/services/account_service.rb', line 3908

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



3910
3911
3912
# File 'lib/stripe/services/account_service.rb', line 3910

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



3912
3913
3914
# File 'lib/stripe/services/account_service.rb', line 3912

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



3914
3915
3916
# File 'lib/stripe/services/account_service.rb', line 3914

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3916
3917
3918
# File 'lib/stripe/services/account_service.rb', line 3916

def 
  @metadata
end

#phoneObject

The individual’s phone number.



3918
3919
3920
# File 'lib/stripe/services/account_service.rb', line 3918

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



3920
3921
3922
# File 'lib/stripe/services/account_service.rb', line 3920

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



3922
3923
3924
# File 'lib/stripe/services/account_service.rb', line 3922

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



3924
3925
3926
# File 'lib/stripe/services/account_service.rb', line 3924

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



3926
3927
3928
# File 'lib/stripe/services/account_service.rb', line 3926

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



3928
3929
3930
# File 'lib/stripe/services/account_service.rb', line 3928

def verification
  @verification
end