Class: Stripe::AccountService::CreateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
4401
4402
4403
4404
4405
4406
4407
4408
4409
4410
4411
4412
4413
4414
4415
4416
4417
4418
4419
4420
4421
4422
4423
4424
4425
4426
4427
4428
4429
4430
4431
4432
4433
4434
4435
4436
4437
# File 'lib/stripe/services/account_service.rb', line 4389

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



4321
4322
4323
# File 'lib/stripe/services/account_service.rb', line 4321

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



4324
4325
4326
# File 'lib/stripe/services/account_service.rb', line 4324

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



4327
4328
4329
# File 'lib/stripe/services/account_service.rb', line 4327

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



4330
4331
4332
# File 'lib/stripe/services/account_service.rb', line 4330

def dob
  @dob
end

#emailObject

The individual’s email address.



4333
4334
4335
# File 'lib/stripe/services/account_service.rb', line 4333

def email
  @email
end

#first_nameObject

The individual’s first name.



4336
4337
4338
# File 'lib/stripe/services/account_service.rb', line 4336

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



4339
4340
4341
# File 'lib/stripe/services/account_service.rb', line 4339

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



4342
4343
4344
# File 'lib/stripe/services/account_service.rb', line 4342

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



4345
4346
4347
# File 'lib/stripe/services/account_service.rb', line 4345

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



4348
4349
4350
# File 'lib/stripe/services/account_service.rb', line 4348

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4351
4352
4353
# File 'lib/stripe/services/account_service.rb', line 4351

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



4354
4355
4356
# File 'lib/stripe/services/account_service.rb', line 4354

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



4357
4358
4359
# File 'lib/stripe/services/account_service.rb', line 4357

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



4360
4361
4362
# File 'lib/stripe/services/account_service.rb', line 4360

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



4363
4364
4365
# File 'lib/stripe/services/account_service.rb', line 4363

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



4366
4367
4368
# File 'lib/stripe/services/account_service.rb', line 4366

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4369
4370
4371
# File 'lib/stripe/services/account_service.rb', line 4369

def 
  @metadata
end

#phoneObject

The individual’s phone number.



4372
4373
4374
# File 'lib/stripe/services/account_service.rb', line 4372

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



4375
4376
4377
# File 'lib/stripe/services/account_service.rb', line 4375

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



4378
4379
4380
# File 'lib/stripe/services/account_service.rb', line 4378

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



4381
4382
4383
# File 'lib/stripe/services/account_service.rb', line 4381

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



4384
4385
4386
# File 'lib/stripe/services/account_service.rb', line 4384

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



4387
4388
4389
# File 'lib/stripe/services/account_service.rb', line 4387

def verification
  @verification
end