Class: Stripe::AccountService::CreateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Individual::Relationship
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 |
# File 'lib/stripe/services/account_service.rb', line 4102 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
4092 4093 4094 |
# File 'lib/stripe/services/account_service.rb', line 4092 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
4094 4095 4096 |
# File 'lib/stripe/services/account_service.rb', line 4094 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
4096 4097 4098 |
# File 'lib/stripe/services/account_service.rb', line 4096 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
4098 4099 4100 |
# File 'lib/stripe/services/account_service.rb', line 4098 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
4100 4101 4102 |
# File 'lib/stripe/services/account_service.rb', line 4100 def title @title end |