Class: Stripe::AccountService::CreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



3621
3622
3623
3624
3625
3626
3627
3628
3629
3630
3631
3632
3633
# File 'lib/stripe/services/account_service.rb', line 3621

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3611
3612
3613
# File 'lib/stripe/services/account_service.rb', line 3611

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



3613
3614
3615
# File 'lib/stripe/services/account_service.rb', line 3613

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



3615
3616
3617
# File 'lib/stripe/services/account_service.rb', line 3615

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



3617
3618
3619
# File 'lib/stripe/services/account_service.rb', line 3617

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



3619
3620
3621
# File 'lib/stripe/services/account_service.rb', line 3619

def title
  @title
end