Class: Stripe::AccountService::CreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



3596
3597
3598
3599
3600
3601
3602
3603
3604
3605
3606
3607
3608
# File 'lib/stripe/services/account_service.rb', line 3596

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



3586
3587
3588
# File 'lib/stripe/services/account_service.rb', line 3586

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



3588
3589
3590
# File 'lib/stripe/services/account_service.rb', line 3588

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



3590
3591
3592
# File 'lib/stripe/services/account_service.rb', line 3590

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



3592
3593
3594
# File 'lib/stripe/services/account_service.rb', line 3592

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



3594
3595
3596
# File 'lib/stripe/services/account_service.rb', line 3594

def title
  @title
end