Class: Stripe::AccountService::CreateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
# File 'lib/stripe/services/account_service.rb', line 4268

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



4254
4255
4256
# File 'lib/stripe/services/account_service.rb', line 4254

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



4257
4258
4259
# File 'lib/stripe/services/account_service.rb', line 4257

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



4260
4261
4262
# File 'lib/stripe/services/account_service.rb', line 4260

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



4263
4264
4265
# File 'lib/stripe/services/account_service.rb', line 4263

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



4266
4267
4268
# File 'lib/stripe/services/account_service.rb', line 4266

def title
  @title
end