Class: Stripe::AccountService::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Settings
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
4030 4031 4032 4033 4034 4035 4036 4037 4038 4039 4040 4041 4042 4043 4044 4045 4046 4047 4048 |
# File 'lib/stripe/services/account_service.rb', line 4030 def initialize( bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @branding = branding @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
4014 4015 4016 |
# File 'lib/stripe/services/account_service.rb', line 4014 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
4016 4017 4018 |
# File 'lib/stripe/services/account_service.rb', line 4016 def branding @branding end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
4018 4019 4020 |
# File 'lib/stripe/services/account_service.rb', line 4018 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
4020 4021 4022 |
# File 'lib/stripe/services/account_service.rb', line 4020 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
4022 4023 4024 |
# File 'lib/stripe/services/account_service.rb', line 4022 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
4024 4025 4026 |
# File 'lib/stripe/services/account_service.rb', line 4024 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
4026 4027 4028 |
# File 'lib/stripe/services/account_service.rb', line 4026 def payouts @payouts end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
4028 4029 4030 |
# File 'lib/stripe/services/account_service.rb', line 4028 def treasury @treasury end |