Class: Stripe::AccountService::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Settings
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
4581 4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 4597 4598 4599 4600 4601 4602 4603 4604 4605 |
# File 'lib/stripe/services/account_service.rb', line 4581 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
4559 4560 4561 |
# File 'lib/stripe/services/account_service.rb', line 4559 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
4561 4562 4563 |
# File 'lib/stripe/services/account_service.rb', line 4561 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
4563 4564 4565 |
# File 'lib/stripe/services/account_service.rb', line 4563 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
4565 4566 4567 |
# File 'lib/stripe/services/account_service.rb', line 4565 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
4567 4568 4569 |
# File 'lib/stripe/services/account_service.rb', line 4567 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
4569 4570 4571 |
# File 'lib/stripe/services/account_service.rb', line 4569 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
4571 4572 4573 |
# File 'lib/stripe/services/account_service.rb', line 4571 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
4573 4574 4575 |
# File 'lib/stripe/services/account_service.rb', line 4573 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
4575 4576 4577 |
# File 'lib/stripe/services/account_service.rb', line 4575 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
4577 4578 4579 |
# File 'lib/stripe/services/account_service.rb', line 4577 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
4579 4580 4581 |
# File 'lib/stripe/services/account_service.rb', line 4579 def treasury @treasury end |