Class: Stripe::AccountService::CreateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



3952
3953
3954
3955
3956
3957
3958
3959
3960
3961
3962
3963
3964
3965
3966
3967
3968
3969
3970
# File 'lib/stripe/services/account_service.rb', line 3952

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



3936
3937
3938
# File 'lib/stripe/services/account_service.rb', line 3936

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



3938
3939
3940
# File 'lib/stripe/services/account_service.rb', line 3938

def branding
  @branding
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



3940
3941
3942
# File 'lib/stripe/services/account_service.rb', line 3940

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



3942
3943
3944
# File 'lib/stripe/services/account_service.rb', line 3942

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



3944
3945
3946
# File 'lib/stripe/services/account_service.rb', line 3944

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



3946
3947
3948
# File 'lib/stripe/services/account_service.rb', line 3946

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



3948
3949
3950
# File 'lib/stripe/services/account_service.rb', line 3948

def payouts
  @payouts
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



3950
3951
3952
# File 'lib/stripe/services/account_service.rb', line 3950

def treasury
  @treasury
end