Class: Stripe::AccountService::CreateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



3927
3928
3929
3930
3931
3932
3933
3934
3935
3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
# File 'lib/stripe/services/account_service.rb', line 3927

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



3911
3912
3913
# File 'lib/stripe/services/account_service.rb', line 3911

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



3913
3914
3915
# File 'lib/stripe/services/account_service.rb', line 3913

def branding
  @branding
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



3915
3916
3917
# File 'lib/stripe/services/account_service.rb', line 3915

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



3917
3918
3919
# File 'lib/stripe/services/account_service.rb', line 3917

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



3919
3920
3921
# File 'lib/stripe/services/account_service.rb', line 3919

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



3921
3922
3923
# File 'lib/stripe/services/account_service.rb', line 3921

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



3923
3924
3925
# File 'lib/stripe/services/account_service.rb', line 3923

def payouts
  @payouts
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



3925
3926
3927
# File 'lib/stripe/services/account_service.rb', line 3925

def treasury
  @treasury
end