Class: Stripe::AccountService::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Settings
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
4478 4479 4480 4481 4482 4483 4484 4485 4486 4487 4488 4489 4490 4491 4492 4493 4494 4495 4496 4497 4498 4499 4500 4501 4502 |
# File 'lib/stripe/services/account_service.rb', line 4478 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
4456 4457 4458 |
# File 'lib/stripe/services/account_service.rb', line 4456 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
4458 4459 4460 |
# File 'lib/stripe/services/account_service.rb', line 4458 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
4460 4461 4462 |
# File 'lib/stripe/services/account_service.rb', line 4460 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
4462 4463 4464 |
# File 'lib/stripe/services/account_service.rb', line 4462 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
4464 4465 4466 |
# File 'lib/stripe/services/account_service.rb', line 4464 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
4466 4467 4468 |
# File 'lib/stripe/services/account_service.rb', line 4466 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
4468 4469 4470 |
# File 'lib/stripe/services/account_service.rb', line 4468 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
4470 4471 4472 |
# File 'lib/stripe/services/account_service.rb', line 4470 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
4472 4473 4474 |
# File 'lib/stripe/services/account_service.rb', line 4472 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
4474 4475 4476 |
# File 'lib/stripe/services/account_service.rb', line 4474 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
4476 4477 4478 |
# File 'lib/stripe/services/account_service.rb', line 4476 def treasury @treasury end |