Class: Stripe::AccountService::CreateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Settings
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
4314 4315 4316 4317 4318 4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 |
# File 'lib/stripe/services/account_service.rb', line 4314 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit.
4294 4295 4296 |
# File 'lib/stripe/services/account_service.rb', line 4294 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
4296 4297 4298 |
# File 'lib/stripe/services/account_service.rb', line 4296 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
4298 4299 4300 |
# File 'lib/stripe/services/account_service.rb', line 4298 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
4300 4301 4302 |
# File 'lib/stripe/services/account_service.rb', line 4300 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
4302 4303 4304 |
# File 'lib/stripe/services/account_service.rb', line 4302 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
4304 4305 4306 |
# File 'lib/stripe/services/account_service.rb', line 4304 def card_payments @card_payments end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
4306 4307 4308 |
# File 'lib/stripe/services/account_service.rb', line 4306 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
4308 4309 4310 |
# File 'lib/stripe/services/account_service.rb', line 4308 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
4310 4311 4312 |
# File 'lib/stripe/services/account_service.rb', line 4310 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
4312 4313 4314 |
# File 'lib/stripe/services/account_service.rb', line 4312 def treasury @treasury end |