Class: Stripe::AccountService::CreateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



4224
4225
4226
4227
4228
4229
4230
4231
4232
4233
4234
4235
4236
4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
# File 'lib/stripe/services/account_service.rb', line 4224

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



4204
4205
4206
# File 'lib/stripe/services/account_service.rb', line 4204

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



4206
4207
4208
# File 'lib/stripe/services/account_service.rb', line 4206

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



4208
4209
4210
# File 'lib/stripe/services/account_service.rb', line 4208

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



4210
4211
4212
# File 'lib/stripe/services/account_service.rb', line 4210

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



4212
4213
4214
# File 'lib/stripe/services/account_service.rb', line 4212

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



4214
4215
4216
# File 'lib/stripe/services/account_service.rb', line 4214

def card_payments
  @card_payments
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



4216
4217
4218
# File 'lib/stripe/services/account_service.rb', line 4216

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



4218
4219
4220
# File 'lib/stripe/services/account_service.rb', line 4218

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



4220
4221
4222
# File 'lib/stripe/services/account_service.rb', line 4220

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



4222
4223
4224
# File 'lib/stripe/services/account_service.rb', line 4222

def treasury
  @treasury
end