Class: Stripe::AccountService::CreateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



4713
4714
4715
4716
4717
4718
4719
4720
4721
4722
4723
4724
4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
4735
# File 'lib/stripe/services/account_service.rb', line 4713

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit.



4684
4685
4686
# File 'lib/stripe/services/account_service.rb', line 4684

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



4687
4688
4689
# File 'lib/stripe/services/account_service.rb', line 4687

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



4690
4691
4692
# File 'lib/stripe/services/account_service.rb', line 4690

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



4693
4694
4695
# File 'lib/stripe/services/account_service.rb', line 4693

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



4696
4697
4698
# File 'lib/stripe/services/account_service.rb', line 4696

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



4699
4700
4701
# File 'lib/stripe/services/account_service.rb', line 4699

def card_payments
  @card_payments
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



4702
4703
4704
# File 'lib/stripe/services/account_service.rb', line 4702

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



4705
4706
4707
# File 'lib/stripe/services/account_service.rb', line 4705

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



4708
4709
4710
# File 'lib/stripe/services/account_service.rb', line 4708

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



4711
4712
4713
# File 'lib/stripe/services/account_service.rb', line 4711

def treasury
  @treasury
end