Class: Stripe::AccountService::CreateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



3717
3718
3719
3720
3721
3722
# File 'lib/stripe/services/account_service.rb', line 3717

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



3709
3710
3711
# File 'lib/stripe/services/account_service.rb', line 3709

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



3711
3712
3713
# File 'lib/stripe/services/account_service.rb', line 3711

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



3713
3714
3715
# File 'lib/stripe/services/account_service.rb', line 3713

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



3715
3716
3717
# File 'lib/stripe/services/account_service.rb', line 3715

def secondary_color
  @secondary_color
end