Class: Stripe::AccountService::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



3805
3806
3807
3808
3809
# File 'lib/stripe/services/account_service.rb', line 3805

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



3799
3800
3801
# File 'lib/stripe/services/account_service.rb', line 3799

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



3801
3802
3803
# File 'lib/stripe/services/account_service.rb', line 3801

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



3803
3804
3805
# File 'lib/stripe/services/account_service.rb', line 3803

def user_agent
  @user_agent
end