Class: Stripe::AccountService::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4316
4317
4318
4319
4320
# File 'lib/stripe/services/account_service.rb', line 4316

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4310
4311
4312
# File 'lib/stripe/services/account_service.rb', line 4310

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4312
4313
4314
# File 'lib/stripe/services/account_service.rb', line 4312

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4314
4315
4316
# File 'lib/stripe/services/account_service.rb', line 4314

def user_agent
  @user_agent
end