Class: Stripe::AccountService::CreateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4163
4164
4165
4166
4167
# File 'lib/stripe/services/account_service.rb', line 4163

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4157
4158
4159
# File 'lib/stripe/services/account_service.rb', line 4157

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4159
4160
4161
# File 'lib/stripe/services/account_service.rb', line 4159

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4161
4162
4163
# File 'lib/stripe/services/account_service.rb', line 4161

def user_agent
  @user_agent
end