Class: Stripe::AccountService::CreateParams::Settings::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: DeclineOn

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



4441
4442
4443
4444
4445
4446
4447
4448
4449
4450
4451
# File 'lib/stripe/services/account_service.rb', line 4441

def initialize(
  decline_on: nil,
  statement_descriptor_prefix: nil,
  statement_descriptor_prefix_kana: nil,
  statement_descriptor_prefix_kanji: nil
)
  @decline_on = decline_on
  @statement_descriptor_prefix = statement_descriptor_prefix
  @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji
end

Instance Attribute Details

#decline_onObject

Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.



4433
4434
4435
# File 'lib/stripe/services/account_service.rb', line 4433

def decline_on
  @decline_on
end

#statement_descriptor_prefixObject

The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.



4435
4436
4437
# File 'lib/stripe/services/account_service.rb', line 4435

def statement_descriptor_prefix
  @statement_descriptor_prefix
end

#statement_descriptor_prefix_kanaObject

The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.



4437
4438
4439
# File 'lib/stripe/services/account_service.rb', line 4437

def statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kana
end

#statement_descriptor_prefix_kanjiObject

The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.



4439
4440
4441
# File 'lib/stripe/services/account_service.rb', line 4439

def statement_descriptor_prefix_kanji
  @statement_descriptor_prefix_kanji
end