Class: Stripe::AccountService::CreateParams::Settings::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: DeclineOn

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



4351
4352
4353
4354
4355
4356
4357
4358
4359
4360
4361
# File 'lib/stripe/services/account_service.rb', line 4351

def initialize(
  decline_on: nil,
  statement_descriptor_prefix: nil,
  statement_descriptor_prefix_kana: nil,
  statement_descriptor_prefix_kanji: nil
)
  @decline_on = decline_on
  @statement_descriptor_prefix = statement_descriptor_prefix
  @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji
end

Instance Attribute Details

#decline_onObject

Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.



4343
4344
4345
# File 'lib/stripe/services/account_service.rb', line 4343

def decline_on
  @decline_on
end

#statement_descriptor_prefixObject

The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.



4345
4346
4347
# File 'lib/stripe/services/account_service.rb', line 4345

def statement_descriptor_prefix
  @statement_descriptor_prefix
end

#statement_descriptor_prefix_kanaObject

The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.



4347
4348
4349
# File 'lib/stripe/services/account_service.rb', line 4347

def statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kana
end

#statement_descriptor_prefix_kanjiObject

The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.



4349
4350
4351
# File 'lib/stripe/services/account_service.rb', line 4349

def statement_descriptor_prefix_kanji
  @statement_descriptor_prefix_kanji
end