Class: Stripe::AccountService::CreateParams::Settings::CardPayments::DeclineOn

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn

Returns a new instance of DeclineOn.



4562
4563
4564
4565
# File 'lib/stripe/services/account_service.rb', line 4562

def initialize(avs_failure: nil, cvc_failure: nil)
  @avs_failure = avs_failure
  @cvc_failure = cvc_failure
end

Instance Attribute Details

#avs_failureObject

Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.



4557
4558
4559
# File 'lib/stripe/services/account_service.rb', line 4557

def avs_failure
  @avs_failure
end

#cvc_failureObject

Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.



4560
4561
4562
# File 'lib/stripe/services/account_service.rb', line 4560

def cvc_failure
  @cvc_failure
end