Class: Stripe::AccountService::CreateParams::Settings::Payments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments

Returns a new instance of Payments.



4406
4407
4408
4409
4410
4411
4412
4413
4414
# File 'lib/stripe/services/account_service.rb', line 4406

def initialize(
  statement_descriptor: nil,
  statement_descriptor_kana: nil,
  statement_descriptor_kanji: nil
)
  @statement_descriptor = statement_descriptor
  @statement_descriptor_kana = statement_descriptor_kana
  @statement_descriptor_kanji = statement_descriptor_kanji
end

Instance Attribute Details

#statement_descriptorObject

The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a ‘statement_descriptor_prefix`, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the `statement_descriptor` text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the [account settings documentation](docs.stripe.com/get-started/account/statement-descriptors).



4400
4401
4402
# File 'lib/stripe/services/account_service.rb', line 4400

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_kanaObject

The Kana variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).



4402
4403
4404
# File 'lib/stripe/services/account_service.rb', line 4402

def statement_descriptor_kana
  @statement_descriptor_kana
end

#statement_descriptor_kanjiObject

The Kanji variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).



4404
4405
4406
# File 'lib/stripe/services/account_service.rb', line 4404

def statement_descriptor_kanji
  @statement_descriptor_kanji
end