Class: Stripe::AccountService::CreateParams::Settings::Payouts

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts

Returns a new instance of Payouts.



4643
4644
4645
4646
4647
# File 'lib/stripe/services/account_service.rb', line 4643

def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil)
  @debit_negative_balances = debit_negative_balances
  @schedule = schedule
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#debit_negative_balancesObject

A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](/connect/account-balances).



4635
4636
4637
# File 'lib/stripe/services/account_service.rb', line 4635

def debit_negative_balances
  @debit_negative_balances
end

#scheduleObject

Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.



4638
4639
4640
# File 'lib/stripe/services/account_service.rb', line 4638

def schedule
  @schedule
end

#statement_descriptorObject

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.



4641
4642
4643
# File 'lib/stripe/services/account_service.rb', line 4641

def statement_descriptor
  @statement_descriptor
end