Class: Stripe::AccountService::CreateParams::Settings::Payouts::Schedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::Settings::Payouts::Schedule
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
The number of days charge funds are held before being paid out.
-
#interval ⇒ Object
How frequently available funds are paid out.
-
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31.
-
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc.
Instance Method Summary collapse
-
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, weekly_anchor: nil) ⇒ Schedule
constructor
A new instance of Schedule.
Methods inherited from RequestParams
Constructor Details
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, weekly_anchor: nil) ⇒ Schedule
Returns a new instance of Schedule.
4428 4429 4430 4431 4432 4433 |
# File 'lib/stripe/services/account_service.rb', line 4428 def initialize(delay_days: nil, interval: nil, monthly_anchor: nil, weekly_anchor: nil) @delay_days = delay_days @interval = interval @monthly_anchor = monthly_anchor @weekly_anchor = weekly_anchor end |
Instance Attribute Details
#delay_days ⇒ Object
The number of days charge funds are held before being paid out. May also be set to ‘minimum`, representing the lowest available value for the account country. Default is `minimum`. The `delay_days` parameter remains at the last configured value if `interval` is `manual`. [Learn more about controlling payout delay days](/connect/manage-payout-schedule).
4420 4421 4422 |
# File 'lib/stripe/services/account_service.rb', line 4420 def delay_days @delay_days end |
#interval ⇒ Object
How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.
4422 4423 4424 |
# File 'lib/stripe/services/account_service.rb', line 4422 def interval @interval end |
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.
4424 4425 4426 |
# File 'lib/stripe/services/account_service.rb', line 4424 def monthly_anchor @monthly_anchor end |
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc. (required and applicable only if `interval` is `weekly`.)
4426 4427 4428 |
# File 'lib/stripe/services/account_service.rb', line 4426 def weekly_anchor @weekly_anchor end |