Class: Stripe::AccountService::CreateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4670
4671
4672
4673
4674
# File 'lib/stripe/services/account_service.rb', line 4670

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



4662
4663
4664
# File 'lib/stripe/services/account_service.rb', line 4662

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



4665
4666
4667
# File 'lib/stripe/services/account_service.rb', line 4665

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



4668
4669
4670
# File 'lib/stripe/services/account_service.rb', line 4668

def user_agent
  @user_agent
end