Class: Stripe::AccountService::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



3983
3984
3985
3986
3987
3988
# File 'lib/stripe/services/account_service.rb', line 3983

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



3975
3976
3977
# File 'lib/stripe/services/account_service.rb', line 3975

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



3977
3978
3979
# File 'lib/stripe/services/account_service.rb', line 3977

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



3979
3980
3981
# File 'lib/stripe/services/account_service.rb', line 3979

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



3981
3982
3983
# File 'lib/stripe/services/account_service.rb', line 3981

def user_agent
  @user_agent
end