Class: Stripe::AccountService::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4515
4516
4517
4518
4519
4520
# File 'lib/stripe/services/account_service.rb', line 4515

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



4507
4508
4509
# File 'lib/stripe/services/account_service.rb', line 4507

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



4509
4510
4511
# File 'lib/stripe/services/account_service.rb', line 4509

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



4511
4512
4513
# File 'lib/stripe/services/account_service.rb', line 4511

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



4513
4514
4515
# File 'lib/stripe/services/account_service.rb', line 4513

def user_agent
  @user_agent
end