Class: Stripe::AccountService::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
3958 3959 3960 3961 3962 3963 |
# File 'lib/stripe/services/account_service.rb', line 3958 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
3950 3951 3952 |
# File 'lib/stripe/services/account_service.rb', line 3950 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
3952 3953 3954 |
# File 'lib/stripe/services/account_service.rb', line 3952 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
3954 3955 3956 |
# File 'lib/stripe/services/account_service.rb', line 3954 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
3956 3957 3958 |
# File 'lib/stripe/services/account_service.rb', line 3956 def user_agent @user_agent end |