Class: Stripe::AccountService::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4477
4478
4479
4480
4481
4482
# File 'lib/stripe/services/account_service.rb', line 4477

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



4469
4470
4471
# File 'lib/stripe/services/account_service.rb', line 4469

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



4471
4472
4473
# File 'lib/stripe/services/account_service.rb', line 4471

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



4473
4474
4475
# File 'lib/stripe/services/account_service.rb', line 4473

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



4475
4476
4477
# File 'lib/stripe/services/account_service.rb', line 4475

def user_agent
  @user_agent
end