Class: Stripe::AccountService::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



3912
3913
3914
3915
3916
3917
# File 'lib/stripe/services/account_service.rb', line 3912

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



3904
3905
3906
# File 'lib/stripe/services/account_service.rb', line 3904

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



3906
3907
3908
# File 'lib/stripe/services/account_service.rb', line 3906

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



3908
3909
3910
# File 'lib/stripe/services/account_service.rb', line 3908

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



3910
3911
3912
# File 'lib/stripe/services/account_service.rb', line 3910

def user_agent
  @user_agent
end