Class: Stripe::AccountService::CreateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



4349
4350
4351
4352
4353
4354
# File 'lib/stripe/services/account_service.rb', line 4349

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



4341
4342
4343
# File 'lib/stripe/services/account_service.rb', line 4341

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



4343
4344
4345
# File 'lib/stripe/services/account_service.rb', line 4343

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



4345
4346
4347
# File 'lib/stripe/services/account_service.rb', line 4345

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



4347
4348
4349
# File 'lib/stripe/services/account_service.rb', line 4347

def user_agent
  @user_agent
end