Class: Stripe::AccountService::CreateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::CreateParams::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
4259 4260 4261 4262 4263 4264 |
# File 'lib/stripe/services/account_service.rb', line 4259 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
4251 4252 4253 |
# File 'lib/stripe/services/account_service.rb', line 4251 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
4253 4254 4255 |
# File 'lib/stripe/services/account_service.rb', line 4253 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
4255 4256 4257 |
# File 'lib/stripe/services/account_service.rb', line 4255 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
4257 4258 4259 |
# File 'lib/stripe/services/account_service.rb', line 4257 def user_agent @user_agent end |