Class: Stripe::AccountService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



2039
2040
2041
2042
2043
2044
2045
# File 'lib/stripe/services/account_service.rb', line 2039

def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return connected accounts that were created during the given date interval.



2029
2030
2031
# File 'lib/stripe/services/account_service.rb', line 2029

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2031
2032
2033
# File 'lib/stripe/services/account_service.rb', line 2031

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2033
2034
2035
# File 'lib/stripe/services/account_service.rb', line 2033

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2035
2036
2037
# File 'lib/stripe/services/account_service.rb', line 2035

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2037
2038
2039
# File 'lib/stripe/services/account_service.rb', line 2037

def starting_after
  @starting_after
end