Class: Stripe::AccountService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::ListParams
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return connected accounts that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/stripe/services/account_service.rb', line 2027 def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return connected accounts that were created during the given date interval.
2017 2018 2019 |
# File 'lib/stripe/services/account_service.rb', line 2017 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2019 2020 2021 |
# File 'lib/stripe/services/account_service.rb', line 2019 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2021 2022 2023 |
# File 'lib/stripe/services/account_service.rb', line 2021 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2023 2024 2025 |
# File 'lib/stripe/services/account_service.rb', line 2023 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2025 2026 2027 |
# File 'lib/stripe/services/account_service.rb', line 2025 def starting_after @starting_after end |