Class: Stripe::AccountService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



2266
2267
2268
2269
2270
2271
2272
# File 'lib/stripe/services/account_service.rb', line 2266

def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return connected accounts that were created during the given date interval.



2256
2257
2258
# File 'lib/stripe/services/account_service.rb', line 2256

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2258
2259
2260
# File 'lib/stripe/services/account_service.rb', line 2258

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2260
2261
2262
# File 'lib/stripe/services/account_service.rb', line 2260

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2262
2263
2264
# File 'lib/stripe/services/account_service.rb', line 2262

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2264
2265
2266
# File 'lib/stripe/services/account_service.rb', line 2264

def starting_after
  @starting_after
end