Class: Stripe::AccountService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::ListParams
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return connected accounts that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/stripe/services/account_service.rb', line 2211 def initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return connected accounts that were created during the given date interval.
2201 2202 2203 |
# File 'lib/stripe/services/account_service.rb', line 2201 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2203 2204 2205 |
# File 'lib/stripe/services/account_service.rb', line 2203 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2205 2206 2207 |
# File 'lib/stripe/services/account_service.rb', line 2205 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2207 2208 2209 |
# File 'lib/stripe/services/account_service.rb', line 2207 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2209 2210 2211 |
# File 'lib/stripe/services/account_service.rb', line 2209 def starting_after @starting_after end |