Class: Stripe::AccountService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance
Instance Attribute Summary collapse
-
#account_token ⇒ Object
An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.
-
#business_profile ⇒ Object
Business information about the account.
-
#business_type ⇒ Object
The business type.
-
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not).
-
#company ⇒ Object
Information about the company or business.
-
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account.
-
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
-
#email ⇒ Object
The email address of the account holder.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups).
-
#groups ⇒ Object
A hash of account group type to tokens.
-
#individual ⇒ Object
Information about the person represented by the account.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#risk_controls ⇒ Object
A hash to configure risk controls on the account.
-
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
-
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance).
Instance Method Summary collapse
-
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 |
# File 'lib/stripe/services/account_service.rb', line 2191 def initialize( account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil ) @account_token = account_token @business_profile = business_profile @business_type = business_type @capabilities = capabilities @company = company @default_currency = default_currency @documents = documents @email = email @expand = @external_account = external_account @groups = groups @individual = individual @metadata = @risk_controls = risk_controls @settings = settings @tos_acceptance = tos_acceptance end |
Instance Attribute Details
#account_token ⇒ Object
An [account token](stripe.com/docs/api#create_account_token), used to securely provide details to the account.
2152 2153 2154 |
# File 'lib/stripe/services/account_service.rb', line 2152 def account_token @account_token end |
#business_profile ⇒ Object
Business information about the account.
2154 2155 2156 |
# File 'lib/stripe/services/account_service.rb', line 2154 def business_profile @business_profile end |
#business_type ⇒ Object
The business type. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.
2156 2157 2158 |
# File 'lib/stripe/services/account_service.rb', line 2156 def business_type @business_type end |
#capabilities ⇒ Object
Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.
Required when [account.controller.stripe_dashboard.type](/api/accounts/create#create_account-controller-dashboard-type) is ‘none`, which includes Custom accounts.
2165 2166 2167 |
# File 'lib/stripe/services/account_service.rb', line 2165 def capabilities @capabilities end |
#company ⇒ Object
Information about the company or business. This field is available for any ‘business_type`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2167 2168 2169 |
# File 'lib/stripe/services/account_service.rb', line 2167 def company @company end |
#default_currency ⇒ Object
Three-letter ISO currency code representing the default currency for the account. This must be a currency that [Stripe supports in the account’s country](docs.stripe.com/payouts).
2169 2170 2171 |
# File 'lib/stripe/services/account_service.rb', line 2169 def default_currency @default_currency end |
#documents ⇒ Object
Documents that may be submitted to satisfy various informational requests.
2171 2172 2173 |
# File 'lib/stripe/services/account_service.rb', line 2171 def documents @documents end |
#email ⇒ Object
The email address of the account holder. This is only to make the account easier to identify to you. If [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts, Stripe doesn’t email the account without your consent.
2173 2174 2175 |
# File 'lib/stripe/services/account_service.rb', line 2173 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2175 2176 2177 |
# File 'lib/stripe/services/account_service.rb', line 2175 def @expand end |
#external_account ⇒ Object
A card or bank account to attach to the account for receiving [payouts](/connect/bank-debit-card-payouts) (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by [Stripe.js](/js), or a dictionary, as documented in the ‘external_account` parameter for [bank account](/api#account_create_bank_account) creation.
By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the [bank account](/api#account_create_bank_account) or [card creation](/api#account_create_card) APIs. After you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2177 2178 2179 |
# File 'lib/stripe/services/account_service.rb', line 2177 def external_account @external_account end |
#groups ⇒ Object
A hash of account group type to tokens. These are account groups this account should be added to.
2179 2180 2181 |
# File 'lib/stripe/services/account_service.rb', line 2179 def groups @groups end |
#individual ⇒ Object
Information about the person represented by the account. This field is null unless ‘business_type` is set to `individual`. Once you create an [Account Link](/api/account_links) or [Account Session](/api/account_sessions), this property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is `application`, which includes Custom accounts.
2181 2182 2183 |
# File 'lib/stripe/services/account_service.rb', line 2181 def individual @individual end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2183 2184 2185 |
# File 'lib/stripe/services/account_service.rb', line 2183 def @metadata end |
#risk_controls ⇒ Object
A hash to configure risk controls on the account. Please see [this page for more details](/connect/pausing-payments-or-payouts-on-connected-accounts).
2185 2186 2187 |
# File 'lib/stripe/services/account_service.rb', line 2185 def risk_controls @risk_controls end |
#settings ⇒ Object
Options for customizing how the account functions within Stripe.
2187 2188 2189 |
# File 'lib/stripe/services/account_service.rb', line 2187 def settings @settings end |
#tos_acceptance ⇒ Object
Details on the account’s acceptance of the [Stripe Services Agreement](/connect/updating-accounts#tos-acceptance). This property can only be updated for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. This property defaults to a `full` service agreement when empty.
2189 2190 2191 |
# File 'lib/stripe/services/account_service.rb', line 2189 def tos_acceptance @tos_acceptance end |