Class: Stripe::AccountService::UpdateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, minority_owned_business_designation: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/stripe/services/account_service.rb', line 147

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  minority_owned_business_designation: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @minority_owned_business_designation = minority_owned_business_designation
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



123
124
125
# File 'lib/stripe/services/account_service.rb', line 123

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



125
126
127
# File 'lib/stripe/services/account_service.rb', line 125

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



127
128
129
# File 'lib/stripe/services/account_service.rb', line 127

def mcc
  @mcc
end

#minority_owned_business_designationObject

Whether the business is a minority-owned, women-owned, and/or LGBTQI+-owned business.



129
130
131
# File 'lib/stripe/services/account_service.rb', line 129

def minority_owned_business_designation
  @minority_owned_business_designation
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



131
132
133
# File 'lib/stripe/services/account_service.rb', line 131

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



133
134
135
# File 'lib/stripe/services/account_service.rb', line 133

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



135
136
137
# File 'lib/stripe/services/account_service.rb', line 135

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



137
138
139
# File 'lib/stripe/services/account_service.rb', line 137

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



139
140
141
# File 'lib/stripe/services/account_service.rb', line 139

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



141
142
143
# File 'lib/stripe/services/account_service.rb', line 141

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



143
144
145
# File 'lib/stripe/services/account_service.rb', line 143

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



145
146
147
# File 'lib/stripe/services/account_service.rb', line 145

def url
  @url
end