Class: Stripe::AccountService::UpdateParams::BusinessProfile

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: AnnualRevenue, MonthlyEstimatedRevenue, SupportAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(annual_revenue: nil, estimated_worker_count: nil, mcc: nil, monthly_estimated_revenue: nil, name: nil, product_description: nil, support_address: nil, support_email: nil, support_phone: nil, support_url: nil, url: nil) ⇒ BusinessProfile

Returns a new instance of BusinessProfile.



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/stripe/services/account_service.rb', line 169

def initialize(
  annual_revenue: nil,
  estimated_worker_count: nil,
  mcc: nil,
  monthly_estimated_revenue: nil,
  name: nil,
  product_description: nil,
  support_address: nil,
  support_email: nil,
  support_phone: nil,
  support_url: nil,
  url: nil
)
  @annual_revenue = annual_revenue
  @estimated_worker_count = estimated_worker_count
  @mcc = mcc
  @monthly_estimated_revenue = monthly_estimated_revenue
  @name = name
  @product_description = product_description
  @support_address = support_address
  @support_email = support_email
  @support_phone = support_phone
  @support_url = support_url
  @url = url
end

Instance Attribute Details

#annual_revenueObject

The applicant’s gross annual revenue for its preceding fiscal year.



137
138
139
# File 'lib/stripe/services/account_service.rb', line 137

def annual_revenue
  @annual_revenue
end

#estimated_worker_countObject

An estimated upper bound of employees, contractors, vendors, etc. currently working for the business.



140
141
142
# File 'lib/stripe/services/account_service.rb', line 140

def estimated_worker_count
  @estimated_worker_count
end

#mccObject

[The merchant category code for the account](/connect/setting-mcc). MCCs are used to classify businesses based on the goods or services they provide.



143
144
145
# File 'lib/stripe/services/account_service.rb', line 143

def mcc
  @mcc
end

#monthly_estimated_revenueObject

An estimate of the monthly revenue of the business. Only accepted for accounts in Brazil and India.



146
147
148
# File 'lib/stripe/services/account_service.rb', line 146

def monthly_estimated_revenue
  @monthly_estimated_revenue
end

#nameObject

The customer-facing business name.



149
150
151
# File 'lib/stripe/services/account_service.rb', line 149

def name
  @name
end

#product_descriptionObject

Internal-only description of the product sold by, or service provided by, the business. Used by Stripe for risk and underwriting purposes.



152
153
154
# File 'lib/stripe/services/account_service.rb', line 152

def product_description
  @product_description
end

#support_addressObject

A publicly available mailing address for sending support issues to.



155
156
157
# File 'lib/stripe/services/account_service.rb', line 155

def support_address
  @support_address
end

#support_emailObject

A publicly available email address for sending support issues to.



158
159
160
# File 'lib/stripe/services/account_service.rb', line 158

def support_email
  @support_email
end

#support_phoneObject

A publicly available phone number to call with support issues.



161
162
163
# File 'lib/stripe/services/account_service.rb', line 161

def support_phone
  @support_phone
end

#support_urlObject

A publicly available website for handling support issues.



164
165
166
# File 'lib/stripe/services/account_service.rb', line 164

def support_url
  @support_url
end

#urlObject

The business’s publicly available website.



167
168
169
# File 'lib/stripe/services/account_service.rb', line 167

def url
  @url
end