Class: Stripe::AccountService::UpdateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
1256
1257
1258
1259
1260
1261
1262
1263
1264
1265
1266
1267
1268
1269
1270
1271
1272
1273
1274
# File 'lib/stripe/services/account_service.rb', line 1228

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1184
1185
1186
# File 'lib/stripe/services/account_service.rb', line 1184

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1186
1187
1188
# File 'lib/stripe/services/account_service.rb', line 1186

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1188
1189
1190
# File 'lib/stripe/services/account_service.rb', line 1188

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1190
1191
1192
# File 'lib/stripe/services/account_service.rb', line 1190

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1192
1193
1194
# File 'lib/stripe/services/account_service.rb', line 1192

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1194
1195
1196
# File 'lib/stripe/services/account_service.rb', line 1194

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1196
1197
1198
# File 'lib/stripe/services/account_service.rb', line 1196

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1198
1199
1200
# File 'lib/stripe/services/account_service.rb', line 1198

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1200
1201
1202
# File 'lib/stripe/services/account_service.rb', line 1200

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1202
1203
1204
# File 'lib/stripe/services/account_service.rb', line 1202

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1204
1205
1206
# File 'lib/stripe/services/account_service.rb', line 1204

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1206
1207
1208
# File 'lib/stripe/services/account_service.rb', line 1206

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1208
1209
1210
# File 'lib/stripe/services/account_service.rb', line 1208

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



1210
1211
1212
# File 'lib/stripe/services/account_service.rb', line 1210

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



1212
1213
1214
# File 'lib/stripe/services/account_service.rb', line 1212

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



1214
1215
1216
# File 'lib/stripe/services/account_service.rb', line 1214

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1216
1217
1218
# File 'lib/stripe/services/account_service.rb', line 1216

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1218
1219
1220
# File 'lib/stripe/services/account_service.rb', line 1218

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1220
1221
1222
# File 'lib/stripe/services/account_service.rb', line 1220

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1222
1223
1224
# File 'lib/stripe/services/account_service.rb', line 1222

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1224
1225
1226
# File 'lib/stripe/services/account_service.rb', line 1224

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1226
1227
1228
# File 'lib/stripe/services/account_service.rb', line 1226

def verification
  @verification
end