Class: Stripe::AccountService::UpdateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/stripe/services/account_service.rb', line 1398

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1354
1355
1356
# File 'lib/stripe/services/account_service.rb', line 1354

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1356
1357
1358
# File 'lib/stripe/services/account_service.rb', line 1356

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1358
1359
1360
# File 'lib/stripe/services/account_service.rb', line 1358

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1360
1361
1362
# File 'lib/stripe/services/account_service.rb', line 1360

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1362
1363
1364
# File 'lib/stripe/services/account_service.rb', line 1362

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1364
1365
1366
# File 'lib/stripe/services/account_service.rb', line 1364

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1366
1367
1368
# File 'lib/stripe/services/account_service.rb', line 1366

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1368
1369
1370
# File 'lib/stripe/services/account_service.rb', line 1368

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1370
1371
1372
# File 'lib/stripe/services/account_service.rb', line 1370

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1372
1373
1374
# File 'lib/stripe/services/account_service.rb', line 1372

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1374
1375
1376
# File 'lib/stripe/services/account_service.rb', line 1374

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1376
1377
1378
# File 'lib/stripe/services/account_service.rb', line 1376

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1378
1379
1380
# File 'lib/stripe/services/account_service.rb', line 1378

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



1380
1381
1382
# File 'lib/stripe/services/account_service.rb', line 1380

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



1382
1383
1384
# File 'lib/stripe/services/account_service.rb', line 1382

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



1384
1385
1386
# File 'lib/stripe/services/account_service.rb', line 1384

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1386
1387
1388
# File 'lib/stripe/services/account_service.rb', line 1386

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1388
1389
1390
# File 'lib/stripe/services/account_service.rb', line 1388

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1390
1391
1392
# File 'lib/stripe/services/account_service.rb', line 1390

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1392
1393
1394
# File 'lib/stripe/services/account_service.rb', line 1392

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1394
1395
1396
# File 'lib/stripe/services/account_service.rb', line 1394

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1396
1397
1398
# File 'lib/stripe/services/account_service.rb', line 1396

def verification
  @verification
end