Class: Stripe::AccountService::UpdateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
# File 'lib/stripe/services/account_service.rb', line 1377

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1335
1336
1337
# File 'lib/stripe/services/account_service.rb', line 1335

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1337
1338
1339
# File 'lib/stripe/services/account_service.rb', line 1337

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1339
1340
1341
# File 'lib/stripe/services/account_service.rb', line 1339

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1341
1342
1343
# File 'lib/stripe/services/account_service.rb', line 1341

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1343
1344
1345
# File 'lib/stripe/services/account_service.rb', line 1343

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1345
1346
1347
# File 'lib/stripe/services/account_service.rb', line 1345

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1347
1348
1349
# File 'lib/stripe/services/account_service.rb', line 1347

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1349
1350
1351
# File 'lib/stripe/services/account_service.rb', line 1349

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1351
1352
1353
# File 'lib/stripe/services/account_service.rb', line 1351

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1353
1354
1355
# File 'lib/stripe/services/account_service.rb', line 1353

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1355
1356
1357
# File 'lib/stripe/services/account_service.rb', line 1355

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1357
1358
1359
# File 'lib/stripe/services/account_service.rb', line 1357

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1359
1360
1361
# File 'lib/stripe/services/account_service.rb', line 1359

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



1361
1362
1363
# File 'lib/stripe/services/account_service.rb', line 1361

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



1363
1364
1365
# File 'lib/stripe/services/account_service.rb', line 1363

def phone
  @phone
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1365
1366
1367
# File 'lib/stripe/services/account_service.rb', line 1365

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1367
1368
1369
# File 'lib/stripe/services/account_service.rb', line 1367

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1369
1370
1371
# File 'lib/stripe/services/account_service.rb', line 1369

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1371
1372
1373
# File 'lib/stripe/services/account_service.rb', line 1371

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1373
1374
1375
# File 'lib/stripe/services/account_service.rb', line 1373

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1375
1376
1377
# File 'lib/stripe/services/account_service.rb', line 1375

def verification
  @verification
end