Class: Stripe::AccountService::UpdateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
1346
1347
1348
1349
1350
1351
1352
1353
1354
1355
1356
1357
1358
1359
1360
1361
1362
1363
1364
1365
1366
1367
1368
1369
# File 'lib/stripe/services/account_service.rb', line 1325

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1283
1284
1285
# File 'lib/stripe/services/account_service.rb', line 1283

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1285
1286
1287
# File 'lib/stripe/services/account_service.rb', line 1285

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1287
1288
1289
# File 'lib/stripe/services/account_service.rb', line 1287

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1289
1290
1291
# File 'lib/stripe/services/account_service.rb', line 1289

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1291
1292
1293
# File 'lib/stripe/services/account_service.rb', line 1291

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1293
1294
1295
# File 'lib/stripe/services/account_service.rb', line 1293

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1295
1296
1297
# File 'lib/stripe/services/account_service.rb', line 1295

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1297
1298
1299
# File 'lib/stripe/services/account_service.rb', line 1297

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1299
1300
1301
# File 'lib/stripe/services/account_service.rb', line 1299

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1301
1302
1303
# File 'lib/stripe/services/account_service.rb', line 1301

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1303
1304
1305
# File 'lib/stripe/services/account_service.rb', line 1303

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1305
1306
1307
# File 'lib/stripe/services/account_service.rb', line 1305

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1307
1308
1309
# File 'lib/stripe/services/account_service.rb', line 1307

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

Attribute for param field ownership_exemption_reason



1309
1310
1311
# File 'lib/stripe/services/account_service.rb', line 1309

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



1311
1312
1313
# File 'lib/stripe/services/account_service.rb', line 1311

def phone
  @phone
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1313
1314
1315
# File 'lib/stripe/services/account_service.rb', line 1313

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1315
1316
1317
# File 'lib/stripe/services/account_service.rb', line 1315

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1317
1318
1319
# File 'lib/stripe/services/account_service.rb', line 1317

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1319
1320
1321
# File 'lib/stripe/services/account_service.rb', line 1319

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1321
1322
1323
# File 'lib/stripe/services/account_service.rb', line 1321

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1323
1324
1325
# File 'lib/stripe/services/account_service.rb', line 1323

def verification
  @verification
end