Class: Stripe::AccountService::UpdateParams::Company

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, OwnershipDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, phone: nil, registration_number: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/stripe/services/account_service.rb', line 1436

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  phone: nil,
  registration_number: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @phone = phone
  @registration_number = registration_number
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1380
1381
1382
# File 'lib/stripe/services/account_service.rb', line 1380

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1383
1384
1385
# File 'lib/stripe/services/account_service.rb', line 1383

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1386
1387
1388
# File 'lib/stripe/services/account_service.rb', line 1386

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1389
1390
1391
# File 'lib/stripe/services/account_service.rb', line 1389

def directors_provided
  @directors_provided
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1392
1393
1394
# File 'lib/stripe/services/account_service.rb', line 1392

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1395
1396
1397
# File 'lib/stripe/services/account_service.rb', line 1395

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1398
1399
1400
# File 'lib/stripe/services/account_service.rb', line 1398

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1401
1402
1403
# File 'lib/stripe/services/account_service.rb', line 1401

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1404
1405
1406
# File 'lib/stripe/services/account_service.rb', line 1404

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1407
1408
1409
# File 'lib/stripe/services/account_service.rb', line 1407

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1410
1411
1412
# File 'lib/stripe/services/account_service.rb', line 1410

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1413
1414
1415
# File 'lib/stripe/services/account_service.rb', line 1413

def ownership_declaration
  @ownership_declaration
end

#phoneObject

The company’s phone number (used for verification).



1416
1417
1418
# File 'lib/stripe/services/account_service.rb', line 1416

def phone
  @phone
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1419
1420
1421
# File 'lib/stripe/services/account_service.rb', line 1419

def registration_number
  @registration_number
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1422
1423
1424
# File 'lib/stripe/services/account_service.rb', line 1422

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1425
1426
1427
# File 'lib/stripe/services/account_service.rb', line 1425

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1428
1429
1430
# File 'lib/stripe/services/account_service.rb', line 1428

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1431
1432
1433
# File 'lib/stripe/services/account_service.rb', line 1431

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1434
1435
1436
# File 'lib/stripe/services/account_service.rb', line 1434

def verification
  @verification
end