Class: Stripe::AccountService::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1111
1112
1113
1114
1115
# File 'lib/stripe/services/account_service.rb', line 1111

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1105
1106
1107
# File 'lib/stripe/services/account_service.rb', line 1105

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1107
1108
1109
# File 'lib/stripe/services/account_service.rb', line 1107

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1109
1110
1111
# File 'lib/stripe/services/account_service.rb', line 1109

def user_agent
  @user_agent
end