Class: Stripe::AccountService::UpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1293
1294
1295
1296
1297
# File 'lib/stripe/services/account_service.rb', line 1293

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1287
1288
1289
# File 'lib/stripe/services/account_service.rb', line 1287

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1289
1290
1291
# File 'lib/stripe/services/account_service.rb', line 1289

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1291
1292
1293
# File 'lib/stripe/services/account_service.rb', line 1291

def user_agent
  @user_agent
end