Class: Stripe::AccountService::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1312
1313
1314
1315
1316
# File 'lib/stripe/services/account_service.rb', line 1312

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1306
1307
1308
# File 'lib/stripe/services/account_service.rb', line 1306

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1308
1309
1310
# File 'lib/stripe/services/account_service.rb', line 1308

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1310
1311
1312
# File 'lib/stripe/services/account_service.rb', line 1310

def user_agent
  @user_agent
end