Class: Stripe::AccountService::UpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1126
1127
1128
1129
1130
# File 'lib/stripe/services/account_service.rb', line 1126

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1120
1121
1122
# File 'lib/stripe/services/account_service.rb', line 1120

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1122
1123
1124
# File 'lib/stripe/services/account_service.rb', line 1122

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1124
1125
1126
# File 'lib/stripe/services/account_service.rb', line 1124

def user_agent
  @user_agent
end