Class: Stripe::AccountService::UpdateParams::Documents
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Documents
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: BankAccountOwnershipVerification, CompanyLicense, CompanyMemorandumOfAssociation, CompanyMinisterialDecree, CompanyRegistrationVerification, CompanyTaxIdVerification, ProofOfRegistration
Instance Attribute Summary collapse
-
#bank_account_ownership_verification ⇒ Object
One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement.
-
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
-
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
-
#company_ministerial_decree ⇒ Object
(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.
-
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
-
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
-
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
Instance Method Summary collapse
-
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_registration: nil) ⇒ Documents
constructor
A new instance of Documents.
Methods inherited from RequestParams
Constructor Details
#initialize(bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_registration: nil) ⇒ Documents
Returns a new instance of Documents.
1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 |
# File 'lib/stripe/services/account_service.rb', line 1418 def initialize( bank_account_ownership_verification: nil, company_license: nil, company_memorandum_of_association: nil, company_ministerial_decree: nil, company_registration_verification: nil, company_tax_id_verification: nil, proof_of_registration: nil ) @bank_account_ownership_verification = bank_account_ownership_verification @company_license = company_license @company_memorandum_of_association = company_memorandum_of_association @company_ministerial_decree = company_ministerial_decree @company_registration_verification = company_registration_verification @company_tax_id_verification = company_tax_id_verification @proof_of_registration = proof_of_registration end |
Instance Attribute Details
#bank_account_ownership_verification ⇒ Object
One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement. Must be a document associated with the account’s primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
1404 1405 1406 |
# File 'lib/stripe/services/account_service.rb', line 1404 def bank_account_ownership_verification @bank_account_ownership_verification end |
#company_license ⇒ Object
One or more documents that demonstrate proof of a company’s license to operate.
1406 1407 1408 |
# File 'lib/stripe/services/account_service.rb', line 1406 def company_license @company_license end |
#company_memorandum_of_association ⇒ Object
One or more documents showing the company’s Memorandum of Association.
1408 1409 1410 |
# File 'lib/stripe/services/account_service.rb', line 1408 def company_memorandum_of_association @company_memorandum_of_association end |
#company_ministerial_decree ⇒ Object
(Certain countries only) One or more documents showing the ministerial decree legalizing the company’s establishment.
1410 1411 1412 |
# File 'lib/stripe/services/account_service.rb', line 1410 def company_ministerial_decree @company_ministerial_decree end |
#company_registration_verification ⇒ Object
One or more documents that demonstrate proof of a company’s registration with the appropriate local authorities.
1412 1413 1414 |
# File 'lib/stripe/services/account_service.rb', line 1412 def company_registration_verification @company_registration_verification end |
#company_tax_id_verification ⇒ Object
One or more documents that demonstrate proof of a company’s tax ID.
1414 1415 1416 |
# File 'lib/stripe/services/account_service.rb', line 1414 def company_tax_id_verification @company_tax_id_verification end |
#proof_of_registration ⇒ Object
One or more documents showing the company’s proof of registration with the national business registry.
1416 1417 1418 |
# File 'lib/stripe/services/account_service.rb', line 1416 def proof_of_registration @proof_of_registration end |