Class: Stripe::AccountService::UpdateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
# File 'lib/stripe/services/account_service.rb', line 1834

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



1788
1789
1790
# File 'lib/stripe/services/account_service.rb', line 1788

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



1790
1791
1792
# File 'lib/stripe/services/account_service.rb', line 1790

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



1792
1793
1794
# File 'lib/stripe/services/account_service.rb', line 1792

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



1794
1795
1796
# File 'lib/stripe/services/account_service.rb', line 1794

def dob
  @dob
end

#emailObject

The individual’s email address.



1796
1797
1798
# File 'lib/stripe/services/account_service.rb', line 1796

def email
  @email
end

#first_nameObject

The individual’s first name.



1798
1799
1800
# File 'lib/stripe/services/account_service.rb', line 1798

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



1800
1801
1802
# File 'lib/stripe/services/account_service.rb', line 1800

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



1802
1803
1804
# File 'lib/stripe/services/account_service.rb', line 1802

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



1804
1805
1806
# File 'lib/stripe/services/account_service.rb', line 1804

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



1806
1807
1808
# File 'lib/stripe/services/account_service.rb', line 1806

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



1808
1809
1810
# File 'lib/stripe/services/account_service.rb', line 1808

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



1810
1811
1812
# File 'lib/stripe/services/account_service.rb', line 1810

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



1812
1813
1814
# File 'lib/stripe/services/account_service.rb', line 1812

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



1814
1815
1816
# File 'lib/stripe/services/account_service.rb', line 1814

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



1816
1817
1818
# File 'lib/stripe/services/account_service.rb', line 1816

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



1818
1819
1820
# File 'lib/stripe/services/account_service.rb', line 1818

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1820
1821
1822
# File 'lib/stripe/services/account_service.rb', line 1820

def 
  @metadata
end

#phoneObject

The individual’s phone number.



1822
1823
1824
# File 'lib/stripe/services/account_service.rb', line 1822

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1824
1825
1826
# File 'lib/stripe/services/account_service.rb', line 1824

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



1826
1827
1828
# File 'lib/stripe/services/account_service.rb', line 1826

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



1828
1829
1830
# File 'lib/stripe/services/account_service.rb', line 1828

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



1830
1831
1832
# File 'lib/stripe/services/account_service.rb', line 1830

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



1832
1833
1834
# File 'lib/stripe/services/account_service.rb', line 1832

def verification
  @verification
end