Class: Stripe::AccountService::UpdateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
# File 'lib/stripe/services/account_service.rb', line 1617

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



1571
1572
1573
# File 'lib/stripe/services/account_service.rb', line 1571

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



1573
1574
1575
# File 'lib/stripe/services/account_service.rb', line 1573

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



1575
1576
1577
# File 'lib/stripe/services/account_service.rb', line 1575

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



1577
1578
1579
# File 'lib/stripe/services/account_service.rb', line 1577

def dob
  @dob
end

#emailObject

The individual’s email address.



1579
1580
1581
# File 'lib/stripe/services/account_service.rb', line 1579

def email
  @email
end

#first_nameObject

The individual’s first name.



1581
1582
1583
# File 'lib/stripe/services/account_service.rb', line 1581

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



1583
1584
1585
# File 'lib/stripe/services/account_service.rb', line 1583

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



1585
1586
1587
# File 'lib/stripe/services/account_service.rb', line 1585

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



1587
1588
1589
# File 'lib/stripe/services/account_service.rb', line 1587

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



1589
1590
1591
# File 'lib/stripe/services/account_service.rb', line 1589

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



1591
1592
1593
# File 'lib/stripe/services/account_service.rb', line 1591

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



1593
1594
1595
# File 'lib/stripe/services/account_service.rb', line 1593

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



1595
1596
1597
# File 'lib/stripe/services/account_service.rb', line 1595

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



1597
1598
1599
# File 'lib/stripe/services/account_service.rb', line 1597

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



1599
1600
1601
# File 'lib/stripe/services/account_service.rb', line 1599

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



1601
1602
1603
# File 'lib/stripe/services/account_service.rb', line 1601

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1603
1604
1605
# File 'lib/stripe/services/account_service.rb', line 1603

def 
  @metadata
end

#phoneObject

The individual’s phone number.



1605
1606
1607
# File 'lib/stripe/services/account_service.rb', line 1605

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1607
1608
1609
# File 'lib/stripe/services/account_service.rb', line 1607

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



1609
1610
1611
# File 'lib/stripe/services/account_service.rb', line 1609

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



1611
1612
1613
# File 'lib/stripe/services/account_service.rb', line 1611

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



1613
1614
1615
# File 'lib/stripe/services/account_service.rb', line 1613

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



1615
1616
1617
# File 'lib/stripe/services/account_service.rb', line 1615

def verification
  @verification
end