Class: Stripe::AccountService::UpdateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Individual
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 |
# File 'lib/stripe/services/account_service.rb', line 1799 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
1753 1754 1755 |
# File 'lib/stripe/services/account_service.rb', line 1753 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
1755 1756 1757 |
# File 'lib/stripe/services/account_service.rb', line 1755 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
1757 1758 1759 |
# File 'lib/stripe/services/account_service.rb', line 1757 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
1759 1760 1761 |
# File 'lib/stripe/services/account_service.rb', line 1759 def dob @dob end |
#email ⇒ Object
The individual’s email address.
1761 1762 1763 |
# File 'lib/stripe/services/account_service.rb', line 1761 def email @email end |
#first_name ⇒ Object
The individual’s first name.
1763 1764 1765 |
# File 'lib/stripe/services/account_service.rb', line 1763 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
1765 1766 1767 |
# File 'lib/stripe/services/account_service.rb', line 1765 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
1767 1768 1769 |
# File 'lib/stripe/services/account_service.rb', line 1767 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
1769 1770 1771 |
# File 'lib/stripe/services/account_service.rb', line 1769 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
1771 1772 1773 |
# File 'lib/stripe/services/account_service.rb', line 1771 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
1773 1774 1775 |
# File 'lib/stripe/services/account_service.rb', line 1773 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
1775 1776 1777 |
# File 'lib/stripe/services/account_service.rb', line 1775 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
1777 1778 1779 |
# File 'lib/stripe/services/account_service.rb', line 1777 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
1779 1780 1781 |
# File 'lib/stripe/services/account_service.rb', line 1779 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
1781 1782 1783 |
# File 'lib/stripe/services/account_service.rb', line 1781 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
1783 1784 1785 |
# File 'lib/stripe/services/account_service.rb', line 1783 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1785 1786 1787 |
# File 'lib/stripe/services/account_service.rb', line 1785 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
1787 1788 1789 |
# File 'lib/stripe/services/account_service.rb', line 1787 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
1789 1790 1791 |
# File 'lib/stripe/services/account_service.rb', line 1789 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
1791 1792 1793 |
# File 'lib/stripe/services/account_service.rb', line 1791 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
1793 1794 1795 |
# File 'lib/stripe/services/account_service.rb', line 1793 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
1795 1796 1797 |
# File 'lib/stripe/services/account_service.rb', line 1795 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
1797 1798 1799 |
# File 'lib/stripe/services/account_service.rb', line 1797 def verification @verification end |