Class: Stripe::AccountService::UpdateParams::Individual

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
# File 'lib/stripe/services/account_service.rb', line 1702

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



1656
1657
1658
# File 'lib/stripe/services/account_service.rb', line 1656

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



1658
1659
1660
# File 'lib/stripe/services/account_service.rb', line 1658

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



1660
1661
1662
# File 'lib/stripe/services/account_service.rb', line 1660

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



1662
1663
1664
# File 'lib/stripe/services/account_service.rb', line 1662

def dob
  @dob
end

#emailObject

The individual’s email address.



1664
1665
1666
# File 'lib/stripe/services/account_service.rb', line 1664

def email
  @email
end

#first_nameObject

The individual’s first name.



1666
1667
1668
# File 'lib/stripe/services/account_service.rb', line 1666

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



1668
1669
1670
# File 'lib/stripe/services/account_service.rb', line 1668

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



1670
1671
1672
# File 'lib/stripe/services/account_service.rb', line 1670

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



1672
1673
1674
# File 'lib/stripe/services/account_service.rb', line 1672

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



1674
1675
1676
# File 'lib/stripe/services/account_service.rb', line 1674

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



1676
1677
1678
# File 'lib/stripe/services/account_service.rb', line 1676

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



1678
1679
1680
# File 'lib/stripe/services/account_service.rb', line 1678

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



1680
1681
1682
# File 'lib/stripe/services/account_service.rb', line 1680

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



1682
1683
1684
# File 'lib/stripe/services/account_service.rb', line 1682

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



1684
1685
1686
# File 'lib/stripe/services/account_service.rb', line 1684

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



1686
1687
1688
# File 'lib/stripe/services/account_service.rb', line 1686

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1688
1689
1690
# File 'lib/stripe/services/account_service.rb', line 1688

def 
  @metadata
end

#phoneObject

The individual’s phone number.



1690
1691
1692
# File 'lib/stripe/services/account_service.rb', line 1690

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1692
1693
1694
# File 'lib/stripe/services/account_service.rb', line 1692

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



1694
1695
1696
# File 'lib/stripe/services/account_service.rb', line 1694

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



1696
1697
1698
# File 'lib/stripe/services/account_service.rb', line 1696

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



1698
1699
1700
# File 'lib/stripe/services/account_service.rb', line 1698

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



1700
1701
1702
# File 'lib/stripe/services/account_service.rb', line 1700

def verification
  @verification
end