Class: Stripe::AccountService::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
# File 'lib/stripe/services/account_service.rb', line 1556

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1546
1547
1548
# File 'lib/stripe/services/account_service.rb', line 1546

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1548
1549
1550
# File 'lib/stripe/services/account_service.rb', line 1548

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1550
1551
1552
# File 'lib/stripe/services/account_service.rb', line 1550

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1552
1553
1554
# File 'lib/stripe/services/account_service.rb', line 1552

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1554
1555
1556
# File 'lib/stripe/services/account_service.rb', line 1554

def title
  @title
end