Class: Stripe::AccountService::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/stripe/services/account_service.rb', line 1726

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1716
1717
1718
# File 'lib/stripe/services/account_service.rb', line 1716

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1718
1719
1720
# File 'lib/stripe/services/account_service.rb', line 1718

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1720
1721
1722
# File 'lib/stripe/services/account_service.rb', line 1720

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1722
1723
1724
# File 'lib/stripe/services/account_service.rb', line 1722

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1724
1725
1726
# File 'lib/stripe/services/account_service.rb', line 1724

def title
  @title
end