Class: Stripe::AccountService::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
# File 'lib/stripe/services/account_service.rb', line 1521

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1511
1512
1513
# File 'lib/stripe/services/account_service.rb', line 1511

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1513
1514
1515
# File 'lib/stripe/services/account_service.rb', line 1513

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1515
1516
1517
# File 'lib/stripe/services/account_service.rb', line 1515

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1517
1518
1519
# File 'lib/stripe/services/account_service.rb', line 1517

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1519
1520
1521
# File 'lib/stripe/services/account_service.rb', line 1519

def title
  @title
end