Class: Stripe::AccountService::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
# File 'lib/stripe/services/account_service.rb', line 1703

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1693
1694
1695
# File 'lib/stripe/services/account_service.rb', line 1693

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1695
1696
1697
# File 'lib/stripe/services/account_service.rb', line 1695

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1697
1698
1699
# File 'lib/stripe/services/account_service.rb', line 1697

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1699
1700
1701
# File 'lib/stripe/services/account_service.rb', line 1699

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1701
1702
1703
# File 'lib/stripe/services/account_service.rb', line 1701

def title
  @title
end