Class: Stripe::AccountService::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
# File 'lib/stripe/services/account_service.rb', line 1651

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1641
1642
1643
# File 'lib/stripe/services/account_service.rb', line 1641

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1643
1644
1645
# File 'lib/stripe/services/account_service.rb', line 1643

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1645
1646
1647
# File 'lib/stripe/services/account_service.rb', line 1645

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1647
1648
1649
# File 'lib/stripe/services/account_service.rb', line 1647

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1649
1650
1651
# File 'lib/stripe/services/account_service.rb', line 1649

def title
  @title
end