Class: Stripe::AccountService::UpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
# File 'lib/stripe/services/account_service.rb', line 1779

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1765
1766
1767
# File 'lib/stripe/services/account_service.rb', line 1765

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1768
1769
1770
# File 'lib/stripe/services/account_service.rb', line 1768

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1771
1772
1773
# File 'lib/stripe/services/account_service.rb', line 1771

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1774
1775
1776
# File 'lib/stripe/services/account_service.rb', line 1774

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1777
1778
1779
# File 'lib/stripe/services/account_service.rb', line 1777

def title
  @title
end