Class: Stripe::AccountService::UpdateParams::Individual::Relationship
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Individual::Relationship
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#director ⇒ Object
Whether the person is a director of the account’s legal entity.
-
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
-
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
-
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
-
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
Instance Method Summary collapse
-
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
constructor
A new instance of Relationship.
Methods inherited from RequestParams
Constructor Details
#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship
Returns a new instance of Relationship.
1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 |
# File 'lib/stripe/services/account_service.rb', line 1606 def initialize( director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil ) @director = director @executive = executive @owner = owner @percent_ownership = percent_ownership @title = title end |
Instance Attribute Details
#director ⇒ Object
Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
1596 1597 1598 |
# File 'lib/stripe/services/account_service.rb', line 1596 def director @director end |
#executive ⇒ Object
Whether the person has significant responsibility to control, manage, or direct the organization.
1598 1599 1600 |
# File 'lib/stripe/services/account_service.rb', line 1598 def executive @executive end |
#owner ⇒ Object
Whether the person is an owner of the account’s legal entity.
1600 1601 1602 |
# File 'lib/stripe/services/account_service.rb', line 1600 def owner @owner end |
#percent_ownership ⇒ Object
The percent owned by the person of the account’s legal entity.
1602 1603 1604 |
# File 'lib/stripe/services/account_service.rb', line 1602 def percent_ownership @percent_ownership end |
#title ⇒ Object
The person’s title (e.g., CEO, Support Engineer).
1604 1605 1606 |
# File 'lib/stripe/services/account_service.rb', line 1604 def title @title end |