Class: Stripe::AccountService::UpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 |
# File 'lib/stripe/services/account_service.rb', line 1890 def initialize( bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @branding = branding @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
1874 1875 1876 |
# File 'lib/stripe/services/account_service.rb', line 1874 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
1876 1877 1878 |
# File 'lib/stripe/services/account_service.rb', line 1876 def branding @branding end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
1878 1879 1880 |
# File 'lib/stripe/services/account_service.rb', line 1878 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
1880 1881 1882 |
# File 'lib/stripe/services/account_service.rb', line 1880 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
1882 1883 1884 |
# File 'lib/stripe/services/account_service.rb', line 1882 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
1884 1885 1886 |
# File 'lib/stripe/services/account_service.rb', line 1884 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
1886 1887 1888 |
# File 'lib/stripe/services/account_service.rb', line 1886 def payouts @payouts end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
1888 1889 1890 |
# File 'lib/stripe/services/account_service.rb', line 1888 def treasury @treasury end |