Class: Stripe::AccountService::UpdateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
# File 'lib/stripe/services/account_service.rb', line 1878

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



1862
1863
1864
# File 'lib/stripe/services/account_service.rb', line 1862

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



1864
1865
1866
# File 'lib/stripe/services/account_service.rb', line 1864

def branding
  @branding
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



1866
1867
1868
# File 'lib/stripe/services/account_service.rb', line 1866

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



1868
1869
1870
# File 'lib/stripe/services/account_service.rb', line 1868

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



1870
1871
1872
# File 'lib/stripe/services/account_service.rb', line 1870

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



1872
1873
1874
# File 'lib/stripe/services/account_service.rb', line 1872

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



1874
1875
1876
# File 'lib/stripe/services/account_service.rb', line 1874

def payouts
  @payouts
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



1876
1877
1878
# File 'lib/stripe/services/account_service.rb', line 1876

def treasury
  @treasury
end