Class: Stripe::AccountService::UpdateParams::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
# File 'lib/stripe/services/account_service.rb', line 1855

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



1839
1840
1841
# File 'lib/stripe/services/account_service.rb', line 1839

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



1841
1842
1843
# File 'lib/stripe/services/account_service.rb', line 1841

def branding
  @branding
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



1843
1844
1845
# File 'lib/stripe/services/account_service.rb', line 1843

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



1845
1846
1847
# File 'lib/stripe/services/account_service.rb', line 1845

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



1847
1848
1849
# File 'lib/stripe/services/account_service.rb', line 1847

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



1849
1850
1851
# File 'lib/stripe/services/account_service.rb', line 1849

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



1851
1852
1853
# File 'lib/stripe/services/account_service.rb', line 1851

def payouts
  @payouts
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



1853
1854
1855
# File 'lib/stripe/services/account_service.rb', line 1853

def treasury
  @treasury
end