Class: Stripe::AccountService::UpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 |
# File 'lib/stripe/services/account_service.rb', line 2007 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
1985 1986 1987 |
# File 'lib/stripe/services/account_service.rb', line 1985 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
1987 1988 1989 |
# File 'lib/stripe/services/account_service.rb', line 1987 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
1989 1990 1991 |
# File 'lib/stripe/services/account_service.rb', line 1989 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
1991 1992 1993 |
# File 'lib/stripe/services/account_service.rb', line 1991 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
1993 1994 1995 |
# File 'lib/stripe/services/account_service.rb', line 1993 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
1995 1996 1997 |
# File 'lib/stripe/services/account_service.rb', line 1995 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
1997 1998 1999 |
# File 'lib/stripe/services/account_service.rb', line 1997 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
1999 2000 2001 |
# File 'lib/stripe/services/account_service.rb', line 1999 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
2001 2002 2003 |
# File 'lib/stripe/services/account_service.rb', line 2001 def payouts @payouts end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
2003 2004 2005 |
# File 'lib/stripe/services/account_service.rb', line 2003 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
2005 2006 2007 |
# File 'lib/stripe/services/account_service.rb', line 2005 def treasury @treasury end |