Class: Stripe::AccountService::UpdateParams::Settings::BacsDebitPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings::BacsDebitPayments
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#display_name ⇒ Object
The Bacs Direct Debit Display Name for this account.
Instance Method Summary collapse
-
#initialize(display_name: nil) ⇒ BacsDebitPayments
constructor
A new instance of BacsDebitPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(display_name: nil) ⇒ BacsDebitPayments
Returns a new instance of BacsDebitPayments.
1696 1697 1698 |
# File 'lib/stripe/services/account_service.rb', line 1696 def initialize(display_name: nil) @display_name = display_name end |
Instance Attribute Details
#display_name ⇒ Object
The Bacs Direct Debit Display Name for this account. For payments made with Bacs Direct Debit, this name appears on the mandate as the statement descriptor. Mobile banking apps display it as the name of the business. To use custom branding, set the Bacs Direct Debit Display Name during or right after creation. Custom branding incurs an additional monthly fee for the platform. If you don’t set the display name before requesting Bacs capability, it’s automatically set as “Stripe” and the account is onboarded to Stripe branding, which is free.
1694 1695 1696 |
# File 'lib/stripe/services/account_service.rb', line 1694 def display_name @display_name end |