Class: Stripe::AccountService::UpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



1948
1949
1950
1951
1952
1953
# File 'lib/stripe/services/account_service.rb', line 1948

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



1940
1941
1942
# File 'lib/stripe/services/account_service.rb', line 1940

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



1942
1943
1944
# File 'lib/stripe/services/account_service.rb', line 1942

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



1944
1945
1946
# File 'lib/stripe/services/account_service.rb', line 1944

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



1946
1947
1948
# File 'lib/stripe/services/account_service.rb', line 1946

def secondary_color
  @secondary_color
end