Class: Stripe::AccountService::UpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



1917
1918
1919
1920
1921
1922
# File 'lib/stripe/services/account_service.rb', line 1917

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



1909
1910
1911
# File 'lib/stripe/services/account_service.rb', line 1909

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



1911
1912
1913
# File 'lib/stripe/services/account_service.rb', line 1911

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



1913
1914
1915
# File 'lib/stripe/services/account_service.rb', line 1913

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



1915
1916
1917
# File 'lib/stripe/services/account_service.rb', line 1915

def secondary_color
  @secondary_color
end