Class: Stripe::AccountService::UpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



1936
1937
1938
1939
1940
1941
# File 'lib/stripe/services/account_service.rb', line 1936

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



1928
1929
1930
# File 'lib/stripe/services/account_service.rb', line 1928

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



1930
1931
1932
# File 'lib/stripe/services/account_service.rb', line 1930

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



1932
1933
1934
# File 'lib/stripe/services/account_service.rb', line 1932

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



1934
1935
1936
# File 'lib/stripe/services/account_service.rb', line 1934

def secondary_color
  @secondary_color
end