Class: Stripe::AccountService::UpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1977
1978
1979
1980
1981
# File 'lib/stripe/services/account_service.rb', line 1977

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1971
1972
1973
# File 'lib/stripe/services/account_service.rb', line 1971

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1973
1974
1975
# File 'lib/stripe/services/account_service.rb', line 1973

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1975
1976
1977
# File 'lib/stripe/services/account_service.rb', line 1975

def user_agent
  @user_agent
end