Class: Stripe::AccountService::UpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1740
1741
1742
1743
1744
# File 'lib/stripe/services/account_service.rb', line 1740

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1734
1735
1736
# File 'lib/stripe/services/account_service.rb', line 1734

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1736
1737
1738
# File 'lib/stripe/services/account_service.rb', line 1736

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1738
1739
1740
# File 'lib/stripe/services/account_service.rb', line 1738

def user_agent
  @user_agent
end