Class: Stripe::AccountService::UpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1728
1729
1730
1731
1732
# File 'lib/stripe/services/account_service.rb', line 1728

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1722
1723
1724
# File 'lib/stripe/services/account_service.rb', line 1722

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1724
1725
1726
# File 'lib/stripe/services/account_service.rb', line 1724

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1726
1727
1728
# File 'lib/stripe/services/account_service.rb', line 1726

def user_agent
  @user_agent
end