Class: Stripe::AccountService::UpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2051
2052
2053
2054
2055
# File 'lib/stripe/services/account_service.rb', line 2051

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2043
2044
2045
# File 'lib/stripe/services/account_service.rb', line 2043

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2046
2047
2048
# File 'lib/stripe/services/account_service.rb', line 2046

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2049
2050
2051
# File 'lib/stripe/services/account_service.rb', line 2049

def user_agent
  @user_agent
end