Class: Stripe::AccountService::UpdateParams::Settings::CardPayments::DeclineOn
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings::CardPayments::DeclineOn
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#avs_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect ZIP or postal code.
-
#cvc_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect CVC.
Instance Method Summary collapse
-
#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn
constructor
A new instance of DeclineOn.
Methods inherited from RequestParams
Constructor Details
#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn
Returns a new instance of DeclineOn.
1911 1912 1913 1914 |
# File 'lib/stripe/services/account_service.rb', line 1911 def initialize(avs_failure: nil, cvc_failure: nil) @avs_failure = avs_failure @cvc_failure = cvc_failure end |
Instance Attribute Details
#avs_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.
1907 1908 1909 |
# File 'lib/stripe/services/account_service.rb', line 1907 def avs_failure @avs_failure end |
#cvc_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.
1909 1910 1911 |
# File 'lib/stripe/services/account_service.rb', line 1909 def cvc_failure @cvc_failure end |