Class: Stripe::AccountService::UpdateParams::Settings::Payouts

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Defined Under Namespace

Classes: Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts

Returns a new instance of Payouts.



1809
1810
1811
1812
1813
# File 'lib/stripe/services/account_service.rb', line 1809

def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil)
  @debit_negative_balances = debit_negative_balances
  @schedule = schedule
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#debit_negative_balancesObject

A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](/connect/account-balances).



1803
1804
1805
# File 'lib/stripe/services/account_service.rb', line 1803

def debit_negative_balances
  @debit_negative_balances
end

#scheduleObject

Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.



1805
1806
1807
# File 'lib/stripe/services/account_service.rb', line 1805

def schedule
  @schedule
end

#statement_descriptorObject

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.



1807
1808
1809
# File 'lib/stripe/services/account_service.rb', line 1807

def statement_descriptor
  @statement_descriptor
end