Class: Stripe::AccountService::UpdateParams::Settings::Payouts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings::Payouts
- Defined in:
- lib/stripe/services/account_service.rb
Defined Under Namespace
Classes: Schedule
Instance Attribute Summary collapse
-
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account.
-
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account.
-
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts.
Instance Method Summary collapse
-
#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
constructor
A new instance of Payouts.
Methods inherited from RequestParams
Constructor Details
#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
Returns a new instance of Payouts.
2163 2164 2165 2166 2167 |
# File 'lib/stripe/services/account_service.rb', line 2163 def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) @debit_negative_balances = debit_negative_balances @schedule = schedule @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](/connect/account-balances).
2155 2156 2157 |
# File 'lib/stripe/services/account_service.rb', line 2155 def debit_negative_balances @debit_negative_balances end |
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.
2158 2159 2160 |
# File 'lib/stripe/services/account_service.rb', line 2158 def schedule @schedule end |
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.
2161 2162 2163 |
# File 'lib/stripe/services/account_service.rb', line 2161 def statement_descriptor @statement_descriptor end |