Class: Stripe::AccountService::UpdateParams::Settings::Payouts::Schedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule

Returns a new instance of Schedule.



2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
# File 'lib/stripe/services/account_service.rb', line 2097

def initialize(
  delay_days: nil,
  interval: nil,
  monthly_anchor: nil,
  monthly_payout_days: nil,
  weekly_anchor: nil,
  weekly_payout_days: nil
)
  @delay_days = delay_days
  @interval = interval
  @monthly_anchor = monthly_anchor
  @monthly_payout_days = monthly_payout_days
  @weekly_anchor = weekly_anchor
  @weekly_payout_days = weekly_payout_days
end

Instance Attribute Details

#delay_daysObject

The number of days charge funds are held before being paid out. May also be set to ‘minimum`, representing the lowest available value for the account country. Default is `minimum`. The `delay_days` parameter remains at the last configured value if `interval` is `manual`. [Learn more about controlling payout delay days](/connect/manage-payout-schedule).



2085
2086
2087
# File 'lib/stripe/services/account_service.rb', line 2085

def delay_days
  @delay_days
end

#intervalObject

How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.



2087
2088
2089
# File 'lib/stripe/services/account_service.rb', line 2087

def interval
  @interval
end

#monthly_anchorObject

The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.



2089
2090
2091
# File 'lib/stripe/services/account_service.rb', line 2089

def monthly_anchor
  @monthly_anchor
end

#monthly_payout_daysObject

The days of the month when available funds are paid out, specified as an array of numbers between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly` and `monthly_anchor` is not set.



2091
2092
2093
# File 'lib/stripe/services/account_service.rb', line 2091

def monthly_payout_days
  @monthly_payout_days
end

#weekly_anchorObject

The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc. (required and applicable only if `interval` is `weekly`.)



2093
2094
2095
# File 'lib/stripe/services/account_service.rb', line 2093

def weekly_anchor
  @weekly_anchor
end

#weekly_payout_daysObject

The days of the week when available funds are paid out, specified as an array, e.g., [‘monday`, `tuesday`]. (required and applicable only if `interval` is `weekly` and `weekly_anchor` is not set.)



2095
2096
2097
# File 'lib/stripe/services/account_service.rb', line 2095

def weekly_payout_days
  @weekly_payout_days
end