Class: Stripe::AccountService::UpdateParams::Settings::Payouts::Schedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, weekly_anchor: nil) ⇒ Schedule

Returns a new instance of Schedule.



2055
2056
2057
2058
2059
2060
# File 'lib/stripe/services/account_service.rb', line 2055

def initialize(delay_days: nil, interval: nil, monthly_anchor: nil, weekly_anchor: nil)
  @delay_days = delay_days
  @interval = interval
  @monthly_anchor = monthly_anchor
  @weekly_anchor = weekly_anchor
end

Instance Attribute Details

#delay_daysObject

The number of days charge funds are held before being paid out. May also be set to ‘minimum`, representing the lowest available value for the account country. Default is `minimum`. The `delay_days` parameter remains at the last configured value if `interval` is `manual`. [Learn more about controlling payout delay days](/connect/manage-payout-schedule).



2047
2048
2049
# File 'lib/stripe/services/account_service.rb', line 2047

def delay_days
  @delay_days
end

#intervalObject

How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.



2049
2050
2051
# File 'lib/stripe/services/account_service.rb', line 2049

def interval
  @interval
end

#monthly_anchorObject

The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.



2051
2052
2053
# File 'lib/stripe/services/account_service.rb', line 2051

def monthly_anchor
  @monthly_anchor
end

#weekly_anchorObject

The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc. (required and applicable only if `interval` is `weekly`.)



2053
2054
2055
# File 'lib/stripe/services/account_service.rb', line 2053

def weekly_anchor
  @weekly_anchor
end