Class: Stripe::AccountService::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1899
1900
1901
1902
1903
# File 'lib/stripe/services/account_service.rb', line 1899

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1893
1894
1895
# File 'lib/stripe/services/account_service.rb', line 1893

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1895
1896
1897
# File 'lib/stripe/services/account_service.rb', line 1895

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1897
1898
1899
# File 'lib/stripe/services/account_service.rb', line 1897

def user_agent
  @user_agent
end