Class: Stripe::AccountService::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2106
2107
2108
2109
2110
# File 'lib/stripe/services/account_service.rb', line 2106

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2100
2101
2102
# File 'lib/stripe/services/account_service.rb', line 2100

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2102
2103
2104
# File 'lib/stripe/services/account_service.rb', line 2102

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2104
2105
2106
# File 'lib/stripe/services/account_service.rb', line 2104

def user_agent
  @user_agent
end