Class: Stripe::AccountService::UpdateParams::Settings::Treasury::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings::Treasury::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
1860 1861 1862 1863 1864 |
# File 'lib/stripe/services/account_service.rb', line 1860 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
1854 1855 1856 |
# File 'lib/stripe/services/account_service.rb', line 1854 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
1856 1857 1858 |
# File 'lib/stripe/services/account_service.rb', line 1856 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
1858 1859 1860 |
# File 'lib/stripe/services/account_service.rb', line 1858 def user_agent @user_agent end |