Class: Stripe::AccountService::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1825
1826
1827
1828
1829
# File 'lib/stripe/services/account_service.rb', line 1825

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1819
1820
1821
# File 'lib/stripe/services/account_service.rb', line 1819

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1821
1822
1823
# File 'lib/stripe/services/account_service.rb', line 1821

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1823
1824
1825
# File 'lib/stripe/services/account_service.rb', line 1823

def user_agent
  @user_agent
end