Class: Stripe::AccountService::UpdateParams::Settings::Treasury::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::Settings::Treasury::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
1971 1972 1973 1974 1975 |
# File 'lib/stripe/services/account_service.rb', line 1971 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
1965 1966 1967 |
# File 'lib/stripe/services/account_service.rb', line 1965 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
1967 1968 1969 |
# File 'lib/stripe/services/account_service.rb', line 1967 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
1969 1970 1971 |
# File 'lib/stripe/services/account_service.rb', line 1969 def user_agent @user_agent end |