Class: Stripe::AccountService::UpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2190
2191
2192
2193
2194
# File 'lib/stripe/services/account_service.rb', line 2190

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2182
2183
2184
# File 'lib/stripe/services/account_service.rb', line 2182

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2185
2186
2187
# File 'lib/stripe/services/account_service.rb', line 2185

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2188
2189
2190
# File 'lib/stripe/services/account_service.rb', line 2188

def user_agent
  @user_agent
end