Class: Stripe::AccountService::UpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1921
1922
1923
1924
1925
1926
# File 'lib/stripe/services/account_service.rb', line 1921

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



1913
1914
1915
# File 'lib/stripe/services/account_service.rb', line 1913

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



1915
1916
1917
# File 'lib/stripe/services/account_service.rb', line 1915

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



1917
1918
1919
# File 'lib/stripe/services/account_service.rb', line 1917

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



1919
1920
1921
# File 'lib/stripe/services/account_service.rb', line 1919

def user_agent
  @user_agent
end