Class: Stripe::AccountService::UpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1886
1887
1888
1889
1890
1891
# File 'lib/stripe/services/account_service.rb', line 1886

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



1878
1879
1880
# File 'lib/stripe/services/account_service.rb', line 1878

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



1880
1881
1882
# File 'lib/stripe/services/account_service.rb', line 1880

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



1882
1883
1884
# File 'lib/stripe/services/account_service.rb', line 1882

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



1884
1885
1886
# File 'lib/stripe/services/account_service.rb', line 1884

def user_agent
  @user_agent
end