Class: Stripe::AccountService::UpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2144
2145
2146
2147
2148
2149
# File 'lib/stripe/services/account_service.rb', line 2144

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2136
2137
2138
# File 'lib/stripe/services/account_service.rb', line 2136

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2138
2139
2140
# File 'lib/stripe/services/account_service.rb', line 2138

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2140
2141
2142
# File 'lib/stripe/services/account_service.rb', line 2140

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2142
2143
2144
# File 'lib/stripe/services/account_service.rb', line 2142

def user_agent
  @user_agent
end