Class: Stripe::AccountService::UpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2144 2145 2146 2147 2148 2149 |
# File 'lib/stripe/services/account_service.rb', line 2144 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2136 2137 2138 |
# File 'lib/stripe/services/account_service.rb', line 2136 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2138 2139 2140 |
# File 'lib/stripe/services/account_service.rb', line 2138 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2140 2141 2142 |
# File 'lib/stripe/services/account_service.rb', line 2140 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2142 2143 2144 |
# File 'lib/stripe/services/account_service.rb', line 2142 def user_agent @user_agent end |