Class: Stripe::AccountService::UpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
1886 1887 1888 1889 1890 1891 |
# File 'lib/stripe/services/account_service.rb', line 1886 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
1878 1879 1880 |
# File 'lib/stripe/services/account_service.rb', line 1878 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
1880 1881 1882 |
# File 'lib/stripe/services/account_service.rb', line 1880 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
1882 1883 1884 |
# File 'lib/stripe/services/account_service.rb', line 1882 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
1884 1885 1886 |
# File 'lib/stripe/services/account_service.rb', line 1884 def user_agent @user_agent end |