Class: Stripe::AccountService::UpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2089 2090 2091 2092 2093 2094 |
# File 'lib/stripe/services/account_service.rb', line 2089 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2081 2082 2083 |
# File 'lib/stripe/services/account_service.rb', line 2081 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2083 2084 2085 |
# File 'lib/stripe/services/account_service.rb', line 2083 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2085 2086 2087 |
# File 'lib/stripe/services/account_service.rb', line 2085 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2087 2088 2089 |
# File 'lib/stripe/services/account_service.rb', line 2087 def user_agent @user_agent end |