Class: Stripe::AccountService::UpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2276
2277
2278
2279
2280
2281
# File 'lib/stripe/services/account_service.rb', line 2276

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2265
2266
2267
# File 'lib/stripe/services/account_service.rb', line 2265

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2268
2269
2270
# File 'lib/stripe/services/account_service.rb', line 2268

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2271
2272
2273
# File 'lib/stripe/services/account_service.rb', line 2271

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2274
2275
2276
# File 'lib/stripe/services/account_service.rb', line 2274

def user_agent
  @user_agent
end