Class: Stripe::AccountService::UpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountService::UpdateParams::TosAcceptance
- Defined in:
- lib/stripe/services/account_service.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2276 2277 2278 2279 2280 2281 |
# File 'lib/stripe/services/account_service.rb', line 2276 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2265 2266 2267 |
# File 'lib/stripe/services/account_service.rb', line 2265 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2268 2269 2270 |
# File 'lib/stripe/services/account_service.rb', line 2268 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2271 2272 2273 |
# File 'lib/stripe/services/account_service.rb', line 2271 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2274 2275 2276 |
# File 'lib/stripe/services/account_service.rb', line 2274 def user_agent @user_agent end |