Class: Stripe::AccountSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::AccountSession
- Extended by:
- Stripe::APIOperations::Create
- Defined in:
- lib/stripe/resources/account_session.rb
Overview
An AccountSession allows a Connect platform to grant access to a connected account in Connect embedded components.
We recommend that you create an AccountSession each time you need to display an embedded component to your user. Do not save AccountSessions to your database as they expire relatively quickly, and cannot be used more than once.
Related guide: Connect embedded components
Defined Under Namespace
Classes: Components
Constant Summary collapse
- OBJECT_NAME =
"account_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the account the AccountSession was created for.
-
#client_secret ⇒ Object
readonly
The client secret of this AccountSession.
-
#components ⇒ Object
readonly
Attribute for field components.
-
#expires_at ⇒ Object
readonly
The timestamp at which this AccountSession will expire.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#object ⇒ Object
readonly
String representing the object's type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a AccountSession object that includes a single-use token that the platform can use on their front-end to grant client-side API access.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods included from Stripe::APIOperations::Create
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from Stripe::APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the account the AccountSession was created for
797 798 799 |
# File 'lib/stripe/resources/account_session.rb', line 797 def account @account end |
#client_secret ⇒ Object (readonly)
The client secret of this AccountSession. Used on the client to set up secure access to the given account.
The client secret can be used to provide access to account from your frontend. It should not be stored, logged, or exposed to anyone other than the connected account. Make sure that you have TLS enabled on any page that includes the client secret.
Refer to our docs to setup Connect embedded components and learn about how client_secret should be handled.
803 804 805 |
# File 'lib/stripe/resources/account_session.rb', line 803 def client_secret @client_secret end |
#components ⇒ Object (readonly)
Attribute for field components
805 806 807 |
# File 'lib/stripe/resources/account_session.rb', line 805 def components @components end |
#expires_at ⇒ Object (readonly)
The timestamp at which this AccountSession will expire.
807 808 809 |
# File 'lib/stripe/resources/account_session.rb', line 807 def expires_at @expires_at end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
809 810 811 |
# File 'lib/stripe/resources/account_session.rb', line 809 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
811 812 813 |
# File 'lib/stripe/resources/account_session.rb', line 811 def object @object end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a AccountSession object that includes a single-use token that the platform can use on their front-end to grant client-side API access.
814 815 816 |
# File 'lib/stripe/resources/account_session.rb', line 814 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/account_sessions", params: params, opts: opts) end |
.field_remappings ⇒ Object
822 823 824 |
# File 'lib/stripe/resources/account_session.rb', line 822 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
818 819 820 |
# File 'lib/stripe/resources/account_session.rb', line 818 def self.inner_class_types @inner_class_types = { components: Components } end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/account_session.rb', line 16 def self.object_name "account_session" end |