Class: Stripe::AccountSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::AccountSession
- Extended by:
- Stripe::APIOperations::Create
- Defined in:
- lib/stripe/resources/account_session.rb
Overview
An AccountSession allows a Connect platform to grant access to a connected account in Connect embedded components.
We recommend that you create an AccountSession each time you need to display an embedded component to your user. Do not save AccountSessions to your database as they expire relatively quickly, and cannot be used more than once.
Related guide: [Connect embedded components](stripe.com/docs/connect/get-started-connect-embedded-components)
Defined Under Namespace
Classes: Components, CreateParams
Constant Summary collapse
- OBJECT_NAME =
"account_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the account the AccountSession was created for.
-
#client_secret ⇒ Object
readonly
The client secret of this AccountSession.
-
#components ⇒ Object
readonly
Attribute for field components.
-
#expires_at ⇒ Object
readonly
The timestamp at which this AccountSession will expire.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a AccountSession object that includes a single-use token that the platform can use on their front-end to grant client-side API access.
- .object_name ⇒ Object
Methods included from Stripe::APIOperations::Create
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from Stripe::APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the account the AccountSession was created for
1234 1235 1236 |
# File 'lib/stripe/resources/account_session.rb', line 1234 def account @account end |
#client_secret ⇒ Object (readonly)
The client secret of this AccountSession. Used on the client to set up secure access to the given ‘account`.
The client secret can be used to provide access to ‘account` from your frontend. It should not be stored, logged, or exposed to anyone other than the connected account. Make sure that you have TLS enabled on any page that includes the client secret.
Refer to our docs to [setup Connect embedded components](stripe.com/docs/connect/get-started-connect-embedded-components) and learn about how ‘client_secret` should be handled.
1240 1241 1242 |
# File 'lib/stripe/resources/account_session.rb', line 1240 def client_secret @client_secret end |
#components ⇒ Object (readonly)
Attribute for field components
1242 1243 1244 |
# File 'lib/stripe/resources/account_session.rb', line 1242 def components @components end |
#expires_at ⇒ Object (readonly)
The timestamp at which this AccountSession will expire.
1244 1245 1246 |
# File 'lib/stripe/resources/account_session.rb', line 1244 def expires_at @expires_at end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
1246 1247 1248 |
# File 'lib/stripe/resources/account_session.rb', line 1246 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1248 1249 1250 |
# File 'lib/stripe/resources/account_session.rb', line 1248 def object @object end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a AccountSession object that includes a single-use token that the platform can use on their front-end to grant client-side API access.
1251 1252 1253 |
# File 'lib/stripe/resources/account_session.rb', line 1251 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/account_sessions", params: params, opts: opts) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/account_session.rb', line 16 def self.object_name "account_session" end |