Class: Stripe::AccountSession

Inherits:
APIResource show all
Extended by:
Stripe::APIOperations::Create
Defined in:
lib/stripe/resources/account_session.rb

Overview

An AccountSession allows a Connect platform to grant access to a connected account in Connect embedded components.

We recommend that you create an AccountSession each time you need to display an embedded component to your user. Do not save AccountSessions to your database as they expire relatively quickly, and cannot be used more than once.

Related guide: [Connect embedded components](stripe.com/docs/connect/get-started-connect-embedded-components)

Defined Under Namespace

Classes: Components

Constant Summary collapse

OBJECT_NAME =
"account_session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from Stripe::APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from Stripe::APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The ID of the account the AccountSession was created for



107
108
109
# File 'lib/stripe/resources/account_session.rb', line 107

def 
  @account
end

#client_secretObject (readonly)

The client secret of this AccountSession. Used on the client to set up secure access to the given ‘account`.

The client secret can be used to provide access to ‘account` from your frontend. It should not be stored, logged, or exposed to anyone other than the connected account. Make sure that you have TLS enabled on any page that includes the client secret.

Refer to our docs to [setup Connect embedded components](stripe.com/docs/connect/get-started-connect-embedded-components) and learn about how ‘client_secret` should be handled.



113
114
115
# File 'lib/stripe/resources/account_session.rb', line 113

def client_secret
  @client_secret
end

#componentsObject (readonly)

Attribute for field components



115
116
117
# File 'lib/stripe/resources/account_session.rb', line 115

def components
  @components
end

#expires_atObject (readonly)

The timestamp at which this AccountSession will expire.



117
118
119
# File 'lib/stripe/resources/account_session.rb', line 117

def expires_at
  @expires_at
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



119
120
121
# File 'lib/stripe/resources/account_session.rb', line 119

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



121
122
123
# File 'lib/stripe/resources/account_session.rb', line 121

def object
  @object
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a AccountSession object that includes a single-use token that the platform can use on their front-end to grant client-side API access.



124
125
126
# File 'lib/stripe/resources/account_session.rb', line 124

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/account_sessions", params: params, opts: opts)
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/account_session.rb', line 16

def self.object_name
  "account_session"
end