Class: Stripe::AccountSession::Components::FinancialAccount::Features

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#disable_stripe_user_authenticationObject (readonly)

Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.



200
201
202
# File 'lib/stripe/resources/account_session.rb', line 200

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject (readonly)

Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.



202
203
204
# File 'lib/stripe/resources/account_session.rb', line 202

def 
  @external_account_collection
end

#send_moneyObject (readonly)

Whether to allow sending money.



204
205
206
# File 'lib/stripe/resources/account_session.rb', line 204

def send_money
  @send_money
end

#transfer_balanceObject (readonly)

Whether to allow transferring balance.



206
207
208
# File 'lib/stripe/resources/account_session.rb', line 206

def transfer_balance
  @transfer_balance
end

Class Method Details

.field_remappingsObject



212
213
214
# File 'lib/stripe/resources/account_session.rb', line 212

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



208
209
210
# File 'lib/stripe/resources/account_session.rb', line 208

def self.inner_class_types
  @inner_class_types = {}
end