Class: Stripe::AccountSession::Components::FinancialAccounts::Features
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::AccountSession::Components::FinancialAccounts::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bill_management ⇒ Object
readonly
Whether to allow bill management features.
-
#card_management ⇒ Object
readonly
Whether to allow card management features.
-
#disable_stripe_user_authentication ⇒ Object
readonly
Whether Stripe user authentication is disabled.
-
#edit_payout_schedule ⇒ Object
readonly
Whether to allow payout schedule to be changed.
-
#send_money ⇒ Object
readonly
Whether to enable the send money feature that grants access to the v2 CreateOutboundPayment API.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bill_management ⇒ Object (readonly)
Whether to allow bill management features.
435 436 437 |
# File 'lib/stripe/resources/account_session.rb', line 435 def bill_management @bill_management end |
#card_management ⇒ Object (readonly)
Whether to allow card management features.
437 438 439 |
# File 'lib/stripe/resources/account_session.rb', line 437 def card_management @card_management end |
#disable_stripe_user_authentication ⇒ Object (readonly)
Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. This is false by default.
439 440 441 |
# File 'lib/stripe/resources/account_session.rb', line 439 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#edit_payout_schedule ⇒ Object (readonly)
Whether to allow payout schedule to be changed. Defaults to true when controller.losses.payments is set to stripe for the account, otherwise false.
441 442 443 |
# File 'lib/stripe/resources/account_session.rb', line 441 def edit_payout_schedule @edit_payout_schedule end |
#send_money ⇒ Object (readonly)
Whether to enable the send money feature that grants access to the v2 CreateOutboundPayment API.
443 444 445 |
# File 'lib/stripe/resources/account_session.rb', line 443 def send_money @send_money end |
Class Method Details
.field_remappings ⇒ Object
449 450 451 |
# File 'lib/stripe/resources/account_session.rb', line 449 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
445 446 447 |
# File 'lib/stripe/resources/account_session.rb', line 445 def self.inner_class_types @inner_class_types = {} end |