Class: Stripe::AccountSession::Components::InstantPayoutsPromotion::Features
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::AccountSession::Components::InstantPayoutsPromotion::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
readonly
Whether Stripe user authentication is disabled.
-
#external_account_collection ⇒ Object
readonly
Whether external account collection is enabled.
-
#instant_payouts ⇒ Object
readonly
Whether to allow creation of instant payouts.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object (readonly)
Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
332 333 334 |
# File 'lib/stripe/resources/account_session.rb', line 332 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object (readonly)
Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.
334 335 336 |
# File 'lib/stripe/resources/account_session.rb', line 334 def external_account_collection @external_account_collection end |
#instant_payouts ⇒ Object (readonly)
Whether to allow creation of instant payouts. The default value is enabled when Stripe is responsible for negative account balances, and use_dashboard_rules otherwise.
336 337 338 |
# File 'lib/stripe/resources/account_session.rb', line 336 def instant_payouts @instant_payouts end |
Class Method Details
.field_remappings ⇒ Object
342 343 344 |
# File 'lib/stripe/resources/account_session.rb', line 342 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
338 339 340 |
# File 'lib/stripe/resources/account_session.rb', line 338 def self.inner_class_types @inner_class_types = {} end |