Class: Stripe::AccountSession::Components::PaymentDisputes::Features

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#destination_on_behalf_of_charge_managementObject (readonly)

Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.



539
540
541
# File 'lib/stripe/resources/account_session.rb', line 539

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject (readonly)

Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.



541
542
543
# File 'lib/stripe/resources/account_session.rb', line 541

def dispute_management
  @dispute_management
end

#refund_managementObject (readonly)

Whether sending refunds is enabled. This is ‘true` by default.



543
544
545
# File 'lib/stripe/resources/account_session.rb', line 543

def refund_management
  @refund_management
end

Class Method Details

.field_remappingsObject



549
550
551
# File 'lib/stripe/resources/account_session.rb', line 549

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



545
546
547
# File 'lib/stripe/resources/account_session.rb', line 545

def self.inner_class_types
  @inner_class_types = {}
end