Class: Stripe::AccountSession::Components::Payments::Features

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_paymentsObject (readonly)

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



195
196
197
# File 'lib/stripe/resources/account_session.rb', line 195

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject (readonly)

Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.



197
198
199
# File 'lib/stripe/resources/account_session.rb', line 197

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject (readonly)

Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.



199
200
201
# File 'lib/stripe/resources/account_session.rb', line 199

def dispute_management
  @dispute_management
end

#refund_managementObject (readonly)

Whether to allow sending refunds. This is ‘true` by default.



201
202
203
# File 'lib/stripe/resources/account_session.rb', line 201

def refund_management
  @refund_management
end