Class: Stripe::AccountSession::Components::Payouts::Features

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#disable_stripe_user_authenticationObject (readonly)

Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.



611
612
613
# File 'lib/stripe/resources/account_session.rb', line 611

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#edit_payout_scheduleObject (readonly)

Whether to allow payout schedule to be changed. Defaults to true when controller.losses.payments is set to stripe for the account, otherwise false.



613
614
615
# File 'lib/stripe/resources/account_session.rb', line 613

def edit_payout_schedule
  @edit_payout_schedule
end

#external_account_collectionObject (readonly)

Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.



615
616
617
# File 'lib/stripe/resources/account_session.rb', line 615

def 
  @external_account_collection
end

#instant_payoutsObject (readonly)

Whether to allow creation of instant payouts. The default value is enabled when Stripe is responsible for negative account balances, and use_dashboard_rules otherwise.



617
618
619
# File 'lib/stripe/resources/account_session.rb', line 617

def instant_payouts
  @instant_payouts
end

#standard_payoutsObject (readonly)

Whether to allow creation of standard payouts. Defaults to true when controller.losses.payments is set to stripe for the account, otherwise false.



619
620
621
# File 'lib/stripe/resources/account_session.rb', line 619

def standard_payouts
  @standard_payouts
end

Class Method Details

.field_remappingsObject



625
626
627
# File 'lib/stripe/resources/account_session.rb', line 625

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



621
622
623
# File 'lib/stripe/resources/account_session.rb', line 621

def self.inner_class_types
  @inner_class_types = {}
end