Class: Stripe::AccountSession::Components::Payouts::Features
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::AccountSession::Components::Payouts::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
readonly
Disables Stripe user authentication for this embedded component.
-
#edit_payout_schedule ⇒ Object
readonly
Whether to allow payout schedule to be changed.
-
#external_account_collection ⇒ Object
readonly
Whether to allow platforms to control bank account collection for their connected accounts.
-
#instant_payouts ⇒ Object
readonly
Whether to allow creation of instant payouts.
-
#standard_payouts ⇒ Object
readonly
Whether to allow creation of standard payouts.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object (readonly)
Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.
212 213 214 |
# File 'lib/stripe/resources/account_session.rb', line 212 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#edit_payout_schedule ⇒ Object (readonly)
Whether to allow payout schedule to be changed. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.
214 215 216 |
# File 'lib/stripe/resources/account_session.rb', line 214 def edit_payout_schedule @edit_payout_schedule end |
#external_account_collection ⇒ Object (readonly)
Whether to allow platforms to control bank account collection for their connected accounts. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts. Otherwise, bank account collection is determined by compliance requirements. The default value for this feature is ‘true`.
216 217 218 |
# File 'lib/stripe/resources/account_session.rb', line 216 def external_account_collection @external_account_collection end |
#instant_payouts ⇒ Object (readonly)
Whether to allow creation of instant payouts. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.
218 219 220 |
# File 'lib/stripe/resources/account_session.rb', line 218 def instant_payouts @instant_payouts end |
#standard_payouts ⇒ Object (readonly)
Whether to allow creation of standard payouts. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.
220 221 222 |
# File 'lib/stripe/resources/account_session.rb', line 220 def standard_payouts @standard_payouts end |