Class: Stripe::AccountSession::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#account ⇒ Object
The identifier of the account to create an Account Session for.
-
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
972 973 974 975 976 |
# File 'lib/stripe/resources/account_session.rb', line 972 def initialize(account: nil, components: nil, expand: nil) @account = account @components = components @expand = end |
Instance Attribute Details
#account ⇒ Object
The identifier of the account to create an Account Session for.
966 967 968 |
# File 'lib/stripe/resources/account_session.rb', line 966 def account @account end |
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
968 969 970 |
# File 'lib/stripe/resources/account_session.rb', line 968 def components @components end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
970 971 972 |
# File 'lib/stripe/resources/account_session.rb', line 970 def @expand end |