Class: Stripe::AccountSession::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account_session.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1146
1147
1148
1149
1150
# File 'lib/stripe/resources/account_session.rb', line 1146

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



1140
1141
1142
# File 'lib/stripe/resources/account_session.rb', line 1140

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



1142
1143
1144
# File 'lib/stripe/resources/account_session.rb', line 1142

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



1144
1145
1146
# File 'lib/stripe/resources/account_session.rb', line 1144

def expand
  @expand
end