Class: Stripe::AccountSession::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account_session.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



891
892
893
894
895
# File 'lib/stripe/resources/account_session.rb', line 891

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



885
886
887
# File 'lib/stripe/resources/account_session.rb', line 885

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



887
888
889
# File 'lib/stripe/resources/account_session.rb', line 887

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



889
890
891
# File 'lib/stripe/resources/account_session.rb', line 889

def expand
  @expand
end