Class: Stripe::AccountSession::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account_session.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1034
1035
1036
1037
1038
# File 'lib/stripe/resources/account_session.rb', line 1034

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



1028
1029
1030
# File 'lib/stripe/resources/account_session.rb', line 1028

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



1030
1031
1032
# File 'lib/stripe/resources/account_session.rb', line 1030

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



1032
1033
1034
# File 'lib/stripe/resources/account_session.rb', line 1032

def expand
  @expand
end