Class: Stripe::AccountSession::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account_session.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



964
965
966
967
968
# File 'lib/stripe/resources/account_session.rb', line 964

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



958
959
960
# File 'lib/stripe/resources/account_session.rb', line 958

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



960
961
962
# File 'lib/stripe/resources/account_session.rb', line 960

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



962
963
964
# File 'lib/stripe/resources/account_session.rb', line 962

def expand
  @expand
end