Class: Stripe::AccountSession::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/account_session.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



994
995
996
997
998
# File 'lib/stripe/resources/account_session.rb', line 994

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



986
987
988
# File 'lib/stripe/resources/account_session.rb', line 986

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



989
990
991
# File 'lib/stripe/resources/account_session.rb', line 989

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



992
993
994
# File 'lib/stripe/resources/account_session.rb', line 992

def expand
  @expand
end