Class: Stripe::AccountSession::CreateParams::Components
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: AccountManagement, AccountOnboarding, AppInstall, AppViewport, Balances, CapitalFinancing, CapitalFinancingApplication, CapitalFinancingPromotion, CapitalOverview, Documents, FinancialAccount, FinancialAccountTransactions, IssuingCard, IssuingCardsList, NotificationBanner, PaymentDetails, PaymentMethodSettings, Payments, Payouts, PayoutsList, ProductTaxCodeSelector, Recipients, ReportingChart, TaxRegistrations, TaxSettings, TaxThresholdMonitoring
Instance Attribute Summary collapse
-
#account_management ⇒ Object
Configuration for the account management embedded component.
-
#account_onboarding ⇒ Object
Configuration for the account onboarding embedded component.
-
#app_install ⇒ Object
Configuration for the app install component.
-
#app_viewport ⇒ Object
Configuration for the app viewport component.
-
#balances ⇒ Object
Configuration for the balances embedded component.
-
#capital_financing ⇒ Object
Configuration for the capital financing embedded component.
-
#capital_financing_application ⇒ Object
Configuration for the capital financing application embedded component.
-
#capital_financing_promotion ⇒ Object
Configuration for the capital financing promotion embedded component.
-
#capital_overview ⇒ Object
Configuration for the capital overview embedded component.
-
#documents ⇒ Object
Configuration for the documents embedded component.
-
#financial_account ⇒ Object
Configuration for the financial account embedded component.
-
#financial_account_transactions ⇒ Object
Configuration for the financial account transactions embedded component.
-
#issuing_card ⇒ Object
Configuration for the issuing card embedded component.
-
#issuing_cards_list ⇒ Object
Configuration for the issuing cards list embedded component.
-
#notification_banner ⇒ Object
Configuration for the notification banner embedded component.
-
#payment_details ⇒ Object
Configuration for the payment details embedded component.
-
#payment_method_settings ⇒ Object
Configuration for the payment method settings embedded component.
-
#payments ⇒ Object
Configuration for the payments embedded component.
-
#payouts ⇒ Object
Configuration for the payouts embedded component.
-
#payouts_list ⇒ Object
Configuration for the payouts list embedded component.
-
#product_tax_code_selector ⇒ Object
Configuration for the product tax code selector embedded component.
-
#recipients ⇒ Object
Configuration for the recipients component.
-
#reporting_chart ⇒ Object
Configuration for the reporting chart embedded component.
-
#tax_registrations ⇒ Object
Configuration for the tax registrations embedded component.
-
#tax_settings ⇒ Object
Configuration for the tax settings embedded component.
-
#tax_threshold_monitoring ⇒ Object
Configuration for the tax threshold monitoring embedded component.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(account_management: nil, account_onboarding: nil, app_install: nil, app_viewport: nil, balances: nil, capital_financing: nil, capital_financing_application: nil, capital_financing_promotion: nil, capital_overview: nil, documents: nil, financial_account: nil, financial_account_transactions: nil, issuing_card: nil, issuing_cards_list: nil, notification_banner: nil, payment_details: nil, payment_method_settings: nil, payments: nil, payouts: nil, payouts_list: nil, product_tax_code_selector: nil, recipients: nil, reporting_chart: nil, tax_registrations: nil, tax_settings: nil, tax_threshold_monitoring: nil) ⇒ Components
Returns a new instance of Components.
919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 |
# File 'lib/stripe/resources/account_session.rb', line 919 def initialize( account_management: nil, account_onboarding: nil, app_install: nil, app_viewport: nil, balances: nil, capital_financing: nil, capital_financing_application: nil, capital_financing_promotion: nil, capital_overview: nil, documents: nil, financial_account: nil, financial_account_transactions: nil, issuing_card: nil, issuing_cards_list: nil, notification_banner: nil, payment_details: nil, payment_method_settings: nil, payments: nil, payouts: nil, payouts_list: nil, product_tax_code_selector: nil, recipients: nil, reporting_chart: nil, tax_registrations: nil, tax_settings: nil, tax_threshold_monitoring: nil ) @account_management = account_management @account_onboarding = account_onboarding @app_install = app_install @app_viewport = @balances = balances @capital_financing = capital_financing @capital_financing_application = capital_financing_application @capital_financing_promotion = capital_financing_promotion @capital_overview = capital_overview @documents = documents @financial_account = financial_account @financial_account_transactions = financial_account_transactions @issuing_card = issuing_card @issuing_cards_list = issuing_cards_list @notification_banner = @payment_details = payment_details @payment_method_settings = payment_method_settings @payments = payments @payouts = payouts @payouts_list = payouts_list @product_tax_code_selector = product_tax_code_selector @recipients = recipients @reporting_chart = reporting_chart @tax_registrations = tax_registrations @tax_settings = tax_settings @tax_threshold_monitoring = tax_threshold_monitoring end |
Instance Attribute Details
#account_management ⇒ Object
Configuration for the account management embedded component.
867 868 869 |
# File 'lib/stripe/resources/account_session.rb', line 867 def account_management @account_management end |
#account_onboarding ⇒ Object
Configuration for the account onboarding embedded component.
869 870 871 |
# File 'lib/stripe/resources/account_session.rb', line 869 def account_onboarding @account_onboarding end |
#app_install ⇒ Object
Configuration for the app install component.
871 872 873 |
# File 'lib/stripe/resources/account_session.rb', line 871 def app_install @app_install end |
#app_viewport ⇒ Object
Configuration for the app viewport component.
873 874 875 |
# File 'lib/stripe/resources/account_session.rb', line 873 def @app_viewport end |
#balances ⇒ Object
Configuration for the balances embedded component.
875 876 877 |
# File 'lib/stripe/resources/account_session.rb', line 875 def balances @balances end |
#capital_financing ⇒ Object
Configuration for the capital financing embedded component.
877 878 879 |
# File 'lib/stripe/resources/account_session.rb', line 877 def capital_financing @capital_financing end |
#capital_financing_application ⇒ Object
Configuration for the capital financing application embedded component.
879 880 881 |
# File 'lib/stripe/resources/account_session.rb', line 879 def capital_financing_application @capital_financing_application end |
#capital_financing_promotion ⇒ Object
Configuration for the capital financing promotion embedded component.
881 882 883 |
# File 'lib/stripe/resources/account_session.rb', line 881 def capital_financing_promotion @capital_financing_promotion end |
#capital_overview ⇒ Object
Configuration for the capital overview embedded component.
883 884 885 |
# File 'lib/stripe/resources/account_session.rb', line 883 def capital_overview @capital_overview end |
#documents ⇒ Object
Configuration for the documents embedded component.
885 886 887 |
# File 'lib/stripe/resources/account_session.rb', line 885 def documents @documents end |
#financial_account ⇒ Object
Configuration for the financial account embedded component.
887 888 889 |
# File 'lib/stripe/resources/account_session.rb', line 887 def financial_account @financial_account end |
#financial_account_transactions ⇒ Object
Configuration for the financial account transactions embedded component.
889 890 891 |
# File 'lib/stripe/resources/account_session.rb', line 889 def financial_account_transactions @financial_account_transactions end |
#issuing_card ⇒ Object
Configuration for the issuing card embedded component.
891 892 893 |
# File 'lib/stripe/resources/account_session.rb', line 891 def issuing_card @issuing_card end |
#issuing_cards_list ⇒ Object
Configuration for the issuing cards list embedded component.
893 894 895 |
# File 'lib/stripe/resources/account_session.rb', line 893 def issuing_cards_list @issuing_cards_list end |
#notification_banner ⇒ Object
Configuration for the notification banner embedded component.
895 896 897 |
# File 'lib/stripe/resources/account_session.rb', line 895 def @notification_banner end |
#payment_details ⇒ Object
Configuration for the payment details embedded component.
897 898 899 |
# File 'lib/stripe/resources/account_session.rb', line 897 def payment_details @payment_details end |
#payment_method_settings ⇒ Object
Configuration for the payment method settings embedded component.
899 900 901 |
# File 'lib/stripe/resources/account_session.rb', line 899 def payment_method_settings @payment_method_settings end |
#payments ⇒ Object
Configuration for the payments embedded component.
901 902 903 |
# File 'lib/stripe/resources/account_session.rb', line 901 def payments @payments end |
#payouts ⇒ Object
Configuration for the payouts embedded component.
903 904 905 |
# File 'lib/stripe/resources/account_session.rb', line 903 def payouts @payouts end |
#payouts_list ⇒ Object
Configuration for the payouts list embedded component.
905 906 907 |
# File 'lib/stripe/resources/account_session.rb', line 905 def payouts_list @payouts_list end |
#product_tax_code_selector ⇒ Object
Configuration for the product tax code selector embedded component.
907 908 909 |
# File 'lib/stripe/resources/account_session.rb', line 907 def product_tax_code_selector @product_tax_code_selector end |
#recipients ⇒ Object
Configuration for the recipients component.
909 910 911 |
# File 'lib/stripe/resources/account_session.rb', line 909 def recipients @recipients end |
#reporting_chart ⇒ Object
Configuration for the reporting chart embedded component.
911 912 913 |
# File 'lib/stripe/resources/account_session.rb', line 911 def reporting_chart @reporting_chart end |
#tax_registrations ⇒ Object
Configuration for the tax registrations embedded component.
913 914 915 |
# File 'lib/stripe/resources/account_session.rb', line 913 def tax_registrations @tax_registrations end |
#tax_settings ⇒ Object
Configuration for the tax settings embedded component.
915 916 917 |
# File 'lib/stripe/resources/account_session.rb', line 915 def tax_settings @tax_settings end |
#tax_threshold_monitoring ⇒ Object
Configuration for the tax threshold monitoring embedded component.
917 918 919 |
# File 'lib/stripe/resources/account_session.rb', line 917 def tax_threshold_monitoring @tax_threshold_monitoring end |