Class: Stripe::AccountSession::CreateParams::Components::AccountOnboarding::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil) ⇒ Features

Returns a new instance of Features.



252
253
254
255
256
257
258
# File 'lib/stripe/resources/account_session.rb', line 252

def initialize(
  disable_stripe_user_authentication: nil,
  external_account_collection: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @external_account_collection = 
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.



248
249
250
# File 'lib/stripe/resources/account_session.rb', line 248

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject

Whether to allow platforms to control bank account collection for their connected accounts. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts. Otherwise, bank account collection is determined by compliance requirements. The default value for this feature is ‘true`.



250
251
252
# File 'lib/stripe/resources/account_session.rb', line 250

def 
  @external_account_collection
end