Class: Stripe::AccountSession::CreateParams::Components::CapitalFinancing
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::CapitalFinancing
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancing
constructor
A new instance of CapitalFinancing.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ CapitalFinancing
Returns a new instance of CapitalFinancing.
464 465 466 467 |
# File 'lib/stripe/resources/account_session.rb', line 464 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
460 461 462 |
# File 'lib/stripe/resources/account_session.rb', line 460 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
462 463 464 |
# File 'lib/stripe/resources/account_session.rb', line 462 def features @features end |