Class: Stripe::AccountSession::CreateParams::Components::FinancialAccount::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features

Returns a new instance of Features.



640
641
642
643
644
645
646
647
648
649
650
# File 'lib/stripe/resources/account_session.rb', line 640

def initialize(
  disable_stripe_user_authentication: nil,
  external_account_collection: nil,
  send_money: nil,
  transfer_balance: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @external_account_collection = 
  @send_money = send_money
  @transfer_balance = transfer_balance
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.



632
633
634
# File 'lib/stripe/resources/account_session.rb', line 632

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject

Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.



634
635
636
# File 'lib/stripe/resources/account_session.rb', line 634

def 
  @external_account_collection
end

#send_moneyObject

Whether to allow sending money.



636
637
638
# File 'lib/stripe/resources/account_session.rb', line 636

def send_money
  @send_money
end

#transfer_balanceObject

Whether to allow transferring balance.



638
639
640
# File 'lib/stripe/resources/account_session.rb', line 638

def transfer_balance
  @transfer_balance
end