Class: Stripe::AccountSession::CreateParams::Components::FinancialAccount::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::FinancialAccount::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled.
-
#external_account_collection ⇒ Object
Whether external account collection is enabled.
-
#send_money ⇒ Object
Whether to allow sending money.
-
#transfer_balance ⇒ Object
Whether to allow transferring balance.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features
Returns a new instance of Features.
597 598 599 600 601 602 603 604 605 606 607 |
# File 'lib/stripe/resources/account_session.rb', line 597 def initialize( disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @external_account_collection = external_account_collection @send_money = send_money @transfer_balance = transfer_balance end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.
589 590 591 |
# File 'lib/stripe/resources/account_session.rb', line 589 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object
Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.
591 592 593 |
# File 'lib/stripe/resources/account_session.rb', line 591 def external_account_collection @external_account_collection end |
#send_money ⇒ Object
Whether to allow sending money.
593 594 595 |
# File 'lib/stripe/resources/account_session.rb', line 593 def send_money @send_money end |
#transfer_balance ⇒ Object
Whether to allow transferring balance.
595 596 597 |
# File 'lib/stripe/resources/account_session.rb', line 595 def transfer_balance @transfer_balance end |