Class: Stripe::AccountSession::CreateParams::Components::FinancialAccount::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features

Returns a new instance of Features.



580
581
582
583
584
585
586
587
588
589
590
# File 'lib/stripe/resources/account_session.rb', line 580

def initialize(
  disable_stripe_user_authentication: nil,
  external_account_collection: nil,
  send_money: nil,
  transfer_balance: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @external_account_collection = 
  @send_money = send_money
  @transfer_balance = transfer_balance
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.



572
573
574
# File 'lib/stripe/resources/account_session.rb', line 572

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject

Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.



574
575
576
# File 'lib/stripe/resources/account_session.rb', line 574

def 
  @external_account_collection
end

#send_moneyObject

Whether to allow sending money.



576
577
578
# File 'lib/stripe/resources/account_session.rb', line 576

def send_money
  @send_money
end

#transfer_balanceObject

Whether to allow transferring balance.



578
579
580
# File 'lib/stripe/resources/account_session.rb', line 578

def transfer_balance
  @transfer_balance
end