Class: Stripe::AccountSession::CreateParams::Components::FinancialAccount::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features

Returns a new instance of Features.



445
446
447
448
449
450
451
452
453
454
455
# File 'lib/stripe/resources/account_session.rb', line 445

def initialize(
  disable_stripe_user_authentication: nil,
  external_account_collection: nil,
  send_money: nil,
  transfer_balance: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @external_account_collection = 
  @send_money = send_money
  @transfer_balance = transfer_balance
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.



437
438
439
# File 'lib/stripe/resources/account_session.rb', line 437

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject

Whether to allow external accounts to be linked for money transfer.



439
440
441
# File 'lib/stripe/resources/account_session.rb', line 439

def 
  @external_account_collection
end

#send_moneyObject

Whether to allow sending money.



441
442
443
# File 'lib/stripe/resources/account_session.rb', line 441

def send_money
  @send_money
end

#transfer_balanceObject

Whether to allow transferring balance.



443
444
445
# File 'lib/stripe/resources/account_session.rb', line 443

def transfer_balance
  @transfer_balance
end