Class: Stripe::AccountSession::CreateParams::Components::IssuingCardsList::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::IssuingCardsList::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#card_management ⇒ Object
Whether to allow card management features.
-
#card_spend_dispute_management ⇒ Object
Whether to allow card spend dispute management features.
-
#cardholder_management ⇒ Object
Whether to allow cardholder management features.
-
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component.
-
#spend_control_management ⇒ Object
Whether to allow spend control management features.
Instance Method Summary collapse
-
#initialize(card_management: nil, card_spend_dispute_management: nil, cardholder_management: nil, disable_stripe_user_authentication: nil, spend_control_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(card_management: nil, card_spend_dispute_management: nil, cardholder_management: nil, disable_stripe_user_authentication: nil, spend_control_management: nil) ⇒ Features
Returns a new instance of Features.
535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/stripe/resources/account_session.rb', line 535 def initialize( card_management: nil, card_spend_dispute_management: nil, cardholder_management: nil, disable_stripe_user_authentication: nil, spend_control_management: nil ) @card_management = card_management @card_spend_dispute_management = card_spend_dispute_management @cardholder_management = cardholder_management @disable_stripe_user_authentication = disable_stripe_user_authentication @spend_control_management = spend_control_management end |
Instance Attribute Details
#card_management ⇒ Object
Whether to allow card management features.
525 526 527 |
# File 'lib/stripe/resources/account_session.rb', line 525 def card_management @card_management end |
#card_spend_dispute_management ⇒ Object
Whether to allow card spend dispute management features.
527 528 529 |
# File 'lib/stripe/resources/account_session.rb', line 527 def card_spend_dispute_management @card_spend_dispute_management end |
#cardholder_management ⇒ Object
Whether to allow cardholder management features.
529 530 531 |
# File 'lib/stripe/resources/account_session.rb', line 529 def cardholder_management @cardholder_management end |
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts.
531 532 533 |
# File 'lib/stripe/resources/account_session.rb', line 531 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#spend_control_management ⇒ Object
Whether to allow spend control management features.
533 534 535 |
# File 'lib/stripe/resources/account_session.rb', line 533 def spend_control_management @spend_control_management end |