Class: Stripe::AccountSession::CreateParams::Components::IssuingCardsList::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_management: nil, card_spend_dispute_management: nil, cardholder_management: nil, disable_stripe_user_authentication: nil, spend_control_management: nil) ⇒ Features

Returns a new instance of Features.



466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/stripe/resources/account_session.rb', line 466

def initialize(
  card_management: nil,
  card_spend_dispute_management: nil,
  cardholder_management: nil,
  disable_stripe_user_authentication: nil,
  spend_control_management: nil
)
  @card_management = card_management
  @card_spend_dispute_management = card_spend_dispute_management
  @cardholder_management = cardholder_management
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @spend_control_management = spend_control_management
end

Instance Attribute Details

#card_managementObject

Whether to allow card management features.



456
457
458
# File 'lib/stripe/resources/account_session.rb', line 456

def card_management
  @card_management
end

#card_spend_dispute_managementObject

Whether to allow card spend dispute management features.



458
459
460
# File 'lib/stripe/resources/account_session.rb', line 458

def card_spend_dispute_management
  @card_spend_dispute_management
end

#cardholder_managementObject

Whether to allow cardholder management features.



460
461
462
# File 'lib/stripe/resources/account_session.rb', line 460

def cardholder_management
  @cardholder_management
end

#disable_stripe_user_authenticationObject

Disables Stripe user authentication for this embedded component. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts.



462
463
464
# File 'lib/stripe/resources/account_session.rb', line 462

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#spend_control_managementObject

Whether to allow spend control management features.



464
465
466
# File 'lib/stripe/resources/account_session.rb', line 464

def spend_control_management
  @spend_control_management
end