Class: Stripe::AccountSession::CreateParams::Components::IssuingCardsList::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::IssuingCardsList::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#card_management ⇒ Object
Whether to allow card management features.
-
#card_spend_dispute_management ⇒ Object
Whether to allow card spend dispute management features.
-
#cardholder_management ⇒ Object
Whether to allow cardholder management features.
-
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component.
-
#spend_control_management ⇒ Object
Whether to allow spend control management features.
Instance Method Summary collapse
-
#initialize(card_management: nil, card_spend_dispute_management: nil, cardholder_management: nil, disable_stripe_user_authentication: nil, spend_control_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(card_management: nil, card_spend_dispute_management: nil, cardholder_management: nil, disable_stripe_user_authentication: nil, spend_control_management: nil) ⇒ Features
Returns a new instance of Features.
520 521 522 523 524 525 526 527 528 529 530 531 532 |
# File 'lib/stripe/resources/account_session.rb', line 520 def initialize( card_management: nil, card_spend_dispute_management: nil, cardholder_management: nil, disable_stripe_user_authentication: nil, spend_control_management: nil ) @card_management = card_management @card_spend_dispute_management = card_spend_dispute_management @cardholder_management = cardholder_management @disable_stripe_user_authentication = disable_stripe_user_authentication @spend_control_management = spend_control_management end |
Instance Attribute Details
#card_management ⇒ Object
Whether to allow card management features.
510 511 512 |
# File 'lib/stripe/resources/account_session.rb', line 510 def card_management @card_management end |
#card_spend_dispute_management ⇒ Object
Whether to allow card spend dispute management features.
512 513 514 |
# File 'lib/stripe/resources/account_session.rb', line 512 def card_spend_dispute_management @card_spend_dispute_management end |
#cardholder_management ⇒ Object
Whether to allow cardholder management features.
514 515 516 |
# File 'lib/stripe/resources/account_session.rb', line 514 def cardholder_management @cardholder_management end |
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts.
516 517 518 |
# File 'lib/stripe/resources/account_session.rb', line 516 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#spend_control_management ⇒ Object
Whether to allow spend control management features.
518 519 520 |
# File 'lib/stripe/resources/account_session.rb', line 518 def spend_control_management @spend_control_management end |