Class: Stripe::AccountSession::CreateParams::Components::PaymentDetails::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



668
669
670
671
672
673
674
675
676
677
678
# File 'lib/stripe/resources/account_session.rb', line 668

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



660
661
662
# File 'lib/stripe/resources/account_session.rb', line 660

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.



662
663
664
# File 'lib/stripe/resources/account_session.rb', line 662

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.



664
665
666
# File 'lib/stripe/resources/account_session.rb', line 664

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether to allow sending refunds. This is ‘true` by default.



666
667
668
# File 'lib/stripe/resources/account_session.rb', line 666

def refund_management
  @refund_management
end