Class: Stripe::AccountSession::CreateParams::Components::PaymentDetails::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



582
583
584
585
586
587
588
589
590
591
592
# File 'lib/stripe/resources/account_session.rb', line 582

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



574
575
576
# File 'lib/stripe/resources/account_session.rb', line 574

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.



576
577
578
# File 'lib/stripe/resources/account_session.rb', line 576

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.



578
579
580
# File 'lib/stripe/resources/account_session.rb', line 578

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether to allow sending refunds. This is ‘true` by default.



580
581
582
# File 'lib/stripe/resources/account_session.rb', line 580

def refund_management
  @refund_management
end