Class: Stripe::AccountSession::CreateParams::Components::PaymentDisputes::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::PaymentDisputes::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether to allow connected accounts to manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether to allow responding to disputes, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether to allow sending refunds.
Instance Method Summary collapse
-
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
Returns a new instance of Features.
629 630 631 632 633 634 635 636 637 |
# File 'lib/stripe/resources/account_session.rb', line 629 def initialize( destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil ) @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management end |
Instance Attribute Details
#destination_on_behalf_of_charge_management ⇒ Object
Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.
623 624 625 |
# File 'lib/stripe/resources/account_session.rb', line 623 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.
625 626 627 |
# File 'lib/stripe/resources/account_session.rb', line 625 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether to allow sending refunds. This is ‘true` by default.
627 628 629 |
# File 'lib/stripe/resources/account_session.rb', line 627 def refund_management @refund_management end |