Class: Stripe::AccountSession::CreateParams::Components::Payments::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



746
747
748
749
750
751
752
753
754
755
756
# File 'lib/stripe/resources/account_session.rb', line 746

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



738
739
740
# File 'lib/stripe/resources/account_session.rb', line 738

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.



740
741
742
# File 'lib/stripe/resources/account_session.rb', line 740

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.



742
743
744
# File 'lib/stripe/resources/account_session.rb', line 742

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether to allow sending refunds. This is ‘true` by default.



744
745
746
# File 'lib/stripe/resources/account_session.rb', line 744

def refund_management
  @refund_management
end