Class: Stripe::AccountSession::CreateParams::Components::Payments::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



714
715
716
717
718
719
720
721
722
723
724
# File 'lib/stripe/resources/account_session.rb', line 714

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



703
704
705
# File 'lib/stripe/resources/account_session.rb', line 703

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.



706
707
708
# File 'lib/stripe/resources/account_session.rb', line 706

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.



709
710
711
# File 'lib/stripe/resources/account_session.rb', line 709

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether to allow sending refunds. This is ‘true` by default.



712
713
714
# File 'lib/stripe/resources/account_session.rb', line 712

def refund_management
  @refund_management
end