Class: Stripe::AccountSession::CreateParams::Components::Payouts::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::Payouts::Features
- Defined in:
- lib/stripe/resources/account_session.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled.
-
#edit_payout_schedule ⇒ Object
Whether to allow payout schedule to be changed.
-
#external_account_collection ⇒ Object
Whether external account collection is enabled.
-
#instant_payouts ⇒ Object
Whether to allow creation of instant payouts.
-
#standard_payouts ⇒ Object
Whether to allow creation of standard payouts.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features
Returns a new instance of Features.
813 814 815 816 817 818 819 820 821 822 823 824 825 |
# File 'lib/stripe/resources/account_session.rb', line 813 def initialize( disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @edit_payout_schedule = edit_payout_schedule @external_account_collection = external_account_collection @instant_payouts = instant_payouts @standard_payouts = standard_payouts end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.
803 804 805 |
# File 'lib/stripe/resources/account_session.rb', line 803 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#edit_payout_schedule ⇒ Object
Whether to allow payout schedule to be changed. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.
805 806 807 |
# File 'lib/stripe/resources/account_session.rb', line 805 def edit_payout_schedule @edit_payout_schedule end |
#external_account_collection ⇒ Object
Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.
807 808 809 |
# File 'lib/stripe/resources/account_session.rb', line 807 def external_account_collection @external_account_collection end |
#instant_payouts ⇒ Object
Whether to allow creation of instant payouts. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.
809 810 811 |
# File 'lib/stripe/resources/account_session.rb', line 809 def instant_payouts @instant_payouts end |
#standard_payouts ⇒ Object
Whether to allow creation of standard payouts. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.
811 812 813 |
# File 'lib/stripe/resources/account_session.rb', line 811 def standard_payouts @standard_payouts end |