Class: Stripe::AccountSession::CreateParams::Components::Payouts::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features

Returns a new instance of Features.



744
745
746
747
748
749
750
751
752
753
754
755
756
# File 'lib/stripe/resources/account_session.rb', line 744

def initialize(
  disable_stripe_user_authentication: nil,
  edit_payout_schedule: nil,
  external_account_collection: nil,
  instant_payouts: nil,
  standard_payouts: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @edit_payout_schedule = edit_payout_schedule
  @external_account_collection = 
  @instant_payouts = instant_payouts
  @standard_payouts = standard_payouts
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.



734
735
736
# File 'lib/stripe/resources/account_session.rb', line 734

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#edit_payout_scheduleObject

Whether to allow payout schedule to be changed. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.



736
737
738
# File 'lib/stripe/resources/account_session.rb', line 736

def edit_payout_schedule
  @edit_payout_schedule
end

#external_account_collectionObject

Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.



738
739
740
# File 'lib/stripe/resources/account_session.rb', line 738

def 
  @external_account_collection
end

#instant_payoutsObject

Whether to allow creation of instant payouts. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.



740
741
742
# File 'lib/stripe/resources/account_session.rb', line 740

def instant_payouts
  @instant_payouts
end

#standard_payoutsObject

Whether to allow creation of standard payouts. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.



742
743
744
# File 'lib/stripe/resources/account_session.rb', line 742

def standard_payouts
  @standard_payouts
end