Class: Stripe::AccountSession::CreateParams::Components::Payouts::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/account_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features

Returns a new instance of Features.



755
756
757
758
759
760
761
762
763
764
765
766
767
# File 'lib/stripe/resources/account_session.rb', line 755

def initialize(
  disable_stripe_user_authentication: nil,
  edit_payout_schedule: nil,
  external_account_collection: nil,
  instant_payouts: nil,
  standard_payouts: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @edit_payout_schedule = edit_payout_schedule
  @external_account_collection = 
  @instant_payouts = instant_payouts
  @standard_payouts = standard_payouts
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.



741
742
743
# File 'lib/stripe/resources/account_session.rb', line 741

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#edit_payout_scheduleObject

Whether to allow payout schedule to be changed. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.



744
745
746
# File 'lib/stripe/resources/account_session.rb', line 744

def edit_payout_schedule
  @edit_payout_schedule
end

#external_account_collectionObject

Whether to allow platforms to control bank account collection for their connected accounts. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts. Otherwise, bank account collection is determined by compliance requirements. The default value for this feature is ‘true`.



747
748
749
# File 'lib/stripe/resources/account_session.rb', line 747

def 
  @external_account_collection
end

#instant_payoutsObject

Whether to allow creation of instant payouts. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.



750
751
752
# File 'lib/stripe/resources/account_session.rb', line 750

def instant_payouts
  @instant_payouts
end

#standard_payoutsObject

Whether to allow creation of standard payouts. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.



753
754
755
# File 'lib/stripe/resources/account_session.rb', line 753

def standard_payouts
  @standard_payouts
end