Class: Stripe::AccountSession::CreateParams::Components::PayoutsList
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::PayoutsList
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PayoutsList
constructor
A new instance of PayoutsList.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PayoutsList
Returns a new instance of PayoutsList.
771 772 773 774 |
# File 'lib/stripe/resources/account_session.rb', line 771 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
767 768 769 |
# File 'lib/stripe/resources/account_session.rb', line 767 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
769 770 771 |
# File 'lib/stripe/resources/account_session.rb', line 769 def features @features end |