Class: Stripe::AccountSession::CreateParams::Components::TaxRegistrations
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSession::CreateParams::Components::TaxRegistrations
- Defined in:
- lib/stripe/resources/account_session.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ TaxRegistrations
constructor
A new instance of TaxRegistrations.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ TaxRegistrations
Returns a new instance of TaxRegistrations.
877 878 879 880 |
# File 'lib/stripe/resources/account_session.rb', line 877 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
873 874 875 |
# File 'lib/stripe/resources/account_session.rb', line 873 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
875 876 877 |
# File 'lib/stripe/resources/account_session.rb', line 875 def features @features end |