Class: Stripe::AccountSessionCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ AccountSessionCreateParams

Returns a new instance of AccountSessionCreateParams.



642
643
644
645
646
# File 'lib/stripe/params/account_session_create_params.rb', line 642

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



636
637
638
# File 'lib/stripe/params/account_session_create_params.rb', line 636

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



638
639
640
# File 'lib/stripe/params/account_session_create_params.rb', line 638

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



640
641
642
# File 'lib/stripe/params/account_session_create_params.rb', line 640

def expand
  @expand
end