Class: Stripe::AccountSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#account ⇒ Object
The identifier of the account to create an Account Session for.
-
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(account: nil, components: nil, expand: nil) ⇒ AccountSessionCreateParams
constructor
A new instance of AccountSessionCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil, components: nil, expand: nil) ⇒ AccountSessionCreateParams
Returns a new instance of AccountSessionCreateParams.
867 868 869 870 871 |
# File 'lib/stripe/params/account_session_create_params.rb', line 867 def initialize(account: nil, components: nil, expand: nil) @account = account @components = components @expand = end |
Instance Attribute Details
#account ⇒ Object
The identifier of the account to create an Account Session for.
861 862 863 |
# File 'lib/stripe/params/account_session_create_params.rb', line 861 def account @account end |
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
863 864 865 |
# File 'lib/stripe/params/account_session_create_params.rb', line 863 def components @components end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
865 866 867 |
# File 'lib/stripe/params/account_session_create_params.rb', line 865 def @expand end |