Class: Stripe::AccountSessionCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ AccountSessionCreateParams

Returns a new instance of AccountSessionCreateParams.



851
852
853
854
855
# File 'lib/stripe/params/account_session_create_params.rb', line 851

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



845
846
847
# File 'lib/stripe/params/account_session_create_params.rb', line 845

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



847
848
849
# File 'lib/stripe/params/account_session_create_params.rb', line 847

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



849
850
851
# File 'lib/stripe/params/account_session_create_params.rb', line 849

def expand
  @expand
end