Class: Stripe::AccountSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#account ⇒ Object
The identifier of the account to create an Account Session for.
-
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(account: nil, components: nil, expand: nil) ⇒ AccountSessionCreateParams
constructor
A new instance of AccountSessionCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, components: nil, expand: nil) ⇒ AccountSessionCreateParams
Returns a new instance of AccountSessionCreateParams.
885 886 887 888 889 |
# File 'lib/stripe/params/account_session_create_params.rb', line 885 def initialize(account: nil, components: nil, expand: nil) @account = account @components = components @expand = end |
Instance Attribute Details
#account ⇒ Object
The identifier of the account to create an Account Session for.
879 880 881 |
# File 'lib/stripe/params/account_session_create_params.rb', line 879 def account @account end |
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
881 882 883 |
# File 'lib/stripe/params/account_session_create_params.rb', line 881 def components @components end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
883 884 885 |
# File 'lib/stripe/params/account_session_create_params.rb', line 883 def @expand end |