Class: Stripe::AccountSessionCreateParams::Components::Balances::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::Balances::Features
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled.
-
#edit_payout_schedule ⇒ Object
Whether to allow payout schedule to be changed.
-
#external_account_collection ⇒ Object
Whether external account collection is enabled.
-
#instant_payouts ⇒ Object
Whether instant payouts are enabled for this component.
-
#standard_payouts ⇒ Object
Whether to allow creation of standard payouts.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features
Returns a new instance of Features.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/stripe/params/account_session_create_params.rb', line 132 def initialize( disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @edit_payout_schedule = edit_payout_schedule @external_account_collection = external_account_collection @instant_payouts = instant_payouts @standard_payouts = standard_payouts end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
122 123 124 |
# File 'lib/stripe/params/account_session_create_params.rb', line 122 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#edit_payout_schedule ⇒ Object
Whether to allow payout schedule to be changed. Defaults to true when controller.losses.payments is set to stripe for the account, otherwise false.
124 125 126 |
# File 'lib/stripe/params/account_session_create_params.rb', line 124 def edit_payout_schedule @edit_payout_schedule end |
#external_account_collection ⇒ Object
Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.
126 127 128 |
# File 'lib/stripe/params/account_session_create_params.rb', line 126 def external_account_collection @external_account_collection end |
#instant_payouts ⇒ Object
Whether instant payouts are enabled for this component.
128 129 130 |
# File 'lib/stripe/params/account_session_create_params.rb', line 128 def instant_payouts @instant_payouts end |
#standard_payouts ⇒ Object
Whether to allow creation of standard payouts. Defaults to true when controller.losses.payments is set to stripe for the account, otherwise false.
130 131 132 |
# File 'lib/stripe/params/account_session_create_params.rb', line 130 def standard_payouts @standard_payouts end |