Class: Stripe::AccountSessionCreateParams::Components::Balances::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features

Returns a new instance of Features.



79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/stripe/params/account_session_create_params.rb', line 79

def initialize(
  disable_stripe_user_authentication: nil,
  edit_payout_schedule: nil,
  external_account_collection: nil,
  instant_payouts: nil,
  standard_payouts: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @edit_payout_schedule = edit_payout_schedule
  @external_account_collection = 
  @instant_payouts = instant_payouts
  @standard_payouts = standard_payouts
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.



69
70
71
# File 'lib/stripe/params/account_session_create_params.rb', line 69

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#edit_payout_scheduleObject

Whether to allow payout schedule to be changed. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.



71
72
73
# File 'lib/stripe/params/account_session_create_params.rb', line 71

def edit_payout_schedule
  @edit_payout_schedule
end

#external_account_collectionObject

Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.



73
74
75
# File 'lib/stripe/params/account_session_create_params.rb', line 73

def 
  @external_account_collection
end

#instant_payoutsObject

Whether instant payouts are enabled for this component.



75
76
77
# File 'lib/stripe/params/account_session_create_params.rb', line 75

def instant_payouts
  @instant_payouts
end

#standard_payoutsObject

Whether to allow creation of standard payouts. Defaults to ‘true` when `controller.losses.payments` is set to `stripe` for the account, otherwise `false`.



77
78
79
# File 'lib/stripe/params/account_session_create_params.rb', line 77

def standard_payouts
  @standard_payouts
end