Class: Stripe::AccountSessionCreateParams::Components::DisputesList::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



207
208
209
210
211
212
213
214
215
216
217
# File 'lib/stripe/params/account_session_create_params.rb', line 207

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



199
200
201
# File 'lib/stripe/params/account_session_create_params.rb', line 199

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.



201
202
203
# File 'lib/stripe/params/account_session_create_params.rb', line 201

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.



203
204
205
# File 'lib/stripe/params/account_session_create_params.rb', line 203

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether sending refunds is enabled. This is ‘true` by default.



205
206
207
# File 'lib/stripe/params/account_session_create_params.rb', line 205

def refund_management
  @refund_management
end