Class: Stripe::AccountSessionCreateParams::Components::FinancialAccount::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::FinancialAccount::Features
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled.
-
#external_account_collection ⇒ Object
Whether external account collection is enabled.
-
#send_money ⇒ Object
Whether to allow sending money.
-
#transfer_balance ⇒ Object
Whether to allow transferring balance.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features
Returns a new instance of Features.
304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/stripe/params/account_session_create_params.rb', line 304 def initialize( disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @external_account_collection = external_account_collection @send_money = send_money @transfer_balance = transfer_balance end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
296 297 298 |
# File 'lib/stripe/params/account_session_create_params.rb', line 296 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object
Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.
298 299 300 |
# File 'lib/stripe/params/account_session_create_params.rb', line 298 def external_account_collection @external_account_collection end |
#send_money ⇒ Object
Whether to allow sending money.
300 301 302 |
# File 'lib/stripe/params/account_session_create_params.rb', line 300 def send_money @send_money end |
#transfer_balance ⇒ Object
Whether to allow transferring balance.
302 303 304 |
# File 'lib/stripe/params/account_session_create_params.rb', line 302 def transfer_balance @transfer_balance end |