Class: Stripe::AccountSessionCreateParams::Components::FinancialAccount::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features

Returns a new instance of Features.



271
272
273
274
275
276
277
278
279
280
281
# File 'lib/stripe/params/account_session_create_params.rb', line 271

def initialize(
  disable_stripe_user_authentication: nil,
  external_account_collection: nil,
  send_money: nil,
  transfer_balance: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @external_account_collection = 
  @send_money = send_money
  @transfer_balance = transfer_balance
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.



263
264
265
# File 'lib/stripe/params/account_session_create_params.rb', line 263

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject

Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.



265
266
267
# File 'lib/stripe/params/account_session_create_params.rb', line 265

def 
  @external_account_collection
end

#send_moneyObject

Whether to allow sending money.



267
268
269
# File 'lib/stripe/params/account_session_create_params.rb', line 267

def send_money
  @send_money
end

#transfer_balanceObject

Whether to allow transferring balance.



269
270
271
# File 'lib/stripe/params/account_session_create_params.rb', line 269

def transfer_balance
  @transfer_balance
end