Class: Stripe::AccountSessionCreateParams::Components::FinancialAccount::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features

Returns a new instance of Features.



254
255
256
257
258
259
260
261
262
263
264
# File 'lib/stripe/params/account_session_create_params.rb', line 254

def initialize(
  disable_stripe_user_authentication: nil,
  external_account_collection: nil,
  send_money: nil,
  transfer_balance: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @external_account_collection = 
  @send_money = send_money
  @transfer_balance = transfer_balance
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.



246
247
248
# File 'lib/stripe/params/account_session_create_params.rb', line 246

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject

Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.



248
249
250
# File 'lib/stripe/params/account_session_create_params.rb', line 248

def 
  @external_account_collection
end

#send_moneyObject

Whether to allow sending money.



250
251
252
# File 'lib/stripe/params/account_session_create_params.rb', line 250

def send_money
  @send_money
end

#transfer_balanceObject

Whether to allow transferring balance.



252
253
254
# File 'lib/stripe/params/account_session_create_params.rb', line 252

def transfer_balance
  @transfer_balance
end