Class: Stripe::AccountSessionCreateParams::Components::InstantPayoutsPromotion::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::InstantPayoutsPromotion::Features
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled.
-
#external_account_collection ⇒ Object
Whether external account collection is enabled.
-
#instant_payouts ⇒ Object
Whether instant payouts are enabled for this component.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, instant_payouts: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, instant_payouts: nil) ⇒ Features
Returns a new instance of Features.
356 357 358 359 360 361 362 363 364 |
# File 'lib/stripe/params/account_session_create_params.rb', line 356 def initialize( disable_stripe_user_authentication: nil, external_account_collection: nil, instant_payouts: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @external_account_collection = external_account_collection @instant_payouts = instant_payouts end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Whether Stripe user authentication is disabled. This value can only be true for accounts where controller.requirement_collection is application for the account. The default value is the opposite of the external_account_collection value. For example, if you don't set external_account_collection, it defaults to true and disable_stripe_user_authentication defaults to false.
350 351 352 |
# File 'lib/stripe/params/account_session_create_params.rb', line 350 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object
Whether external account collection is enabled. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is true.
352 353 354 |
# File 'lib/stripe/params/account_session_create_params.rb', line 352 def external_account_collection @external_account_collection end |
#instant_payouts ⇒ Object
Whether instant payouts are enabled for this component.
354 355 356 |
# File 'lib/stripe/params/account_session_create_params.rb', line 354 def instant_payouts @instant_payouts end |