Class: Stripe::AccountSessionCreateParams::Components::InstantPayoutsPromotion::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, instant_payouts: nil) ⇒ Features

Returns a new instance of Features.



319
320
321
322
323
324
325
326
327
# File 'lib/stripe/params/account_session_create_params.rb', line 319

def initialize(
  disable_stripe_user_authentication: nil,
  external_account_collection: nil,
  instant_payouts: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @external_account_collection = 
  @instant_payouts = instant_payouts
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Whether Stripe user authentication is disabled. This value can only be ‘true` for accounts where `controller.requirement_collection` is `application` for the account. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set ‘external_account_collection`, it defaults to `true` and `disable_stripe_user_authentication` defaults to `false`.



313
314
315
# File 'lib/stripe/params/account_session_create_params.rb', line 313

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#external_account_collectionObject

Whether external account collection is enabled. This feature can only be ‘false` for accounts where you’re responsible for collecting updated information when requirements are due or change, like Custom accounts. The default value for this feature is `true`.



315
316
317
# File 'lib/stripe/params/account_session_create_params.rb', line 315

def 
  @external_account_collection
end

#instant_payoutsObject

Whether instant payouts are enabled for this component.



317
318
319
# File 'lib/stripe/params/account_session_create_params.rb', line 317

def instant_payouts
  @instant_payouts
end