Class: Stripe::AccountSessionCreateParams::Components::PaymentDetails::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil, smart_disputes_management: nil) ⇒ Features

Returns a new instance of Features.



452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/stripe/params/account_session_create_params.rb', line 452

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil,
  smart_disputes_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
  @smart_disputes_management = smart_disputes_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is true by default.



442
443
444
# File 'lib/stripe/params/account_session_create_params.rb', line 442

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.



444
445
446
# File 'lib/stripe/params/account_session_create_params.rb', line 444

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is true by default.



446
447
448
# File 'lib/stripe/params/account_session_create_params.rb', line 446

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether sending refunds is enabled. This is true by default.



448
449
450
# File 'lib/stripe/params/account_session_create_params.rb', line 448

def refund_management
  @refund_management
end

#smart_disputes_managementObject

Whether to allow connected accounts to submit disputes using Smart Disputes. Defaults to the value of dispute_management.



450
451
452
# File 'lib/stripe/params/account_session_create_params.rb', line 450

def smart_disputes_management
  @smart_disputes_management
end