Class: Stripe::AccountSessionCreateParams::Components::PaymentDetails::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



433
434
435
436
437
438
439
440
441
442
443
# File 'lib/stripe/params/account_session_create_params.rb', line 433

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



425
426
427
# File 'lib/stripe/params/account_session_create_params.rb', line 425

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.



427
428
429
# File 'lib/stripe/params/account_session_create_params.rb', line 427

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.



429
430
431
# File 'lib/stripe/params/account_session_create_params.rb', line 429

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether sending refunds is enabled. This is ‘true` by default.



431
432
433
# File 'lib/stripe/params/account_session_create_params.rb', line 431

def refund_management
  @refund_management
end