Class: Stripe::AccountSessionCreateParams::Components::PaymentDisputes::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionCreateParams::Components::PaymentDisputes::Features
- Defined in:
- lib/stripe/params/account_session_create_params.rb
Instance Attribute Summary collapse
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether sending refunds is enabled.
-
#smart_disputes_management ⇒ Object
Whether to allow connected accounts to submit disputes using Smart Disputes.
Instance Method Summary collapse
-
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil, smart_disputes_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil, smart_disputes_management: nil) ⇒ Features
Returns a new instance of Features.
383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/stripe/params/account_session_create_params.rb', line 383 def initialize( destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil, smart_disputes_management: nil ) @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management @smart_disputes_management = smart_disputes_management end |
Instance Attribute Details
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.
375 376 377 |
# File 'lib/stripe/params/account_session_create_params.rb', line 375 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is true by default.
377 378 379 |
# File 'lib/stripe/params/account_session_create_params.rb', line 377 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether sending refunds is enabled. This is true by default.
379 380 381 |
# File 'lib/stripe/params/account_session_create_params.rb', line 379 def refund_management @refund_management end |
#smart_disputes_management ⇒ Object
Whether to allow connected accounts to submit disputes using Smart Disputes. Defaults to the value of dispute_management.
381 382 383 |
# File 'lib/stripe/params/account_session_create_params.rb', line 381 def smart_disputes_management @smart_disputes_management end |