Class: Stripe::AccountSessionCreateParams::Components::PaymentDisputes::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil, smart_disputes_management: nil) ⇒ Features

Returns a new instance of Features.



488
489
490
491
492
493
494
495
496
497
498
# File 'lib/stripe/params/account_session_create_params.rb', line 488

def initialize(
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil,
  smart_disputes_management: nil
)
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
  @smart_disputes_management = smart_disputes_management
end

Instance Attribute Details

#destination_on_behalf_of_charge_managementObject

Whether connected accounts can manage destination charges that are created on behalf of them. This is false by default.



480
481
482
# File 'lib/stripe/params/account_session_create_params.rb', line 480

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is true by default.



482
483
484
# File 'lib/stripe/params/account_session_create_params.rb', line 482

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether sending refunds is enabled. This is true by default.



484
485
486
# File 'lib/stripe/params/account_session_create_params.rb', line 484

def refund_management
  @refund_management
end

#smart_disputes_managementObject

Whether to allow connected accounts to submit disputes using Smart Disputes. Defaults to the value of dispute_management.



486
487
488
# File 'lib/stripe/params/account_session_create_params.rb', line 486

def smart_disputes_management
  @smart_disputes_management
end