Class: Stripe::AccountSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



636
637
638
639
640
# File 'lib/stripe/services/account_session_service.rb', line 636

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



630
631
632
# File 'lib/stripe/services/account_session_service.rb', line 630

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



632
633
634
# File 'lib/stripe/services/account_session_service.rb', line 632

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



634
635
636
# File 'lib/stripe/services/account_session_service.rb', line 634

def expand
  @expand
end