Class: Stripe::AccountSessionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#account ⇒ Object
The identifier of the account to create an Account Session for.
-
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
636 637 638 639 640 |
# File 'lib/stripe/services/account_session_service.rb', line 636 def initialize(account: nil, components: nil, expand: nil) @account = account @components = components @expand = end |
Instance Attribute Details
#account ⇒ Object
The identifier of the account to create an Account Session for.
630 631 632 |
# File 'lib/stripe/services/account_session_service.rb', line 630 def account @account end |
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
632 633 634 |
# File 'lib/stripe/services/account_session_service.rb', line 632 def components @components end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
634 635 636 |
# File 'lib/stripe/services/account_session_service.rb', line 634 def @expand end |