Class: Stripe::AccountSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



585
586
587
588
589
# File 'lib/stripe/services/account_session_service.rb', line 585

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



579
580
581
# File 'lib/stripe/services/account_session_service.rb', line 579

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



581
582
583
# File 'lib/stripe/services/account_session_service.rb', line 581

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



583
584
585
# File 'lib/stripe/services/account_session_service.rb', line 583

def expand
  @expand
end