Class: Stripe::AccountSessionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#account ⇒ Object
The identifier of the account to create an Account Session for.
-
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
551 552 553 554 555 |
# File 'lib/stripe/services/account_session_service.rb', line 551 def initialize(account: nil, components: nil, expand: nil) @account = account @components = components @expand = end |
Instance Attribute Details
#account ⇒ Object
The identifier of the account to create an Account Session for.
545 546 547 |
# File 'lib/stripe/services/account_session_service.rb', line 545 def account @account end |
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
547 548 549 |
# File 'lib/stripe/services/account_session_service.rb', line 547 def components @components end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
549 550 551 |
# File 'lib/stripe/services/account_session_service.rb', line 549 def @expand end |