Class: Stripe::AccountSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



751
752
753
754
755
# File 'lib/stripe/services/account_session_service.rb', line 751

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



745
746
747
# File 'lib/stripe/services/account_session_service.rb', line 745

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



747
748
749
# File 'lib/stripe/services/account_session_service.rb', line 747

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



749
750
751
# File 'lib/stripe/services/account_session_service.rb', line 749

def expand
  @expand
end