Class: Stripe::AccountSessionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#account ⇒ Object
The identifier of the account to create an Account Session for.
-
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
751 752 753 754 755 |
# File 'lib/stripe/services/account_session_service.rb', line 751 def initialize(account: nil, components: nil, expand: nil) @account = account @components = components @expand = end |
Instance Attribute Details
#account ⇒ Object
The identifier of the account to create an Account Session for.
745 746 747 |
# File 'lib/stripe/services/account_session_service.rb', line 745 def account @account end |
#components ⇒ Object
Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).
747 748 749 |
# File 'lib/stripe/services/account_session_service.rb', line 747 def components @components end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
749 750 751 |
# File 'lib/stripe/services/account_session_service.rb', line 749 def @expand end |