Class: Stripe::AccountSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, components: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



483
484
485
486
487
# File 'lib/stripe/services/account_session_service.rb', line 483

def initialize(account: nil, components: nil, expand: nil)
  @account = 
  @components = components
  @expand = expand
end

Instance Attribute Details

#accountObject

The identifier of the account to create an Account Session for.



477
478
479
# File 'lib/stripe/services/account_session_service.rb', line 477

def 
  @account
end

#componentsObject

Each key of the dictionary represents an embedded component, and each embedded component maps to its configuration (e.g. whether it has been enabled or not).



479
480
481
# File 'lib/stripe/services/account_session_service.rb', line 479

def components
  @components
end

#expandObject

Specifies which fields in the response should be expanded.



481
482
483
# File 'lib/stripe/services/account_session_service.rb', line 481

def expand
  @expand
end