Class: Stripe::AccountSessionService::CreateParams::Components
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: AccountManagement, AccountOnboarding, AppInstall, AppViewport, Balances, CapitalFinancing, CapitalFinancingApplication, CapitalFinancingPromotion, CapitalOverview, Documents, ExportTaxTransactions, FinancialAccount, FinancialAccountTransactions, IssuingCard, IssuingCardsList, NotificationBanner, PaymentDetails, PaymentDisputes, PaymentMethodSettings, Payments, Payouts, PayoutsList, ProductTaxCodeSelector, Recipients, ReportingChart, TaxRegistrations, TaxSettings, TaxThresholdMonitoring
Instance Attribute Summary collapse
-
#account_management ⇒ Object
Configuration for the account management embedded component.
-
#account_onboarding ⇒ Object
Configuration for the account onboarding embedded component.
-
#app_install ⇒ Object
Configuration for the app install component.
-
#app_viewport ⇒ Object
Configuration for the app viewport component.
-
#balances ⇒ Object
Configuration for the balances embedded component.
-
#capital_financing ⇒ Object
Configuration for the capital financing embedded component.
-
#capital_financing_application ⇒ Object
Configuration for the capital financing application embedded component.
-
#capital_financing_promotion ⇒ Object
Configuration for the capital financing promotion embedded component.
-
#capital_overview ⇒ Object
Configuration for the capital overview embedded component.
-
#documents ⇒ Object
Configuration for the documents embedded component.
-
#export_tax_transactions ⇒ Object
Configuration for the export tax transactions embedded component.
-
#financial_account ⇒ Object
Configuration for the financial account embedded component.
-
#financial_account_transactions ⇒ Object
Configuration for the financial account transactions embedded component.
-
#issuing_card ⇒ Object
Configuration for the issuing card embedded component.
-
#issuing_cards_list ⇒ Object
Configuration for the issuing cards list embedded component.
-
#notification_banner ⇒ Object
Configuration for the notification banner embedded component.
-
#payment_details ⇒ Object
Configuration for the payment details embedded component.
-
#payment_disputes ⇒ Object
Configuration for the payment disputes embedded component.
-
#payment_method_settings ⇒ Object
Configuration for the payment method settings embedded component.
-
#payments ⇒ Object
Configuration for the payments embedded component.
-
#payouts ⇒ Object
Configuration for the payouts embedded component.
-
#payouts_list ⇒ Object
Configuration for the payouts list embedded component.
-
#product_tax_code_selector ⇒ Object
Configuration for the product tax code selector embedded component.
-
#recipients ⇒ Object
Configuration for the recipients component.
-
#reporting_chart ⇒ Object
Configuration for the reporting chart embedded component.
-
#tax_registrations ⇒ Object
Configuration for the tax registrations embedded component.
-
#tax_settings ⇒ Object
Configuration for the tax settings embedded component.
-
#tax_threshold_monitoring ⇒ Object
Configuration for the tax threshold monitoring embedded component.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(account_management: nil, account_onboarding: nil, app_install: nil, app_viewport: nil, balances: nil, capital_financing: nil, capital_financing_application: nil, capital_financing_promotion: nil, capital_overview: nil, documents: nil, export_tax_transactions: nil, financial_account: nil, financial_account_transactions: nil, issuing_card: nil, issuing_cards_list: nil, notification_banner: nil, payment_details: nil, payment_disputes: nil, payment_method_settings: nil, payments: nil, payouts: nil, payouts_list: nil, product_tax_code_selector: nil, recipients: nil, reporting_chart: nil, tax_registrations: nil, tax_settings: nil, tax_threshold_monitoring: nil) ⇒ Components
Returns a new instance of Components.
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'lib/stripe/services/account_session_service.rb', line 684 def initialize( account_management: nil, account_onboarding: nil, app_install: nil, app_viewport: nil, balances: nil, capital_financing: nil, capital_financing_application: nil, capital_financing_promotion: nil, capital_overview: nil, documents: nil, export_tax_transactions: nil, financial_account: nil, financial_account_transactions: nil, issuing_card: nil, issuing_cards_list: nil, notification_banner: nil, payment_details: nil, payment_disputes: nil, payment_method_settings: nil, payments: nil, payouts: nil, payouts_list: nil, product_tax_code_selector: nil, recipients: nil, reporting_chart: nil, tax_registrations: nil, tax_settings: nil, tax_threshold_monitoring: nil ) @account_management = account_management @account_onboarding = account_onboarding @app_install = app_install @app_viewport = @balances = balances @capital_financing = capital_financing @capital_financing_application = capital_financing_application @capital_financing_promotion = capital_financing_promotion @capital_overview = capital_overview @documents = documents @export_tax_transactions = export_tax_transactions @financial_account = financial_account @financial_account_transactions = financial_account_transactions @issuing_card = issuing_card @issuing_cards_list = issuing_cards_list @notification_banner = @payment_details = payment_details @payment_disputes = payment_disputes @payment_method_settings = payment_method_settings @payments = payments @payouts = payouts @payouts_list = payouts_list @product_tax_code_selector = product_tax_code_selector @recipients = recipients @reporting_chart = reporting_chart @tax_registrations = tax_registrations @tax_settings = tax_settings @tax_threshold_monitoring = tax_threshold_monitoring end |
Instance Attribute Details
#account_management ⇒ Object
Configuration for the account management embedded component.
628 629 630 |
# File 'lib/stripe/services/account_session_service.rb', line 628 def account_management @account_management end |
#account_onboarding ⇒ Object
Configuration for the account onboarding embedded component.
630 631 632 |
# File 'lib/stripe/services/account_session_service.rb', line 630 def account_onboarding @account_onboarding end |
#app_install ⇒ Object
Configuration for the app install component.
632 633 634 |
# File 'lib/stripe/services/account_session_service.rb', line 632 def app_install @app_install end |
#app_viewport ⇒ Object
Configuration for the app viewport component.
634 635 636 |
# File 'lib/stripe/services/account_session_service.rb', line 634 def @app_viewport end |
#balances ⇒ Object
Configuration for the balances embedded component.
636 637 638 |
# File 'lib/stripe/services/account_session_service.rb', line 636 def balances @balances end |
#capital_financing ⇒ Object
Configuration for the capital financing embedded component.
638 639 640 |
# File 'lib/stripe/services/account_session_service.rb', line 638 def capital_financing @capital_financing end |
#capital_financing_application ⇒ Object
Configuration for the capital financing application embedded component.
640 641 642 |
# File 'lib/stripe/services/account_session_service.rb', line 640 def capital_financing_application @capital_financing_application end |
#capital_financing_promotion ⇒ Object
Configuration for the capital financing promotion embedded component.
642 643 644 |
# File 'lib/stripe/services/account_session_service.rb', line 642 def capital_financing_promotion @capital_financing_promotion end |
#capital_overview ⇒ Object
Configuration for the capital overview embedded component.
644 645 646 |
# File 'lib/stripe/services/account_session_service.rb', line 644 def capital_overview @capital_overview end |
#documents ⇒ Object
Configuration for the documents embedded component.
646 647 648 |
# File 'lib/stripe/services/account_session_service.rb', line 646 def documents @documents end |
#export_tax_transactions ⇒ Object
Configuration for the export tax transactions embedded component.
648 649 650 |
# File 'lib/stripe/services/account_session_service.rb', line 648 def export_tax_transactions @export_tax_transactions end |
#financial_account ⇒ Object
Configuration for the financial account embedded component.
650 651 652 |
# File 'lib/stripe/services/account_session_service.rb', line 650 def financial_account @financial_account end |
#financial_account_transactions ⇒ Object
Configuration for the financial account transactions embedded component.
652 653 654 |
# File 'lib/stripe/services/account_session_service.rb', line 652 def financial_account_transactions @financial_account_transactions end |
#issuing_card ⇒ Object
Configuration for the issuing card embedded component.
654 655 656 |
# File 'lib/stripe/services/account_session_service.rb', line 654 def issuing_card @issuing_card end |
#issuing_cards_list ⇒ Object
Configuration for the issuing cards list embedded component.
656 657 658 |
# File 'lib/stripe/services/account_session_service.rb', line 656 def issuing_cards_list @issuing_cards_list end |
#notification_banner ⇒ Object
Configuration for the notification banner embedded component.
658 659 660 |
# File 'lib/stripe/services/account_session_service.rb', line 658 def @notification_banner end |
#payment_details ⇒ Object
Configuration for the payment details embedded component.
660 661 662 |
# File 'lib/stripe/services/account_session_service.rb', line 660 def payment_details @payment_details end |
#payment_disputes ⇒ Object
Configuration for the payment disputes embedded component.
662 663 664 |
# File 'lib/stripe/services/account_session_service.rb', line 662 def payment_disputes @payment_disputes end |
#payment_method_settings ⇒ Object
Configuration for the payment method settings embedded component.
664 665 666 |
# File 'lib/stripe/services/account_session_service.rb', line 664 def payment_method_settings @payment_method_settings end |
#payments ⇒ Object
Configuration for the payments embedded component.
666 667 668 |
# File 'lib/stripe/services/account_session_service.rb', line 666 def payments @payments end |
#payouts ⇒ Object
Configuration for the payouts embedded component.
668 669 670 |
# File 'lib/stripe/services/account_session_service.rb', line 668 def payouts @payouts end |
#payouts_list ⇒ Object
Configuration for the payouts list embedded component.
670 671 672 |
# File 'lib/stripe/services/account_session_service.rb', line 670 def payouts_list @payouts_list end |
#product_tax_code_selector ⇒ Object
Configuration for the product tax code selector embedded component.
672 673 674 |
# File 'lib/stripe/services/account_session_service.rb', line 672 def product_tax_code_selector @product_tax_code_selector end |
#recipients ⇒ Object
Configuration for the recipients component.
674 675 676 |
# File 'lib/stripe/services/account_session_service.rb', line 674 def recipients @recipients end |
#reporting_chart ⇒ Object
Configuration for the reporting chart embedded component.
676 677 678 |
# File 'lib/stripe/services/account_session_service.rb', line 676 def reporting_chart @reporting_chart end |
#tax_registrations ⇒ Object
Configuration for the tax registrations embedded component.
678 679 680 |
# File 'lib/stripe/services/account_session_service.rb', line 678 def tax_registrations @tax_registrations end |
#tax_settings ⇒ Object
Configuration for the tax settings embedded component.
680 681 682 |
# File 'lib/stripe/services/account_session_service.rb', line 680 def tax_settings @tax_settings end |
#tax_threshold_monitoring ⇒ Object
Configuration for the tax threshold monitoring embedded component.
682 683 684 |
# File 'lib/stripe/services/account_session_service.rb', line 682 def tax_threshold_monitoring @tax_threshold_monitoring end |