Class: Stripe::AccountSessionService::CreateParams::Components::AppInstall
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::AppInstall
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ AppInstall
constructor
A new instance of AppInstall.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ AppInstall
Returns a new instance of AppInstall.
79 80 81 82 |
# File 'lib/stripe/services/account_session_service.rb', line 79 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
74 75 76 |
# File 'lib/stripe/services/account_session_service.rb', line 74 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
77 78 79 |
# File 'lib/stripe/services/account_session_service.rb', line 77 def features @features end |