Class: Stripe::AccountSessionService::CreateParams::Components::AppViewport::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::AppViewport::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#allowed_apps ⇒ Object
List of apps allowed to be enabled for this account session.
Instance Method Summary collapse
-
#initialize(allowed_apps: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(allowed_apps: nil) ⇒ Features
Returns a new instance of Features.
90 91 92 |
# File 'lib/stripe/services/account_session_service.rb', line 90 def initialize(allowed_apps: nil) @allowed_apps = allowed_apps end |
Instance Attribute Details
#allowed_apps ⇒ Object
List of apps allowed to be enabled for this account session.
88 89 90 |
# File 'lib/stripe/services/account_session_service.rb', line 88 def allowed_apps @allowed_apps end |