Class: Stripe::AccountSessionService::CreateParams::Components::FinancialAccount::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::FinancialAccount::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component.
-
#external_account_collection ⇒ Object
Whether to allow external accounts to be linked for money transfer.
-
#send_money ⇒ Object
Whether to allow sending money.
-
#transfer_balance ⇒ Object
Whether to allow transferring balance.
Instance Method Summary collapse
-
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil) ⇒ Features
Returns a new instance of Features.
261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/stripe/services/account_session_service.rb', line 261 def initialize( disable_stripe_user_authentication: nil, external_account_collection: nil, send_money: nil, transfer_balance: nil ) @disable_stripe_user_authentication = disable_stripe_user_authentication @external_account_collection = external_account_collection @send_money = send_money @transfer_balance = transfer_balance end |
Instance Attribute Details
#disable_stripe_user_authentication ⇒ Object
Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.
253 254 255 |
# File 'lib/stripe/services/account_session_service.rb', line 253 def disable_stripe_user_authentication @disable_stripe_user_authentication end |
#external_account_collection ⇒ Object
Whether to allow external accounts to be linked for money transfer.
255 256 257 |
# File 'lib/stripe/services/account_session_service.rb', line 255 def external_account_collection @external_account_collection end |
#send_money ⇒ Object
Whether to allow sending money.
257 258 259 |
# File 'lib/stripe/services/account_session_service.rb', line 257 def send_money @send_money end |
#transfer_balance ⇒ Object
Whether to allow transferring balance.
259 260 261 |
# File 'lib/stripe/services/account_session_service.rb', line 259 def transfer_balance @transfer_balance end |