Class: Stripe::AccountSessionService::CreateParams::Components::IssuingCard
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::IssuingCard
- Defined in:
- lib/stripe/services/account_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the embedded component is enabled.
-
#features ⇒ Object
The list of features enabled in the embedded component.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ IssuingCard
constructor
A new instance of IssuingCard.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ IssuingCard
Returns a new instance of IssuingCard.
290 291 292 293 |
# File 'lib/stripe/services/account_session_service.rb', line 290 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the embedded component is enabled.
286 287 288 |
# File 'lib/stripe/services/account_session_service.rb', line 286 def enabled @enabled end |
#features ⇒ Object
The list of features enabled in the embedded component.
288 289 290 |
# File 'lib/stripe/services/account_session_service.rb', line 288 def features @features end |