Class: Stripe::AccountSessionService::CreateParams::Components::IssuingCardsList::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card_management: nil, card_spend_dispute_management: nil, cardholder_management: nil, disable_stripe_user_authentication: nil, spend_control_management: nil) ⇒ Features

Returns a new instance of Features.



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/stripe/services/account_session_service.rb', line 338

def initialize(
  card_management: nil,
  card_spend_dispute_management: nil,
  cardholder_management: nil,
  disable_stripe_user_authentication: nil,
  spend_control_management: nil
)
  @card_management = card_management
  @card_spend_dispute_management = card_spend_dispute_management
  @cardholder_management = cardholder_management
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @spend_control_management = spend_control_management
end

Instance Attribute Details

#card_managementObject

Whether to allow card management features.



324
325
326
# File 'lib/stripe/services/account_session_service.rb', line 324

def card_management
  @card_management
end

#card_spend_dispute_managementObject

Whether to allow card spend dispute management features.



327
328
329
# File 'lib/stripe/services/account_session_service.rb', line 327

def card_spend_dispute_management
  @card_spend_dispute_management
end

#cardholder_managementObject

Whether to allow cardholder management features.



330
331
332
# File 'lib/stripe/services/account_session_service.rb', line 330

def cardholder_management
  @cardholder_management
end

#disable_stripe_user_authenticationObject

Disables Stripe user authentication for this embedded component. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts.



333
334
335
# File 'lib/stripe/services/account_session_service.rb', line 333

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#spend_control_managementObject

Whether to allow spend control management features.



336
337
338
# File 'lib/stripe/services/account_session_service.rb', line 336

def spend_control_management
  @spend_control_management
end