Class: Stripe::AccountSessionService::CreateParams::Components::PaymentDetails::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



308
309
310
311
312
313
314
315
316
317
318
# File 'lib/stripe/services/account_session_service.rb', line 308

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



300
301
302
# File 'lib/stripe/services/account_session_service.rb', line 300

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.



302
303
304
# File 'lib/stripe/services/account_session_service.rb', line 302

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.



304
305
306
# File 'lib/stripe/services/account_session_service.rb', line 304

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether sending refunds is enabled. This is ‘true` by default.



306
307
308
# File 'lib/stripe/services/account_session_service.rb', line 306

def refund_management
  @refund_management
end