Class: Stripe::AccountSessionService::CreateParams::Components::PaymentDisputes::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::PaymentDisputes::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether to allow connected accounts to manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether to allow responding to disputes, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether to allow sending refunds.
Instance Method Summary collapse
-
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
Returns a new instance of Features.
417 418 419 420 421 422 423 424 425 |
# File 'lib/stripe/services/account_session_service.rb', line 417 def initialize( destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil ) @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management end |
Instance Attribute Details
#destination_on_behalf_of_charge_management ⇒ Object
Whether to allow connected accounts to manage destination charges that are created on behalf of them. This is ‘false` by default.
411 412 413 |
# File 'lib/stripe/services/account_session_service.rb', line 411 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether to allow responding to disputes, including submitting evidence and accepting disputes. This is ‘true` by default.
413 414 415 |
# File 'lib/stripe/services/account_session_service.rb', line 413 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether to allow sending refunds. This is ‘true` by default.
415 416 417 |
# File 'lib/stripe/services/account_session_service.rb', line 415 def refund_management @refund_management end |