Class: Stripe::AccountSessionService::CreateParams::Components::Payments::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountSessionService::CreateParams::Components::Payments::Features
- Defined in:
- lib/stripe/services/account_session_service.rb
Instance Attribute Summary collapse
-
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents.
-
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them.
-
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes.
-
#refund_management ⇒ Object
Whether sending refunds is enabled.
Instance Method Summary collapse
-
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features
Returns a new instance of Features.
533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/stripe/services/account_session_service.rb', line 533 def initialize( capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil ) @capture_payments = capture_payments @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management @dispute_management = dispute_management @refund_management = refund_management end |
Instance Attribute Details
#capture_payments ⇒ Object
Whether to allow capturing and cancelling payment intents. This is ‘true` by default.
525 526 527 |
# File 'lib/stripe/services/account_session_service.rb', line 525 def capture_payments @capture_payments end |
#destination_on_behalf_of_charge_management ⇒ Object
Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.
527 528 529 |
# File 'lib/stripe/services/account_session_service.rb', line 527 def destination_on_behalf_of_charge_management @destination_on_behalf_of_charge_management end |
#dispute_management ⇒ Object
Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.
529 530 531 |
# File 'lib/stripe/services/account_session_service.rb', line 529 def dispute_management @dispute_management end |
#refund_management ⇒ Object
Whether sending refunds is enabled. This is ‘true` by default.
531 532 533 |
# File 'lib/stripe/services/account_session_service.rb', line 531 def refund_management @refund_management end |