Class: Stripe::AccountSessionService::CreateParams::Components::Payments::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_payments: nil, destination_on_behalf_of_charge_management: nil, dispute_management: nil, refund_management: nil) ⇒ Features

Returns a new instance of Features.



372
373
374
375
376
377
378
379
380
381
382
# File 'lib/stripe/services/account_session_service.rb', line 372

def initialize(
  capture_payments: nil,
  destination_on_behalf_of_charge_management: nil,
  dispute_management: nil,
  refund_management: nil
)
  @capture_payments = capture_payments
  @destination_on_behalf_of_charge_management = destination_on_behalf_of_charge_management
  @dispute_management = dispute_management
  @refund_management = refund_management
end

Instance Attribute Details

#capture_paymentsObject

Whether to allow capturing and cancelling payment intents. This is ‘true` by default.



364
365
366
# File 'lib/stripe/services/account_session_service.rb', line 364

def capture_payments
  @capture_payments
end

#destination_on_behalf_of_charge_managementObject

Whether connected accounts can manage destination charges that are created on behalf of them. This is ‘false` by default.



366
367
368
# File 'lib/stripe/services/account_session_service.rb', line 366

def destination_on_behalf_of_charge_management
  @destination_on_behalf_of_charge_management
end

#dispute_managementObject

Whether responding to disputes is enabled, including submitting evidence and accepting disputes. This is ‘true` by default.



368
369
370
# File 'lib/stripe/services/account_session_service.rb', line 368

def dispute_management
  @dispute_management
end

#refund_managementObject

Whether sending refunds is enabled. This is ‘true` by default.



370
371
372
# File 'lib/stripe/services/account_session_service.rb', line 370

def refund_management
  @refund_management
end