Class: Stripe::AccountSessionService::CreateParams::Components::Payouts::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/account_session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(disable_stripe_user_authentication: nil, edit_payout_schedule: nil, external_account_collection: nil, instant_payouts: nil, standard_payouts: nil) ⇒ Features

Returns a new instance of Features.



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/stripe/services/account_session_service.rb', line 408

def initialize(
  disable_stripe_user_authentication: nil,
  edit_payout_schedule: nil,
  external_account_collection: nil,
  instant_payouts: nil,
  standard_payouts: nil
)
  @disable_stripe_user_authentication = disable_stripe_user_authentication
  @edit_payout_schedule = edit_payout_schedule
  @external_account_collection = 
  @instant_payouts = instant_payouts
  @standard_payouts = standard_payouts
end

Instance Attribute Details

#disable_stripe_user_authenticationObject

Disables Stripe user authentication for this embedded component. This value can only be true for accounts where ‘controller.requirement_collection` is `application`. The default value is the opposite of the `external_account_collection` value. For example, if you don’t set `external_account_collection`, it defaults to true and `disable_stripe_user_authentication` defaults to false.



398
399
400
# File 'lib/stripe/services/account_session_service.rb', line 398

def disable_stripe_user_authentication
  @disable_stripe_user_authentication
end

#edit_payout_scheduleObject

Whether to allow payout schedule to be changed. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.



400
401
402
# File 'lib/stripe/services/account_session_service.rb', line 400

def edit_payout_schedule
  @edit_payout_schedule
end

#external_account_collectionObject

Whether to allow platforms to control bank account collection for their connected accounts. This feature can only be false for accounts where you’re responsible for collecting updated information when requirements are due or change, like custom accounts. Otherwise, bank account collection is determined by compliance requirements. The default value for this feature is ‘true`.



402
403
404
# File 'lib/stripe/services/account_session_service.rb', line 402

def 
  @external_account_collection
end

#instant_payoutsObject

Whether to allow creation of instant payouts. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.



404
405
406
# File 'lib/stripe/services/account_session_service.rb', line 404

def instant_payouts
  @instant_payouts
end

#standard_payoutsObject

Whether to allow creation of standard payouts. Default ‘true` when Stripe owns Loss Liability, default `false` otherwise.



406
407
408
# File 'lib/stripe/services/account_session_service.rb', line 406

def standard_payouts
  @standard_payouts
end