Class: Stripe::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
2650
2651
2652
2653
2654
# File 'lib/stripe/params/account_update_params.rb', line 2620

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  risk_controls: nil,
  settings: nil,
  tos_acceptance: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
  @external_account = 
  @groups = groups
  @individual = individual
  @metadata = 
  @risk_controls = risk_controls
  @settings = settings
  @tos_acceptance = tos_acceptance
end

Instance Attribute Details

#account_tokenObject

An account token, used to securely provide details to the account.



2581
2582
2583
# File 'lib/stripe/params/account_update_params.rb', line 2581

def 
  @account_token
end

#business_profileObject

Business information about the account.



2583
2584
2585
# File 'lib/stripe/params/account_update_params.rb', line 2583

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2585
2586
2587
# File 'lib/stripe/params/account_update_params.rb', line 2585

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when account.controller.stripe_dashboard.type is none, which includes Custom accounts.



2594
2595
2596
# File 'lib/stripe/params/account_update_params.rb', line 2594

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any business_type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2596
2597
2598
# File 'lib/stripe/params/account_update_params.rb', line 2596

def company
  @company
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.



2598
2599
2600
# File 'lib/stripe/params/account_update_params.rb', line 2598

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



2600
2601
2602
# File 'lib/stripe/params/account_update_params.rb', line 2600

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If controller.requirement_collection is application, which includes Custom accounts, Stripe doesn't email the account without your consent.



2602
2603
2604
# File 'lib/stripe/params/account_update_params.rb', line 2602

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



2604
2605
2606
# File 'lib/stripe/params/account_update_params.rb', line 2604

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving payouts (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by Stripe.js, or a dictionary, as documented in the external_account parameter for bank account creation.

By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the bank account or card creation APIs. After you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2606
2607
2608
# File 'lib/stripe/params/account_update_params.rb', line 2606

def 
  @external_account
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



2608
2609
2610
# File 'lib/stripe/params/account_update_params.rb', line 2608

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless business_type is set to individual. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2610
2611
2612
# File 'lib/stripe/params/account_update_params.rb', line 2610

def individual
  @individual
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2612
2613
2614
# File 'lib/stripe/params/account_update_params.rb', line 2612

def 
  @metadata
end

#risk_controlsObject

A hash to configure risk controls on the account. Please see this page for more details.



2614
2615
2616
# File 'lib/stripe/params/account_update_params.rb', line 2614

def risk_controls
  @risk_controls
end

#settingsObject

Options for customizing how the account functions within Stripe.



2616
2617
2618
# File 'lib/stripe/params/account_update_params.rb', line 2616

def settings
  @settings
end

#tos_acceptanceObject

Details on the account's acceptance of the Stripe Services Agreement. This property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts. This property defaults to a full service agreement when empty.



2618
2619
2620
# File 'lib/stripe/params/account_update_params.rb', line 2618

def tos_acceptance
  @tos_acceptance
end