Class: Stripe::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Documents, Groups, Individual, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, settings: nil, tos_acceptance: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
# File 'lib/stripe/params/account_update_params.rb', line 2200

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  settings: nil,
  tos_acceptance: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
  @external_account = 
  @groups = groups
  @individual = individual
  @metadata = 
  @settings = settings
  @tos_acceptance = tos_acceptance
end

Instance Attribute Details

#account_tokenObject

An account token, used to securely provide details to the account.



2163
2164
2165
# File 'lib/stripe/params/account_update_params.rb', line 2163

def 
  @account_token
end

#business_profileObject

Business information about the account.



2165
2166
2167
# File 'lib/stripe/params/account_update_params.rb', line 2165

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2167
2168
2169
# File 'lib/stripe/params/account_update_params.rb', line 2167

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when account.controller.stripe_dashboard.type is none, which includes Custom accounts.



2176
2177
2178
# File 'lib/stripe/params/account_update_params.rb', line 2176

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any business_type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2178
2179
2180
# File 'lib/stripe/params/account_update_params.rb', line 2178

def company
  @company
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.



2180
2181
2182
# File 'lib/stripe/params/account_update_params.rb', line 2180

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



2182
2183
2184
# File 'lib/stripe/params/account_update_params.rb', line 2182

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If controller.requirement_collection is application, which includes Custom accounts, Stripe doesn't email the account without your consent.



2184
2185
2186
# File 'lib/stripe/params/account_update_params.rb', line 2184

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



2186
2187
2188
# File 'lib/stripe/params/account_update_params.rb', line 2186

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving payouts (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by Stripe.js, or a dictionary, as documented in the external_account parameter for bank account creation.

By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the bank account or card creation APIs. After you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2188
2189
2190
# File 'lib/stripe/params/account_update_params.rb', line 2188

def 
  @external_account
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



2190
2191
2192
# File 'lib/stripe/params/account_update_params.rb', line 2190

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless business_type is set to individual. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2192
2193
2194
# File 'lib/stripe/params/account_update_params.rb', line 2192

def individual
  @individual
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2194
2195
2196
# File 'lib/stripe/params/account_update_params.rb', line 2194

def 
  @metadata
end

#settingsObject

Options for customizing how the account functions within Stripe.



2196
2197
2198
# File 'lib/stripe/params/account_update_params.rb', line 2196

def settings
  @settings
end

#tos_acceptanceObject

Details on the account's acceptance of the Stripe Services Agreement. This property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts. This property defaults to a full service agreement when empty.



2198
2199
2200
# File 'lib/stripe/params/account_update_params.rb', line 2198

def tos_acceptance
  @tos_acceptance
end