Class: Stripe::AccountUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BankAccount, BusinessProfile, Capabilities, Card, CardToken, Company, Documents, Groups, Individual, RiskControls, Settings, TosAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_token: nil, business_profile: nil, business_type: nil, capabilities: nil, company: nil, default_currency: nil, documents: nil, email: nil, expand: nil, external_account: nil, groups: nil, individual: nil, metadata: nil, risk_controls: nil, settings: nil, tos_acceptance: nil) ⇒ AccountUpdateParams

Returns a new instance of AccountUpdateParams.



2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
# File 'lib/stripe/params/account_update_params.rb', line 2534

def initialize(
  account_token: nil,
  business_profile: nil,
  business_type: nil,
  capabilities: nil,
  company: nil,
  default_currency: nil,
  documents: nil,
  email: nil,
  expand: nil,
  external_account: nil,
  groups: nil,
  individual: nil,
  metadata: nil,
  risk_controls: nil,
  settings: nil,
  tos_acceptance: nil
)
  @account_token = 
  @business_profile = business_profile
  @business_type = business_type
  @capabilities = capabilities
  @company = company
  @default_currency = default_currency
  @documents = documents
  @email = email
  @expand = expand
  @external_account = 
  @groups = groups
  @individual = individual
  @metadata = 
  @risk_controls = risk_controls
  @settings = settings
  @tos_acceptance = tos_acceptance
end

Instance Attribute Details

#account_tokenObject

An account token, used to securely provide details to the account.



2495
2496
2497
# File 'lib/stripe/params/account_update_params.rb', line 2495

def 
  @account_token
end

#business_profileObject

Business information about the account.



2497
2498
2499
# File 'lib/stripe/params/account_update_params.rb', line 2497

def business_profile
  @business_profile
end

#business_typeObject

The business type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2499
2500
2501
# File 'lib/stripe/params/account_update_params.rb', line 2499

def business_type
  @business_type
end

#capabilitiesObject

Each key of the dictionary represents a capability, and each capability maps to its settings (for example, whether it has been requested or not). Each capability is inactive until you have provided its specific requirements and Stripe has verified them. An account might have some of its requested capabilities be active and some be inactive.

Required when account.controller.stripe_dashboard.type is none, which includes Custom accounts.



2508
2509
2510
# File 'lib/stripe/params/account_update_params.rb', line 2508

def capabilities
  @capabilities
end

#companyObject

Information about the company or business. This field is available for any business_type. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2510
2511
2512
# File 'lib/stripe/params/account_update_params.rb', line 2510

def company
  @company
end

#default_currencyObject

Three-letter ISO currency code representing the default currency for the account. This must be a currency that Stripe supports in the account's country.



2512
2513
2514
# File 'lib/stripe/params/account_update_params.rb', line 2512

def default_currency
  @default_currency
end

#documentsObject

Documents that may be submitted to satisfy various informational requests.



2514
2515
2516
# File 'lib/stripe/params/account_update_params.rb', line 2514

def documents
  @documents
end

#emailObject

The email address of the account holder. This is only to make the account easier to identify to you. If controller.requirement_collection is application, which includes Custom accounts, Stripe doesn't email the account without your consent.



2516
2517
2518
# File 'lib/stripe/params/account_update_params.rb', line 2516

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



2518
2519
2520
# File 'lib/stripe/params/account_update_params.rb', line 2518

def expand
  @expand
end

#external_accountObject

A card or bank account to attach to the account for receiving payouts (you won’t be able to use it for top-ups). You can provide either a token, like the ones returned by Stripe.js, or a dictionary, as documented in the external_account parameter for bank account creation.

By default, providing an external account sets it as the new default external account for its currency, and deletes the old default if one exists. To add additional external accounts without replacing the existing default for the currency, use the bank account or card creation APIs. After you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2520
2521
2522
# File 'lib/stripe/params/account_update_params.rb', line 2520

def 
  @external_account
end

#groupsObject

A hash of account group type to tokens. These are account groups this account should be added to.



2522
2523
2524
# File 'lib/stripe/params/account_update_params.rb', line 2522

def groups
  @groups
end

#individualObject

Information about the person represented by the account. This field is null unless business_type is set to individual. Once you create an Account Link or Account Session, this property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts.



2524
2525
2526
# File 'lib/stripe/params/account_update_params.rb', line 2524

def individual
  @individual
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2526
2527
2528
# File 'lib/stripe/params/account_update_params.rb', line 2526

def 
  @metadata
end

#risk_controlsObject

A hash to configure risk controls on the account. Please see this page for more details.



2528
2529
2530
# File 'lib/stripe/params/account_update_params.rb', line 2528

def risk_controls
  @risk_controls
end

#settingsObject

Options for customizing how the account functions within Stripe.



2530
2531
2532
# File 'lib/stripe/params/account_update_params.rb', line 2530

def settings
  @settings
end

#tos_acceptanceObject

Details on the account's acceptance of the Stripe Services Agreement. This property can only be updated for accounts where controller.requirement_collection is application, which includes Custom accounts. This property defaults to a full service agreement when empty.



2532
2533
2534
# File 'lib/stripe/params/account_update_params.rb', line 2532

def tos_acceptance
  @tos_acceptance
end