Class: Stripe::AccountUpdateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, RepresentativeDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, representative_declaration: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
# File 'lib/stripe/params/account_update_params.rb', line 1500

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  representative_declaration: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @representative_declaration = representative_declaration
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1454
1455
1456
# File 'lib/stripe/params/account_update_params.rb', line 1454

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1456
1457
1458
# File 'lib/stripe/params/account_update_params.rb', line 1456

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1458
1459
1460
# File 'lib/stripe/params/account_update_params.rb', line 1458

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1460
1461
1462
# File 'lib/stripe/params/account_update_params.rb', line 1460

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1462
1463
1464
# File 'lib/stripe/params/account_update_params.rb', line 1462

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1464
1465
1466
# File 'lib/stripe/params/account_update_params.rb', line 1464

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1466
1467
1468
# File 'lib/stripe/params/account_update_params.rb', line 1466

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1468
1469
1470
# File 'lib/stripe/params/account_update_params.rb', line 1468

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1470
1471
1472
# File 'lib/stripe/params/account_update_params.rb', line 1470

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1472
1473
1474
# File 'lib/stripe/params/account_update_params.rb', line 1472

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1474
1475
1476
# File 'lib/stripe/params/account_update_params.rb', line 1474

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1476
1477
1478
# File 'lib/stripe/params/account_update_params.rb', line 1476

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1478
1479
1480
# File 'lib/stripe/params/account_update_params.rb', line 1478

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



1480
1481
1482
# File 'lib/stripe/params/account_update_params.rb', line 1480

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



1482
1483
1484
# File 'lib/stripe/params/account_update_params.rb', line 1482

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



1484
1485
1486
# File 'lib/stripe/params/account_update_params.rb', line 1484

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1486
1487
1488
# File 'lib/stripe/params/account_update_params.rb', line 1486

def registration_number
  @registration_number
end

#representative_declarationObject

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



1488
1489
1490
# File 'lib/stripe/params/account_update_params.rb', line 1488

def representative_declaration
  @representative_declaration
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1490
1491
1492
# File 'lib/stripe/params/account_update_params.rb', line 1490

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1492
1493
1494
# File 'lib/stripe/params/account_update_params.rb', line 1492

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1494
1495
1496
# File 'lib/stripe/params/account_update_params.rb', line 1494

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1496
1497
1498
# File 'lib/stripe/params/account_update_params.rb', line 1496

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1498
1499
1500
# File 'lib/stripe/params/account_update_params.rb', line 1498

def verification
  @verification
end