Class: Stripe::AccountUpdateParams::Company

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, DirectorshipDeclaration, OwnershipDeclaration, RegistrationDate, RepresentativeDeclaration, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, directors_provided: nil, directorship_declaration: nil, executives_provided: nil, export_license_id: nil, export_purpose_code: nil, name: nil, name_kana: nil, name_kanji: nil, owners_provided: nil, ownership_declaration: nil, ownership_exemption_reason: nil, phone: nil, registration_date: nil, registration_number: nil, representative_declaration: nil, structure: nil, tax_id: nil, tax_id_registrar: nil, vat_id: nil, verification: nil) ⇒ Company

Returns a new instance of Company.



1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
# File 'lib/stripe/params/account_update_params.rb', line 1435

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  directors_provided: nil,
  directorship_declaration: nil,
  executives_provided: nil,
  export_license_id: nil,
  export_purpose_code: nil,
  name: nil,
  name_kana: nil,
  name_kanji: nil,
  owners_provided: nil,
  ownership_declaration: nil,
  ownership_exemption_reason: nil,
  phone: nil,
  registration_date: nil,
  registration_number: nil,
  representative_declaration: nil,
  structure: nil,
  tax_id: nil,
  tax_id_registrar: nil,
  vat_id: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @directors_provided = directors_provided
  @directorship_declaration = directorship_declaration
  @executives_provided = executives_provided
  @export_license_id = export_license_id
  @export_purpose_code = export_purpose_code
  @name = name
  @name_kana = name_kana
  @name_kanji = name_kanji
  @owners_provided = owners_provided
  @ownership_declaration = ownership_declaration
  @ownership_exemption_reason = ownership_exemption_reason
  @phone = phone
  @registration_date = registration_date
  @registration_number = registration_number
  @representative_declaration = representative_declaration
  @structure = structure
  @tax_id = tax_id
  @tax_id_registrar = tax_id_registrar
  @vat_id = vat_id
  @verification = verification
end

Instance Attribute Details

#addressObject

The company’s primary address.



1389
1390
1391
# File 'lib/stripe/params/account_update_params.rb', line 1389

def address
  @address
end

#address_kanaObject

The Kana variation of the company’s primary address (Japan only).



1391
1392
1393
# File 'lib/stripe/params/account_update_params.rb', line 1391

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the company’s primary address (Japan only).



1393
1394
1395
# File 'lib/stripe/params/account_update_params.rb', line 1393

def address_kanji
  @address_kanji
end

#directors_providedObject

Whether the company’s directors have been provided. Set this Boolean to ‘true` after creating all the company’s directors with [the Persons API](/api/persons) for accounts with a ‘relationship.director` requirement. This value is not automatically set to `true` after creating directors, so it needs to be updated to indicate all directors have been provided.



1395
1396
1397
# File 'lib/stripe/params/account_update_params.rb', line 1395

def directors_provided
  @directors_provided
end

#directorship_declarationObject

This hash is used to attest that the directors information provided to Stripe is both current and correct.



1397
1398
1399
# File 'lib/stripe/params/account_update_params.rb', line 1397

def directorship_declaration
  @directorship_declaration
end

#executives_providedObject

Whether the company’s executives have been provided. Set this Boolean to ‘true` after creating all the company’s executives with [the Persons API](/api/persons) for accounts with a ‘relationship.executive` requirement.



1399
1400
1401
# File 'lib/stripe/params/account_update_params.rb', line 1399

def executives_provided
  @executives_provided
end

#export_license_idObject

The export license ID number of the company, also referred as Import Export Code (India only).



1401
1402
1403
# File 'lib/stripe/params/account_update_params.rb', line 1401

def export_license_id
  @export_license_id
end

#export_purpose_codeObject

The purpose code to use for export transactions (India only).



1403
1404
1405
# File 'lib/stripe/params/account_update_params.rb', line 1403

def export_purpose_code
  @export_purpose_code
end

#nameObject

The company’s legal name.



1405
1406
1407
# File 'lib/stripe/params/account_update_params.rb', line 1405

def name
  @name
end

#name_kanaObject

The Kana variation of the company’s legal name (Japan only).



1407
1408
1409
# File 'lib/stripe/params/account_update_params.rb', line 1407

def name_kana
  @name_kana
end

#name_kanjiObject

The Kanji variation of the company’s legal name (Japan only).



1409
1410
1411
# File 'lib/stripe/params/account_update_params.rb', line 1409

def name_kanji
  @name_kanji
end

#owners_providedObject

Whether the company’s owners have been provided. Set this Boolean to ‘true` after creating all the company’s owners with [the Persons API](/api/persons) for accounts with a ‘relationship.owner` requirement.



1411
1412
1413
# File 'lib/stripe/params/account_update_params.rb', line 1411

def owners_provided
  @owners_provided
end

#ownership_declarationObject

This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.



1413
1414
1415
# File 'lib/stripe/params/account_update_params.rb', line 1413

def ownership_declaration
  @ownership_declaration
end

#ownership_exemption_reasonObject

This value is used to determine if a business is exempt from providing ultimate beneficial owners. See [this support article](support.stripe.com/questions/exemption-from-providing-ownership-details) and [changelog](docs.stripe.com/changelog/acacia/2025-01-27/ownership-exemption-reason-accounts-api) for more details.



1415
1416
1417
# File 'lib/stripe/params/account_update_params.rb', line 1415

def ownership_exemption_reason
  @ownership_exemption_reason
end

#phoneObject

The company’s phone number (used for verification).



1417
1418
1419
# File 'lib/stripe/params/account_update_params.rb', line 1417

def phone
  @phone
end

#registration_dateObject

Attribute for param field registration_date



1419
1420
1421
# File 'lib/stripe/params/account_update_params.rb', line 1419

def registration_date
  @registration_date
end

#registration_numberObject

The identification number given to a company when it is registered or incorporated, if distinct from the identification number used for filing taxes. (Examples are the CIN for companies and LLP IN for partnerships in India, and the Company Registration Number in Hong Kong).



1421
1422
1423
# File 'lib/stripe/params/account_update_params.rb', line 1421

def registration_number
  @registration_number
end

#representative_declarationObject

This hash is used to attest that the representative is authorized to act as the representative of their legal entity.



1423
1424
1425
# File 'lib/stripe/params/account_update_params.rb', line 1423

def representative_declaration
  @representative_declaration
end

#structureObject

The category identifying the legal structure of the company or legal entity. See [Business structure](/connect/identity-verification#business-structure) for more details. Pass an empty string to unset this value.



1425
1426
1427
# File 'lib/stripe/params/account_update_params.rb', line 1425

def structure
  @structure
end

#tax_idObject

The business ID number of the company, as appropriate for the company’s country. (Examples are an Employer ID Number in the U.S., a Business Number in Canada, or a Company Number in the UK.)



1427
1428
1429
# File 'lib/stripe/params/account_update_params.rb', line 1427

def tax_id
  @tax_id
end

#tax_id_registrarObject

The jurisdiction in which the ‘tax_id` is registered (Germany-based companies only).



1429
1430
1431
# File 'lib/stripe/params/account_update_params.rb', line 1429

def tax_id_registrar
  @tax_id_registrar
end

#vat_idObject

The VAT number of the company.



1431
1432
1433
# File 'lib/stripe/params/account_update_params.rb', line 1431

def vat_id
  @vat_id
end

#verificationObject

Information on the verification state of the company.



1433
1434
1435
# File 'lib/stripe/params/account_update_params.rb', line 1433

def verification
  @verification
end