Class: Stripe::AccountUpdateParams::Company::DirectorshipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Company::DirectorshipDeclaration
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
constructor
A new instance of DirectorshipDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration
Returns a new instance of DirectorshipDeclaration.
1413 1414 1415 1416 1417 |
# File 'lib/stripe/params/account_update_params.rb', line 1413 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the directorship declaration attestation was made.
1407 1408 1409 |
# File 'lib/stripe/params/account_update_params.rb', line 1407 def date @date end |
#ip ⇒ Object
The IP address from which the directorship declaration attestation was made.
1409 1410 1411 |
# File 'lib/stripe/params/account_update_params.rb', line 1409 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the directorship declaration attestation was made.
1411 1412 1413 |
# File 'lib/stripe/params/account_update_params.rb', line 1411 def user_agent @user_agent end |