Class: Stripe::AccountUpdateParams::Company::DirectorshipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ DirectorshipDeclaration

Returns a new instance of DirectorshipDeclaration.



1356
1357
1358
1359
1360
# File 'lib/stripe/params/account_update_params.rb', line 1356

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the directorship declaration attestation was made.



1350
1351
1352
# File 'lib/stripe/params/account_update_params.rb', line 1350

def date
  @date
end

#ipObject

The IP address from which the directorship declaration attestation was made.



1352
1353
1354
# File 'lib/stripe/params/account_update_params.rb', line 1352

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the directorship declaration attestation was made.



1354
1355
1356
# File 'lib/stripe/params/account_update_params.rb', line 1354

def user_agent
  @user_agent
end