Class: Stripe::AccountUpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1447
1448
1449
1450
1451
# File 'lib/stripe/params/account_update_params.rb', line 1447

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1441
1442
1443
# File 'lib/stripe/params/account_update_params.rb', line 1441

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1443
1444
1445
# File 'lib/stripe/params/account_update_params.rb', line 1443

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1445
1446
1447
# File 'lib/stripe/params/account_update_params.rb', line 1445

def user_agent
  @user_agent
end