Class: Stripe::AccountUpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1390
1391
1392
1393
1394
# File 'lib/stripe/params/account_update_params.rb', line 1390

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1384
1385
1386
# File 'lib/stripe/params/account_update_params.rb', line 1384

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1386
1387
1388
# File 'lib/stripe/params/account_update_params.rb', line 1386

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1388
1389
1390
# File 'lib/stripe/params/account_update_params.rb', line 1388

def user_agent
  @user_agent
end