Class: Stripe::AccountUpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1345
1346
1347
1348
1349
# File 'lib/stripe/params/account_update_params.rb', line 1345

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1339
1340
1341
# File 'lib/stripe/params/account_update_params.rb', line 1339

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1341
1342
1343
# File 'lib/stripe/params/account_update_params.rb', line 1341

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1343
1344
1345
# File 'lib/stripe/params/account_update_params.rb', line 1343

def user_agent
  @user_agent
end