Class: Stripe::AccountUpdateParams::Company::OwnershipDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration

Returns a new instance of OwnershipDeclaration.



1371
1372
1373
1374
1375
# File 'lib/stripe/params/account_update_params.rb', line 1371

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the beneficial owner attestation was made.



1365
1366
1367
# File 'lib/stripe/params/account_update_params.rb', line 1365

def date
  @date
end

#ipObject

The IP address from which the beneficial owner attestation was made.



1367
1368
1369
# File 'lib/stripe/params/account_update_params.rb', line 1367

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the beneficial owner attestation was made.



1369
1370
1371
# File 'lib/stripe/params/account_update_params.rb', line 1369

def user_agent
  @user_agent
end