Class: Stripe::AccountUpdateParams::Company::OwnershipDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Company::OwnershipDeclaration
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
-
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
constructor
A new instance of OwnershipDeclaration.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ OwnershipDeclaration
Returns a new instance of OwnershipDeclaration.
1332 1333 1334 1335 1336 |
# File 'lib/stripe/params/account_update_params.rb', line 1332 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the beneficial owner attestation was made.
1326 1327 1328 |
# File 'lib/stripe/params/account_update_params.rb', line 1326 def date @date end |
#ip ⇒ Object
The IP address from which the beneficial owner attestation was made.
1328 1329 1330 |
# File 'lib/stripe/params/account_update_params.rb', line 1328 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the beneficial owner attestation was made.
1330 1331 1332 |
# File 'lib/stripe/params/account_update_params.rb', line 1330 def user_agent @user_agent end |