Class: Stripe::AccountUpdateParams::Company::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1316
1317
1318
1319
1320
# File 'lib/stripe/params/account_update_params.rb', line 1316

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the representative declaration attestation was made.



1310
1311
1312
# File 'lib/stripe/params/account_update_params.rb', line 1310

def date
  @date
end

#ipObject

The IP address from which the representative declaration attestation was made.



1312
1313
1314
# File 'lib/stripe/params/account_update_params.rb', line 1312

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative declaration attestation was made.



1314
1315
1316
# File 'lib/stripe/params/account_update_params.rb', line 1314

def user_agent
  @user_agent
end