Class: Stripe::AccountUpdateParams::Company::RepresentativeDeclaration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Company::RepresentativeDeclaration
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the representative declaration attestation was made.
-
#ip ⇒ Object
The IP address from which the representative declaration attestation was made.
-
#user_agent ⇒ Object
The user agent of the browser from which the representative declaration attestation was made.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
constructor
A new instance of RepresentativeDeclaration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration
Returns a new instance of RepresentativeDeclaration.
1489 1490 1491 1492 1493 |
# File 'lib/stripe/params/account_update_params.rb', line 1489 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the representative declaration attestation was made.
1483 1484 1485 |
# File 'lib/stripe/params/account_update_params.rb', line 1483 def date @date end |
#ip ⇒ Object
The IP address from which the representative declaration attestation was made.
1485 1486 1487 |
# File 'lib/stripe/params/account_update_params.rb', line 1485 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the representative declaration attestation was made.
1487 1488 1489 |
# File 'lib/stripe/params/account_update_params.rb', line 1487 def user_agent @user_agent end |