Class: Stripe::AccountUpdateParams::Company::RepresentativeDeclaration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ RepresentativeDeclaration

Returns a new instance of RepresentativeDeclaration.



1427
1428
1429
1430
1431
# File 'lib/stripe/params/account_update_params.rb', line 1427

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the representative declaration attestation was made.



1421
1422
1423
# File 'lib/stripe/params/account_update_params.rb', line 1421

def date
  @date
end

#ipObject

The IP address from which the representative declaration attestation was made.



1423
1424
1425
# File 'lib/stripe/params/account_update_params.rb', line 1423

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the representative declaration attestation was made.



1425
1426
1427
# File 'lib/stripe/params/account_update_params.rb', line 1425

def user_agent
  @user_agent
end