Class: Stripe::AccountUpdateParams::Documents::ProofOfRegistration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Documents::ProofOfRegistration
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.
-
#signer ⇒ Object
Information regarding the person signing the document if applicable.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil) ⇒ ProofOfRegistration
constructor
A new instance of ProofOfRegistration.
Methods inherited from RequestParams
Constructor Details
#initialize(files: nil, signer: nil) ⇒ ProofOfRegistration
Returns a new instance of ProofOfRegistration.
1564 1565 1566 1567 |
# File 'lib/stripe/params/account_update_params.rb', line 1564 def initialize(files: nil, signer: nil) @files = files @signer = signer end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.
1560 1561 1562 |
# File 'lib/stripe/params/account_update_params.rb', line 1560 def files @files end |
#signer ⇒ Object
Information regarding the person signing the document if applicable.
1562 1563 1564 |
# File 'lib/stripe/params/account_update_params.rb', line 1562 def signer @signer end |