Class: Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a file upload with a
purposevalue ofaccount_requirement. -
#signer ⇒ Object
Information regarding the person signing the document if applicable.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership
constructor
A new instance of ProofOfUltimateBeneficialOwnership.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership
Returns a new instance of ProofOfUltimateBeneficialOwnership.
1548 1549 1550 1551 |
# File 'lib/stripe/params/account_update_params.rb', line 1548 def initialize(files: nil, signer: nil) @files = files @signer = signer end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a file upload with a purpose value of account_requirement.
1544 1545 1546 |
# File 'lib/stripe/params/account_update_params.rb', line 1544 def files @files end |
#signer ⇒ Object
Information regarding the person signing the document if applicable.
1546 1547 1548 |
# File 'lib/stripe/params/account_update_params.rb', line 1546 def signer @signer end |