Class: Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership

Returns a new instance of ProofOfUltimateBeneficialOwnership.



1668
1669
1670
1671
# File 'lib/stripe/params/account_update_params.rb', line 1668

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.



1664
1665
1666
# File 'lib/stripe/params/account_update_params.rb', line 1664

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1666
1667
1668
# File 'lib/stripe/params/account_update_params.rb', line 1666

def signer
  @signer
end