Class: Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership

Returns a new instance of ProofOfUltimateBeneficialOwnership.



1649
1650
1651
1652
# File 'lib/stripe/params/account_update_params.rb', line 1649

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.



1645
1646
1647
# File 'lib/stripe/params/account_update_params.rb', line 1645

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1647
1648
1649
# File 'lib/stripe/params/account_update_params.rb', line 1647

def signer
  @signer
end