Class: Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Signer
Instance Attribute Summary collapse
-
#files ⇒ Object
One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.
-
#signer ⇒ Object
Information regarding the person signing the document if applicable.
Instance Method Summary collapse
-
#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership
constructor
A new instance of ProofOfUltimateBeneficialOwnership.
Methods inherited from RequestParams
Constructor Details
#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership
Returns a new instance of ProofOfUltimateBeneficialOwnership.
1411 1412 1413 1414 |
# File 'lib/stripe/params/account_update_params.rb', line 1411 def initialize(files: nil, signer: nil) @files = files @signer = signer end |
Instance Attribute Details
#files ⇒ Object
One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.
1407 1408 1409 |
# File 'lib/stripe/params/account_update_params.rb', line 1407 def files @files end |
#signer ⇒ Object
Information regarding the person signing the document if applicable.
1409 1410 1411 |
# File 'lib/stripe/params/account_update_params.rb', line 1409 def signer @signer end |