Class: Stripe::AccountUpdateParams::Documents::ProofOfUltimateBeneficialOwnership

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: Signer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(files: nil, signer: nil) ⇒ ProofOfUltimateBeneficialOwnership

Returns a new instance of ProofOfUltimateBeneficialOwnership.



1584
1585
1586
1587
# File 'lib/stripe/params/account_update_params.rb', line 1584

def initialize(files: nil, signer: nil)
  @files = files
  @signer = signer
end

Instance Attribute Details

#filesObject

One or more document ids returned by a [file upload](api.stripe.com#create_file) with a ‘purpose` value of `account_requirement`.



1580
1581
1582
# File 'lib/stripe/params/account_update_params.rb', line 1580

def files
  @files
end

#signerObject

Information regarding the person signing the document if applicable.



1582
1583
1584
# File 'lib/stripe/params/account_update_params.rb', line 1582

def signer
  @signer
end