Class: Stripe::AccountUpdateParams::Groups
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Groups
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#payments_pricing ⇒ Object
The group the account is in to determine their payments pricing, and null if the account is on customized pricing.
Instance Method Summary collapse
-
#initialize(payments_pricing: nil) ⇒ Groups
constructor
A new instance of Groups.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payments_pricing: nil) ⇒ Groups
Returns a new instance of Groups.
1599 1600 1601 |
# File 'lib/stripe/params/account_update_params.rb', line 1599 def initialize(payments_pricing: nil) @payments_pricing = payments_pricing end |
Instance Attribute Details
#payments_pricing ⇒ Object
The group the account is in to determine their payments pricing, and null if the account is on customized pricing. See the Platform pricing tool documentation for details.
1597 1598 1599 |
# File 'lib/stripe/params/account_update_params.rb', line 1597 def payments_pricing @payments_pricing end |