Class: Stripe::AccountUpdateParams::Individual

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual

Returns a new instance of Individual.



1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
# File 'lib/stripe/params/account_update_params.rb', line 1961

def initialize(
  address: nil,
  address_kana: nil,
  address_kanji: nil,
  dob: nil,
  email: nil,
  first_name: nil,
  first_name_kana: nil,
  first_name_kanji: nil,
  full_name_aliases: nil,
  gender: nil,
  id_number: nil,
  id_number_secondary: nil,
  last_name: nil,
  last_name_kana: nil,
  last_name_kanji: nil,
  maiden_name: nil,
  metadata: nil,
  phone: nil,
  political_exposure: nil,
  registered_address: nil,
  relationship: nil,
  ssn_last_4: nil,
  verification: nil
)
  @address = address
  @address_kana = address_kana
  @address_kanji = address_kanji
  @dob = dob
  @email = email
  @first_name = first_name
  @first_name_kana = first_name_kana
  @first_name_kanji = first_name_kanji
  @full_name_aliases = full_name_aliases
  @gender = gender
  @id_number = id_number
  @id_number_secondary = id_number_secondary
  @last_name = last_name
  @last_name_kana = last_name_kana
  @last_name_kanji = last_name_kanji
  @maiden_name = maiden_name
  @metadata = 
  @phone = phone
  @political_exposure = political_exposure
  @registered_address = registered_address
  @relationship = relationship
  @ssn_last_4 = ssn_last_4
  @verification = verification
end

Instance Attribute Details

#addressObject

The individual’s primary address.



1915
1916
1917
# File 'lib/stripe/params/account_update_params.rb', line 1915

def address
  @address
end

#address_kanaObject

The Kana variation of the individual’s primary address (Japan only).



1917
1918
1919
# File 'lib/stripe/params/account_update_params.rb', line 1917

def address_kana
  @address_kana
end

#address_kanjiObject

The Kanji variation of the individual’s primary address (Japan only).



1919
1920
1921
# File 'lib/stripe/params/account_update_params.rb', line 1919

def address_kanji
  @address_kanji
end

#dobObject

The individual’s date of birth.



1921
1922
1923
# File 'lib/stripe/params/account_update_params.rb', line 1921

def dob
  @dob
end

#emailObject

The individual’s email address.



1923
1924
1925
# File 'lib/stripe/params/account_update_params.rb', line 1923

def email
  @email
end

#first_nameObject

The individual’s first name.



1925
1926
1927
# File 'lib/stripe/params/account_update_params.rb', line 1925

def first_name
  @first_name
end

#first_name_kanaObject

The Kana variation of the individual’s first name (Japan only).



1927
1928
1929
# File 'lib/stripe/params/account_update_params.rb', line 1927

def first_name_kana
  @first_name_kana
end

#first_name_kanjiObject

The Kanji variation of the individual’s first name (Japan only).



1929
1930
1931
# File 'lib/stripe/params/account_update_params.rb', line 1929

def first_name_kanji
  @first_name_kanji
end

#full_name_aliasesObject

A list of alternate names or aliases that the individual is known by.



1931
1932
1933
# File 'lib/stripe/params/account_update_params.rb', line 1931

def full_name_aliases
  @full_name_aliases
end

#genderObject

The individual’s gender



1933
1934
1935
# File 'lib/stripe/params/account_update_params.rb', line 1933

def gender
  @gender
end

#id_numberObject

The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



1935
1936
1937
# File 'lib/stripe/params/account_update_params.rb', line 1935

def id_number
  @id_number
end

#id_number_secondaryObject

The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).



1937
1938
1939
# File 'lib/stripe/params/account_update_params.rb', line 1937

def id_number_secondary
  @id_number_secondary
end

#last_nameObject

The individual’s last name.



1939
1940
1941
# File 'lib/stripe/params/account_update_params.rb', line 1939

def last_name
  @last_name
end

#last_name_kanaObject

The Kana variation of the individual’s last name (Japan only).



1941
1942
1943
# File 'lib/stripe/params/account_update_params.rb', line 1941

def last_name_kana
  @last_name_kana
end

#last_name_kanjiObject

The Kanji variation of the individual’s last name (Japan only).



1943
1944
1945
# File 'lib/stripe/params/account_update_params.rb', line 1943

def last_name_kanji
  @last_name_kanji
end

#maiden_nameObject

The individual’s maiden name.



1945
1946
1947
# File 'lib/stripe/params/account_update_params.rb', line 1945

def maiden_name
  @maiden_name
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1947
1948
1949
# File 'lib/stripe/params/account_update_params.rb', line 1947

def 
  @metadata
end

#phoneObject

The individual’s phone number.



1949
1950
1951
# File 'lib/stripe/params/account_update_params.rb', line 1949

def phone
  @phone
end

#political_exposureObject

Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.



1951
1952
1953
# File 'lib/stripe/params/account_update_params.rb', line 1951

def political_exposure
  @political_exposure
end

#registered_addressObject

The individual’s registered address.



1953
1954
1955
# File 'lib/stripe/params/account_update_params.rb', line 1953

def registered_address
  @registered_address
end

#relationshipObject

Describes the person’s relationship to the account.



1955
1956
1957
# File 'lib/stripe/params/account_update_params.rb', line 1955

def relationship
  @relationship
end

#ssn_last_4Object

The last four digits of the individual’s Social Security Number (U.S. only).



1957
1958
1959
# File 'lib/stripe/params/account_update_params.rb', line 1957

def ssn_last_4
  @ssn_last_4
end

#verificationObject

The individual’s verification document information.



1959
1960
1961
# File 'lib/stripe/params/account_update_params.rb', line 1959

def verification
  @verification
end