Class: Stripe::AccountUpdateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Individual
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 |
# File 'lib/stripe/params/account_update_params.rb', line 1870 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
1824 1825 1826 |
# File 'lib/stripe/params/account_update_params.rb', line 1824 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
1826 1827 1828 |
# File 'lib/stripe/params/account_update_params.rb', line 1826 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
1828 1829 1830 |
# File 'lib/stripe/params/account_update_params.rb', line 1828 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
1830 1831 1832 |
# File 'lib/stripe/params/account_update_params.rb', line 1830 def dob @dob end |
#email ⇒ Object
The individual’s email address.
1832 1833 1834 |
# File 'lib/stripe/params/account_update_params.rb', line 1832 def email @email end |
#first_name ⇒ Object
The individual’s first name.
1834 1835 1836 |
# File 'lib/stripe/params/account_update_params.rb', line 1834 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
1836 1837 1838 |
# File 'lib/stripe/params/account_update_params.rb', line 1836 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
1838 1839 1840 |
# File 'lib/stripe/params/account_update_params.rb', line 1838 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
1840 1841 1842 |
# File 'lib/stripe/params/account_update_params.rb', line 1840 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
1842 1843 1844 |
# File 'lib/stripe/params/account_update_params.rb', line 1842 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
1844 1845 1846 |
# File 'lib/stripe/params/account_update_params.rb', line 1844 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
1846 1847 1848 |
# File 'lib/stripe/params/account_update_params.rb', line 1846 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
1848 1849 1850 |
# File 'lib/stripe/params/account_update_params.rb', line 1848 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
1850 1851 1852 |
# File 'lib/stripe/params/account_update_params.rb', line 1850 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
1852 1853 1854 |
# File 'lib/stripe/params/account_update_params.rb', line 1852 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
1854 1855 1856 |
# File 'lib/stripe/params/account_update_params.rb', line 1854 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1856 1857 1858 |
# File 'lib/stripe/params/account_update_params.rb', line 1856 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
1858 1859 1860 |
# File 'lib/stripe/params/account_update_params.rb', line 1858 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
1860 1861 1862 |
# File 'lib/stripe/params/account_update_params.rb', line 1860 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
1862 1863 1864 |
# File 'lib/stripe/params/account_update_params.rb', line 1862 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
1864 1865 1866 |
# File 'lib/stripe/params/account_update_params.rb', line 1864 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
1866 1867 1868 |
# File 'lib/stripe/params/account_update_params.rb', line 1866 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
1868 1869 1870 |
# File 'lib/stripe/params/account_update_params.rb', line 1868 def verification @verification end |