Class: Stripe::AccountUpdateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Individual
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Address, AddressKana, AddressKanji, Dob, RegisteredAddress, Relationship, Verification
Instance Attribute Summary collapse
-
#address ⇒ Object
The individual’s primary address.
-
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
-
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
-
#dob ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#first_name ⇒ Object
The individual’s first name.
-
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
-
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
-
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
-
#gender ⇒ Object
The individual’s gender.
-
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country.
-
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks.
-
#last_name ⇒ Object
The individual’s last name.
-
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
-
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
-
#maiden_name ⇒ Object
The individual’s maiden name.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#phone ⇒ Object
The individual’s phone number.
-
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
-
#registered_address ⇒ Object
The individual’s registered address.
-
#relationship ⇒ Object
Describes the person’s relationship to the account.
-
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
-
#verification ⇒ Object
The individual’s verification document information.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/stripe/params/account_update_params.rb', line 1669 def initialize( address: nil, address_kana: nil, address_kanji: nil, dob: nil, email: nil, first_name: nil, first_name_kana: nil, first_name_kanji: nil, full_name_aliases: nil, gender: nil, id_number: nil, id_number_secondary: nil, last_name: nil, last_name_kana: nil, last_name_kanji: nil, maiden_name: nil, metadata: nil, phone: nil, political_exposure: nil, registered_address: nil, relationship: nil, ssn_last_4: nil, verification: nil ) @address = address @address_kana = address_kana @address_kanji = address_kanji @dob = dob @email = email @first_name = first_name @first_name_kana = first_name_kana @first_name_kanji = first_name_kanji @full_name_aliases = full_name_aliases @gender = gender @id_number = id_number @id_number_secondary = id_number_secondary @last_name = last_name @last_name_kana = last_name_kana @last_name_kanji = last_name_kanji @maiden_name = maiden_name @metadata = @phone = phone @political_exposure = political_exposure @registered_address = registered_address @relationship = relationship @ssn_last_4 = ssn_last_4 @verification = verification end |
Instance Attribute Details
#address ⇒ Object
The individual’s primary address.
1623 1624 1625 |
# File 'lib/stripe/params/account_update_params.rb', line 1623 def address @address end |
#address_kana ⇒ Object
The Kana variation of the individual’s primary address (Japan only).
1625 1626 1627 |
# File 'lib/stripe/params/account_update_params.rb', line 1625 def address_kana @address_kana end |
#address_kanji ⇒ Object
The Kanji variation of the individual’s primary address (Japan only).
1627 1628 1629 |
# File 'lib/stripe/params/account_update_params.rb', line 1627 def address_kanji @address_kanji end |
#dob ⇒ Object
The individual’s date of birth.
1629 1630 1631 |
# File 'lib/stripe/params/account_update_params.rb', line 1629 def dob @dob end |
#email ⇒ Object
The individual’s email address.
1631 1632 1633 |
# File 'lib/stripe/params/account_update_params.rb', line 1631 def email @email end |
#first_name ⇒ Object
The individual’s first name.
1633 1634 1635 |
# File 'lib/stripe/params/account_update_params.rb', line 1633 def first_name @first_name end |
#first_name_kana ⇒ Object
The Kana variation of the individual’s first name (Japan only).
1635 1636 1637 |
# File 'lib/stripe/params/account_update_params.rb', line 1635 def first_name_kana @first_name_kana end |
#first_name_kanji ⇒ Object
The Kanji variation of the individual’s first name (Japan only).
1637 1638 1639 |
# File 'lib/stripe/params/account_update_params.rb', line 1637 def first_name_kanji @first_name_kanji end |
#full_name_aliases ⇒ Object
A list of alternate names or aliases that the individual is known by.
1639 1640 1641 |
# File 'lib/stripe/params/account_update_params.rb', line 1639 def full_name_aliases @full_name_aliases end |
#gender ⇒ Object
The individual’s gender
1641 1642 1643 |
# File 'lib/stripe/params/account_update_params.rb', line 1641 def gender @gender end |
#id_number ⇒ Object
The government-issued ID number of the individual, as appropriate for the representative’s country. (Examples are a Social Security Number in the U.S., or a Social Insurance Number in Canada). Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
1643 1644 1645 |
# File 'lib/stripe/params/account_update_params.rb', line 1643 def id_number @id_number end |
#id_number_secondary ⇒ Object
The government-issued secondary ID number of the individual, as appropriate for the representative’s country, will be used for enhanced verification checks. In Thailand, this would be the laser code found on the back of an ID card. Instead of the number itself, you can also provide a [PII token created with Stripe.js](/js/tokens/create_token?type=pii).
1645 1646 1647 |
# File 'lib/stripe/params/account_update_params.rb', line 1645 def id_number_secondary @id_number_secondary end |
#last_name ⇒ Object
The individual’s last name.
1647 1648 1649 |
# File 'lib/stripe/params/account_update_params.rb', line 1647 def last_name @last_name end |
#last_name_kana ⇒ Object
The Kana variation of the individual’s last name (Japan only).
1649 1650 1651 |
# File 'lib/stripe/params/account_update_params.rb', line 1649 def last_name_kana @last_name_kana end |
#last_name_kanji ⇒ Object
The Kanji variation of the individual’s last name (Japan only).
1651 1652 1653 |
# File 'lib/stripe/params/account_update_params.rb', line 1651 def last_name_kanji @last_name_kanji end |
#maiden_name ⇒ Object
The individual’s maiden name.
1653 1654 1655 |
# File 'lib/stripe/params/account_update_params.rb', line 1653 def maiden_name @maiden_name end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1655 1656 1657 |
# File 'lib/stripe/params/account_update_params.rb', line 1655 def @metadata end |
#phone ⇒ Object
The individual’s phone number.
1657 1658 1659 |
# File 'lib/stripe/params/account_update_params.rb', line 1657 def phone @phone end |
#political_exposure ⇒ Object
Indicates if the person or any of their representatives, family members, or other closely related persons, declares that they hold or have held an important public job or function, in any jurisdiction.
1659 1660 1661 |
# File 'lib/stripe/params/account_update_params.rb', line 1659 def political_exposure @political_exposure end |
#registered_address ⇒ Object
The individual’s registered address.
1661 1662 1663 |
# File 'lib/stripe/params/account_update_params.rb', line 1661 def registered_address @registered_address end |
#relationship ⇒ Object
Describes the person’s relationship to the account.
1663 1664 1665 |
# File 'lib/stripe/params/account_update_params.rb', line 1663 def relationship @relationship end |
#ssn_last_4 ⇒ Object
The last four digits of the individual’s Social Security Number (U.S. only).
1665 1666 1667 |
# File 'lib/stripe/params/account_update_params.rb', line 1665 def ssn_last_4 @ssn_last_4 end |
#verification ⇒ Object
The individual’s verification document information.
1667 1668 1669 |
# File 'lib/stripe/params/account_update_params.rb', line 1667 def verification @verification end |