Class: Stripe::AccountUpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
# File 'lib/stripe/params/account_update_params.rb', line 1692

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1682
1683
1684
# File 'lib/stripe/params/account_update_params.rb', line 1682

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1684
1685
1686
# File 'lib/stripe/params/account_update_params.rb', line 1684

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1686
1687
1688
# File 'lib/stripe/params/account_update_params.rb', line 1686

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1688
1689
1690
# File 'lib/stripe/params/account_update_params.rb', line 1688

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1690
1691
1692
# File 'lib/stripe/params/account_update_params.rb', line 1690

def title
  @title
end