Class: Stripe::AccountUpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
# File 'lib/stripe/params/account_update_params.rb', line 1813

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1803
1804
1805
# File 'lib/stripe/params/account_update_params.rb', line 1803

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1805
1806
1807
# File 'lib/stripe/params/account_update_params.rb', line 1805

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1807
1808
1809
# File 'lib/stripe/params/account_update_params.rb', line 1807

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1809
1810
1811
# File 'lib/stripe/params/account_update_params.rb', line 1809

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1811
1812
1813
# File 'lib/stripe/params/account_update_params.rb', line 1811

def title
  @title
end