Class: Stripe::AccountUpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
# File 'lib/stripe/params/account_update_params.rb', line 1800

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1790
1791
1792
# File 'lib/stripe/params/account_update_params.rb', line 1790

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1792
1793
1794
# File 'lib/stripe/params/account_update_params.rb', line 1792

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1794
1795
1796
# File 'lib/stripe/params/account_update_params.rb', line 1794

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1796
1797
1798
# File 'lib/stripe/params/account_update_params.rb', line 1796

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1798
1799
1800
# File 'lib/stripe/params/account_update_params.rb', line 1798

def title
  @title
end