Class: Stripe::AccountUpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
# File 'lib/stripe/params/account_update_params.rb', line 1755

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1745
1746
1747
# File 'lib/stripe/params/account_update_params.rb', line 1745

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1747
1748
1749
# File 'lib/stripe/params/account_update_params.rb', line 1747

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1749
1750
1751
# File 'lib/stripe/params/account_update_params.rb', line 1749

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1751
1752
1753
# File 'lib/stripe/params/account_update_params.rb', line 1751

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1753
1754
1755
# File 'lib/stripe/params/account_update_params.rb', line 1753

def title
  @title
end