Class: Stripe::AccountUpdateParams::Individual::Relationship

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(director: nil, executive: nil, owner: nil, percent_ownership: nil, title: nil) ⇒ Relationship

Returns a new instance of Relationship.



1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
# File 'lib/stripe/params/account_update_params.rb', line 1573

def initialize(
  director: nil,
  executive: nil,
  owner: nil,
  percent_ownership: nil,
  title: nil
)
  @director = director
  @executive = executive
  @owner = owner
  @percent_ownership = percent_ownership
  @title = title
end

Instance Attribute Details

#directorObject

Whether the person is a director of the account’s legal entity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.



1563
1564
1565
# File 'lib/stripe/params/account_update_params.rb', line 1563

def director
  @director
end

#executiveObject

Whether the person has significant responsibility to control, manage, or direct the organization.



1565
1566
1567
# File 'lib/stripe/params/account_update_params.rb', line 1565

def executive
  @executive
end

#ownerObject

Whether the person is an owner of the account’s legal entity.



1567
1568
1569
# File 'lib/stripe/params/account_update_params.rb', line 1567

def owner
  @owner
end

#percent_ownershipObject

The percent owned by the person of the account’s legal entity.



1569
1570
1571
# File 'lib/stripe/params/account_update_params.rb', line 1569

def percent_ownership
  @percent_ownership
end

#titleObject

The person’s title (e.g., CEO, Support Engineer).



1571
1572
1573
# File 'lib/stripe/params/account_update_params.rb', line 1571

def title
  @title
end