Class: Stripe::AccountUpdateParams::Individual::Verification::AdditionalDocument

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(back: nil, front: nil) ⇒ AdditionalDocument

Returns a new instance of AdditionalDocument.



1777
1778
1779
1780
# File 'lib/stripe/params/account_update_params.rb', line 1777

def initialize(back: nil, front: nil)
  @back = back
  @front = front
end

Instance Attribute Details

#backObject

The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1773
1774
1775
# File 'lib/stripe/params/account_update_params.rb', line 1773

def back
  @back
end

#frontObject

The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.



1775
1776
1777
# File 'lib/stripe/params/account_update_params.rb', line 1775

def front
  @front
end