Class: Stripe::AccountUpdateParams::Individual::Verification::AdditionalDocument
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Individual::Verification::AdditionalDocument
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#back ⇒ Object
The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`.
-
#front ⇒ Object
The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`.
Instance Method Summary collapse
-
#initialize(back: nil, front: nil) ⇒ AdditionalDocument
constructor
A new instance of AdditionalDocument.
Methods inherited from RequestParams
Constructor Details
#initialize(back: nil, front: nil) ⇒ AdditionalDocument
Returns a new instance of AdditionalDocument.
1595 1596 1597 1598 |
# File 'lib/stripe/params/account_update_params.rb', line 1595 def initialize(back: nil, front: nil) @back = back @front = front end |
Instance Attribute Details
#back ⇒ Object
The back of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
1591 1592 1593 |
# File 'lib/stripe/params/account_update_params.rb', line 1591 def back @back end |
#front ⇒ Object
The front of an ID returned by a [file upload](stripe.com/docs/api#create_file) with a ‘purpose` value of `identity_document`. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
1593 1594 1595 |
# File 'lib/stripe/params/account_update_params.rb', line 1593 def front @front end |