Class: Stripe::AccountUpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SepaDebitPayments, SmartDisputes, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account's use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account's use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account's payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#sepa_debit_payments ⇒ Object
Settings specific to SEPA Direct Debit payments.
-
#smart_disputes ⇒ Object
Settings specific to the account's use of Smart Disputes.
-
#tax_forms ⇒ Object
Settings specific to the account's tax forms.
-
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, sepa_debit_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, sepa_debit_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 |
# File 'lib/stripe/params/account_update_params.rb', line 2530 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, sepa_debit_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @sepa_debit_payments = sepa_debit_payments @smart_disputes = smart_disputes @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
2502 2503 2504 |
# File 'lib/stripe/params/account_update_params.rb', line 2502 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2504 2505 2506 |
# File 'lib/stripe/params/account_update_params.rb', line 2504 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
2506 2507 2508 |
# File 'lib/stripe/params/account_update_params.rb', line 2506 def branding @branding end |
#capital ⇒ Object
Settings specific to the account's use of the Capital product.
2508 2509 2510 |
# File 'lib/stripe/params/account_update_params.rb', line 2508 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
2510 2511 2512 |
# File 'lib/stripe/params/account_update_params.rb', line 2510 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2512 2513 2514 |
# File 'lib/stripe/params/account_update_params.rb', line 2512 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account's use of Invoices.
2514 2515 2516 |
# File 'lib/stripe/params/account_update_params.rb', line 2514 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2516 2517 2518 |
# File 'lib/stripe/params/account_update_params.rb', line 2516 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account's payouts.
2518 2519 2520 |
# File 'lib/stripe/params/account_update_params.rb', line 2518 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2520 2521 2522 |
# File 'lib/stripe/params/account_update_params.rb', line 2520 def paypay_payments @paypay_payments end |
#sepa_debit_payments ⇒ Object
Settings specific to SEPA Direct Debit payments.
2522 2523 2524 |
# File 'lib/stripe/params/account_update_params.rb', line 2522 def sepa_debit_payments @sepa_debit_payments end |
#smart_disputes ⇒ Object
Settings specific to the account's use of Smart Disputes.
2524 2525 2526 |
# File 'lib/stripe/params/account_update_params.rb', line 2524 def smart_disputes @smart_disputes end |
#tax_forms ⇒ Object
Settings specific to the account's tax forms.
2526 2527 2528 |
# File 'lib/stripe/params/account_update_params.rb', line 2526 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
2528 2529 2530 |
# File 'lib/stripe/params/account_update_params.rb', line 2528 def treasury @treasury end |