Class: Stripe::AccountUpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, SepaDebitPayments, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
-
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account's use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account's payouts.
-
#sepa_debit_payments ⇒ Object
Settings specific to SEPA Direct Debit payments.
-
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, sepa_debit_payments: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, sepa_debit_payments: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2122 2123 2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 |
# File 'lib/stripe/params/account_update_params.rb', line 2122 def initialize( bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, sepa_debit_payments: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @branding = branding @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @sepa_debit_payments = sepa_debit_payments @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
2104 2105 2106 |
# File 'lib/stripe/params/account_update_params.rb', line 2104 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
2106 2107 2108 |
# File 'lib/stripe/params/account_update_params.rb', line 2106 def branding @branding end |
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
2108 2109 2110 |
# File 'lib/stripe/params/account_update_params.rb', line 2108 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2110 2111 2112 |
# File 'lib/stripe/params/account_update_params.rb', line 2110 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account's use of Invoices.
2112 2113 2114 |
# File 'lib/stripe/params/account_update_params.rb', line 2112 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2114 2115 2116 |
# File 'lib/stripe/params/account_update_params.rb', line 2114 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account's payouts.
2116 2117 2118 |
# File 'lib/stripe/params/account_update_params.rb', line 2116 def payouts @payouts end |
#sepa_debit_payments ⇒ Object
Settings specific to SEPA Direct Debit payments.
2118 2119 2120 |
# File 'lib/stripe/params/account_update_params.rb', line 2118 def sepa_debit_payments @sepa_debit_payments end |
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
2120 2121 2122 |
# File 'lib/stripe/params/account_update_params.rb', line 2120 def treasury @treasury end |