Class: Stripe::AccountUpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SepaDebitPayments, SmartDisputes, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account's use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account's use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account's payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#sepa_debit_payments ⇒ Object
Settings specific to SEPA Direct Debit payments.
-
#smart_disputes ⇒ Object
Settings specific to the account's use of Smart Disputes.
-
#tax_forms ⇒ Object
Settings specific to the account's tax forms.
-
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, sepa_debit_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, sepa_debit_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 2474 |
# File 'lib/stripe/params/account_update_params.rb', line 2444 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, sepa_debit_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @sepa_debit_payments = sepa_debit_payments @smart_disputes = smart_disputes @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
2416 2417 2418 |
# File 'lib/stripe/params/account_update_params.rb', line 2416 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2418 2419 2420 |
# File 'lib/stripe/params/account_update_params.rb', line 2418 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account's branding to email receipts, invoices, Checkout, and other products.
2420 2421 2422 |
# File 'lib/stripe/params/account_update_params.rb', line 2420 def branding @branding end |
#capital ⇒ Object
Settings specific to the account's use of the Capital product.
2422 2423 2424 |
# File 'lib/stripe/params/account_update_params.rb', line 2422 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account's use of the Card Issuing product.
2424 2425 2426 |
# File 'lib/stripe/params/account_update_params.rb', line 2424 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2426 2427 2428 |
# File 'lib/stripe/params/account_update_params.rb', line 2426 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account's use of Invoices.
2428 2429 2430 |
# File 'lib/stripe/params/account_update_params.rb', line 2428 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2430 2431 2432 |
# File 'lib/stripe/params/account_update_params.rb', line 2430 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account's payouts.
2432 2433 2434 |
# File 'lib/stripe/params/account_update_params.rb', line 2432 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2434 2435 2436 |
# File 'lib/stripe/params/account_update_params.rb', line 2434 def paypay_payments @paypay_payments end |
#sepa_debit_payments ⇒ Object
Settings specific to SEPA Direct Debit payments.
2436 2437 2438 |
# File 'lib/stripe/params/account_update_params.rb', line 2436 def sepa_debit_payments @sepa_debit_payments end |
#smart_disputes ⇒ Object
Settings specific to the account's use of Smart Disputes.
2438 2439 2440 |
# File 'lib/stripe/params/account_update_params.rb', line 2438 def smart_disputes @smart_disputes end |
#tax_forms ⇒ Object
Settings specific to the account's tax forms.
2440 2441 2442 |
# File 'lib/stripe/params/account_update_params.rb', line 2440 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account's Treasury FinancialAccounts.
2442 2443 2444 |
# File 'lib/stripe/params/account_update_params.rb', line 2442 def treasury @treasury end |