Class: Stripe::AccountUpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/stripe/params/account_update_params.rb', line 2039

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2023
2024
2025
# File 'lib/stripe/params/account_update_params.rb', line 2023

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2025
2026
2027
# File 'lib/stripe/params/account_update_params.rb', line 2025

def branding
  @branding
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2027
2028
2029
# File 'lib/stripe/params/account_update_params.rb', line 2027

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2029
2030
2031
# File 'lib/stripe/params/account_update_params.rb', line 2029

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2031
2032
2033
# File 'lib/stripe/params/account_update_params.rb', line 2031

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2033
2034
2035
# File 'lib/stripe/params/account_update_params.rb', line 2033

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2035
2036
2037
# File 'lib/stripe/params/account_update_params.rb', line 2035

def payouts
  @payouts
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2037
2038
2039
# File 'lib/stripe/params/account_update_params.rb', line 2037

def treasury
  @treasury
end