Class: Stripe::AccountUpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, SmartDisputes, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#smart_disputes ⇒ Object
Settings specific to the account’s use of Smart Disputes.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 2355 2356 2357 2358 2359 2360 2361 2362 2363 |
# File 'lib/stripe/params/account_update_params.rb', line 2335 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, smart_disputes: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @smart_disputes = smart_disputes @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
2309 2310 2311 |
# File 'lib/stripe/params/account_update_params.rb', line 2309 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2311 2312 2313 |
# File 'lib/stripe/params/account_update_params.rb', line 2311 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
2313 2314 2315 |
# File 'lib/stripe/params/account_update_params.rb', line 2313 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
2315 2316 2317 |
# File 'lib/stripe/params/account_update_params.rb', line 2315 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
2317 2318 2319 |
# File 'lib/stripe/params/account_update_params.rb', line 2317 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2319 2320 2321 |
# File 'lib/stripe/params/account_update_params.rb', line 2319 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
2321 2322 2323 |
# File 'lib/stripe/params/account_update_params.rb', line 2321 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2323 2324 2325 |
# File 'lib/stripe/params/account_update_params.rb', line 2323 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
2325 2326 2327 |
# File 'lib/stripe/params/account_update_params.rb', line 2325 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2327 2328 2329 |
# File 'lib/stripe/params/account_update_params.rb', line 2327 def paypay_payments @paypay_payments end |
#smart_disputes ⇒ Object
Settings specific to the account’s use of Smart Disputes.
2329 2330 2331 |
# File 'lib/stripe/params/account_update_params.rb', line 2329 def smart_disputes @smart_disputes end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
2331 2332 2333 |
# File 'lib/stripe/params/account_update_params.rb', line 2331 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
2333 2334 2335 |
# File 'lib/stripe/params/account_update_params.rb', line 2333 def treasury @treasury end |