Class: Stripe::AccountUpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
# File 'lib/stripe/params/account_update_params.rb', line 1987

def initialize(
  bacs_debit_payments: nil,
  branding: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @branding = branding
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



1971
1972
1973
# File 'lib/stripe/params/account_update_params.rb', line 1971

def bacs_debit_payments
  @bacs_debit_payments
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



1973
1974
1975
# File 'lib/stripe/params/account_update_params.rb', line 1973

def branding
  @branding
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



1975
1976
1977
# File 'lib/stripe/params/account_update_params.rb', line 1975

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



1977
1978
1979
# File 'lib/stripe/params/account_update_params.rb', line 1977

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



1979
1980
1981
# File 'lib/stripe/params/account_update_params.rb', line 1979

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



1981
1982
1983
# File 'lib/stripe/params/account_update_params.rb', line 1981

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



1983
1984
1985
# File 'lib/stripe/params/account_update_params.rb', line 1983

def payouts
  @payouts
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



1985
1986
1987
# File 'lib/stripe/params/account_update_params.rb', line 1985

def treasury
  @treasury
end