Class: Stripe::AccountUpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
# File 'lib/stripe/params/account_update_params.rb', line 2305

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  paypay_payments: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @paypay_payments = paypay_payments
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2281
2282
2283
# File 'lib/stripe/params/account_update_params.rb', line 2281

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2283
2284
2285
# File 'lib/stripe/params/account_update_params.rb', line 2283

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2285
2286
2287
# File 'lib/stripe/params/account_update_params.rb', line 2285

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2287
2288
2289
# File 'lib/stripe/params/account_update_params.rb', line 2287

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2289
2290
2291
# File 'lib/stripe/params/account_update_params.rb', line 2289

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2291
2292
2293
# File 'lib/stripe/params/account_update_params.rb', line 2291

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2293
2294
2295
# File 'lib/stripe/params/account_update_params.rb', line 2293

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2295
2296
2297
# File 'lib/stripe/params/account_update_params.rb', line 2295

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2297
2298
2299
# File 'lib/stripe/params/account_update_params.rb', line 2297

def payouts
  @payouts
end

#paypay_paymentsObject

Settings specific to the PayPay payments method.



2299
2300
2301
# File 'lib/stripe/params/account_update_params.rb', line 2299

def paypay_payments
  @paypay_payments
end

#tax_formsObject

Settings specific to the account’s tax forms.



2301
2302
2303
# File 'lib/stripe/params/account_update_params.rb', line 2301

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2303
2304
2305
# File 'lib/stripe/params/account_update_params.rb', line 2303

def treasury
  @treasury
end