Class: Stripe::AccountUpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, PaypayPayments, TaxForms, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
-
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 |
# File 'lib/stripe/params/account_update_params.rb', line 2273 def initialize( bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, paypay_payments: nil, tax_forms: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @bank_bca_onboarding = bank_bca_onboarding @branding = branding @capital = capital @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @paypay_payments = paypay_payments @tax_forms = tax_forms @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
2249 2250 2251 |
# File 'lib/stripe/params/account_update_params.rb', line 2249 def bacs_debit_payments @bacs_debit_payments end |
#bank_bca_onboarding ⇒ Object
Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.
2251 2252 2253 |
# File 'lib/stripe/params/account_update_params.rb', line 2251 def bank_bca_onboarding @bank_bca_onboarding end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
2253 2254 2255 |
# File 'lib/stripe/params/account_update_params.rb', line 2253 def branding @branding end |
#capital ⇒ Object
Settings specific to the account’s use of the Capital product.
2255 2256 2257 |
# File 'lib/stripe/params/account_update_params.rb', line 2255 def capital @capital end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
2257 2258 2259 |
# File 'lib/stripe/params/account_update_params.rb', line 2257 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
2259 2260 2261 |
# File 'lib/stripe/params/account_update_params.rb', line 2259 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
2261 2262 2263 |
# File 'lib/stripe/params/account_update_params.rb', line 2261 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
2263 2264 2265 |
# File 'lib/stripe/params/account_update_params.rb', line 2263 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
2265 2266 2267 |
# File 'lib/stripe/params/account_update_params.rb', line 2265 def payouts @payouts end |
#paypay_payments ⇒ Object
Settings specific to the PayPay payments method.
2267 2268 2269 |
# File 'lib/stripe/params/account_update_params.rb', line 2267 def paypay_payments @paypay_payments end |
#tax_forms ⇒ Object
Settings specific to the account’s tax forms.
2269 2270 2271 |
# File 'lib/stripe/params/account_update_params.rb', line 2269 def tax_forms @tax_forms end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
2271 2272 2273 |
# File 'lib/stripe/params/account_update_params.rb', line 2271 def treasury @treasury end |