Class: Stripe::AccountUpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/stripe/params/account_update_params.rb', line 2191

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2169
2170
2171
# File 'lib/stripe/params/account_update_params.rb', line 2169

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2171
2172
2173
# File 'lib/stripe/params/account_update_params.rb', line 2171

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2173
2174
2175
# File 'lib/stripe/params/account_update_params.rb', line 2173

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2175
2176
2177
# File 'lib/stripe/params/account_update_params.rb', line 2175

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2177
2178
2179
# File 'lib/stripe/params/account_update_params.rb', line 2177

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2179
2180
2181
# File 'lib/stripe/params/account_update_params.rb', line 2179

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2181
2182
2183
# File 'lib/stripe/params/account_update_params.rb', line 2181

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2183
2184
2185
# File 'lib/stripe/params/account_update_params.rb', line 2183

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2185
2186
2187
# File 'lib/stripe/params/account_update_params.rb', line 2185

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



2187
2188
2189
# File 'lib/stripe/params/account_update_params.rb', line 2187

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2189
2190
2191
# File 'lib/stripe/params/account_update_params.rb', line 2189

def treasury
  @treasury
end