Class: Stripe::AccountUpdateParams::Settings

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: BacsDebitPayments, BankBcaOnboarding, Branding, Capital, CardIssuing, CardPayments, Invoices, Payments, Payouts, TaxForms, Treasury

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bacs_debit_payments: nil, bank_bca_onboarding: nil, branding: nil, capital: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, tax_forms: nil, treasury: nil) ⇒ Settings

Returns a new instance of Settings.



2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
# File 'lib/stripe/params/account_update_params.rb', line 2172

def initialize(
  bacs_debit_payments: nil,
  bank_bca_onboarding: nil,
  branding: nil,
  capital: nil,
  card_issuing: nil,
  card_payments: nil,
  invoices: nil,
  payments: nil,
  payouts: nil,
  tax_forms: nil,
  treasury: nil
)
  @bacs_debit_payments = bacs_debit_payments
  @bank_bca_onboarding = bank_bca_onboarding
  @branding = branding
  @capital = capital
  @card_issuing = card_issuing
  @card_payments = card_payments
  @invoices = invoices
  @payments = payments
  @payouts = payouts
  @tax_forms = tax_forms
  @treasury = treasury
end

Instance Attribute Details

#bacs_debit_paymentsObject

Settings specific to Bacs Direct Debit payments.



2150
2151
2152
# File 'lib/stripe/params/account_update_params.rb', line 2150

def bacs_debit_payments
  @bacs_debit_payments
end

#bank_bca_onboardingObject

Settings specific to bank BCA onboarding for Indonesia bank transfers payments method.



2152
2153
2154
# File 'lib/stripe/params/account_update_params.rb', line 2152

def bank_bca_onboarding
  @bank_bca_onboarding
end

#brandingObject

Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.



2154
2155
2156
# File 'lib/stripe/params/account_update_params.rb', line 2154

def branding
  @branding
end

#capitalObject

Settings specific to the account’s use of the Capital product.



2156
2157
2158
# File 'lib/stripe/params/account_update_params.rb', line 2156

def capital
  @capital
end

#card_issuingObject

Settings specific to the account’s use of the Card Issuing product.



2158
2159
2160
# File 'lib/stripe/params/account_update_params.rb', line 2158

def card_issuing
  @card_issuing
end

#card_paymentsObject

Settings specific to card charging on the account.



2160
2161
2162
# File 'lib/stripe/params/account_update_params.rb', line 2160

def card_payments
  @card_payments
end

#invoicesObject

Settings specific to the account’s use of Invoices.



2162
2163
2164
# File 'lib/stripe/params/account_update_params.rb', line 2162

def invoices
  @invoices
end

#paymentsObject

Settings that apply across payment methods for charging on the account.



2164
2165
2166
# File 'lib/stripe/params/account_update_params.rb', line 2164

def payments
  @payments
end

#payoutsObject

Settings specific to the account’s payouts.



2166
2167
2168
# File 'lib/stripe/params/account_update_params.rb', line 2166

def payouts
  @payouts
end

#tax_formsObject

Settings specific to the account’s tax forms.



2168
2169
2170
# File 'lib/stripe/params/account_update_params.rb', line 2168

def tax_forms
  @tax_forms
end

#treasuryObject

Settings specific to the account’s Treasury FinancialAccounts.



2170
2171
2172
# File 'lib/stripe/params/account_update_params.rb', line 2170

def treasury
  @treasury
end