Class: Stripe::AccountUpdateParams::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: BacsDebitPayments, Branding, CardIssuing, CardPayments, Invoices, Payments, Payouts, Treasury
Instance Attribute Summary collapse
-
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
-
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
-
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
-
#card_payments ⇒ Object
Settings specific to card charging on the account.
-
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
-
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
Instance Method Summary collapse
-
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil) ⇒ Settings
Returns a new instance of Settings.
1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/stripe/params/account_update_params.rb', line 1920 def initialize( bacs_debit_payments: nil, branding: nil, card_issuing: nil, card_payments: nil, invoices: nil, payments: nil, payouts: nil, treasury: nil ) @bacs_debit_payments = bacs_debit_payments @branding = branding @card_issuing = card_issuing @card_payments = card_payments @invoices = invoices @payments = payments @payouts = payouts @treasury = treasury end |
Instance Attribute Details
#bacs_debit_payments ⇒ Object
Settings specific to Bacs Direct Debit payments.
1904 1905 1906 |
# File 'lib/stripe/params/account_update_params.rb', line 1904 def bacs_debit_payments @bacs_debit_payments end |
#branding ⇒ Object
Settings used to apply the account’s branding to email receipts, invoices, Checkout, and other products.
1906 1907 1908 |
# File 'lib/stripe/params/account_update_params.rb', line 1906 def branding @branding end |
#card_issuing ⇒ Object
Settings specific to the account’s use of the Card Issuing product.
1908 1909 1910 |
# File 'lib/stripe/params/account_update_params.rb', line 1908 def card_issuing @card_issuing end |
#card_payments ⇒ Object
Settings specific to card charging on the account.
1910 1911 1912 |
# File 'lib/stripe/params/account_update_params.rb', line 1910 def card_payments @card_payments end |
#invoices ⇒ Object
Settings specific to the account’s use of Invoices.
1912 1913 1914 |
# File 'lib/stripe/params/account_update_params.rb', line 1912 def invoices @invoices end |
#payments ⇒ Object
Settings that apply across payment methods for charging on the account.
1914 1915 1916 |
# File 'lib/stripe/params/account_update_params.rb', line 1914 def payments @payments end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
1916 1917 1918 |
# File 'lib/stripe/params/account_update_params.rb', line 1916 def payouts @payouts end |
#treasury ⇒ Object
Settings specific to the account’s Treasury FinancialAccounts.
1918 1919 1920 |
# File 'lib/stripe/params/account_update_params.rb', line 1918 def treasury @treasury end |