Class: Stripe::AccountUpdateParams::Settings::BacsDebitPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(display_name: nil) ⇒ BacsDebitPayments

Returns a new instance of BacsDebitPayments.



2022
2023
2024
# File 'lib/stripe/params/account_update_params.rb', line 2022

def initialize(display_name: nil)
  @display_name = display_name
end

Instance Attribute Details

#display_nameObject

The Bacs Direct Debit Display Name for this account. For payments made with Bacs Direct Debit, this name appears on the mandate as the statement descriptor. Mobile banking apps display it as the name of the business. To use custom branding, set the Bacs Direct Debit Display Name during or right after creation. Custom branding incurs an additional monthly fee for the platform. If you don’t set the display name before requesting Bacs capability, it’s automatically set as “Stripe” and the account is onboarded to Stripe branding, which is free.



2020
2021
2022
# File 'lib/stripe/params/account_update_params.rb', line 2020

def display_name
  @display_name
end