Class: Stripe::AccountUpdateParams::Settings::Branding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::Branding
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#icon ⇒ Object
(ID of a file upload) An icon for the account.
-
#logo ⇒ Object
(ID of a file upload) A logo for the account that will be used in Checkout instead of the icon and without the account's name next to it if provided.
-
#primary_color ⇒ Object
A CSS hex color value representing the primary branding color for this account.
-
#secondary_color ⇒ Object
A CSS hex color value representing the secondary branding color for this account.
Instance Method Summary collapse
-
#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding
constructor
A new instance of Branding.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding
Returns a new instance of Branding.
2147 2148 2149 2150 2151 2152 |
# File 'lib/stripe/params/account_update_params.rb', line 2147 def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) @icon = icon @logo = logo @primary_color = primary_color @secondary_color = secondary_color end |
Instance Attribute Details
#icon ⇒ Object
(ID of a file upload) An icon for the account. Must be square and at least 128px x 128px.
2139 2140 2141 |
# File 'lib/stripe/params/account_update_params.rb', line 2139 def icon @icon end |
#logo ⇒ Object
(ID of a file upload) A logo for the account that will be used in Checkout instead of the icon and without the account's name next to it if provided. Must be at least 128px x 128px.
2141 2142 2143 |
# File 'lib/stripe/params/account_update_params.rb', line 2141 def logo @logo end |
#primary_color ⇒ Object
A CSS hex color value representing the primary branding color for this account.
2143 2144 2145 |
# File 'lib/stripe/params/account_update_params.rb', line 2143 def primary_color @primary_color end |
#secondary_color ⇒ Object
A CSS hex color value representing the secondary branding color for this account.
2145 2146 2147 |
# File 'lib/stripe/params/account_update_params.rb', line 2145 def secondary_color @secondary_color end |