Class: Stripe::AccountUpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2049
2050
2051
2052
2053
2054
# File 'lib/stripe/params/account_update_params.rb', line 2049

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2041
2042
2043
# File 'lib/stripe/params/account_update_params.rb', line 2041

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2043
2044
2045
# File 'lib/stripe/params/account_update_params.rb', line 2043

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2045
2046
2047
# File 'lib/stripe/params/account_update_params.rb', line 2045

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2047
2048
2049
# File 'lib/stripe/params/account_update_params.rb', line 2047

def secondary_color
  @secondary_color
end