Class: Stripe::AccountUpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2010
2011
2012
2013
2014
2015
# File 'lib/stripe/params/account_update_params.rb', line 2010

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2002
2003
2004
# File 'lib/stripe/params/account_update_params.rb', line 2002

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2004
2005
2006
# File 'lib/stripe/params/account_update_params.rb', line 2004

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2006
2007
2008
# File 'lib/stripe/params/account_update_params.rb', line 2006

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2008
2009
2010
# File 'lib/stripe/params/account_update_params.rb', line 2008

def secondary_color
  @secondary_color
end