Class: Stripe::AccountUpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



2020
2021
2022
2023
2024
2025
# File 'lib/stripe/params/account_update_params.rb', line 2020

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



2012
2013
2014
# File 'lib/stripe/params/account_update_params.rb', line 2012

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



2014
2015
2016
# File 'lib/stripe/params/account_update_params.rb', line 2014

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



2016
2017
2018
# File 'lib/stripe/params/account_update_params.rb', line 2016

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



2018
2019
2020
# File 'lib/stripe/params/account_update_params.rb', line 2018

def secondary_color
  @secondary_color
end