Class: Stripe::AccountUpdateParams::Settings::Branding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::Branding
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#icon ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account.
-
#logo ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided.
-
#primary_color ⇒ Object
A CSS hex color value representing the primary branding color for this account.
-
#secondary_color ⇒ Object
A CSS hex color value representing the secondary branding color for this account.
Instance Method Summary collapse
-
#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding
constructor
A new instance of Branding.
Methods inherited from RequestParams
Constructor Details
#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding
Returns a new instance of Branding.
1984 1985 1986 1987 1988 1989 |
# File 'lib/stripe/params/account_update_params.rb', line 1984 def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) @icon = icon @logo = logo @primary_color = primary_color @secondary_color = secondary_color end |
Instance Attribute Details
#icon ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.
1976 1977 1978 |
# File 'lib/stripe/params/account_update_params.rb', line 1976 def icon @icon end |
#logo ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.
1978 1979 1980 |
# File 'lib/stripe/params/account_update_params.rb', line 1978 def logo @logo end |
#primary_color ⇒ Object
A CSS hex color value representing the primary branding color for this account.
1980 1981 1982 |
# File 'lib/stripe/params/account_update_params.rb', line 1980 def primary_color @primary_color end |
#secondary_color ⇒ Object
A CSS hex color value representing the secondary branding color for this account.
1982 1983 1984 |
# File 'lib/stripe/params/account_update_params.rb', line 1982 def secondary_color @secondary_color end |