Class: Stripe::AccountUpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



1965
1966
1967
1968
1969
1970
# File 'lib/stripe/params/account_update_params.rb', line 1965

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



1957
1958
1959
# File 'lib/stripe/params/account_update_params.rb', line 1957

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



1959
1960
1961
# File 'lib/stripe/params/account_update_params.rb', line 1959

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



1961
1962
1963
# File 'lib/stripe/params/account_update_params.rb', line 1961

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



1963
1964
1965
# File 'lib/stripe/params/account_update_params.rb', line 1963

def secondary_color
  @secondary_color
end