Class: Stripe::AccountUpdateParams::Settings::Branding

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil) ⇒ Branding

Returns a new instance of Branding.



1740
1741
1742
1743
1744
1745
# File 'lib/stripe/params/account_update_params.rb', line 1740

def initialize(icon: nil, logo: nil, primary_color: nil, secondary_color: nil)
  @icon = icon
  @logo = 
  @primary_color = primary_color
  @secondary_color = secondary_color
end

Instance Attribute Details

#iconObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) An icon for the account. Must be square and at least 128px x 128px.



1732
1733
1734
# File 'lib/stripe/params/account_update_params.rb', line 1732

def icon
  @icon
end

#logoObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A logo for the account that will be used in Checkout instead of the icon and without the account’s name next to it if provided. Must be at least 128px x 128px.



1734
1735
1736
# File 'lib/stripe/params/account_update_params.rb', line 1734

def 
  @logo
end

#primary_colorObject

A CSS hex color value representing the primary branding color for this account.



1736
1737
1738
# File 'lib/stripe/params/account_update_params.rb', line 1736

def primary_color
  @primary_color
end

#secondary_colorObject

A CSS hex color value representing the secondary branding color for this account.



1738
1739
1740
# File 'lib/stripe/params/account_update_params.rb', line 1738

def secondary_color
  @secondary_color
end