Class: Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2129
2130
2131
2132
2133
# File 'lib/stripe/params/account_update_params.rb', line 2129

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2123
2124
2125
# File 'lib/stripe/params/account_update_params.rb', line 2123

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2125
2126
2127
# File 'lib/stripe/params/account_update_params.rb', line 2125

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2127
2128
2129
# File 'lib/stripe/params/account_update_params.rb', line 2127

def user_agent
  @user_agent
end