Class: Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2078
2079
2080
2081
2082
# File 'lib/stripe/params/account_update_params.rb', line 2078

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2072
2073
2074
# File 'lib/stripe/params/account_update_params.rb', line 2072

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2074
2075
2076
# File 'lib/stripe/params/account_update_params.rb', line 2074

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2076
2077
2078
# File 'lib/stripe/params/account_update_params.rb', line 2076

def user_agent
  @user_agent
end