Class: Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2071 2072 2073 2074 2075 |
# File 'lib/stripe/params/account_update_params.rb', line 2071 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
2065 2066 2067 |
# File 'lib/stripe/params/account_update_params.rb', line 2065 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
2067 2068 2069 |
# File 'lib/stripe/params/account_update_params.rb', line 2067 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
2069 2070 2071 |
# File 'lib/stripe/params/account_update_params.rb', line 2069 def user_agent @user_agent end |