Class: Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2049
2050
2051
2052
2053
# File 'lib/stripe/params/account_update_params.rb', line 2049

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2043
2044
2045
# File 'lib/stripe/params/account_update_params.rb', line 2043

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2045
2046
2047
# File 'lib/stripe/params/account_update_params.rb', line 2045

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2047
2048
2049
# File 'lib/stripe/params/account_update_params.rb', line 2047

def user_agent
  @user_agent
end