Class: Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2013
2014
2015
2016
2017
# File 'lib/stripe/params/account_update_params.rb', line 2013

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2007
2008
2009
# File 'lib/stripe/params/account_update_params.rb', line 2007

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2009
2010
2011
# File 'lib/stripe/params/account_update_params.rb', line 2009

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2011
2012
2013
# File 'lib/stripe/params/account_update_params.rb', line 2011

def user_agent
  @user_agent
end