Class: Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1994
1995
1996
1997
1998
# File 'lib/stripe/params/account_update_params.rb', line 1994

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



1988
1989
1990
# File 'lib/stripe/params/account_update_params.rb', line 1988

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



1990
1991
1992
# File 'lib/stripe/params/account_update_params.rb', line 1990

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



1992
1993
1994
# File 'lib/stripe/params/account_update_params.rb', line 1992

def user_agent
  @user_agent
end