Class: Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::CardIssuing::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
1757 1758 1759 1760 1761 |
# File 'lib/stripe/params/account_update_params.rb', line 1757 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
1751 1752 1753 |
# File 'lib/stripe/params/account_update_params.rb', line 1751 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
1753 1754 1755 |
# File 'lib/stripe/params/account_update_params.rb', line 1753 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
1755 1756 1757 |
# File 'lib/stripe/params/account_update_params.rb', line 1755 def user_agent @user_agent end |