Class: Stripe::AccountUpdateParams::Settings::CardPayments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: DeclineOn

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments

Returns a new instance of CardPayments.



2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
# File 'lib/stripe/params/account_update_params.rb', line 2211

def initialize(
  decline_on: nil,
  statement_descriptor_prefix: nil,
  statement_descriptor_prefix_kana: nil,
  statement_descriptor_prefix_kanji: nil
)
  @decline_on = decline_on
  @statement_descriptor_prefix = statement_descriptor_prefix
  @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji
end

Instance Attribute Details

#decline_onObject

Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.



2203
2204
2205
# File 'lib/stripe/params/account_update_params.rb', line 2203

def decline_on
  @decline_on
end

#statement_descriptor_prefixObject

The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic statement_descriptor specified on the charge. statement_descriptor_prefix is useful for maximizing descriptor space for the dynamic portion.



2205
2206
2207
# File 'lib/stripe/params/account_update_params.rb', line 2205

def statement_descriptor_prefix
  @statement_descriptor_prefix
end

#statement_descriptor_prefix_kanaObject

The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kana specified on the charge. statement_descriptor_prefix_kana is useful for maximizing descriptor space for the dynamic portion.



2207
2208
2209
# File 'lib/stripe/params/account_update_params.rb', line 2207

def statement_descriptor_prefix_kana
  @statement_descriptor_prefix_kana
end

#statement_descriptor_prefix_kanjiObject

The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic statement_descriptor_suffix_kanji specified on the charge. statement_descriptor_prefix_kanji is useful for maximizing descriptor space for the dynamic portion.



2209
2210
2211
# File 'lib/stripe/params/account_update_params.rb', line 2209

def statement_descriptor_prefix_kanji
  @statement_descriptor_prefix_kanji
end