Class: Stripe::AccountUpdateParams::Settings::CardPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::CardPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: DeclineOn
Instance Attribute Summary collapse
-
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
-
#statement_descriptor_prefix ⇒ Object
The default text that appears on credit card statements when a charge is made.
-
#statement_descriptor_prefix_kana ⇒ Object
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only).
-
#statement_descriptor_prefix_kanji ⇒ Object
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only).
Instance Method Summary collapse
-
#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments
constructor
A new instance of CardPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil) ⇒ CardPayments
Returns a new instance of CardPayments.
2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/stripe/params/account_update_params.rb', line 2084 def initialize( decline_on: nil, statement_descriptor_prefix: nil, statement_descriptor_prefix_kana: nil, statement_descriptor_prefix_kanji: nil ) @decline_on = decline_on @statement_descriptor_prefix = statement_descriptor_prefix @statement_descriptor_prefix_kana = statement_descriptor_prefix_kana @statement_descriptor_prefix_kanji = statement_descriptor_prefix_kanji end |
Instance Attribute Details
#decline_on ⇒ Object
Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
2076 2077 2078 |
# File 'lib/stripe/params/account_update_params.rb', line 2076 def decline_on @decline_on end |
#statement_descriptor_prefix ⇒ Object
The default text that appears on credit card statements when a charge is made. This field prefixes any dynamic ‘statement_descriptor` specified on the charge. `statement_descriptor_prefix` is useful for maximizing descriptor space for the dynamic portion.
2078 2079 2080 |
# File 'lib/stripe/params/account_update_params.rb', line 2078 def statement_descriptor_prefix @statement_descriptor_prefix end |
#statement_descriptor_prefix_kana ⇒ Object
The Kana variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kana` specified on the charge. `statement_descriptor_prefix_kana` is useful for maximizing descriptor space for the dynamic portion.
2080 2081 2082 |
# File 'lib/stripe/params/account_update_params.rb', line 2080 def statement_descriptor_prefix_kana @statement_descriptor_prefix_kana end |
#statement_descriptor_prefix_kanji ⇒ Object
The Kanji variation of the default text that appears on credit card statements when a charge is made (Japan only). This field prefixes any dynamic ‘statement_descriptor_suffix_kanji` specified on the charge. `statement_descriptor_prefix_kanji` is useful for maximizing descriptor space for the dynamic portion.
2082 2083 2084 |
# File 'lib/stripe/params/account_update_params.rb', line 2082 def statement_descriptor_prefix_kanji @statement_descriptor_prefix_kanji end |