Class: Stripe::AccountUpdateParams::Settings::CardPayments::DeclineOn

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn

Returns a new instance of DeclineOn.



2060
2061
2062
2063
# File 'lib/stripe/params/account_update_params.rb', line 2060

def initialize(avs_failure: nil, cvc_failure: nil)
  @avs_failure = avs_failure
  @cvc_failure = cvc_failure
end

Instance Attribute Details

#avs_failureObject

Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.



2056
2057
2058
# File 'lib/stripe/params/account_update_params.rb', line 2056

def avs_failure
  @avs_failure
end

#cvc_failureObject

Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.



2058
2059
2060
# File 'lib/stripe/params/account_update_params.rb', line 2058

def cvc_failure
  @cvc_failure
end