Class: Stripe::AccountUpdateParams::Settings::CardPayments::DeclineOn
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::CardPayments::DeclineOn
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#avs_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect ZIP or postal code.
-
#cvc_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect CVC.
Instance Method Summary collapse
-
#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn
constructor
A new instance of DeclineOn.
Methods inherited from RequestParams
Constructor Details
#initialize(avs_failure: nil, cvc_failure: nil) ⇒ DeclineOn
Returns a new instance of DeclineOn.
2092 2093 2094 2095 |
# File 'lib/stripe/params/account_update_params.rb', line 2092 def initialize(avs_failure: nil, cvc_failure: nil) @avs_failure = avs_failure @cvc_failure = cvc_failure end |
Instance Attribute Details
#avs_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.
2088 2089 2090 |
# File 'lib/stripe/params/account_update_params.rb', line 2088 def avs_failure @avs_failure end |
#cvc_failure ⇒ Object
Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.
2090 2091 2092 |
# File 'lib/stripe/params/account_update_params.rb', line 2090 def cvc_failure @cvc_failure end |