Class: Stripe::AccountUpdateParams::Settings::Payments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::Payments
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#email_customers_on_successful_payment ⇒ Object
When you enable this parameter, the customer of this Account receives an email receipt when their payment succeeds.
-
#statement_descriptor ⇒ Object
The default text that appears on statements for non-card charges outside of Japan.
-
#statement_descriptor_kana ⇒ Object
The Kana variation of ‘statement_descriptor` used for charges in Japan.
-
#statement_descriptor_kanji ⇒ Object
The Kanji variation of ‘statement_descriptor` used for charges in Japan.
Instance Method Summary collapse
-
#initialize(email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments
constructor
A new instance of Payments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments
Returns a new instance of Payments.
2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 |
# File 'lib/stripe/params/account_update_params.rb', line 2174 def initialize( email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil ) @email_customers_on_successful_payment = email_customers_on_successful_payment @statement_descriptor = statement_descriptor @statement_descriptor_kana = statement_descriptor_kana @statement_descriptor_kanji = statement_descriptor_kanji end |
Instance Attribute Details
#email_customers_on_successful_payment ⇒ Object
When you enable this parameter, the customer of this Account receives an email receipt when their payment succeeds. If this parameter isn’t set, the default value is ‘false`.
2166 2167 2168 |
# File 'lib/stripe/params/account_update_params.rb', line 2166 def email_customers_on_successful_payment @email_customers_on_successful_payment end |
#statement_descriptor ⇒ Object
The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a ‘statement_descriptor_prefix`, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the `statement_descriptor` text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the [account settings documentation](docs.stripe.com/get-started/account/statement-descriptors).
2168 2169 2170 |
# File 'lib/stripe/params/account_update_params.rb', line 2168 def statement_descriptor @statement_descriptor end |
#statement_descriptor_kana ⇒ Object
The Kana variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
2170 2171 2172 |
# File 'lib/stripe/params/account_update_params.rb', line 2170 def statement_descriptor_kana @statement_descriptor_kana end |
#statement_descriptor_kanji ⇒ Object
The Kanji variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
2172 2173 2174 |
# File 'lib/stripe/params/account_update_params.rb', line 2172 def statement_descriptor_kanji @statement_descriptor_kanji end |