Class: Stripe::AccountUpdateParams::Settings::Payments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments

Returns a new instance of Payments.



2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
# File 'lib/stripe/params/account_update_params.rb', line 2148

def initialize(
  email_customers_on_successful_payment: nil,
  statement_descriptor: nil,
  statement_descriptor_kana: nil,
  statement_descriptor_kanji: nil
)
  @email_customers_on_successful_payment = email_customers_on_successful_payment
  @statement_descriptor = statement_descriptor
  @statement_descriptor_kana = statement_descriptor_kana
  @statement_descriptor_kanji = statement_descriptor_kanji
end

Instance Attribute Details

#email_customers_on_successful_paymentObject

When you enable this parameter, the customer of this Account receives an email receipt when their payment succeeds. If this parameter isn’t set, the default value is ‘false`.



2140
2141
2142
# File 'lib/stripe/params/account_update_params.rb', line 2140

def email_customers_on_successful_payment
  @email_customers_on_successful_payment
end

#statement_descriptorObject

The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a ‘statement_descriptor_prefix`, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the `statement_descriptor` text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the [account settings documentation](docs.stripe.com/get-started/account/statement-descriptors).



2142
2143
2144
# File 'lib/stripe/params/account_update_params.rb', line 2142

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_kanaObject

The Kana variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).



2144
2145
2146
# File 'lib/stripe/params/account_update_params.rb', line 2144

def statement_descriptor_kana
  @statement_descriptor_kana
end

#statement_descriptor_kanjiObject

The Kanji variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).



2146
2147
2148
# File 'lib/stripe/params/account_update_params.rb', line 2146

def statement_descriptor_kanji
  @statement_descriptor_kanji
end