Class: Stripe::AccountUpdateParams::Settings::Payments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::Payments
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#email_customers_on_successful_payment ⇒ Object
When you enable this parameter, the customer of this Account receives an email receipt when their payment succeeds.
-
#statement_descriptor ⇒ Object
The default text that appears on statements for non-card charges outside of Japan.
-
#statement_descriptor_kana ⇒ Object
The Kana variation of ‘statement_descriptor` used for charges in Japan.
-
#statement_descriptor_kanji ⇒ Object
The Kanji variation of ‘statement_descriptor` used for charges in Japan.
Instance Method Summary collapse
-
#initialize(email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments
constructor
A new instance of Payments.
Methods inherited from RequestParams
Constructor Details
#initialize(email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil) ⇒ Payments
Returns a new instance of Payments.
2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 |
# File 'lib/stripe/params/account_update_params.rb', line 2141 def initialize( email_customers_on_successful_payment: nil, statement_descriptor: nil, statement_descriptor_kana: nil, statement_descriptor_kanji: nil ) @email_customers_on_successful_payment = email_customers_on_successful_payment @statement_descriptor = statement_descriptor @statement_descriptor_kana = statement_descriptor_kana @statement_descriptor_kanji = statement_descriptor_kanji end |
Instance Attribute Details
#email_customers_on_successful_payment ⇒ Object
When you enable this parameter, the customer of this Account receives an email receipt when their payment succeeds. If this parameter isn’t set, the default value is ‘false`.
2133 2134 2135 |
# File 'lib/stripe/params/account_update_params.rb', line 2133 def email_customers_on_successful_payment @email_customers_on_successful_payment end |
#statement_descriptor ⇒ Object
The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don’t set a ‘statement_descriptor_prefix`, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the `statement_descriptor` text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the [account settings documentation](docs.stripe.com/get-started/account/statement-descriptors).
2135 2136 2137 |
# File 'lib/stripe/params/account_update_params.rb', line 2135 def statement_descriptor @statement_descriptor end |
#statement_descriptor_kana ⇒ Object
The Kana variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
2137 2138 2139 |
# File 'lib/stripe/params/account_update_params.rb', line 2137 def statement_descriptor_kana @statement_descriptor_kana end |
#statement_descriptor_kanji ⇒ Object
The Kanji variation of ‘statement_descriptor` used for charges in Japan. Japanese statement descriptors have [special requirements](docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
2139 2140 2141 |
# File 'lib/stripe/params/account_update_params.rb', line 2139 def statement_descriptor_kanji @statement_descriptor_kanji end |