Class: Stripe::AccountUpdateParams::Settings::Payouts
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::Payouts
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Schedule
Instance Attribute Summary collapse
-
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account.
-
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account.
-
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts.
Instance Method Summary collapse
-
#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
constructor
A new instance of Payouts.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts
Returns a new instance of Payouts.
2297 2298 2299 2300 2301 |
# File 'lib/stripe/params/account_update_params.rb', line 2297 def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) @debit_negative_balances = debit_negative_balances @schedule = schedule @statement_descriptor = statement_descriptor end |
Instance Attribute Details
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see Understanding Connect Account Balances.
2291 2292 2293 |
# File 'lib/stripe/params/account_update_params.rb', line 2291 def debit_negative_balances @debit_negative_balances end |
#schedule ⇒ Object
Details on when funds from charges are available, and when they are paid out to an external account. For details, see our Setting Bank and Debit Card Payouts documentation.
2293 2294 2295 |
# File 'lib/stripe/params/account_update_params.rb', line 2293 def schedule @schedule end |
#statement_descriptor ⇒ Object
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform's bank descriptor as set in the Dashboard.
2295 2296 2297 |
# File 'lib/stripe/params/account_update_params.rb', line 2295 def statement_descriptor @statement_descriptor end |