Class: Stripe::AccountUpdateParams::Settings::Payouts

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Defined Under Namespace

Classes: Schedule

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil) ⇒ Payouts

Returns a new instance of Payouts.



2199
2200
2201
2202
2203
# File 'lib/stripe/params/account_update_params.rb', line 2199

def initialize(debit_negative_balances: nil, schedule: nil, statement_descriptor: nil)
  @debit_negative_balances = debit_negative_balances
  @schedule = schedule
  @statement_descriptor = statement_descriptor
end

Instance Attribute Details

#debit_negative_balancesObject

A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](/connect/account-balances).



2193
2194
2195
# File 'lib/stripe/params/account_update_params.rb', line 2193

def debit_negative_balances
  @debit_negative_balances
end

#scheduleObject

Details on when funds from charges are available, and when they are paid out to an external account. For details, see our [Setting Bank and Debit Card Payouts](/connect/bank-transfers#payout-information) documentation.



2195
2196
2197
# File 'lib/stripe/params/account_update_params.rb', line 2195

def schedule
  @schedule
end

#statement_descriptorObject

The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.



2197
2198
2199
# File 'lib/stripe/params/account_update_params.rb', line 2197

def statement_descriptor
  @statement_descriptor
end