Class: Stripe::AccountUpdateParams::Settings::Payouts::Schedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::Payouts::Schedule
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
The number of days charge funds are held before being paid out.
-
#interval ⇒ Object
How frequently available funds are paid out.
-
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1--31.
-
#monthly_payout_days ⇒ Object
The days of the month when available funds are paid out, specified as an array of numbers between 1--31.
-
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as
monday,tuesday, etc. -
#weekly_payout_days ⇒ Object
The days of the week when available funds are paid out, specified as an array, e.g., [
monday,tuesday].
Instance Method Summary collapse
-
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule
constructor
A new instance of Schedule.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule
Returns a new instance of Schedule.
2360 2361 2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 |
# File 'lib/stripe/params/account_update_params.rb', line 2360 def initialize( delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil ) @delay_days = delay_days @interval = interval @monthly_anchor = monthly_anchor @monthly_payout_days = monthly_payout_days @weekly_anchor = weekly_anchor @weekly_payout_days = weekly_payout_days end |
Instance Attribute Details
#delay_days ⇒ Object
The number of days charge funds are held before being paid out. May also be set to minimum, representing the lowest available value for the account country. Default is minimum. The delay_days parameter remains at the last configured value if interval is manual. Learn more about controlling payout delay days.
2348 2349 2350 |
# File 'lib/stripe/params/account_update_params.rb', line 2348 def delay_days @delay_days end |
#interval ⇒ Object
How frequently available funds are paid out. One of: daily, manual, weekly, or monthly. Default is daily.
2350 2351 2352 |
# File 'lib/stripe/params/account_update_params.rb', line 2350 def interval @interval end |
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1--31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if interval is monthly.
2352 2353 2354 |
# File 'lib/stripe/params/account_update_params.rb', line 2352 def monthly_anchor @monthly_anchor end |
#monthly_payout_days ⇒ Object
The days of the month when available funds are paid out, specified as an array of numbers between 1--31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if interval is monthly and monthly_anchor is not set.
2354 2355 2356 |
# File 'lib/stripe/params/account_update_params.rb', line 2354 def monthly_payout_days @monthly_payout_days end |
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as monday, tuesday, etc. Required and applicable only if interval is weekly.
2356 2357 2358 |
# File 'lib/stripe/params/account_update_params.rb', line 2356 def weekly_anchor @weekly_anchor end |
#weekly_payout_days ⇒ Object
The days of the week when available funds are paid out, specified as an array, e.g., [monday, tuesday]. Required and applicable only if interval is weekly.
2358 2359 2360 |
# File 'lib/stripe/params/account_update_params.rb', line 2358 def weekly_payout_days @weekly_payout_days end |