Class: Stripe::AccountUpdateParams::Settings::Payouts::Schedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule

Returns a new instance of Schedule.



2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
# File 'lib/stripe/params/account_update_params.rb', line 2042

def initialize(
  delay_days: nil,
  interval: nil,
  monthly_anchor: nil,
  monthly_payout_days: nil,
  weekly_anchor: nil,
  weekly_payout_days: nil
)
  @delay_days = delay_days
  @interval = interval
  @monthly_anchor = monthly_anchor
  @monthly_payout_days = monthly_payout_days
  @weekly_anchor = weekly_anchor
  @weekly_payout_days = weekly_payout_days
end

Instance Attribute Details

#delay_daysObject

The number of days charge funds are held before being paid out. May also be set to minimum, representing the lowest available value for the account country. Default is minimum. The delay_days parameter remains at the last configured value if interval is manual. Learn more about controlling payout delay days.



2030
2031
2032
# File 'lib/stripe/params/account_update_params.rb', line 2030

def delay_days
  @delay_days
end

#intervalObject

How frequently available funds are paid out. One of: daily, manual, weekly, or monthly. Default is daily.



2032
2033
2034
# File 'lib/stripe/params/account_update_params.rb', line 2032

def interval
  @interval
end

#monthly_anchorObject

The day of the month when available funds are paid out, specified as a number between 1--31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if interval is monthly.



2034
2035
2036
# File 'lib/stripe/params/account_update_params.rb', line 2034

def monthly_anchor
  @monthly_anchor
end

#monthly_payout_daysObject

The days of the month when available funds are paid out, specified as an array of numbers between 1--31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if interval is monthly and monthly_anchor is not set.



2036
2037
2038
# File 'lib/stripe/params/account_update_params.rb', line 2036

def monthly_payout_days
  @monthly_payout_days
end

#weekly_anchorObject

The day of the week when available funds are paid out, specified as monday, tuesday, etc. Required and applicable only if interval is weekly.



2038
2039
2040
# File 'lib/stripe/params/account_update_params.rb', line 2038

def weekly_anchor
  @weekly_anchor
end

#weekly_payout_daysObject

The days of the week when available funds are paid out, specified as an array, e.g., [monday, tuesday]. Required and applicable only if interval is weekly.



2040
2041
2042
# File 'lib/stripe/params/account_update_params.rb', line 2040

def weekly_payout_days
  @weekly_payout_days
end