Class: Stripe::AccountUpdateParams::Settings::Payouts::Schedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::Payouts::Schedule
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#delay_days ⇒ Object
The number of days charge funds are held before being paid out.
-
#interval ⇒ Object
How frequently available funds are paid out.
-
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1--31.
-
#monthly_payout_days ⇒ Object
The days of the month when available funds are paid out, specified as an array of numbers between 1--31.
-
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as
monday,tuesday, etc. -
#weekly_payout_days ⇒ Object
The days of the week when available funds are paid out, specified as an array, e.g., [
monday,tuesday].
Instance Method Summary collapse
-
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule
constructor
A new instance of Schedule.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule
Returns a new instance of Schedule.
2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/stripe/params/account_update_params.rb', line 2274 def initialize( delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil ) @delay_days = delay_days @interval = interval @monthly_anchor = monthly_anchor @monthly_payout_days = monthly_payout_days @weekly_anchor = weekly_anchor @weekly_payout_days = weekly_payout_days end |
Instance Attribute Details
#delay_days ⇒ Object
The number of days charge funds are held before being paid out. May also be set to minimum, representing the lowest available value for the account country. Default is minimum. The delay_days parameter remains at the last configured value if interval is manual. Learn more about controlling payout delay days.
2262 2263 2264 |
# File 'lib/stripe/params/account_update_params.rb', line 2262 def delay_days @delay_days end |
#interval ⇒ Object
How frequently available funds are paid out. One of: daily, manual, weekly, or monthly. Default is daily.
2264 2265 2266 |
# File 'lib/stripe/params/account_update_params.rb', line 2264 def interval @interval end |
#monthly_anchor ⇒ Object
The day of the month when available funds are paid out, specified as a number between 1--31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if interval is monthly.
2266 2267 2268 |
# File 'lib/stripe/params/account_update_params.rb', line 2266 def monthly_anchor @monthly_anchor end |
#monthly_payout_days ⇒ Object
The days of the month when available funds are paid out, specified as an array of numbers between 1--31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if interval is monthly and monthly_anchor is not set.
2268 2269 2270 |
# File 'lib/stripe/params/account_update_params.rb', line 2268 def monthly_payout_days @monthly_payout_days end |
#weekly_anchor ⇒ Object
The day of the week when available funds are paid out, specified as monday, tuesday, etc. Required and applicable only if interval is weekly.
2270 2271 2272 |
# File 'lib/stripe/params/account_update_params.rb', line 2270 def weekly_anchor @weekly_anchor end |
#weekly_payout_days ⇒ Object
The days of the week when available funds are paid out, specified as an array, e.g., [monday, tuesday]. Required and applicable only if interval is weekly.
2272 2273 2274 |
# File 'lib/stripe/params/account_update_params.rb', line 2272 def weekly_payout_days @weekly_payout_days end |