Class: Stripe::AccountUpdateParams::Settings::Payouts::Schedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(delay_days: nil, interval: nil, monthly_anchor: nil, monthly_payout_days: nil, weekly_anchor: nil, weekly_payout_days: nil) ⇒ Schedule

Returns a new instance of Schedule.



1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
# File 'lib/stripe/params/account_update_params.rb', line 1918

def initialize(
  delay_days: nil,
  interval: nil,
  monthly_anchor: nil,
  monthly_payout_days: nil,
  weekly_anchor: nil,
  weekly_payout_days: nil
)
  @delay_days = delay_days
  @interval = interval
  @monthly_anchor = monthly_anchor
  @monthly_payout_days = monthly_payout_days
  @weekly_anchor = weekly_anchor
  @weekly_payout_days = weekly_payout_days
end

Instance Attribute Details

#delay_daysObject

The number of days charge funds are held before being paid out. May also be set to ‘minimum`, representing the lowest available value for the account country. Default is `minimum`. The `delay_days` parameter remains at the last configured value if `interval` is `manual`. [Learn more about controlling payout delay days](/connect/manage-payout-schedule).



1906
1907
1908
# File 'lib/stripe/params/account_update_params.rb', line 1906

def delay_days
  @delay_days
end

#intervalObject

How frequently available funds are paid out. One of: ‘daily`, `manual`, `weekly`, or `monthly`. Default is `daily`.



1908
1909
1910
# File 'lib/stripe/params/account_update_params.rb', line 1908

def interval
  @interval
end

#monthly_anchorObject

The day of the month when available funds are paid out, specified as a number between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly`.



1910
1911
1912
# File 'lib/stripe/params/account_update_params.rb', line 1910

def monthly_anchor
  @monthly_anchor
end

#monthly_payout_daysObject

The days of the month when available funds are paid out, specified as an array of numbers between 1–31. Payouts nominally scheduled between the 29th and 31st of the month are instead sent on the last day of a shorter month. Required and applicable only if ‘interval` is `monthly` and `monthly_anchor` is not set.



1912
1913
1914
# File 'lib/stripe/params/account_update_params.rb', line 1912

def monthly_payout_days
  @monthly_payout_days
end

#weekly_anchorObject

The day of the week when available funds are paid out, specified as ‘monday`, `tuesday`, etc. Required and applicable only if `interval` is `weekly`.



1914
1915
1916
# File 'lib/stripe/params/account_update_params.rb', line 1914

def weekly_anchor
  @weekly_anchor
end

#weekly_payout_daysObject

The days of the week when available funds are paid out, specified as an array, e.g., [‘monday`, `tuesday`]. Required and applicable only if `interval` is `weekly`.



1916
1917
1918
# File 'lib/stripe/params/account_update_params.rb', line 1916

def weekly_payout_days
  @weekly_payout_days
end