Class: Stripe::AccountUpdateParams::Settings::PaypayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::PaypayPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Site
Instance Attribute Summary collapse
-
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
-
#goods_type ⇒ Object
The type of goods your business sells.
-
#site ⇒ Object
Details regarding your business's website.
Instance Method Summary collapse
-
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
constructor
A new instance of PaypayPayments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
Returns a new instance of PaypayPayments.
2351 2352 2353 2354 2355 |
# File 'lib/stripe/params/account_update_params.rb', line 2351 def initialize(additional_files: nil, goods_type: nil, site: nil) @additional_files = additional_files @goods_type = goods_type @site = site end |
Instance Attribute Details
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
2345 2346 2347 |
# File 'lib/stripe/params/account_update_params.rb', line 2345 def additional_files @additional_files end |
#goods_type ⇒ Object
The type of goods your business sells. Use digital_content if you sell digital content. Use other for all other types of goods or services.
2347 2348 2349 |
# File 'lib/stripe/params/account_update_params.rb', line 2347 def goods_type @goods_type end |
#site ⇒ Object
Details regarding your business's website.
2349 2350 2351 |
# File 'lib/stripe/params/account_update_params.rb', line 2349 def site @site end |