Class: Stripe::AccountUpdateParams::Settings::PaypayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::PaypayPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Site
Instance Attribute Summary collapse
-
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
-
#goods_type ⇒ Object
Whether your business sells digital content or not.
-
#site ⇒ Object
Details regarding your business’s website.
Instance Method Summary collapse
-
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
constructor
A new instance of PaypayPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
Returns a new instance of PaypayPayments.
2246 2247 2248 2249 2250 |
# File 'lib/stripe/params/account_update_params.rb', line 2246 def initialize(additional_files: nil, goods_type: nil, site: nil) @additional_files = additional_files @goods_type = goods_type @site = site end |
Instance Attribute Details
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
2240 2241 2242 |
# File 'lib/stripe/params/account_update_params.rb', line 2240 def additional_files @additional_files end |
#goods_type ⇒ Object
Whether your business sells digital content or not.
2242 2243 2244 |
# File 'lib/stripe/params/account_update_params.rb', line 2242 def goods_type @goods_type end |
#site ⇒ Object
Details regarding your business’s website.
2244 2245 2246 |
# File 'lib/stripe/params/account_update_params.rb', line 2244 def site @site end |