Class: Stripe::AccountUpdateParams::Settings::PaypayPayments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::PaypayPayments
- Defined in:
- lib/stripe/params/account_update_params.rb
Defined Under Namespace
Classes: Site
Instance Attribute Summary collapse
-
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
-
#goods_type ⇒ Object
Whether your business sells digital content or not.
-
#site ⇒ Object
Details regarding your business’s website.
Instance Method Summary collapse
-
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
constructor
A new instance of PaypayPayments.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_files: nil, goods_type: nil, site: nil) ⇒ PaypayPayments
Returns a new instance of PaypayPayments.
2210 2211 2212 2213 2214 |
# File 'lib/stripe/params/account_update_params.rb', line 2210 def initialize(additional_files: nil, goods_type: nil, site: nil) @additional_files = additional_files @goods_type = goods_type @site = site end |
Instance Attribute Details
#additional_files ⇒ Object
Additional files that are required to support the onboarding process of your business.
2204 2205 2206 |
# File 'lib/stripe/params/account_update_params.rb', line 2204 def additional_files @additional_files end |
#goods_type ⇒ Object
Whether your business sells digital content or not.
2206 2207 2208 |
# File 'lib/stripe/params/account_update_params.rb', line 2206 def goods_type @goods_type end |
#site ⇒ Object
Details regarding your business’s website.
2208 2209 2210 |
# File 'lib/stripe/params/account_update_params.rb', line 2208 def site @site end |