Class: Stripe::AccountUpdateParams::Settings::TaxForms
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::TaxForms
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#consented_to_paperless_delivery ⇒ Object
Whether the account opted out of receiving their tax forms by postal delivery.
Instance Method Summary collapse
-
#initialize(consented_to_paperless_delivery: nil) ⇒ TaxForms
constructor
A new instance of TaxForms.
Methods inherited from RequestParams
Constructor Details
#initialize(consented_to_paperless_delivery: nil) ⇒ TaxForms
Returns a new instance of TaxForms.
2208 2209 2210 |
# File 'lib/stripe/params/account_update_params.rb', line 2208 def initialize(consented_to_paperless_delivery: nil) @consented_to_paperless_delivery = end |
Instance Attribute Details
#consented_to_paperless_delivery ⇒ Object
Whether the account opted out of receiving their tax forms by postal delivery.
2206 2207 2208 |
# File 'lib/stripe/params/account_update_params.rb', line 2206 def @consented_to_paperless_delivery end |