Class: Stripe::AccountUpdateParams::Settings::Treasury::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::Settings::Treasury::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2321 2322 2323 2324 2325 |
# File 'lib/stripe/params/account_update_params.rb', line 2321 def initialize(date: nil, ip: nil, user_agent: nil) @date = date @ip = ip @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted the service agreement.
2315 2316 2317 |
# File 'lib/stripe/params/account_update_params.rb', line 2315 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted the service agreement.
2317 2318 2319 |
# File 'lib/stripe/params/account_update_params.rb', line 2317 def ip @ip end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted the service agreement.
2319 2320 2321 |
# File 'lib/stripe/params/account_update_params.rb', line 2319 def user_agent @user_agent end |