Class: Stripe::AccountUpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2327
2328
2329
2330
2331
# File 'lib/stripe/params/account_update_params.rb', line 2327

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2321
2322
2323
# File 'lib/stripe/params/account_update_params.rb', line 2321

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2323
2324
2325
# File 'lib/stripe/params/account_update_params.rb', line 2323

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2325
2326
2327
# File 'lib/stripe/params/account_update_params.rb', line 2325

def user_agent
  @user_agent
end