Class: Stripe::AccountUpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2288
2289
2290
2291
2292
# File 'lib/stripe/params/account_update_params.rb', line 2288

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2282
2283
2284
# File 'lib/stripe/params/account_update_params.rb', line 2282

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2284
2285
2286
# File 'lib/stripe/params/account_update_params.rb', line 2284

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2286
2287
2288
# File 'lib/stripe/params/account_update_params.rb', line 2286

def user_agent
  @user_agent
end