Class: Stripe::AccountUpdateParams::Settings::Treasury::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2136
2137
2138
2139
2140
# File 'lib/stripe/params/account_update_params.rb', line 2136

def initialize(date: nil, ip: nil, user_agent: nil)
  @date = date
  @ip = ip
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted the service agreement.



2130
2131
2132
# File 'lib/stripe/params/account_update_params.rb', line 2130

def date
  @date
end

#ipObject

The IP address from which the account representative accepted the service agreement.



2132
2133
2134
# File 'lib/stripe/params/account_update_params.rb', line 2132

def ip
  @ip
end

#user_agentObject

The user agent of the browser from which the account representative accepted the service agreement.



2134
2135
2136
# File 'lib/stripe/params/account_update_params.rb', line 2134

def user_agent
  @user_agent
end