Class: Stripe::AccountUpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user's service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2586 2587 2588 2589 2590 2591 |
# File 'lib/stripe/params/account_update_params.rb', line 2586 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2578 2579 2580 |
# File 'lib/stripe/params/account_update_params.rb', line 2578 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2580 2581 2582 |
# File 'lib/stripe/params/account_update_params.rb', line 2580 def ip @ip end |
#service_agreement ⇒ Object
The user's service agreement type.
2582 2583 2584 |
# File 'lib/stripe/params/account_update_params.rb', line 2582 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2584 2585 2586 |
# File 'lib/stripe/params/account_update_params.rb', line 2584 def user_agent @user_agent end |