Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2488
2489
2490
2491
2492
2493
# File 'lib/stripe/params/account_update_params.rb', line 2488

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2480
2481
2482
# File 'lib/stripe/params/account_update_params.rb', line 2480

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2482
2483
2484
# File 'lib/stripe/params/account_update_params.rb', line 2482

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2484
2485
2486
# File 'lib/stripe/params/account_update_params.rb', line 2484

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2486
2487
2488
# File 'lib/stripe/params/account_update_params.rb', line 2486

def user_agent
  @user_agent
end