Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2402
2403
2404
2405
2406
2407
# File 'lib/stripe/params/account_update_params.rb', line 2402

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2394
2395
2396
# File 'lib/stripe/params/account_update_params.rb', line 2394

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2396
2397
2398
# File 'lib/stripe/params/account_update_params.rb', line 2396

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2398
2399
2400
# File 'lib/stripe/params/account_update_params.rb', line 2398

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2400
2401
2402
# File 'lib/stripe/params/account_update_params.rb', line 2400

def user_agent
  @user_agent
end