Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2070
2071
2072
2073
2074
2075
# File 'lib/stripe/params/account_update_params.rb', line 2070

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2062
2063
2064
# File 'lib/stripe/params/account_update_params.rb', line 2062

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2064
2065
2066
# File 'lib/stripe/params/account_update_params.rb', line 2064

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2066
2067
2068
# File 'lib/stripe/params/account_update_params.rb', line 2066

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2068
2069
2070
# File 'lib/stripe/params/account_update_params.rb', line 2068

def user_agent
  @user_agent
end