Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2427
2428
2429
2430
2431
2432
# File 'lib/stripe/params/account_update_params.rb', line 2427

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2419
2420
2421
# File 'lib/stripe/params/account_update_params.rb', line 2419

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2421
2422
2423
# File 'lib/stripe/params/account_update_params.rb', line 2421

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2423
2424
2425
# File 'lib/stripe/params/account_update_params.rb', line 2423

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2425
2426
2427
# File 'lib/stripe/params/account_update_params.rb', line 2425

def user_agent
  @user_agent
end