Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2376
2377
2378
2379
2380
2381
# File 'lib/stripe/params/account_update_params.rb', line 2376

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2368
2369
2370
# File 'lib/stripe/params/account_update_params.rb', line 2368

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2370
2371
2372
# File 'lib/stripe/params/account_update_params.rb', line 2370

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2372
2373
2374
# File 'lib/stripe/params/account_update_params.rb', line 2372

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2374
2375
2376
# File 'lib/stripe/params/account_update_params.rb', line 2374

def user_agent
  @user_agent
end