Class: Stripe::AccountUpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2376 2377 2378 2379 2380 2381 |
# File 'lib/stripe/params/account_update_params.rb', line 2376 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2368 2369 2370 |
# File 'lib/stripe/params/account_update_params.rb', line 2368 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2370 2371 2372 |
# File 'lib/stripe/params/account_update_params.rb', line 2370 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2372 2373 2374 |
# File 'lib/stripe/params/account_update_params.rb', line 2372 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2374 2375 2376 |
# File 'lib/stripe/params/account_update_params.rb', line 2374 def user_agent @user_agent end |