Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2018
2019
2020
2021
2022
2023
# File 'lib/stripe/params/account_update_params.rb', line 2018

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2010
2011
2012
# File 'lib/stripe/params/account_update_params.rb', line 2010

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2012
2013
2014
# File 'lib/stripe/params/account_update_params.rb', line 2012

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2014
2015
2016
# File 'lib/stripe/params/account_update_params.rb', line 2014

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2016
2017
2018
# File 'lib/stripe/params/account_update_params.rb', line 2016

def user_agent
  @user_agent
end