Class: Stripe::AccountUpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2369 2370 2371 2372 2373 2374 |
# File 'lib/stripe/params/account_update_params.rb', line 2369 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2361 2362 2363 |
# File 'lib/stripe/params/account_update_params.rb', line 2361 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2363 2364 2365 |
# File 'lib/stripe/params/account_update_params.rb', line 2363 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2365 2366 2367 |
# File 'lib/stripe/params/account_update_params.rb', line 2365 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2367 2368 2369 |
# File 'lib/stripe/params/account_update_params.rb', line 2367 def user_agent @user_agent end |