Class: Stripe::AccountUpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2344 2345 2346 2347 2348 2349 |
# File 'lib/stripe/params/account_update_params.rb', line 2344 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2336 2337 2338 |
# File 'lib/stripe/params/account_update_params.rb', line 2336 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2338 2339 2340 |
# File 'lib/stripe/params/account_update_params.rb', line 2338 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2340 2341 2342 |
# File 'lib/stripe/params/account_update_params.rb', line 2340 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2342 2343 2344 |
# File 'lib/stripe/params/account_update_params.rb', line 2342 def user_agent @user_agent end |