Class: Stripe::AccountUpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2005 2006 2007 2008 2009 2010 |
# File 'lib/stripe/params/account_update_params.rb', line 2005 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
1997 1998 1999 |
# File 'lib/stripe/params/account_update_params.rb', line 1997 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
1999 2000 2001 |
# File 'lib/stripe/params/account_update_params.rb', line 1999 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2001 2002 2003 |
# File 'lib/stripe/params/account_update_params.rb', line 2001 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2003 2004 2005 |
# File 'lib/stripe/params/account_update_params.rb', line 2003 def user_agent @user_agent end |