Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2005
2006
2007
2008
2009
2010
# File 'lib/stripe/params/account_update_params.rb', line 2005

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



1997
1998
1999
# File 'lib/stripe/params/account_update_params.rb', line 1997

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



1999
2000
2001
# File 'lib/stripe/params/account_update_params.rb', line 1999

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2001
2002
2003
# File 'lib/stripe/params/account_update_params.rb', line 2001

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2003
2004
2005
# File 'lib/stripe/params/account_update_params.rb', line 2003

def user_agent
  @user_agent
end