Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2277
2278
2279
2280
2281
2282
# File 'lib/stripe/params/account_update_params.rb', line 2277

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2269
2270
2271
# File 'lib/stripe/params/account_update_params.rb', line 2269

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2271
2272
2273
# File 'lib/stripe/params/account_update_params.rb', line 2271

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2273
2274
2275
# File 'lib/stripe/params/account_update_params.rb', line 2273

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2275
2276
2277
# File 'lib/stripe/params/account_update_params.rb', line 2275

def user_agent
  @user_agent
end