Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



2228
2229
2230
2231
2232
2233
# File 'lib/stripe/params/account_update_params.rb', line 2228

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



2220
2221
2222
# File 'lib/stripe/params/account_update_params.rb', line 2220

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



2222
2223
2224
# File 'lib/stripe/params/account_update_params.rb', line 2222

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



2224
2225
2226
# File 'lib/stripe/params/account_update_params.rb', line 2224

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



2226
2227
2228
# File 'lib/stripe/params/account_update_params.rb', line 2226

def user_agent
  @user_agent
end