Class: Stripe::AccountUpdateParams::TosAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::AccountUpdateParams::TosAcceptance
- Defined in:
- lib/stripe/params/account_update_params.rb
Instance Attribute Summary collapse
-
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
-
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
-
#service_agreement ⇒ Object
The user’s service agreement type.
-
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
Instance Method Summary collapse
-
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
constructor
A new instance of TosAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance
Returns a new instance of TosAcceptance.
2209 2210 2211 2212 2213 2214 |
# File 'lib/stripe/params/account_update_params.rb', line 2209 def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) @date = date @ip = ip @service_agreement = service_agreement @user_agent = user_agent end |
Instance Attribute Details
#date ⇒ Object
The Unix timestamp marking when the account representative accepted their service agreement.
2201 2202 2203 |
# File 'lib/stripe/params/account_update_params.rb', line 2201 def date @date end |
#ip ⇒ Object
The IP address from which the account representative accepted their service agreement.
2203 2204 2205 |
# File 'lib/stripe/params/account_update_params.rb', line 2203 def ip @ip end |
#service_agreement ⇒ Object
The user’s service agreement type.
2205 2206 2207 |
# File 'lib/stripe/params/account_update_params.rb', line 2205 def service_agreement @service_agreement end |
#user_agent ⇒ Object
The user agent of the browser from which the account representative accepted their service agreement.
2207 2208 2209 |
# File 'lib/stripe/params/account_update_params.rb', line 2207 def user_agent @user_agent end |