Class: Stripe::AccountUpdateParams::TosAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/account_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil) ⇒ TosAcceptance

Returns a new instance of TosAcceptance.



1951
1952
1953
1954
1955
1956
# File 'lib/stripe/params/account_update_params.rb', line 1951

def initialize(date: nil, ip: nil, service_agreement: nil, user_agent: nil)
  @date = date
  @ip = ip
  @service_agreement = service_agreement
  @user_agent = user_agent
end

Instance Attribute Details

#dateObject

The Unix timestamp marking when the account representative accepted their service agreement.



1943
1944
1945
# File 'lib/stripe/params/account_update_params.rb', line 1943

def date
  @date
end

#ipObject

The IP address from which the account representative accepted their service agreement.



1945
1946
1947
# File 'lib/stripe/params/account_update_params.rb', line 1945

def ip
  @ip
end

#service_agreementObject

The user’s service agreement type.



1947
1948
1949
# File 'lib/stripe/params/account_update_params.rb', line 1947

def service_agreement
  @service_agreement
end

#user_agentObject

The user agent of the browser from which the account representative accepted their service agreement.



1949
1950
1951
# File 'lib/stripe/params/account_update_params.rb', line 1949

def user_agent
  @user_agent
end