Class: Stripe::ApplicationFee
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::ApplicationFee
- Defined in:
- lib/stripe/resources/application_fee.rb
Defined Under Namespace
Classes: FeeSource
Constant Summary collapse
- OBJECT_NAME =
"application_fee"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
ID of the Stripe account this fee was taken from.
-
#amount ⇒ Object
readonly
Amount earned, in cents (or local equivalent).
-
#amount_refunded ⇒ Object
readonly
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the fee if a partial refund was issued).
-
#application ⇒ Object
readonly
ID of the Connect application that earned the fee.
-
#balance_transaction ⇒ Object
readonly
Balance transaction that describes the impact of this collected application fee on your account balance (not including refunds).
-
#charge ⇒ Object
readonly
ID of the charge that the application fee was taken from.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#fee_source ⇒ Object
readonly
Polymorphic source of the application fee.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#originating_transaction ⇒ Object
readonly
ID of the corresponding charge on the platform account, if this fee was the result of a charge using the ‘destination` parameter.
-
#refunded ⇒ Object
readonly
Whether the fee has been fully refunded.
-
#refunds ⇒ Object
readonly
A list of refunds that have been applied to the fee.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of application fees you’ve previously collected.
- .object_name ⇒ Object
Methods included from Stripe::APIOperations::List
Methods included from Stripe::APIOperations::NestedResource
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from Stripe::APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
ID of the Stripe account this fee was taken from.
20 21 22 |
# File 'lib/stripe/resources/application_fee.rb', line 20 def account @account end |
#amount ⇒ Object (readonly)
Amount earned, in cents (or local equivalent).
22 23 24 |
# File 'lib/stripe/resources/application_fee.rb', line 22 def amount @amount end |
#amount_refunded ⇒ Object (readonly)
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the fee if a partial refund was issued)
24 25 26 |
# File 'lib/stripe/resources/application_fee.rb', line 24 def amount_refunded @amount_refunded end |
#application ⇒ Object (readonly)
ID of the Connect application that earned the fee.
26 27 28 |
# File 'lib/stripe/resources/application_fee.rb', line 26 def application @application end |
#balance_transaction ⇒ Object (readonly)
Balance transaction that describes the impact of this collected application fee on your account balance (not including refunds).
28 29 30 |
# File 'lib/stripe/resources/application_fee.rb', line 28 def balance_transaction @balance_transaction end |
#charge ⇒ Object (readonly)
ID of the charge that the application fee was taken from.
30 31 32 |
# File 'lib/stripe/resources/application_fee.rb', line 30 def charge @charge end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
32 33 34 |
# File 'lib/stripe/resources/application_fee.rb', line 32 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
34 35 36 |
# File 'lib/stripe/resources/application_fee.rb', line 34 def currency @currency end |
#fee_source ⇒ Object (readonly)
Polymorphic source of the application fee. Includes the ID of the object the application fee was created from.
36 37 38 |
# File 'lib/stripe/resources/application_fee.rb', line 36 def fee_source @fee_source end |
#id ⇒ Object (readonly)
Unique identifier for the object.
38 39 40 |
# File 'lib/stripe/resources/application_fee.rb', line 38 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
40 41 42 |
# File 'lib/stripe/resources/application_fee.rb', line 40 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
42 43 44 |
# File 'lib/stripe/resources/application_fee.rb', line 42 def object @object end |
#originating_transaction ⇒ Object (readonly)
ID of the corresponding charge on the platform account, if this fee was the result of a charge using the ‘destination` parameter.
44 45 46 |
# File 'lib/stripe/resources/application_fee.rb', line 44 def originating_transaction @originating_transaction end |
#refunded ⇒ Object (readonly)
Whether the fee has been fully refunded. If the fee is only partially refunded, this attribute will still be false.
46 47 48 |
# File 'lib/stripe/resources/application_fee.rb', line 46 def refunded @refunded end |
#refunds ⇒ Object (readonly)
A list of refunds that have been applied to the fee.
48 49 50 |
# File 'lib/stripe/resources/application_fee.rb', line 48 def refunds @refunds end |
Class Method Details
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of application fees you’ve previously collected. The application fees are returned in sorted order, with the most recent fees appearing first.
51 52 53 |
# File 'lib/stripe/resources/application_fee.rb', line 51 def self.list(filters = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/application_fees", params: filters, opts: opts) end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/application_fee.rb', line 10 def self.object_name "application_fee" end |