Class: Stripe::Apps::InstallCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Apps::InstallCreateParams
- Defined in:
- lib/stripe/params/apps/install_create_params.rb
Instance Attribute Summary collapse
-
#app ⇒ Object
The ID of the app to install.
-
#channel ⇒ Object
The distribution channel to install from.
-
#code_challenge ⇒ Object
For OAuth apps, the PKCE code challenge used to issue the
auth_codereturned on the install. -
#code_challenge_method ⇒ Object
The method used to derive
code_challenge. -
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(app: nil, channel: nil, code_challenge: nil, code_challenge_method: nil, expand: nil) ⇒ InstallCreateParams
constructor
A new instance of InstallCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(app: nil, channel: nil, code_challenge: nil, code_challenge_method: nil, expand: nil) ⇒ InstallCreateParams
Returns a new instance of InstallCreateParams.
18 19 20 21 22 23 24 25 26 27 28 29 30 |
# File 'lib/stripe/params/apps/install_create_params.rb', line 18 def initialize( app: nil, channel: nil, code_challenge: nil, code_challenge_method: nil, expand: nil ) @app = app @channel = channel @code_challenge = code_challenge @code_challenge_method = code_challenge_method @expand = end |
Instance Attribute Details
#app ⇒ Object
The ID of the app to install.
8 9 10 |
# File 'lib/stripe/params/apps/install_create_params.rb', line 8 def app @app end |
#channel ⇒ Object
The distribution channel to install from. Defaults to public. A private app must be installed on private_test or private_live, matching the mode of the API key.
10 11 12 |
# File 'lib/stripe/params/apps/install_create_params.rb', line 10 def channel @channel end |
#code_challenge ⇒ Object
For OAuth apps, the PKCE code challenge used to issue the auth_code returned on the install. Must be 43 to 128 characters and contain only letters, numbers, -, ., _, and ~. Only applies to installs made by the app developer or an embedding platform; ignored when an account installs its own private app.
12 13 14 |
# File 'lib/stripe/params/apps/install_create_params.rb', line 12 def code_challenge @code_challenge end |
#code_challenge_method ⇒ Object
The method used to derive code_challenge. Required when code_challenge is provided, and must be S256.
14 15 16 |
# File 'lib/stripe/params/apps/install_create_params.rb', line 14 def code_challenge_method @code_challenge_method end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
16 17 18 |
# File 'lib/stripe/params/apps/install_create_params.rb', line 16 def @expand end |