Class: Stripe::Apps::Secret::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/apps/secret.rb

Defined Under Namespace

Classes: Scope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil, name: nil, payload: nil, scope: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



97
98
99
100
101
102
103
# File 'lib/stripe/resources/apps/secret.rb', line 97

def initialize(expand: nil, expires_at: nil, name: nil, payload: nil, scope: nil)
  @expand = expand
  @expires_at = expires_at
  @name = name
  @payload = payload
  @scope = scope
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



83
84
85
# File 'lib/stripe/resources/apps/secret.rb', line 83

def expand
  @expand
end

#expires_atObject

The Unix timestamp for the expiry time of the secret, after which the secret deletes.



86
87
88
# File 'lib/stripe/resources/apps/secret.rb', line 86

def expires_at
  @expires_at
end

#nameObject

A name for the secret that’s unique within the scope.



89
90
91
# File 'lib/stripe/resources/apps/secret.rb', line 89

def name
  @name
end

#payloadObject

The plaintext secret value to be stored.



92
93
94
# File 'lib/stripe/resources/apps/secret.rb', line 92

def payload
  @payload
end

#scopeObject

Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.



95
96
97
# File 'lib/stripe/resources/apps/secret.rb', line 95

def scope
  @scope
end