Class: Stripe::Apps::Secret::DeleteWhereParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/apps/secret.rb

Defined Under Namespace

Classes: Scope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, name: nil, scope: nil) ⇒ DeleteWhereParams

Returns a new instance of DeleteWhereParams.



157
158
159
160
161
# File 'lib/stripe/resources/apps/secret.rb', line 157

def initialize(expand: nil, name: nil, scope: nil)
  @expand = expand
  @name = name
  @scope = scope
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



149
150
151
# File 'lib/stripe/resources/apps/secret.rb', line 149

def expand
  @expand
end

#nameObject

A name for the secret that’s unique within the scope.



152
153
154
# File 'lib/stripe/resources/apps/secret.rb', line 152

def name
  @name
end

#scopeObject

Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.



155
156
157
# File 'lib/stripe/resources/apps/secret.rb', line 155

def scope
  @scope
end