Class: Stripe::Apps::Secret::FindParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Apps::Secret::FindParams
- Defined in:
- lib/stripe/resources/apps/secret.rb
Defined Under Namespace
Classes: Scope
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
A name for the secret that’s unique within the scope.
-
#scope ⇒ Object
Specifies the scoping of the secret.
Instance Method Summary collapse
-
#initialize(expand: nil, name: nil, scope: nil) ⇒ FindParams
constructor
A new instance of FindParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, name: nil, scope: nil) ⇒ FindParams
Returns a new instance of FindParams.
128 129 130 131 132 |
# File 'lib/stripe/resources/apps/secret.rb', line 128 def initialize(expand: nil, name: nil, scope: nil) @expand = @name = name @scope = scope end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
120 121 122 |
# File 'lib/stripe/resources/apps/secret.rb', line 120 def @expand end |
#name ⇒ Object
A name for the secret that’s unique within the scope.
123 124 125 |
# File 'lib/stripe/resources/apps/secret.rb', line 123 def name @name end |
#scope ⇒ Object
Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.
126 127 128 |
# File 'lib/stripe/resources/apps/secret.rb', line 126 def scope @scope end |