Class: Stripe::Apps::SecretService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Apps::SecretService::CreateParams
- Defined in:
- lib/stripe/services/apps/secret_service.rb
Defined Under Namespace
Classes: Scope
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
The Unix timestamp for the expiry time of the secret, after which the secret deletes.
-
#name ⇒ Object
A name for the secret that’s unique within the scope.
-
#payload ⇒ Object
The plaintext secret value to be stored.
-
#scope ⇒ Object
Specifies the scoping of the secret.
Instance Method Summary collapse
-
#initialize(expand: nil, expires_at: nil, name: nil, payload: nil, scope: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, expires_at: nil, name: nil, payload: nil, scope: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
72 73 74 75 76 77 78 |
# File 'lib/stripe/services/apps/secret_service.rb', line 72 def initialize(expand: nil, expires_at: nil, name: nil, payload: nil, scope: nil) @expand = @expires_at = expires_at @name = name @payload = payload @scope = scope end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
58 59 60 |
# File 'lib/stripe/services/apps/secret_service.rb', line 58 def @expand end |
#expires_at ⇒ Object
The Unix timestamp for the expiry time of the secret, after which the secret deletes.
61 62 63 |
# File 'lib/stripe/services/apps/secret_service.rb', line 61 def expires_at @expires_at end |
#name ⇒ Object
A name for the secret that’s unique within the scope.
64 65 66 |
# File 'lib/stripe/services/apps/secret_service.rb', line 64 def name @name end |
#payload ⇒ Object
The plaintext secret value to be stored.
67 68 69 |
# File 'lib/stripe/services/apps/secret_service.rb', line 67 def payload @payload end |
#scope ⇒ Object
Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.
70 71 72 |
# File 'lib/stripe/services/apps/secret_service.rb', line 70 def scope @scope end |