Class: Stripe::Apps::SecretService::DeleteWhereParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Apps::SecretService::DeleteWhereParams
- Defined in:
- lib/stripe/services/apps/secret_service.rb
Defined Under Namespace
Classes: Scope
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#name ⇒ Object
A name for the secret that’s unique within the scope.
-
#scope ⇒ Object
Specifies the scoping of the secret.
Instance Method Summary collapse
-
#initialize(expand: nil, name: nil, scope: nil) ⇒ DeleteWhereParams
constructor
A new instance of DeleteWhereParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, name: nil, scope: nil) ⇒ DeleteWhereParams
Returns a new instance of DeleteWhereParams.
132 133 134 135 136 |
# File 'lib/stripe/services/apps/secret_service.rb', line 132 def initialize(expand: nil, name: nil, scope: nil) @expand = @name = name @scope = scope end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
124 125 126 |
# File 'lib/stripe/services/apps/secret_service.rb', line 124 def @expand end |
#name ⇒ Object
A name for the secret that’s unique within the scope.
127 128 129 |
# File 'lib/stripe/services/apps/secret_service.rb', line 127 def name @name end |
#scope ⇒ Object
Specifies the scoping of the secret. Requests originating from UI extensions can only access account-scoped secrets or secrets scoped to their own user.
130 131 132 |
# File 'lib/stripe/services/apps/secret_service.rb', line 130 def scope @scope end |