Class: Stripe::Balance
- Inherits:
-
SingletonAPIResource
- Object
- StripeObject
- APIResource
- SingletonAPIResource
- Stripe::Balance
- Defined in:
- lib/stripe/resources/balance.rb
Overview
This is an object representing your Stripe balance. You can retrieve it to see the balance currently on your Stripe account.
The top-level available and pending comprise your "payments balance."
Related guide: Balances and settlement time, Understanding Connect account balances
Defined Under Namespace
Classes: Available, ConnectReserved, InstantAvailable, Issuing, Pending, RefundAndDisputePrefunding, RiskReserved, TransitBalancesTotal
Constant Summary collapse
- OBJECT_NAME =
"balance"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#available ⇒ Object
readonly
Available funds that you can transfer or pay out automatically by Stripe or explicitly through the Transfers API or Payouts API.
-
#connect_reserved ⇒ Object
readonly
Funds held due to negative balances on connected accounts where account.controller.requirement_collection is
application, which includes Custom accounts. -
#instant_available ⇒ Object
readonly
Funds that you can pay out using Instant Payouts.
-
#issuing ⇒ Object
readonly
Attribute for field issuing.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#object ⇒ Object
readonly
String representing the object's type.
-
#pending ⇒ Object
readonly
Funds that aren't available in the balance yet.
-
#refund_and_dispute_prefunding ⇒ Object
readonly
Attribute for field refund_and_dispute_prefunding.
-
#risk_reserved ⇒ Object
readonly
Attribute for field risk_reserved.
-
#transit_balances_total ⇒ Object
readonly
Attribute for field transit_balances_total.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from SingletonAPIResource
resource_url, #resource_url, retrieve
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#available ⇒ Object (readonly)
Available funds that you can transfer or pay out automatically by Stripe or explicitly through the Transfers API or Payouts API. You can find the available balance for each currency and payment type in the source_types property.
469 470 471 |
# File 'lib/stripe/resources/balance.rb', line 469 def available @available end |
#connect_reserved ⇒ Object (readonly)
Funds held due to negative balances on connected accounts where account.controller.requirement_collection is application, which includes Custom accounts. You can find the connect reserve balance for each currency and payment type in the source_types property.
471 472 473 |
# File 'lib/stripe/resources/balance.rb', line 471 def connect_reserved @connect_reserved end |
#instant_available ⇒ Object (readonly)
Funds that you can pay out using Instant Payouts.
473 474 475 |
# File 'lib/stripe/resources/balance.rb', line 473 def instant_available @instant_available end |
#issuing ⇒ Object (readonly)
Attribute for field issuing
475 476 477 |
# File 'lib/stripe/resources/balance.rb', line 475 def issuing @issuing end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
477 478 479 |
# File 'lib/stripe/resources/balance.rb', line 477 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
479 480 481 |
# File 'lib/stripe/resources/balance.rb', line 479 def object @object end |
#pending ⇒ Object (readonly)
Funds that aren't available in the balance yet. You can find the pending balance for each currency and each payment type in the source_types property.
481 482 483 |
# File 'lib/stripe/resources/balance.rb', line 481 def pending @pending end |
#refund_and_dispute_prefunding ⇒ Object (readonly)
Attribute for field refund_and_dispute_prefunding
483 484 485 |
# File 'lib/stripe/resources/balance.rb', line 483 def refund_and_dispute_prefunding @refund_and_dispute_prefunding end |
#risk_reserved ⇒ Object (readonly)
Attribute for field risk_reserved
485 486 487 |
# File 'lib/stripe/resources/balance.rb', line 485 def risk_reserved @risk_reserved end |
#transit_balances_total ⇒ Object (readonly)
Attribute for field transit_balances_total
487 488 489 |
# File 'lib/stripe/resources/balance.rb', line 487 def transit_balances_total @transit_balances_total end |
Class Method Details
.field_remappings ⇒ Object
502 503 504 |
# File 'lib/stripe/resources/balance.rb', line 502 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/stripe/resources/balance.rb', line 489 def self.inner_class_types @inner_class_types = { available: Available, connect_reserved: ConnectReserved, instant_available: InstantAvailable, issuing: Issuing, pending: Pending, refund_and_dispute_prefunding: RefundAndDisputePrefunding, risk_reserved: RiskReserved, transit_balances_total: TransitBalancesTotal, } end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/balance.rb', line 13 def self.object_name "balance" end |