Class: Stripe::Balance
- Inherits:
-
SingletonAPIResource
- Object
- StripeObject
- APIResource
- SingletonAPIResource
- Stripe::Balance
- Defined in:
- lib/stripe/resources/balance.rb
Overview
This is an object representing your Stripe balance. You can retrieve it to see the balance currently on your Stripe account.
The top-level ‘available` and `pending` comprise your “payments balance.”
Related guide: [Balances and settlement time](stripe.com/docs/payments/balances), [Understanding Connect account balances](stripe.com/docs/connect/account-balances)
Defined Under Namespace
Classes: Available, ConnectReserved, InstantAvailable, Issuing, Pending, RefundAndDisputePrefunding
Constant Summary collapse
- OBJECT_NAME =
"balance"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#available ⇒ Object
readonly
Available funds that you can transfer or pay out automatically by Stripe or explicitly through the [Transfers API](stripe.com/docs/api#transfers) or [Payouts API](stripe.com/docs/api#payouts).
-
#connect_reserved ⇒ Object
readonly
Funds held due to negative balances on connected accounts where [account.controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.
-
#instant_available ⇒ Object
readonly
Funds that you can pay out using Instant Payouts.
-
#issuing ⇒ Object
readonly
Attribute for field issuing.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pending ⇒ Object
readonly
Funds that aren’t available in the balance yet.
-
#refund_and_dispute_prefunding ⇒ Object
readonly
Attribute for field refund_and_dispute_prefunding.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from SingletonAPIResource
resource_url, #resource_url, retrieve
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#available ⇒ Object (readonly)
Available funds that you can transfer or pay out automatically by Stripe or explicitly through the [Transfers API](stripe.com/docs/api#transfers) or [Payouts API](stripe.com/docs/api#payouts). You can find the available balance for each currency and payment type in the ‘source_types` property.
165 166 167 |
# File 'lib/stripe/resources/balance.rb', line 165 def available @available end |
#connect_reserved ⇒ Object (readonly)
Funds held due to negative balances on connected accounts where [account.controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts. You can find the connect reserve balance for each currency and payment type in the `source_types` property.
167 168 169 |
# File 'lib/stripe/resources/balance.rb', line 167 def connect_reserved @connect_reserved end |
#instant_available ⇒ Object (readonly)
Funds that you can pay out using Instant Payouts.
169 170 171 |
# File 'lib/stripe/resources/balance.rb', line 169 def instant_available @instant_available end |
#issuing ⇒ Object (readonly)
Attribute for field issuing
171 172 173 |
# File 'lib/stripe/resources/balance.rb', line 171 def issuing @issuing end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
173 174 175 |
# File 'lib/stripe/resources/balance.rb', line 173 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
175 176 177 |
# File 'lib/stripe/resources/balance.rb', line 175 def object @object end |
#pending ⇒ Object (readonly)
Funds that aren’t available in the balance yet. You can find the pending balance for each currency and each payment type in the ‘source_types` property.
177 178 179 |
# File 'lib/stripe/resources/balance.rb', line 177 def pending @pending end |
#refund_and_dispute_prefunding ⇒ Object (readonly)
Attribute for field refund_and_dispute_prefunding
179 180 181 |
# File 'lib/stripe/resources/balance.rb', line 179 def refund_and_dispute_prefunding @refund_and_dispute_prefunding end |
Class Method Details
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/balance.rb', line 13 def self.object_name "balance" end |