Class: Stripe::BalanceSettings::Payouts
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::BalanceSettings::Payouts
- Defined in:
- lib/stripe/resources/balance_settings.rb
Defined Under Namespace
Classes: Schedule
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#schedule ⇒ Object
readonly
Details on when funds from charges are available, and when they are paid out to an external account.
-
#statement_descriptor ⇒ Object
readonly
The text that appears on the bank account statement for payouts.
-
#status ⇒ Object
readonly
Whether the funds in this account can be paid out.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#schedule ⇒ Object (readonly)
Details on when funds from charges are available, and when they are paid out to an external account. See our [Setting Bank and Debit Card Payouts](stripe.com/docs/connect/bank-transfers#payout-information) documentation for details.
28 29 30 |
# File 'lib/stripe/resources/balance_settings.rb', line 28 def schedule @schedule end |
#statement_descriptor ⇒ Object (readonly)
The text that appears on the bank account statement for payouts. If not set, this defaults to the platform’s bank descriptor as set in the Dashboard.
30 31 32 |
# File 'lib/stripe/resources/balance_settings.rb', line 30 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
Whether the funds in this account can be paid out.
32 33 34 |
# File 'lib/stripe/resources/balance_settings.rb', line 32 def status @status end |