Class: Stripe::BalanceSettings::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettings::UpdateParams
- Defined in:
- lib/stripe/resources/balance_settings.rb
Defined Under Namespace
Classes: Payments
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payments ⇒ Object
Settings that apply to the [Payments Balance](docs.stripe.com/api/balance).
Instance Method Summary collapse
-
#initialize(expand: nil, payments: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payments: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
102 103 104 105 |
# File 'lib/stripe/resources/balance_settings.rb', line 102 def initialize(expand: nil, payments: nil) @expand = @payments = payments end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
98 99 100 |
# File 'lib/stripe/resources/balance_settings.rb', line 98 def @expand end |
#payments ⇒ Object
Settings that apply to the [Payments Balance](docs.stripe.com/api/balance).
100 101 102 |
# File 'lib/stripe/resources/balance_settings.rb', line 100 def payments @payments end |