Class: Stripe::BalanceSettingsService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettingsService::UpdateParams
- Defined in:
- lib/stripe/services/balance_settings_service.rb
Defined Under Namespace
Classes: Payouts, SettlementTiming
Instance Attribute Summary collapse
-
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payouts ⇒ Object
Settings specific to the account’s payouts.
-
#settlement_timing ⇒ Object
Settings related to the account’s balance settlement timing.
Instance Method Summary collapse
-
#initialize(debit_negative_balances: nil, expand: nil, payouts: nil, settlement_timing: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(debit_negative_balances: nil, expand: nil, payouts: nil, settlement_timing: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/stripe/services/balance_settings_service.rb', line 59 def initialize( debit_negative_balances: nil, expand: nil, payouts: nil, settlement_timing: nil ) @debit_negative_balances = debit_negative_balances @expand = @payouts = payouts @settlement_timing = settlement_timing end |
Instance Attribute Details
#debit_negative_balances ⇒ Object
A Boolean indicating whether Stripe should try to reclaim negative balances from an attached bank account. For details, see [Understanding Connect Account Balances](/connect/account-balances).
51 52 53 |
# File 'lib/stripe/services/balance_settings_service.rb', line 51 def debit_negative_balances @debit_negative_balances end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
53 54 55 |
# File 'lib/stripe/services/balance_settings_service.rb', line 53 def @expand end |
#payouts ⇒ Object
Settings specific to the account’s payouts.
55 56 57 |
# File 'lib/stripe/services/balance_settings_service.rb', line 55 def payouts @payouts end |
#settlement_timing ⇒ Object
Settings related to the account’s balance settlement timing.
57 58 59 |
# File 'lib/stripe/services/balance_settings_service.rb', line 57 def settlement_timing @settlement_timing end |