Class: Stripe::BalanceSettingsUpdateParams::Payments::Payouts::AutomaticTransferRulesByCurrency
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettingsUpdateParams::Payments::Payouts::AutomaticTransferRulesByCurrency
- Defined in:
- lib/stripe/params/balance_settings_update_params.rb
Instance Attribute Summary collapse
-
#payout_method ⇒ Object
The ID of the FinancialAccount that funds will be transferred to during automatic transfers.
-
#transfer_up_to_amount ⇒ Object
The maximum amount in minor units to transfer to the FinancialAccount.
-
#type ⇒ Object
The type of automatic transfer rule.
Instance Method Summary collapse
-
#initialize(payout_method: nil, transfer_up_to_amount: nil, type: nil) ⇒ AutomaticTransferRulesByCurrency
constructor
A new instance of AutomaticTransferRulesByCurrency.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payout_method: nil, transfer_up_to_amount: nil, type: nil) ⇒ AutomaticTransferRulesByCurrency
Returns a new instance of AutomaticTransferRulesByCurrency.
16 17 18 19 20 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 16 def initialize(payout_method: nil, transfer_up_to_amount: nil, type: nil) @payout_method = payout_method @transfer_up_to_amount = transfer_up_to_amount @type = type end |
Instance Attribute Details
#payout_method ⇒ Object
The ID of the FinancialAccount that funds will be transferred to during automatic transfers.
10 11 12 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 10 def payout_method @payout_method end |
#transfer_up_to_amount ⇒ Object
The maximum amount in minor units to transfer to the FinancialAccount. Required and only applicable when ‘type` is `transfer_up_to_amount`.
12 13 14 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 12 def transfer_up_to_amount @transfer_up_to_amount end |
#type ⇒ Object
The type of automatic transfer rule.
14 15 16 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 14 def type @type end |