Class: Stripe::BalanceSettingsUpdateParams::Payments::SettlementTiming
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceSettingsUpdateParams::Payments::SettlementTiming
- Defined in:
- lib/stripe/params/balance_settings_update_params.rb
Defined Under Namespace
Classes: StartOfDay
Instance Attribute Summary collapse
-
#delay_days_override ⇒ Object
Change ‘delay_days` for this account, which determines the number of days charge funds are held before becoming available.
-
#start_of_day ⇒ Object
Customized start of day configuration for automatic payouts to group and send payments in local timezones with a customized day starting time.
Instance Method Summary collapse
-
#initialize(delay_days_override: nil, start_of_day: nil) ⇒ SettlementTiming
constructor
A new instance of SettlementTiming.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(delay_days_override: nil, start_of_day: nil) ⇒ SettlementTiming
Returns a new instance of SettlementTiming.
79 80 81 82 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 79 def initialize(delay_days_override: nil, start_of_day: nil) @delay_days_override = delay_days_override @start_of_day = start_of_day end |
Instance Attribute Details
#delay_days_override ⇒ Object
Change ‘delay_days` for this account, which determines the number of days charge funds are held before becoming available. The maximum value is 31. Passing an empty string to `delay_days_override` will return `delay_days` to the default, which is the lowest available value for the account. [Learn more about controlling delay days](/connect/manage-payout-schedule).
75 76 77 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 75 def delay_days_override @delay_days_override end |
#start_of_day ⇒ Object
Customized start of day configuration for automatic payouts to group and send payments in local timezones with a customized day starting time. For details, see our [Customized start of day](/connect/customized-start-of-day) documentation.
77 78 79 |
# File 'lib/stripe/params/balance_settings_update_params.rb', line 77 def start_of_day @start_of_day end |