Class: Stripe::BalanceTransactionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::BalanceTransactionService
- Defined in:
- lib/stripe/services/balance_transaction_service.rb
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of transactions that have contributed to the Stripe account balance (for example, charges, transfers, and so on).
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the balance transaction with the given ID.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
Returns a list of transactions that have contributed to the Stripe account balance (for example, charges, transfers, and so on). The transactions return in sorted order, with the most recent transactions appearing first.
The previous name of this endpoint was “Balance history,” and it used the path /v1/balance/history.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/balance_transaction_service.rb', line 9 def list(params = {}, opts = {}) request( method: :get, path: "/v1/balance_transactions", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the balance transaction with the given ID.
Note that this endpoint previously used the path /v1/balance/history/:id.
22 23 24 25 26 27 28 29 30 |
# File 'lib/stripe/services/balance_transaction_service.rb', line 22 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/balance_transactions/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |