Class: Stripe::BalanceTransferCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BalanceTransferCreateParams
- Defined in:
- lib/stripe/params/balance_transfer_create_params.rb
Defined Under Namespace
Classes: DestinationBalance, SourceBalance
Instance Attribute Summary collapse
-
#amount ⇒ Object
A positive integer representing how much to transfer in the smallest currency unit.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#destination_balance ⇒ Object
The balance to which funds are transferred.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#source_balance ⇒ Object
The balance from which funds are transferred, including details specific to the balance you choose.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, destination_balance: nil, expand: nil, metadata: nil, source_balance: nil) ⇒ BalanceTransferCreateParams
constructor
A new instance of BalanceTransferCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil, destination_balance: nil, expand: nil, metadata: nil, source_balance: nil) ⇒ BalanceTransferCreateParams
Returns a new instance of BalanceTransferCreateParams.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 50 def initialize( amount: nil, currency: nil, destination_balance: nil, expand: nil, metadata: nil, source_balance: nil ) @amount = amount @currency = currency @destination_balance = destination_balance @expand = @metadata = @source_balance = source_balance end |
Instance Attribute Details
#amount ⇒ Object
A positive integer representing how much to transfer in the smallest currency unit.
38 39 40 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 38 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
40 41 42 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 40 def currency @currency end |
#destination_balance ⇒ Object
The balance to which funds are transferred.
42 43 44 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 42 def destination_balance @destination_balance end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
44 45 46 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 44 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
46 47 48 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 46 def @metadata end |
#source_balance ⇒ Object
The balance from which funds are transferred, including details specific to the balance you choose.
48 49 50 |
# File 'lib/stripe/params/balance_transfer_create_params.rb', line 48 def source_balance @source_balance end |