Class: Stripe::BalanceTransferService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::BalanceTransferService
- Defined in:
- lib/stripe/services/balance_transfer_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a balance transfer.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a balance transfer. For Issuing use cases, funds will be debited immediately from the source balance and credited to the destination balance immediately (if your account is based in the US) or next-business-day (if your account is based in the EU). For Segregated Separate Charges and Transfers use cases, funds will be debited immediately from the source balance and credited immediately to the destination balance.
7 8 9 10 11 12 13 14 15 |
# File 'lib/stripe/services/balance_transfer_service.rb', line 7 def create(params = {}, opts = {}) request( method: :post, path: "/v1/balance_transfers", params: params, opts: opts, base_address: :api ) end |