Class: Stripe::Billing::Alert

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Defined in:
lib/stripe/resources/billing/alert.rb

Overview

A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed. For example, you might create a billing alert to notify you when a certain user made 100 API requests.

Defined Under Namespace

Classes: ActivateParams, ArchiveParams, CreateParams, CreditBalanceThreshold, DeactivateParams, ListParams, UsageThreshold

Constant Summary collapse

OBJECT_NAME =
"billing.alert"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alert_typeObject (readonly)

Defines the type of the alert.



326
327
328
# File 'lib/stripe/resources/billing/alert.rb', line 326

def alert_type
  @alert_type
end

#credit_balance_thresholdObject (readonly)

Encapsulates configuration of the alert to monitor billing credit balance.



328
329
330
# File 'lib/stripe/resources/billing/alert.rb', line 328

def credit_balance_threshold
  @credit_balance_threshold
end

#idObject (readonly)

Unique identifier for the object.



330
331
332
# File 'lib/stripe/resources/billing/alert.rb', line 330

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



332
333
334
# File 'lib/stripe/resources/billing/alert.rb', line 332

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



334
335
336
# File 'lib/stripe/resources/billing/alert.rb', line 334

def object
  @object
end

#statusObject (readonly)

Status of the alert. This can be active, inactive or archived.



336
337
338
# File 'lib/stripe/resources/billing/alert.rb', line 336

def status
  @status
end

#titleObject (readonly)

Title of the alert.



338
339
340
# File 'lib/stripe/resources/billing/alert.rb', line 338

def title
  @title
end

#usage_thresholdObject (readonly)

Encapsulates configuration of the alert to monitor usage on a specific [Billing Meter](stripe.com/docs/api/billing/meter).



340
341
342
# File 'lib/stripe/resources/billing/alert.rb', line 340

def usage_threshold
  @usage_threshold
end

Class Method Details

.activate(id, params = {}, opts = {}) ⇒ Object

Reactivates this alert, allowing it to trigger again.



353
354
355
356
357
358
359
360
# File 'lib/stripe/resources/billing/alert.rb', line 353

def self.activate(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/activate", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.archive(id, params = {}, opts = {}) ⇒ Object

Archives this alert, removing it from the list view and APIs. This is non-reversible.



373
374
375
376
377
378
379
380
# File 'lib/stripe/resources/billing/alert.rb', line 373

def self.archive(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/archive", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a billing alert



383
384
385
# File 'lib/stripe/resources/billing/alert.rb', line 383

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/billing/alerts", params: params, opts: opts)
end

.deactivate(id, params = {}, opts = {}) ⇒ Object

Deactivates this alert, preventing it from triggering.



398
399
400
401
402
403
404
405
# File 'lib/stripe/resources/billing/alert.rb', line 398

def self.deactivate(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/deactivate", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



419
420
421
# File 'lib/stripe/resources/billing/alert.rb', line 419

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



412
413
414
415
416
417
# File 'lib/stripe/resources/billing/alert.rb', line 412

def self.inner_class_types
  @inner_class_types = {
    credit_balance_threshold: CreditBalanceThreshold,
    usage_threshold: UsageThreshold,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Lists billing active and inactive alerts



408
409
410
# File 'lib/stripe/resources/billing/alert.rb', line 408

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/billing/alerts", params: params, opts: opts)
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/billing/alert.rb', line 12

def self.object_name
  "billing.alert"
end

Instance Method Details

#activate(params = {}, opts = {}) ⇒ Object

Reactivates this alert, allowing it to trigger again.



343
344
345
346
347
348
349
350
# File 'lib/stripe/resources/billing/alert.rb', line 343

def activate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/activate", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#archive(params = {}, opts = {}) ⇒ Object

Archives this alert, removing it from the list view and APIs. This is non-reversible.



363
364
365
366
367
368
369
370
# File 'lib/stripe/resources/billing/alert.rb', line 363

def archive(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/archive", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#deactivate(params = {}, opts = {}) ⇒ Object

Deactivates this alert, preventing it from triggering.



388
389
390
391
392
393
394
395
# File 'lib/stripe/resources/billing/alert.rb', line 388

def deactivate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/deactivate", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end