Class: Stripe::Billing::Alert
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Billing::Alert
- Extended by:
- APIOperations::Create, APIOperations::List
- Defined in:
- lib/stripe/resources/billing/alert.rb
Overview
A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed. For example, you might create a billing alert to notify you when a certain user made 100 API requests.
Defined Under Namespace
Classes: ActivateParams, ArchiveParams, CreateParams, DeactivateParams, ListParams, UsageThreshold
Constant Summary collapse
- OBJECT_NAME =
"billing.alert"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
readonly
Defines the type of the alert.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Status of the alert.
-
#title ⇒ Object
readonly
Title of the alert.
-
#usage_threshold ⇒ Object
readonly
Encapsulates configuration of the alert to monitor usage on a specific [Billing Meter](stripe.com/docs/api/billing/meter).
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.activate(id, params = {}, opts = {}) ⇒ Object
Reactivates this alert, allowing it to trigger again.
-
.archive(id, params = {}, opts = {}) ⇒ Object
Archives this alert, removing it from the list view and APIs.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a billing alert.
-
.deactivate(id, params = {}, opts = {}) ⇒ Object
Deactivates this alert, preventing it from triggering.
-
.list(params = {}, opts = {}) ⇒ Object
Lists billing active and inactive alerts.
- .object_name ⇒ Object
Instance Method Summary collapse
-
#activate(params = {}, opts = {}) ⇒ Object
Reactivates this alert, allowing it to trigger again.
-
#archive(params = {}, opts = {}) ⇒ Object
Archives this alert, removing it from the list view and APIs.
-
#deactivate(params = {}, opts = {}) ⇒ Object
Deactivates this alert, preventing it from triggering.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alert_type ⇒ Object (readonly)
Defines the type of the alert.
137 138 139 |
# File 'lib/stripe/resources/billing/alert.rb', line 137 def alert_type @alert_type end |
#id ⇒ Object (readonly)
Unique identifier for the object.
139 140 141 |
# File 'lib/stripe/resources/billing/alert.rb', line 139 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
141 142 143 |
# File 'lib/stripe/resources/billing/alert.rb', line 141 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
143 144 145 |
# File 'lib/stripe/resources/billing/alert.rb', line 143 def object @object end |
#status ⇒ Object (readonly)
Status of the alert. This can be active, inactive or archived.
145 146 147 |
# File 'lib/stripe/resources/billing/alert.rb', line 145 def status @status end |
#title ⇒ Object (readonly)
Title of the alert.
147 148 149 |
# File 'lib/stripe/resources/billing/alert.rb', line 147 def title @title end |
#usage_threshold ⇒ Object (readonly)
Encapsulates configuration of the alert to monitor usage on a specific [Billing Meter](stripe.com/docs/api/billing/meter).
149 150 151 |
# File 'lib/stripe/resources/billing/alert.rb', line 149 def usage_threshold @usage_threshold end |
Class Method Details
.activate(id, params = {}, opts = {}) ⇒ Object
Reactivates this alert, allowing it to trigger again.
162 163 164 165 166 167 168 169 |
# File 'lib/stripe/resources/billing/alert.rb', line 162 def self.activate(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/alerts/%<id>s/activate", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.archive(id, params = {}, opts = {}) ⇒ Object
Archives this alert, removing it from the list view and APIs. This is non-reversible.
182 183 184 185 186 187 188 189 |
# File 'lib/stripe/resources/billing/alert.rb', line 182 def self.archive(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/alerts/%<id>s/archive", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a billing alert
192 193 194 |
# File 'lib/stripe/resources/billing/alert.rb', line 192 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/billing/alerts", params: params, opts: opts) end |
.deactivate(id, params = {}, opts = {}) ⇒ Object
Deactivates this alert, preventing it from triggering.
207 208 209 210 211 212 213 214 |
# File 'lib/stripe/resources/billing/alert.rb', line 207 def self.deactivate(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/alerts/%<id>s/deactivate", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Lists billing active and inactive alerts
217 218 219 |
# File 'lib/stripe/resources/billing/alert.rb', line 217 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/billing/alerts", params: params, opts: opts) end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/billing/alert.rb', line 12 def self.object_name "billing.alert" end |
Instance Method Details
#activate(params = {}, opts = {}) ⇒ Object
Reactivates this alert, allowing it to trigger again.
152 153 154 155 156 157 158 159 |
# File 'lib/stripe/resources/billing/alert.rb', line 152 def activate(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/alerts/%<id>s/activate", { id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#archive(params = {}, opts = {}) ⇒ Object
Archives this alert, removing it from the list view and APIs. This is non-reversible.
172 173 174 175 176 177 178 179 |
# File 'lib/stripe/resources/billing/alert.rb', line 172 def archive(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/alerts/%<id>s/archive", { id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#deactivate(params = {}, opts = {}) ⇒ Object
Deactivates this alert, preventing it from triggering.
197 198 199 200 201 202 203 204 |
# File 'lib/stripe/resources/billing/alert.rb', line 197 def deactivate(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/alerts/%<id>s/deactivate", { id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |