Class: Stripe::Billing::Alert

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Defined in:
lib/stripe/resources/billing/alert.rb

Overview

A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed. For example, you might create a billing alert to notify you when a certain user made 100 API requests.

Defined Under Namespace

Classes: UsageThreshold

Constant Summary collapse

OBJECT_NAME =
"billing.alert"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alert_typeObject (readonly)

Defines the type of the alert.



23
24
25
# File 'lib/stripe/resources/billing/alert.rb', line 23

def alert_type
  @alert_type
end

#idObject (readonly)

Unique identifier for the object.



25
26
27
# File 'lib/stripe/resources/billing/alert.rb', line 25

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



27
28
29
# File 'lib/stripe/resources/billing/alert.rb', line 27

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



29
30
31
# File 'lib/stripe/resources/billing/alert.rb', line 29

def object
  @object
end

#statusObject (readonly)

Status of the alert. This can be active, inactive or archived.



31
32
33
# File 'lib/stripe/resources/billing/alert.rb', line 31

def status
  @status
end

#titleObject (readonly)

Title of the alert.



33
34
35
# File 'lib/stripe/resources/billing/alert.rb', line 33

def title
  @title
end

#usage_thresholdObject (readonly)

Encapsulates configuration of the alert to monitor usage on a specific [Billing Meter](stripe.com/docs/api/billing/meter).



35
36
37
# File 'lib/stripe/resources/billing/alert.rb', line 35

def usage_threshold
  @usage_threshold
end

Class Method Details

.activate(id, params = {}, opts = {}) ⇒ Object

Reactivates this alert, allowing it to trigger again.



48
49
50
51
52
53
54
55
# File 'lib/stripe/resources/billing/alert.rb', line 48

def self.activate(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/activate", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.archive(id, params = {}, opts = {}) ⇒ Object

Archives this alert, removing it from the list view and APIs. This is non-reversible.



68
69
70
71
72
73
74
75
# File 'lib/stripe/resources/billing/alert.rb', line 68

def self.archive(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/archive", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a billing alert



78
79
80
# File 'lib/stripe/resources/billing/alert.rb', line 78

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/billing/alerts", params: params, opts: opts)
end

.deactivate(id, params = {}, opts = {}) ⇒ Object

Deactivates this alert, preventing it from triggering.



93
94
95
96
97
98
99
100
# File 'lib/stripe/resources/billing/alert.rb', line 93

def self.deactivate(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/deactivate", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.list(filters = {}, opts = {}) ⇒ Object

Lists billing active and inactive alerts



103
104
105
# File 'lib/stripe/resources/billing/alert.rb', line 103

def self.list(filters = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/billing/alerts", params: filters, opts: opts)
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/billing/alert.rb', line 12

def self.object_name
  "billing.alert"
end

Instance Method Details

#activate(params = {}, opts = {}) ⇒ Object

Reactivates this alert, allowing it to trigger again.



38
39
40
41
42
43
44
45
# File 'lib/stripe/resources/billing/alert.rb', line 38

def activate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/activate", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#archive(params = {}, opts = {}) ⇒ Object

Archives this alert, removing it from the list view and APIs. This is non-reversible.



58
59
60
61
62
63
64
65
# File 'lib/stripe/resources/billing/alert.rb', line 58

def archive(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/archive", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#deactivate(params = {}, opts = {}) ⇒ Object

Deactivates this alert, preventing it from triggering.



83
84
85
86
87
88
89
90
# File 'lib/stripe/resources/billing/alert.rb', line 83

def deactivate(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/alerts/%<id>s/deactivate", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end