Class: Stripe::Billing::Alert::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Alert::CreateParams
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Classes: CreditBalanceThreshold, UsageThreshold
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
The type of alert to create.
-
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#title ⇒ Object
The title of the alert.
-
#usage_threshold ⇒ Object
The configuration of the usage threshold.
Instance Method Summary collapse
-
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/stripe/resources/billing/alert.rb', line 284 def initialize( alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil ) @alert_type = alert_type @credit_balance_threshold = credit_balance_threshold @expand = @title = title @usage_threshold = usage_threshold end |
Instance Attribute Details
#alert_type ⇒ Object
The type of alert to create.
274 275 276 |
# File 'lib/stripe/resources/billing/alert.rb', line 274 def alert_type @alert_type end |
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
276 277 278 |
# File 'lib/stripe/resources/billing/alert.rb', line 276 def credit_balance_threshold @credit_balance_threshold end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
278 279 280 |
# File 'lib/stripe/resources/billing/alert.rb', line 278 def @expand end |
#title ⇒ Object
The title of the alert.
280 281 282 |
# File 'lib/stripe/resources/billing/alert.rb', line 280 def title @title end |
#usage_threshold ⇒ Object
The configuration of the usage threshold.
282 283 284 |
# File 'lib/stripe/resources/billing/alert.rb', line 282 def usage_threshold @usage_threshold end |