Class: Stripe::Billing::Alert::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Alert::CreateParams
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Classes: UsageThreshold
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
The type of alert to create.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#title ⇒ Object
The title of the alert.
-
#usage_threshold ⇒ Object
The configuration of the usage threshold.
Instance Method Summary collapse
-
#initialize(alert_type: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(alert_type: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
118 119 120 121 122 123 |
# File 'lib/stripe/resources/billing/alert.rb', line 118 def initialize(alert_type: nil, expand: nil, title: nil, usage_threshold: nil) @alert_type = alert_type @expand = @title = title @usage_threshold = usage_threshold end |
Instance Attribute Details
#alert_type ⇒ Object
The type of alert to create.
107 108 109 |
# File 'lib/stripe/resources/billing/alert.rb', line 107 def alert_type @alert_type end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
110 111 112 |
# File 'lib/stripe/resources/billing/alert.rb', line 110 def @expand end |
#title ⇒ Object
The title of the alert.
113 114 115 |
# File 'lib/stripe/resources/billing/alert.rb', line 113 def title @title end |
#usage_threshold ⇒ Object
The configuration of the usage threshold.
116 117 118 |
# File 'lib/stripe/resources/billing/alert.rb', line 116 def usage_threshold @usage_threshold end |