Class: Stripe::Billing::Alert::CreateParams::CreditBalanceThreshold
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Alert::CreateParams::CreditBalanceThreshold
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#filters ⇒ Object
The filters allows limiting the scope of this credit balance alert.
-
#lte ⇒ Object
Defines at which value the alert will fire.
Instance Method Summary collapse
-
#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold
constructor
A new instance of CreditBalanceThreshold.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold
Returns a new instance of CreditBalanceThreshold.
175 176 177 178 |
# File 'lib/stripe/resources/billing/alert.rb', line 175 def initialize(filters: nil, lte: nil) @filters = filters @lte = lte end |
Instance Attribute Details
#filters ⇒ Object
The filters allows limiting the scope of this credit balance alert. You must specify a customer filter at this time.
171 172 173 |
# File 'lib/stripe/resources/billing/alert.rb', line 171 def filters @filters end |
#lte ⇒ Object
Defines at which value the alert will fire.
173 174 175 |
# File 'lib/stripe/resources/billing/alert.rb', line 173 def lte @lte end |