Class: Stripe::Billing::Alert::CreateParams::UsageThreshold
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Alert::CreateParams::UsageThreshold
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Classes: Filter
Instance Attribute Summary collapse
-
#filters ⇒ Object
The filters allows limiting the scope of this usage alert.
-
#gte ⇒ Object
Defines at which value the alert will fire.
-
#meter ⇒ Object
The [Billing Meter](/api/billing/meter) ID whose usage is monitored.
-
#recurrence ⇒ Object
Whether the alert should only fire only once, or once per billing cycle.
Instance Method Summary collapse
-
#initialize(filters: nil, gte: nil, meter: nil, recurrence: nil) ⇒ UsageThreshold
constructor
A new instance of UsageThreshold.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, gte: nil, meter: nil, recurrence: nil) ⇒ UsageThreshold
Returns a new instance of UsageThreshold.
99 100 101 102 103 104 |
# File 'lib/stripe/resources/billing/alert.rb', line 99 def initialize(filters: nil, gte: nil, meter: nil, recurrence: nil) @filters = filters @gte = gte @meter = meter @recurrence = recurrence end |
Instance Attribute Details
#filters ⇒ Object
The filters allows limiting the scope of this usage alert. You can only specify up to one filter at this time.
88 89 90 |
# File 'lib/stripe/resources/billing/alert.rb', line 88 def filters @filters end |
#gte ⇒ Object
Defines at which value the alert will fire.
91 92 93 |
# File 'lib/stripe/resources/billing/alert.rb', line 91 def gte @gte end |
#meter ⇒ Object
The [Billing Meter](/api/billing/meter) ID whose usage is monitored.
94 95 96 |
# File 'lib/stripe/resources/billing/alert.rb', line 94 def meter @meter end |
#recurrence ⇒ Object
Whether the alert should only fire only once, or once per billing cycle.
97 98 99 |
# File 'lib/stripe/resources/billing/alert.rb', line 97 def recurrence @recurrence end |