Class: Stripe::Billing::Alert::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/billing/alert.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(alert_type: nil, ending_before: nil, expand: nil, limit: nil, meter: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/stripe/resources/billing/alert.rb', line 56

def initialize(
  alert_type: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  meter: nil,
  starting_after: nil
)
  @alert_type = alert_type
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @meter = meter
  @starting_after = starting_after
end

Instance Attribute Details

#alert_typeObject

Filter results to only include this type of alert.



39
40
41
# File 'lib/stripe/resources/billing/alert.rb', line 39

def alert_type
  @alert_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



42
43
44
# File 'lib/stripe/resources/billing/alert.rb', line 42

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



45
46
47
# File 'lib/stripe/resources/billing/alert.rb', line 45

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



48
49
50
# File 'lib/stripe/resources/billing/alert.rb', line 48

def limit
  @limit
end

#meterObject

Filter results to only include alerts with the given meter.



51
52
53
# File 'lib/stripe/resources/billing/alert.rb', line 51

def meter
  @meter
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



54
55
56
# File 'lib/stripe/resources/billing/alert.rb', line 54

def starting_after
  @starting_after
end