Class: Stripe::Billing::Alert::SpendThreshold
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Billing::Alert::SpendThreshold
- Defined in:
- lib/stripe/resources/billing/alert.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#aggregation_period ⇒ Object
readonly
Defines the period over which spend is aggregated.
-
#filters ⇒ Object
readonly
Filters to scope the spend calculation.
-
#group_by ⇒ Object
readonly
Defines the granularity of spend aggregation.
-
#gte ⇒ Object
readonly
The threshold value configuration for a spend threshold alert.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#aggregation_period ⇒ Object (readonly)
Defines the period over which spend is aggregated.
238 239 240 |
# File 'lib/stripe/resources/billing/alert.rb', line 238 def aggregation_period @aggregation_period end |
#filters ⇒ Object (readonly)
Filters to scope the spend calculation.
240 241 242 |
# File 'lib/stripe/resources/billing/alert.rb', line 240 def filters @filters end |
#group_by ⇒ Object (readonly)
Defines the granularity of spend aggregation.
242 243 244 |
# File 'lib/stripe/resources/billing/alert.rb', line 242 def group_by @group_by end |
#gte ⇒ Object (readonly)
The threshold value configuration for a spend threshold alert.
244 245 246 |
# File 'lib/stripe/resources/billing/alert.rb', line 244 def gte @gte end |
Class Method Details
.field_remappings ⇒ Object
250 251 252 |
# File 'lib/stripe/resources/billing/alert.rb', line 250 def self.field_remappings @field_remappings = {} end |