Class: Stripe::Billing::Alert::UsageThreshold

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/billing/alert.rb

Defined Under Namespace

Classes: Filter

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#filtersObject (readonly)

The filters allow limiting the scope of this usage alert. You can only specify up to one filter at this time.



25
26
27
# File 'lib/stripe/resources/billing/alert.rb', line 25

def filters
  @filters
end

#gteObject (readonly)

The value at which this alert will trigger.



28
29
30
# File 'lib/stripe/resources/billing/alert.rb', line 28

def gte
  @gte
end

#meterObject (readonly)

The [Billing Meter](/api/billing/meter) ID whose usage is monitored.



31
32
33
# File 'lib/stripe/resources/billing/alert.rb', line 31

def meter
  @meter
end

#recurrenceObject (readonly)

Defines how the alert will behave.



34
35
36
# File 'lib/stripe/resources/billing/alert.rb', line 34

def recurrence
  @recurrence
end