Class: Stripe::Billing::AlertCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Defined Under Namespace
Classes: CreditBalanceThreshold, SpendThreshold, UsageThreshold
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
The type of alert to create.
-
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#spend_threshold ⇒ Object
The configuration of the spend threshold.
-
#title ⇒ Object
The title of the alert.
-
#usage_threshold ⇒ Object
The configuration of the usage threshold.
Instance Method Summary collapse
-
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, spend_threshold: nil, title: nil, usage_threshold: nil) ⇒ AlertCreateParams
constructor
A new instance of AlertCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, spend_threshold: nil, title: nil, usage_threshold: nil) ⇒ AlertCreateParams
Returns a new instance of AlertCreateParams.
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 237 def initialize( alert_type: nil, credit_balance_threshold: nil, expand: nil, spend_threshold: nil, title: nil, usage_threshold: nil ) @alert_type = alert_type @credit_balance_threshold = credit_balance_threshold @expand = @spend_threshold = spend_threshold @title = title @usage_threshold = usage_threshold end |
Instance Attribute Details
#alert_type ⇒ Object
The type of alert to create.
225 226 227 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 225 def alert_type @alert_type end |
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
227 228 229 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 227 def credit_balance_threshold @credit_balance_threshold end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
229 230 231 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 229 def @expand end |
#spend_threshold ⇒ Object
The configuration of the spend threshold. An event fires when the amount consumed exceeds the threshold, after all credits and discounts are applied but before tax is applied.
231 232 233 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 231 def spend_threshold @spend_threshold end |
#title ⇒ Object
The title of the alert.
233 234 235 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 233 def title @title end |
#usage_threshold ⇒ Object
The configuration of the usage threshold.
235 236 237 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 235 def usage_threshold @usage_threshold end |