Class: Stripe::Billing::AlertCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Defined Under Namespace
Classes: CreditBalanceThreshold, UsageThreshold
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
The type of alert to create.
-
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#title ⇒ Object
The title of the alert.
-
#usage_threshold ⇒ Object
The configuration of the usage threshold.
Instance Method Summary collapse
-
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ AlertCreateParams
constructor
A new instance of AlertCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ AlertCreateParams
Returns a new instance of AlertCreateParams.
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 157 def initialize( alert_type: nil, credit_balance_threshold: nil, expand: nil, title: nil, usage_threshold: nil ) @alert_type = alert_type @credit_balance_threshold = credit_balance_threshold @expand = @title = title @usage_threshold = usage_threshold end |
Instance Attribute Details
#alert_type ⇒ Object
The type of alert to create.
147 148 149 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 147 def alert_type @alert_type end |
#credit_balance_threshold ⇒ Object
The configuration of the credit balance threshold.
149 150 151 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 149 def credit_balance_threshold @credit_balance_threshold end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
151 152 153 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 151 def @expand end |
#title ⇒ Object
The title of the alert.
153 154 155 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 153 def title @title end |
#usage_threshold ⇒ Object
The configuration of the usage threshold.
155 156 157 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 155 def usage_threshold @usage_threshold end |