Class: Stripe::Billing::AlertCreateParams::CreditBalanceThreshold
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams::CreditBalanceThreshold
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#filters ⇒ Object
The filters allows limiting the scope of this credit balance alert.
-
#lte ⇒ Object
Defines at which value the alert will fire.
Instance Method Summary collapse
-
#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold
constructor
A new instance of CreditBalanceThreshold.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, lte: nil) ⇒ CreditBalanceThreshold
Returns a new instance of CreditBalanceThreshold.
112 113 114 115 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 112 def initialize(filters: nil, lte: nil) @filters = filters @lte = lte end |
Instance Attribute Details
#filters ⇒ Object
The filters allows limiting the scope of this credit balance alert. You must specify a customer filter at this time.
108 109 110 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 108 def filters @filters end |
#lte ⇒ Object
Defines at which value the alert will fire.
110 111 112 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 110 def lte @lte end |