Class: Stripe::Billing::AlertCreateParams::CreditBalanceThreshold::Filter
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams::CreditBalanceThreshold::Filter
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Defined Under Namespace
Classes: CreditGrants
Instance Attribute Summary collapse
-
#credit_grants ⇒ Object
The credit grants for which to configure the credit balance alert.
-
#customer ⇒ Object
Limit the scope to this credit balance alert only to this customer.
-
#type ⇒ Object
What type of filter is being applied to this credit balance alert.
Instance Method Summary collapse
-
#initialize(credit_grants: nil, customer: nil, type: nil) ⇒ Filter
constructor
A new instance of Filter.
Methods inherited from RequestParams
Constructor Details
#initialize(credit_grants: nil, customer: nil, type: nil) ⇒ Filter
Returns a new instance of Filter.
63 64 65 66 67 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 63 def initialize(credit_grants: nil, customer: nil, type: nil) @credit_grants = credit_grants @customer = customer @type = type end |
Instance Attribute Details
#credit_grants ⇒ Object
The credit grants for which to configure the credit balance alert.
57 58 59 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 57 def credit_grants @credit_grants end |
#customer ⇒ Object
Limit the scope to this credit balance alert only to this customer.
59 60 61 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 59 def customer @customer end |
#type ⇒ Object
What type of filter is being applied to this credit balance alert.
61 62 63 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 61 def type @type end |