Class: Stripe::Billing::AlertCreateParams::SpendThreshold::Gte::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams::SpendThreshold::Gte::CustomPricingUnit
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the custom pricing unit.
-
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
161 162 163 164 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 161 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The ID of the custom pricing unit.
157 158 159 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 157 def id @id end |
#value ⇒ Object
A positive decimal string representing the amount of the custom pricing unit threshold.
159 160 161 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 159 def value @value end |