Class: Stripe::Billing::AlertCreateParams::UsageThreshold::Filter
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams::UsageThreshold::Filter
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
Limit the scope to this usage alert only to this customer.
-
#type ⇒ Object
What type of filter is being applied to this usage alert.
Instance Method Summary collapse
-
#initialize(customer: nil, type: nil) ⇒ Filter
constructor
A new instance of Filter.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, type: nil) ⇒ Filter
Returns a new instance of Filter.
203 204 205 206 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 203 def initialize(customer: nil, type: nil) @customer = customer @type = type end |
Instance Attribute Details
#customer ⇒ Object
Limit the scope to this usage alert only to this customer.
199 200 201 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 199 def customer @customer end |
#type ⇒ Object
What type of filter is being applied to this usage alert.
201 202 203 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 201 def type @type end |