Class: Stripe::Billing::AlertCreateParams::UsageThreshold::Filter
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertCreateParams::UsageThreshold::Filter
- Defined in:
- lib/stripe/params/billing/alert_create_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
Limit the scope to this usage alert only to this customer.
-
#type ⇒ Object
What type of filter is being applied to this usage alert.
Instance Method Summary collapse
-
#initialize(customer: nil, type: nil) ⇒ Filter
constructor
A new instance of Filter.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, type: nil) ⇒ Filter
Returns a new instance of Filter.
125 126 127 128 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 125 def initialize(customer: nil, type: nil) @customer = customer @type = type end |
Instance Attribute Details
#customer ⇒ Object
Limit the scope to this usage alert only to this customer.
121 122 123 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 121 def customer @customer end |
#type ⇒ Object
What type of filter is being applied to this usage alert.
123 124 125 |
# File 'lib/stripe/params/billing/alert_create_params.rb', line 123 def type @type end |