Class: Stripe::Billing::AlertNotificationListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertNotificationListParams
- Defined in:
- lib/stripe/params/billing/alert_notification_list_params.rb
Defined Under Namespace
Classes: NotifiedAt
Instance Attribute Summary collapse
-
#action ⇒ Object
Filter results to only include triggered or recovered notifications.
-
#cadence ⇒ Object
Filter results to only include notifications for the given billing cadence.
-
#customer ⇒ Object
The customer to list notifications for.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#meter ⇒ Object
Filter results to only include notifications for the given meter.
-
#notified_at ⇒ Object
Filter results according to when the notification was sent.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#subscription ⇒ Object
Filter results to only include notifications for the given subscription.
Instance Method Summary collapse
-
#initialize(action: nil, cadence: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, meter: nil, notified_at: nil, starting_after: nil, subscription: nil) ⇒ AlertNotificationListParams
constructor
A new instance of AlertNotificationListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(action: nil, cadence: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, meter: nil, notified_at: nil, starting_after: nil, subscription: nil) ⇒ AlertNotificationListParams
Returns a new instance of AlertNotificationListParams.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 45 def initialize( action: nil, cadence: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, meter: nil, notified_at: nil, starting_after: nil, subscription: nil ) @action = action @cadence = cadence @customer = customer @ending_before = ending_before @expand = @limit = limit @meter = meter @notified_at = notified_at @starting_after = starting_after @subscription = subscription end |
Instance Attribute Details
#action ⇒ Object
Filter results to only include triggered or recovered notifications.
25 26 27 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 25 def action @action end |
#cadence ⇒ Object
Filter results to only include notifications for the given billing cadence.
27 28 29 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 27 def cadence @cadence end |
#customer ⇒ Object
The customer to list notifications for.
29 30 31 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 29 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ending_before is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with obj_bar, your subsequent call can include ending_before=obj_bar in order to fetch the previous page of the list.
31 32 33 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 31 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
33 34 35 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 33 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
35 36 37 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 35 def limit @limit end |
#meter ⇒ Object
Filter results to only include notifications for the given meter.
37 38 39 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 37 def meter @meter end |
#notified_at ⇒ Object
Filter results according to when the notification was sent.
39 40 41 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 39 def notified_at @notified_at end |
#starting_after ⇒ Object
A cursor for use in pagination. starting_after is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with obj_foo, your subsequent call can include starting_after=obj_foo in order to fetch the next page of the list.
41 42 43 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 41 def starting_after @starting_after end |
#subscription ⇒ Object
Filter results to only include notifications for the given subscription.
43 44 45 |
# File 'lib/stripe/params/billing/alert_notification_list_params.rb', line 43 def subscription @subscription end |