Class: Stripe::Billing::AlertService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::AlertService::CreateParams
- Defined in:
- lib/stripe/services/billing/alert_service.rb
Defined Under Namespace
Classes: UsageThreshold
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
The type of alert to create.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#title ⇒ Object
The title of the alert.
-
#usage_threshold ⇒ Object
The configuration of the usage threshold.
Instance Method Summary collapse
-
#initialize(alert_type: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(alert_type: nil, expand: nil, title: nil, usage_threshold: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
76 77 78 79 80 81 |
# File 'lib/stripe/services/billing/alert_service.rb', line 76 def initialize(alert_type: nil, expand: nil, title: nil, usage_threshold: nil) @alert_type = alert_type @expand = @title = title @usage_threshold = usage_threshold end |
Instance Attribute Details
#alert_type ⇒ Object
The type of alert to create.
68 69 70 |
# File 'lib/stripe/services/billing/alert_service.rb', line 68 def alert_type @alert_type end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
70 71 72 |
# File 'lib/stripe/services/billing/alert_service.rb', line 70 def @expand end |
#title ⇒ Object
The title of the alert.
72 73 74 |
# File 'lib/stripe/services/billing/alert_service.rb', line 72 def title @title end |
#usage_threshold ⇒ Object
The configuration of the usage threshold.
74 75 76 |
# File 'lib/stripe/services/billing/alert_service.rb', line 74 def usage_threshold @usage_threshold end |