Class: Stripe::Billing::AlertTriggered
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Billing::AlertTriggered
- Defined in:
- lib/stripe/resources/billing/alert_triggered.rb
Defined Under Namespace
Classes: AggregationPeriod, GroupBy
Constant Summary collapse
- OBJECT_NAME =
"billing.alert_triggered"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#aggregation_period ⇒ Object
readonly
The aggregation period for which this alert triggered.
-
#alert ⇒ Object
readonly
A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Currency for the threshold value.
-
#custom_pricing_unit ⇒ Object
readonly
Custom pricing unit for the threshold value.
-
#customer ⇒ Object
readonly
ID of customer for which the alert triggered.
-
#external_customer_id ⇒ Object
readonly
External customer ID for the customer for which the alert triggered.
-
#group_by ⇒ Object
readonly
Populated specifically for spend alerts to notify merchants which group_by entity has the exceeded spend.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#triggered_at ⇒ Object
readonly
Timestamp at which the threshold was crossed.
-
#value ⇒ Object
readonly
The value triggering the alert.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#aggregation_period ⇒ Object (readonly)
The aggregation period for which this alert triggered
62 63 64 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 62 def aggregation_period @aggregation_period end |
#alert ⇒ Object (readonly)
A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed. For example, you might create a billing alert to notify you when a certain user made 100 API requests.
44 45 46 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 44 def alert @alert end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
46 47 48 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 46 def created @created end |
#currency ⇒ Object (readonly)
Currency for the threshold value
48 49 50 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 48 def currency @currency end |
#custom_pricing_unit ⇒ Object (readonly)
Custom pricing unit for the threshold value
50 51 52 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 50 def custom_pricing_unit @custom_pricing_unit end |
#customer ⇒ Object (readonly)
ID of customer for which the alert triggered
52 53 54 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 52 def customer @customer end |
#external_customer_id ⇒ Object (readonly)
External customer ID for the customer for which the alert triggered
54 55 56 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 54 def external_customer_id @external_customer_id end |
#group_by ⇒ Object (readonly)
Populated specifically for spend alerts to notify merchants which group_by entity has the exceeded spend
64 65 66 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 64 def group_by @group_by end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
56 57 58 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 56 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
58 59 60 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 58 def object @object end |
#triggered_at ⇒ Object (readonly)
Timestamp at which the threshold was crossed
66 67 68 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 66 def triggered_at @triggered_at end |
#value ⇒ Object (readonly)
The value triggering the alert
60 61 62 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 60 def value @value end |
Class Method Details
.field_remappings ⇒ Object
72 73 74 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 72 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
68 69 70 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 68 def self.inner_class_types @inner_class_types = { aggregation_period: AggregationPeriod, group_by: GroupBy } end |
.object_name ⇒ Object
8 9 10 |
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 8 def self.object_name "billing.alert_triggered" end |