Class: Stripe::Billing::AlertTriggered

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/billing/alert_triggered.rb

Constant Summary collapse

OBJECT_NAME =
"billing.alert_triggered"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#alertObject (readonly)

A billing alert is a resource that notifies you when a certain usage threshold on a meter is crossed. For example, you might create a billing alert to notify you when a certain user made 100 API requests.



13
14
15
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 13

def alert
  @alert
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



16
17
18
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 16

def created
  @created
end

#customerObject (readonly)

ID of customer for which the alert triggered



19
20
21
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 19

def customer
  @customer
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



22
23
24
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 22

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



25
26
27
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 25

def object
  @object
end

#valueObject (readonly)

The value triggering the alert



28
29
30
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 28

def value
  @value
end

Class Method Details

.object_nameObject



8
9
10
# File 'lib/stripe/resources/billing/alert_triggered.rb', line 8

def self.object_name
  "billing.alert_triggered"
end