Class: Stripe::Billing::Analytics::MeterUsageRow
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Billing::Analytics::MeterUsageRow
- Defined in:
- lib/stripe/resources/billing/analytics/meter_usage_row.rb
Constant Summary collapse
- OBJECT_NAME =
"billing.analytics.meter_usage_row"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#dimensions ⇒ Object
readonly
A set of key-value pairs representing the dimensions of the meter usage.
-
#ends_at ⇒ Object
readonly
Timestamp indicating the end of the bucket.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#meter ⇒ Object
readonly
The unique identifier for the meter.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#starts_at ⇒ Object
readonly
Timestamp indicating the start of the bucket.
-
#value ⇒ Object
readonly
The aggregated meter usage value for the specified bucket.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#dimensions ⇒ Object (readonly)
A set of key-value pairs representing the dimensions of the meter usage.
14 15 16 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 14 def dimensions @dimensions end |
#ends_at ⇒ Object (readonly)
Timestamp indicating the end of the bucket. Measured in seconds since the Unix epoch.
16 17 18 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 16 def ends_at @ends_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
18 19 20 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 18 def id @id end |
#meter ⇒ Object (readonly)
The unique identifier for the meter. Null if no meters were provided and usage was aggregated across all meters.
20 21 22 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 20 def meter @meter end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
22 23 24 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 22 def object @object end |
#starts_at ⇒ Object (readonly)
Timestamp indicating the start of the bucket. Measured in seconds since the Unix epoch.
24 25 26 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 24 def starts_at @starts_at end |
#value ⇒ Object (readonly)
The aggregated meter usage value for the specified bucket.
26 27 28 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 26 def value @value end |
Class Method Details
.field_remappings ⇒ Object
32 33 34 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 32 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
28 29 30 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 28 def self.inner_class_types @inner_class_types = {} end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/billing/analytics/meter_usage_row.rb', line 9 def self.object_name "billing.analytics.meter_usage_row" end |