Class: Stripe::Billing::CreditBalanceSummary

Inherits:
SingletonAPIResource show all
Defined in:
lib/stripe/resources/billing/credit_balance_summary.rb

Overview

Indicates the billing credit balance for billing credits granted to a customer.

Defined Under Namespace

Classes: Balance

Constant Summary collapse

OBJECT_NAME =
"billing.credit_balance_summary"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from SingletonAPIResource

resource_url, #resource_url, retrieve

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balancesObject (readonly)

The billing credit balances. One entry per credit grant currency. If a customer only has credit grants in a single currency, then this will have a single balance entry.



233
234
235
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 233

def balances
  @balances
end

#customerObject (readonly)

The customer the balance is for.



235
236
237
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 235

def customer
  @customer
end

#customer_accountObject (readonly)

The account the balance is for.



237
238
239
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 237

def 
  @customer_account
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



239
240
241
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 239

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



241
242
243
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 241

def object
  @object
end

Class Method Details

.field_encodingsObject



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 251

def self.field_encodings
  @field_encodings = {
    balances: {
      kind: :array,
      element: {
        kind: :object,
        fields: {
          available_balance: {
            kind: :object,
            fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } },
          },
          ledger_balance: {
            kind: :object,
            fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } },
          },
        },
      },
    },
  }
end

.field_remappingsObject



247
248
249
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 247

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



243
244
245
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 243

def self.inner_class_types
  @inner_class_types = { balances: Balance }
end

.object_nameObject



9
10
11
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 9

def self.object_name
  "billing.credit_balance_summary"
end