Class: Stripe::Billing::CreditBalanceSummary::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_balance_summary.rb

Defined Under Namespace

Classes: Filter

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, expand: nil, filter: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



75
76
77
78
79
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 75

def initialize(customer: nil, expand: nil, filter: nil)
  @customer = customer
  @expand = expand
  @filter = filter
end

Instance Attribute Details

#customerObject

The customer for which to fetch credit balance summary.



69
70
71
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 69

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



71
72
73
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 71

def expand
  @expand
end

#filterObject

The filter criteria for the credit balance summary.



73
74
75
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 73

def filter
  @filter
end