Class: Stripe::Billing::CreditBalanceSummary::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditBalanceSummary::RetrieveParams
- Defined in:
- lib/stripe/resources/billing/credit_balance_summary.rb
Defined Under Namespace
Classes: Filter
Instance Attribute Summary collapse
-
#customer ⇒ Object
The customer for which to fetch credit balance summary.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#filter ⇒ Object
The filter criteria for the credit balance summary.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil, filter: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, expand: nil, filter: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
75 76 77 78 79 |
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 75 def initialize(customer: nil, expand: nil, filter: nil) @customer = customer @expand = @filter = filter end |
Instance Attribute Details
#customer ⇒ Object
The customer for which to fetch credit balance summary.
69 70 71 |
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 69 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
71 72 73 |
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 71 def @expand end |
#filter ⇒ Object
The filter criteria for the credit balance summary.
73 74 75 |
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 73 def filter @filter end |