Class: Stripe::Billing::CreditBalanceSummary::RetrieveParams::Filter

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_balance_summary.rb

Defined Under Namespace

Classes: ApplicabilityScope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applicability_scope: nil, credit_grant: nil, type: nil) ⇒ Filter

Returns a new instance of Filter.



69
70
71
72
73
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 69

def initialize(applicability_scope: nil, credit_grant: nil, type: nil)
  @applicability_scope = applicability_scope
  @credit_grant = credit_grant
  @type = type
end

Instance Attribute Details

#applicability_scopeObject

The billing credit applicability scope for which to fetch credit balance summary.



61
62
63
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 61

def applicability_scope
  @applicability_scope
end

#credit_grantObject

The credit grant for which to fetch credit balance summary.



64
65
66
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 64

def credit_grant
  @credit_grant
end

#typeObject

Specify the type of this filter.



67
68
69
# File 'lib/stripe/resources/billing/credit_balance_summary.rb', line 67

def type
  @type
end