Class: Stripe::Billing::CreditBalanceSummaryRetrieveParams::Filter

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb

Defined Under Namespace

Classes: ApplicabilityScope

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(applicability_scope: nil, credit_grant: nil, type: nil) ⇒ Filter

Returns a new instance of Filter.



46
47
48
49
50
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 46

def initialize(applicability_scope: nil, credit_grant: nil, type: nil)
  @applicability_scope = applicability_scope
  @credit_grant = credit_grant
  @type = type
end

Instance Attribute Details

#applicability_scopeObject

The billing credit applicability scope for which to fetch credit balance summary.



40
41
42
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 40

def applicability_scope
  @applicability_scope
end

#credit_grantObject

The credit grant for which to fetch credit balance summary.



42
43
44
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 42

def credit_grant
  @credit_grant
end

#typeObject

Specify the type of this filter.



44
45
46
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 44

def type
  @type
end