Class: Stripe::Billing::CreditBalanceSummaryRetrieveParams::Filter::ApplicabilityScope

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb

Defined Under Namespace

Classes: BillableItem, Price

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billable_items: nil, price_type: nil, prices: nil) ⇒ ApplicabilityScope

Returns a new instance of ApplicabilityScope.



33
34
35
36
37
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 33

def initialize(billable_items: nil, price_type: nil, prices: nil)
  @billable_items = billable_items
  @price_type = price_type
  @prices = prices
end

Instance Attribute Details

#billable_itemsObject

A list of billable items that the credit grant can apply to. We currently only support metered billable items. Cannot be used in combination with ‘price_type` or `prices`.



27
28
29
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 27

def billable_items
  @billable_items
end

#price_typeObject

The price type that credit grants can apply to. We currently only support the ‘metered` price type. Cannot be used in combination with `prices`.



29
30
31
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 29

def price_type
  @price_type
end

#pricesObject

A list of prices that the credit grant can apply to. We currently only support the ‘metered` prices. Cannot be used in combination with `price_type`.



31
32
33
# File 'lib/stripe/params/billing/credit_balance_summary_retrieve_params.rb', line 31

def prices
  @prices
end