Class: Stripe::Billing::CreditBalanceSummaryService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditBalanceSummaryService::RetrieveParams
- Defined in:
- lib/stripe/services/billing/credit_balance_summary_service.rb
Defined Under Namespace
Classes: Filter
Instance Attribute Summary collapse
-
#customer ⇒ Object
The customer for which to fetch credit balance summary.
-
#customer_account ⇒ Object
The account for which to fetch credit balance summary.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#filter ⇒ Object
The filter criteria for the credit balance summary.
Instance Method Summary collapse
-
#initialize(customer: nil, customer_account: nil, expand: nil, filter: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, customer_account: nil, expand: nil, filter: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
62 63 64 65 66 67 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 62 def initialize(customer: nil, customer_account: nil, expand: nil, filter: nil) @customer = customer @customer_account = customer_account @expand = @filter = filter end |
Instance Attribute Details
#customer ⇒ Object
The customer for which to fetch credit balance summary.
54 55 56 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 54 def customer @customer end |
#customer_account ⇒ Object
The account for which to fetch credit balance summary.
56 57 58 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 56 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
58 59 60 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 58 def @expand end |
#filter ⇒ Object
The filter criteria for the credit balance summary.
60 61 62 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 60 def filter @filter end |