Class: Stripe::Billing::CreditBalanceSummaryService::RetrieveParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing/credit_balance_summary_service.rb

Defined Under Namespace

Classes: Filter

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, customer_account: nil, expand: nil, filter: nil) ⇒ RetrieveParams

Returns a new instance of RetrieveParams.



50
51
52
53
54
55
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 50

def initialize(customer: nil, customer_account: nil, expand: nil, filter: nil)
  @customer = customer
  @customer_account = 
  @expand = expand
  @filter = filter
end

Instance Attribute Details

#customerObject

The customer for which to fetch credit balance summary.



42
43
44
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 42

def customer
  @customer
end

#customer_accountObject

The account for which to fetch credit balance summary.



44
45
46
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 44

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



46
47
48
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 46

def expand
  @expand
end

#filterObject

The filter criteria for the credit balance summary.



48
49
50
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 48

def filter
  @filter
end