Class: Stripe::Billing::CreditBalanceSummaryService::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditBalanceSummaryService::RetrieveParams
- Defined in:
- lib/stripe/services/billing/credit_balance_summary_service.rb
Defined Under Namespace
Classes: Filter
Instance Attribute Summary collapse
-
#customer ⇒ Object
The customer for which to fetch credit balance summary.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#filter ⇒ Object
The filter criteria for the credit balance summary.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil, filter: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, expand: nil, filter: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
37 38 39 40 41 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 37 def initialize(customer: nil, expand: nil, filter: nil) @customer = customer @expand = @filter = filter end |
Instance Attribute Details
#customer ⇒ Object
The customer for which to fetch credit balance summary.
31 32 33 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 31 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
33 34 35 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 33 def @expand end |
#filter ⇒ Object
The filter criteria for the credit balance summary.
35 36 37 |
# File 'lib/stripe/services/billing/credit_balance_summary_service.rb', line 35 def filter @filter end |