Class: Stripe::Billing::CreditBalanceTransaction

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/billing/credit_balance_transaction.rb

Overview

A credit balance transaction is a resource representing a transaction (either a credit or a debit) against an existing credit grant.

Defined Under Namespace

Classes: Credit, Debit

Constant Summary collapse

OBJECT_NAME =
"billing.credit_balance_transaction"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



220
221
222
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 220

def created
  @created
end

#creditObject (readonly)

Credit details for this credit balance transaction. Only present if type is ‘credit`.



222
223
224
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 222

def credit
  @credit
end

#credit_grantObject (readonly)

The credit grant associated with this credit balance transaction.



224
225
226
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 224

def credit_grant
  @credit_grant
end

#debitObject (readonly)

Debit details for this credit balance transaction. Only present if type is ‘debit`.



226
227
228
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 226

def debit
  @debit
end

#effective_atObject (readonly)

The effective time of this credit balance transaction.



228
229
230
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 228

def effective_at
  @effective_at
end

#idObject (readonly)

Unique identifier for the object.



230
231
232
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 230

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



232
233
234
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 232

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



234
235
236
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 234

def object
  @object
end

#test_clockObject (readonly)

ID of the test clock this credit balance transaction belongs to.



236
237
238
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 236

def test_clock
  @test_clock
end

#typeObject (readonly)

The type of credit balance transaction (credit or debit).



238
239
240
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 238

def type
  @type
end

Class Method Details

.field_remappingsObject



254
255
256
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 254

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



250
251
252
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 250

def self.inner_class_types
  @inner_class_types = { credit: Credit, debit: Debit }
end

.list(params = {}, opts = {}) ⇒ Object

Retrieve a list of credit balance transactions.



241
242
243
244
245
246
247
248
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 241

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/billing/credit_balance_transactions",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 11

def self.object_name
  "billing.credit_balance_transaction"
end