Class: Stripe::Billing::CreditBalanceTransaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Billing::CreditBalanceTransaction
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/billing/credit_balance_transaction.rb
Overview
A credit balance transaction is a resource representing a transaction (either a credit or a debit) against an existing credit grant.
Defined Under Namespace
Classes: Credit, Debit, ListParams
Constant Summary collapse
- OBJECT_NAME =
"billing.credit_balance_transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#credit ⇒ Object
readonly
Credit details for this credit balance transaction.
-
#credit_grant ⇒ Object
readonly
The credit grant associated with this credit balance transaction.
-
#debit ⇒ Object
readonly
Debit details for this credit balance transaction.
-
#effective_at ⇒ Object
readonly
The effective time of this credit balance transaction.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#test_clock ⇒ Object
readonly
ID of the test clock this credit balance transaction belongs to.
-
#type ⇒ Object
readonly
The type of credit balance transaction (credit or debit).
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Retrieve a list of credit balance transactions.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
255 256 257 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 255 def created @created end |
#credit ⇒ Object (readonly)
Credit details for this credit balance transaction. Only present if type is ‘credit`.
257 258 259 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 257 def credit @credit end |
#credit_grant ⇒ Object (readonly)
The credit grant associated with this credit balance transaction.
259 260 261 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 259 def credit_grant @credit_grant end |
#debit ⇒ Object (readonly)
Debit details for this credit balance transaction. Only present if type is ‘debit`.
261 262 263 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 261 def debit @debit end |
#effective_at ⇒ Object (readonly)
The effective time of this credit balance transaction.
263 264 265 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 263 def effective_at @effective_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
265 266 267 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 265 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
267 268 269 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 267 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
269 270 271 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 269 def object @object end |
#test_clock ⇒ Object (readonly)
ID of the test clock this credit balance transaction belongs to.
271 272 273 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 271 def test_clock @test_clock end |
#type ⇒ Object (readonly)
The type of credit balance transaction (credit or debit).
273 274 275 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 273 def type @type end |
Class Method Details
.field_remappings ⇒ Object
289 290 291 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 289 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
285 286 287 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 285 def self.inner_class_types @inner_class_types = { credit: Credit, debit: Debit } end |
.list(params = {}, opts = {}) ⇒ Object
Retrieve a list of credit balance transactions.
276 277 278 279 280 281 282 283 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 276 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/billing/credit_balance_transactions", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 11 def self.object_name "billing.credit_balance_transaction" end |