Class: Stripe::Billing::CreditBalanceTransaction::Credit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Billing::CreditBalanceTransaction::Credit
- Defined in:
- lib/stripe/resources/billing/credit_balance_transaction.rb
Defined Under Namespace
Classes: Amount, CreditsApplicationInvoiceVoided
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Attribute for field amount.
-
#credits_application_invoice_voided ⇒ Object
readonly
Details of the invoice to which the reinstated credits were originally applied.
-
#type ⇒ Object
readonly
The type of credit transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Attribute for field amount
111 112 113 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 111 def amount @amount end |
#credits_application_invoice_voided ⇒ Object (readonly)
Details of the invoice to which the reinstated credits were originally applied. Only present if ‘type` is `credits_application_invoice_voided`.
113 114 115 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 113 def credits_application_invoice_voided @credits_application_invoice_voided end |
#type ⇒ Object (readonly)
The type of credit transaction.
115 116 117 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 115 def type @type end |
Class Method Details
.field_encodings ⇒ Object
128 129 130 131 132 133 134 135 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 128 def self.field_encodings @field_encodings = { amount: { kind: :object, fields: { custom_pricing_unit: { kind: :object, fields: { value: :decimal_string } } }, }, } end |
.field_remappings ⇒ Object
124 125 126 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 124 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
117 118 119 120 121 122 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 117 def self.inner_class_types @inner_class_types = { amount: Amount, credits_application_invoice_voided: CreditsApplicationInvoiceVoided, } end |