Class: Stripe::Billing::CreditBalanceTransaction::Credit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Billing::CreditBalanceTransaction::Credit
- Defined in:
- lib/stripe/resources/billing/credit_balance_transaction.rb
Defined Under Namespace
Classes: Amount, CreditsApplicationInvoiceVoided
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Attribute for field amount.
-
#credits_application_invoice_voided ⇒ Object
readonly
Details of the invoice to which the reinstated credits were originally applied.
-
#type ⇒ Object
readonly
The type of credit transaction.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Attribute for field amount
61 62 63 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 61 def amount @amount end |
#credits_application_invoice_voided ⇒ Object (readonly)
Details of the invoice to which the reinstated credits were originally applied. Only present if ‘type` is `credits_application_invoice_voided`.
63 64 65 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 63 def credits_application_invoice_voided @credits_application_invoice_voided end |
#type ⇒ Object (readonly)
The type of credit transaction.
65 66 67 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 65 def type @type end |