Class: Stripe::Billing::CreditBalanceTransaction::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_balance_transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(credit_grant: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 85

def initialize(
  credit_grant: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @credit_grant = credit_grant
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#credit_grantObject

The credit grant for which to fetch credit balance transactions.



73
74
75
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 73

def credit_grant
  @credit_grant
end

#customerObject

The customer for which to fetch credit balance transactions.



75
76
77
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 75

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



77
78
79
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 77

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



79
80
81
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 79

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



81
82
83
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 81

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



83
84
85
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 83

def starting_after
  @starting_after
end