Class: Stripe::Billing::CreditBalanceTransaction::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditBalanceTransaction::ListParams
- Defined in:
- lib/stripe/resources/billing/credit_balance_transaction.rb
Instance Attribute Summary collapse
-
#credit_grant ⇒ Object
The credit grant for which to fetch credit balance transactions.
-
#customer ⇒ Object
The customer for which to fetch credit balance transactions.
-
#customer_account ⇒ Object
The account for which to fetch credit balance transactions.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(credit_grant: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(credit_grant: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 87 def initialize( credit_grant: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @credit_grant = credit_grant @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#credit_grant ⇒ Object
The credit grant for which to fetch credit balance transactions.
73 74 75 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 73 def credit_grant @credit_grant end |
#customer ⇒ Object
The customer for which to fetch credit balance transactions.
75 76 77 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 75 def customer @customer end |
#customer_account ⇒ Object
The account for which to fetch credit balance transactions.
77 78 79 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 77 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
79 80 81 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 79 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
81 82 83 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 81 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
83 84 85 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 83 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
85 86 87 |
# File 'lib/stripe/resources/billing/credit_balance_transaction.rb', line 85 def starting_after @starting_after end |