Class: Stripe::Billing::CreditGrant
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Billing::CreditGrant
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/billing/credit_grant.rb
Overview
A credit grant is an API resource that documents the allocation of some billing credits to a customer.
Related guide: [Billing credits](docs.stripe.com/billing/subscriptions/usage-based/billing-credits)
Defined Under Namespace
Classes: Amount, ApplicabilityConfig
Constant Summary collapse
- OBJECT_NAME =
"billing.credit_grant"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Attribute for field amount.
-
#applicability_config ⇒ Object
readonly
Attribute for field applicability_config.
-
#category ⇒ Object
readonly
The category of this credit grant.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
ID of the customer receiving the billing credits.
-
#customer_account ⇒ Object
readonly
ID of the account representing the customer receiving the billing credits.
-
#effective_at ⇒ Object
readonly
The time when the billing credits become effective-when they’re eligible for use.
-
#expires_at ⇒ Object
readonly
The time when the billing credits expire.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
A descriptive name shown in dashboard.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#priority ⇒ Object
readonly
The priority for applying this credit grant.
-
#test_clock ⇒ Object
readonly
ID of the test clock this credit grant belongs to.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
-
#voided_at ⇒ Object
readonly
The time when this credit grant was voided.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a credit grant.
-
.expire(id, params = {}, opts = {}) ⇒ Object
Expires a credit grant.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Retrieve a list of credit grants.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates a credit grant.
-
.void_grant(id, params = {}, opts = {}) ⇒ Object
Voids a credit grant.
Instance Method Summary collapse
-
#expire(params = {}, opts = {}) ⇒ Object
Expires a credit grant.
-
#void_grant(params = {}, opts = {}) ⇒ Object
Voids a credit grant.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Attribute for field amount
143 144 145 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 143 def amount @amount end |
#applicability_config ⇒ Object (readonly)
Attribute for field applicability_config
145 146 147 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 145 def applicability_config @applicability_config end |
#category ⇒ Object (readonly)
The category of this credit grant. This is for tracking purposes and isn’t displayed to the customer.
147 148 149 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 147 def category @category end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
149 150 151 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 149 def created @created end |
#customer ⇒ Object (readonly)
ID of the customer receiving the billing credits.
151 152 153 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 151 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the account representing the customer receiving the billing credits
153 154 155 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 153 def customer_account @customer_account end |
#effective_at ⇒ Object (readonly)
The time when the billing credits become effective-when they’re eligible for use.
155 156 157 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 155 def effective_at @effective_at end |
#expires_at ⇒ Object (readonly)
The time when the billing credits expire. If not present, the billing credits don’t expire.
157 158 159 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 157 def expires_at @expires_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
159 160 161 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 159 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
161 162 163 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 161 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
163 164 165 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 163 def @metadata end |
#name ⇒ Object (readonly)
A descriptive name shown in dashboard.
165 166 167 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 165 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
167 168 169 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 167 def object @object end |
#priority ⇒ Object (readonly)
The priority for applying this credit grant. The highest priority is 0 and the lowest is 100.
169 170 171 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 169 def priority @priority end |
#test_clock ⇒ Object (readonly)
ID of the test clock this credit grant belongs to.
171 172 173 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 171 def test_clock @test_clock end |
#updated ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
173 174 175 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 173 def updated @updated end |
#voided_at ⇒ Object (readonly)
The time when this credit grant was voided. If not present, the credit grant hasn’t been voided.
175 176 177 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 175 def voided_at @voided_at end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a credit grant.
178 179 180 181 182 183 184 185 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 178 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/billing/credit_grants", params: params, opts: opts ) end |
.expire(id, params = {}, opts = {}) ⇒ Object
Expires a credit grant.
198 199 200 201 202 203 204 205 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 198 def self.expire(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/credit_grants/%<id>s/expire", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
251 252 253 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 251 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
247 248 249 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 247 def self.inner_class_types @inner_class_types = { amount: Amount, applicability_config: ApplicabilityConfig } end |
.list(params = {}, opts = {}) ⇒ Object
Retrieve a list of credit grants.
208 209 210 211 212 213 214 215 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 208 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/billing/credit_grants", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 15 def self.object_name "billing.credit_grant" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates a credit grant.
218 219 220 221 222 223 224 225 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 218 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/credit_grants/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.void_grant(id, params = {}, opts = {}) ⇒ Object
Voids a credit grant.
238 239 240 241 242 243 244 245 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 238 def self.void_grant(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/credit_grants/%<id>s/void", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#expire(params = {}, opts = {}) ⇒ Object
Expires a credit grant.
188 189 190 191 192 193 194 195 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 188 def expire(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/credit_grants/%<id>s/expire", { id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#void_grant(params = {}, opts = {}) ⇒ Object
Voids a credit grant.
228 229 230 231 232 233 234 235 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 228 def void_grant(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/credit_grants/%<id>s/void", { id: CGI.escape(self["id"]) }), params: params, opts: opts ) end |