Class: Stripe::Billing::CreditGrant

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/billing/credit_grant.rb

Overview

A credit grant is an API resource that documents the allocation of some billing credits to a customer.

Related guide: [Billing credits](docs.stripe.com/billing/subscriptions/usage-based/billing-credits)

Defined Under Namespace

Classes: Amount, ApplicabilityConfig, CreateParams, ExpireParams, ListParams, UpdateParams, VoidGrantParams

Constant Summary collapse

OBJECT_NAME =
"billing.credit_grant"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Attribute for field amount



271
272
273
# File 'lib/stripe/resources/billing/credit_grant.rb', line 271

def amount
  @amount
end

#applicability_configObject (readonly)

Attribute for field applicability_config



273
274
275
# File 'lib/stripe/resources/billing/credit_grant.rb', line 273

def applicability_config
  @applicability_config
end

#categoryObject (readonly)

The category of this credit grant. This is for tracking purposes and isn’t displayed to the customer.



275
276
277
# File 'lib/stripe/resources/billing/credit_grant.rb', line 275

def category
  @category
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



277
278
279
# File 'lib/stripe/resources/billing/credit_grant.rb', line 277

def created
  @created
end

#customerObject (readonly)

ID of the customer receiving the billing credits.



279
280
281
# File 'lib/stripe/resources/billing/credit_grant.rb', line 279

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the account receiving the billing credits



281
282
283
# File 'lib/stripe/resources/billing/credit_grant.rb', line 281

def 
  @customer_account
end

#effective_atObject (readonly)

The time when the billing credits become effective-when they’re eligible for use.



283
284
285
# File 'lib/stripe/resources/billing/credit_grant.rb', line 283

def effective_at
  @effective_at
end

#expires_atObject (readonly)

The time when the billing credits expire. If not present, the billing credits don’t expire.



285
286
287
# File 'lib/stripe/resources/billing/credit_grant.rb', line 285

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



287
288
289
# File 'lib/stripe/resources/billing/credit_grant.rb', line 287

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



289
290
291
# File 'lib/stripe/resources/billing/credit_grant.rb', line 289

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



291
292
293
# File 'lib/stripe/resources/billing/credit_grant.rb', line 291

def 
  @metadata
end

#nameObject (readonly)

A descriptive name shown in dashboard.



293
294
295
# File 'lib/stripe/resources/billing/credit_grant.rb', line 293

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



295
296
297
# File 'lib/stripe/resources/billing/credit_grant.rb', line 295

def object
  @object
end

#priorityObject (readonly)

The priority for applying this credit grant. The highest priority is 0 and the lowest is 100.



297
298
299
# File 'lib/stripe/resources/billing/credit_grant.rb', line 297

def priority
  @priority
end

#test_clockObject (readonly)

ID of the test clock this credit grant belongs to.



299
300
301
# File 'lib/stripe/resources/billing/credit_grant.rb', line 299

def test_clock
  @test_clock
end

#updatedObject (readonly)

Time at which the object was last updated. Measured in seconds since the Unix epoch.



301
302
303
# File 'lib/stripe/resources/billing/credit_grant.rb', line 301

def updated
  @updated
end

#voided_atObject (readonly)

The time when this credit grant was voided. If not present, the credit grant hasn’t been voided.



303
304
305
# File 'lib/stripe/resources/billing/credit_grant.rb', line 303

def voided_at
  @voided_at
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a credit grant.



306
307
308
309
310
311
312
313
# File 'lib/stripe/resources/billing/credit_grant.rb', line 306

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/billing/credit_grants",
    params: params,
    opts: opts
  )
end

.expire(id, params = {}, opts = {}) ⇒ Object

Expires a credit grant.



326
327
328
329
330
331
332
333
# File 'lib/stripe/resources/billing/credit_grant.rb', line 326

def self.expire(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/credit_grants/%<id>s/expire", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Retrieve a list of credit grants.



336
337
338
339
340
341
342
343
# File 'lib/stripe/resources/billing/credit_grant.rb', line 336

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/billing/credit_grants",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/billing/credit_grant.rb', line 15

def self.object_name
  "billing.credit_grant"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a credit grant.



346
347
348
349
350
351
352
353
# File 'lib/stripe/resources/billing/credit_grant.rb', line 346

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/credit_grants/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.void_grant(id, params = {}, opts = {}) ⇒ Object

Voids a credit grant.



366
367
368
369
370
371
372
373
# File 'lib/stripe/resources/billing/credit_grant.rb', line 366

def self.void_grant(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/credit_grants/%<id>s/void", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#expire(params = {}, opts = {}) ⇒ Object

Expires a credit grant.



316
317
318
319
320
321
322
323
# File 'lib/stripe/resources/billing/credit_grant.rb', line 316

def expire(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/credit_grants/%<id>s/expire", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#void_grant(params = {}, opts = {}) ⇒ Object

Voids a credit grant.



356
357
358
359
360
361
362
363
# File 'lib/stripe/resources/billing/credit_grant.rb', line 356

def void_grant(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing/credit_grants/%<id>s/void", { id: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end