Class: Stripe::Billing::CreditGrant::ApplicabilityConfig::Scope

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_grant.rb

Defined Under Namespace

Classes: BillableItem, Price, RateCard

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billable_itemsObject (readonly)

The billable items that credit grants can apply to. We currently only support metered billable items. Cannot be used in combination with price_type or prices.



140
141
142
# File 'lib/stripe/resources/billing/credit_grant.rb', line 140

def billable_items
  @billable_items
end

#price_typeObject (readonly)

The price type that credit grants can apply to. We currently only support the metered price type. This refers to prices that have a Billing Meter attached to them. Cannot be used in combination with prices.



142
143
144
# File 'lib/stripe/resources/billing/credit_grant.rb', line 142

def price_type
  @price_type
end

#pricesObject (readonly)

The prices that credit grants can apply to. We currently only support metered prices. This refers to prices that have a Billing Meter attached to them. Cannot be used in combination with price_type.



144
145
146
# File 'lib/stripe/resources/billing/credit_grant.rb', line 144

def prices
  @prices
end

#rate_cardsObject (readonly)

The rate cards that credit grants can apply to. The credit grant applies to any metered item billed under one of these rate cards. Cannot be used in combination with price_type, prices, or billable_items.



146
147
148
# File 'lib/stripe/resources/billing/credit_grant.rb', line 146

def rate_cards
  @rate_cards
end

Class Method Details

.field_remappingsObject



152
153
154
# File 'lib/stripe/resources/billing/credit_grant.rb', line 152

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



148
149
150
# File 'lib/stripe/resources/billing/credit_grant.rb', line 148

def self.inner_class_types
  @inner_class_types = { billable_items: BillableItem, prices: Price, rate_cards: RateCard }
end