Class: Stripe::Billing::CreditGrant::ApplicabilityConfig::Scope

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_grant.rb

Defined Under Namespace

Classes: BillableItem, Price

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billable_itemsObject (readonly)

The billable items that credit grants can apply to. We currently only support metered billable items. Cannot be used in combination with ‘price_type` or `prices`.



69
70
71
# File 'lib/stripe/resources/billing/credit_grant.rb', line 69

def billable_items
  @billable_items
end

#price_typeObject (readonly)

The price type that credit grants can apply to. We currently only support the ‘metered` price type. This refers to prices that have a [Billing Meter](docs.stripe.com/api/billing/meter) attached to them. Cannot be used in combination with `prices`.



71
72
73
# File 'lib/stripe/resources/billing/credit_grant.rb', line 71

def price_type
  @price_type
end

#pricesObject (readonly)

The prices that credit grants can apply to. We currently only support ‘metered` prices. This refers to prices that have a [Billing Meter](docs.stripe.com/api/billing/meter) attached to them. Cannot be used in combination with `price_type`.



73
74
75
# File 'lib/stripe/resources/billing/credit_grant.rb', line 73

def prices
  @prices
end