Class: Stripe::Billing::CreditGrant::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_grant.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, applicability_config: nil, category: nil, customer: nil, effective_at: nil, expand: nil, expires_at: nil, metadata: nil, name: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/stripe/resources/billing/credit_grant.rb', line 127

def initialize(
  amount: nil,
  applicability_config: nil,
  category: nil,
  customer: nil,
  effective_at: nil,
  expand: nil,
  expires_at: nil,
  metadata: nil,
  name: nil
)
  @amount = amount
  @applicability_config = applicability_config
  @category = category
  @customer = customer
  @effective_at = effective_at
  @expand = expand
  @expires_at = expires_at
  @metadata = 
  @name = name
end

Instance Attribute Details

#amountObject

Amount of this credit grant.



109
110
111
# File 'lib/stripe/resources/billing/credit_grant.rb', line 109

def amount
  @amount
end

#applicability_configObject

Configuration specifying what this credit grant applies to.



111
112
113
# File 'lib/stripe/resources/billing/credit_grant.rb', line 111

def applicability_config
  @applicability_config
end

#categoryObject

The category of this credit grant.



113
114
115
# File 'lib/stripe/resources/billing/credit_grant.rb', line 113

def category
  @category
end

#customerObject

ID of the customer to receive the billing credits.



115
116
117
# File 'lib/stripe/resources/billing/credit_grant.rb', line 115

def customer
  @customer
end

#effective_atObject

The time when the billing credits become effective-when they’re eligible for use. It defaults to the current timestamp if not specified.



117
118
119
# File 'lib/stripe/resources/billing/credit_grant.rb', line 117

def effective_at
  @effective_at
end

#expandObject

Specifies which fields in the response should be expanded.



119
120
121
# File 'lib/stripe/resources/billing/credit_grant.rb', line 119

def expand
  @expand
end

#expires_atObject

The time when the billing credits expire. If not specified, the billing credits don’t expire.



121
122
123
# File 'lib/stripe/resources/billing/credit_grant.rb', line 121

def expires_at
  @expires_at
end

#metadataObject

Set of key-value pairs that you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.



123
124
125
# File 'lib/stripe/resources/billing/credit_grant.rb', line 123

def 
  @metadata
end

#nameObject

A descriptive name shown in the Dashboard.



125
126
127
# File 'lib/stripe/resources/billing/credit_grant.rb', line 125

def name
  @name
end