Class: Stripe::Billing::CreditGrant::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_grant.rb

Defined Under Namespace

Classes: Amount, ApplicabilityConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, applicability_config: nil, category: nil, customer: nil, effective_at: nil, expand: nil, expires_at: nil, metadata: nil, name: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/stripe/resources/billing/credit_grant.rb', line 143

def initialize(
  amount: nil,
  applicability_config: nil,
  category: nil,
  customer: nil,
  effective_at: nil,
  expand: nil,
  expires_at: nil,
  metadata: nil,
  name: nil
)
  @amount = amount
  @applicability_config = applicability_config
  @category = category
  @customer = customer
  @effective_at = effective_at
  @expand = expand
  @expires_at = expires_at
  @metadata = 
  @name = name
end

Instance Attribute Details

#amountObject

Amount of this credit grant.



117
118
119
# File 'lib/stripe/resources/billing/credit_grant.rb', line 117

def amount
  @amount
end

#applicability_configObject

Configuration specifying what this credit grant applies to.



120
121
122
# File 'lib/stripe/resources/billing/credit_grant.rb', line 120

def applicability_config
  @applicability_config
end

#categoryObject

The category of this credit grant.



123
124
125
# File 'lib/stripe/resources/billing/credit_grant.rb', line 123

def category
  @category
end

#customerObject

ID of the customer to receive the billing credits.



126
127
128
# File 'lib/stripe/resources/billing/credit_grant.rb', line 126

def customer
  @customer
end

#effective_atObject

The time when the billing credits become effective-when they’re eligible for use. It defaults to the current timestamp if not specified.



129
130
131
# File 'lib/stripe/resources/billing/credit_grant.rb', line 129

def effective_at
  @effective_at
end

#expandObject

Specifies which fields in the response should be expanded.



132
133
134
# File 'lib/stripe/resources/billing/credit_grant.rb', line 132

def expand
  @expand
end

#expires_atObject

The time when the billing credits expire. If not specified, the billing credits don’t expire.



135
136
137
# File 'lib/stripe/resources/billing/credit_grant.rb', line 135

def expires_at
  @expires_at
end

#metadataObject

Set of key-value pairs that you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.



138
139
140
# File 'lib/stripe/resources/billing/credit_grant.rb', line 138

def 
  @metadata
end

#nameObject

A descriptive name shown in the Dashboard.



141
142
143
# File 'lib/stripe/resources/billing/credit_grant.rb', line 141

def name
  @name
end