Class: Stripe::Billing::CreditGrant::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrant::CreateParams
- Defined in:
- lib/stripe/resources/billing/credit_grant.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount of this credit grant.
-
#applicability_config ⇒ Object
Configuration specifying what this credit grant applies to.
-
#category ⇒ Object
The category of this credit grant.
-
#customer ⇒ Object
ID of the customer to receive the billing credits.
-
#effective_at ⇒ Object
The time when the billing credits become effective-when they’re eligible for use.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
The time when the billing credits expire.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
A descriptive name shown in the Dashboard.
Instance Method Summary collapse
-
#initialize(amount: nil, applicability_config: nil, category: nil, customer: nil, effective_at: nil, expand: nil, expires_at: nil, metadata: nil, name: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, applicability_config: nil, category: nil, customer: nil, effective_at: nil, expand: nil, expires_at: nil, metadata: nil, name: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 143 def initialize( amount: nil, applicability_config: nil, category: nil, customer: nil, effective_at: nil, expand: nil, expires_at: nil, metadata: nil, name: nil ) @amount = amount @applicability_config = applicability_config @category = category @customer = customer @effective_at = effective_at @expand = @expires_at = expires_at @metadata = @name = name end |
Instance Attribute Details
#amount ⇒ Object
Amount of this credit grant.
117 118 119 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 117 def amount @amount end |
#applicability_config ⇒ Object
Configuration specifying what this credit grant applies to.
120 121 122 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 120 def applicability_config @applicability_config end |
#category ⇒ Object
The category of this credit grant.
123 124 125 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 123 def category @category end |
#customer ⇒ Object
ID of the customer to receive the billing credits.
126 127 128 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 126 def customer @customer end |
#effective_at ⇒ Object
The time when the billing credits become effective-when they’re eligible for use. It defaults to the current timestamp if not specified.
129 130 131 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 129 def effective_at @effective_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
132 133 134 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 132 def @expand end |
#expires_at ⇒ Object
The time when the billing credits expire. If not specified, the billing credits don’t expire.
135 136 137 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 135 def expires_at @expires_at end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.
138 139 140 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 138 def @metadata end |
#name ⇒ Object
A descriptive name shown in the Dashboard.
141 142 143 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 141 def name @name end |