Class: Stripe::Billing::CreditGrant::CreateParams::Amount::CustomPricingUnit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrant::CreateParams::Amount::CustomPricingUnit
- Defined in:
- lib/stripe/resources/billing/credit_grant.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
The ID of the custom pricing unit.
-
#value ⇒ Object
A positive integer representing the amount of the credit grant.
Instance Method Summary collapse
-
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
constructor
A new instance of CustomPricingUnit.
Methods inherited from RequestParams
Constructor Details
#initialize(id: nil, value: nil) ⇒ CustomPricingUnit
Returns a new instance of CustomPricingUnit.
118 119 120 121 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 118 def initialize(id: nil, value: nil) @id = id @value = value end |
Instance Attribute Details
#id ⇒ Object
The ID of the custom pricing unit.
114 115 116 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 114 def id @id end |
#value ⇒ Object
A positive integer representing the amount of the credit grant.
116 117 118 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 116 def value @value end |