Class: Stripe::Billing::CreditGrant::CreateParams::ApplicabilityConfig::Scope
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrant::CreateParams::ApplicabilityConfig::Scope
- Defined in:
- lib/stripe/resources/billing/credit_grant.rb
Defined Under Namespace
Classes: BillableItem, Price
Instance Attribute Summary collapse
-
#billable_items ⇒ Object
A list of billable items that the credit grant can apply to.
-
#price_type ⇒ Object
The price type that credit grants can apply to.
-
#prices ⇒ Object
A list of prices that the credit grant can apply to.
Instance Method Summary collapse
-
#initialize(billable_items: nil, price_type: nil, prices: nil) ⇒ Scope
constructor
A new instance of Scope.
Methods inherited from RequestParams
Constructor Details
#initialize(billable_items: nil, price_type: nil, prices: nil) ⇒ Scope
Returns a new instance of Scope.
239 240 241 242 243 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 239 def initialize(billable_items: nil, price_type: nil, prices: nil) @billable_items = billable_items @price_type = price_type @prices = prices end |
Instance Attribute Details
#billable_items ⇒ Object
A list of billable items that the credit grant can apply to. We currently only support metered billable items. Cannot be used in combination with ‘price_type` or `prices`.
233 234 235 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 233 def billable_items @billable_items end |
#price_type ⇒ Object
The price type that credit grants can apply to. We currently only support the ‘metered` price type. Cannot be used in combination with `prices`.
235 236 237 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 235 def price_type @price_type end |
#prices ⇒ Object
A list of prices that the credit grant can apply to. We currently only support the ‘metered` prices. Cannot be used in combination with `price_type`.
237 238 239 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 237 def prices @prices end |