Class: Stripe::Billing::CreditGrant::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing/credit_grant.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



167
168
169
170
171
# File 'lib/stripe/resources/billing/credit_grant.rb', line 167

def initialize(expand: nil, expires_at: nil, metadata: nil)
  @expand = expand
  @expires_at = expires_at
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



161
162
163
# File 'lib/stripe/resources/billing/credit_grant.rb', line 161

def expand
  @expand
end

#expires_atObject

The time when the billing credits created by this credit grant expire. If set to empty, the billing credits never expire.



163
164
165
# File 'lib/stripe/resources/billing/credit_grant.rb', line 163

def expires_at
  @expires_at
end

#metadataObject

Set of key-value pairs you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.



165
166
167
# File 'lib/stripe/resources/billing/credit_grant.rb', line 165

def 
  @metadata
end