Class: Stripe::Billing::CreditGrant::VoidGrantParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrant::VoidGrantParams
- Defined in:
- lib/stripe/resources/billing/credit_grant.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ VoidGrantParams
constructor
A new instance of VoidGrantParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ VoidGrantParams
Returns a new instance of VoidGrantParams.
187 188 189 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 187 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
185 186 187 |
# File 'lib/stripe/resources/billing/credit_grant.rb', line 185 def @expand end |