Class: Stripe::Billing::CreditGrantCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrantCreateParams
- Defined in:
- lib/stripe/params/billing/credit_grant_create_params.rb
Defined Under Namespace
Classes: Amount, ApplicabilityConfig
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount of this credit grant.
-
#applicability_config ⇒ Object
Configuration specifying what this credit grant applies to.
-
#category ⇒ Object
The category of this credit grant.
-
#customer ⇒ Object
ID of the customer receiving the billing credits.
-
#customer_account ⇒ Object
ID of the account representing the customer receiving the billing credits.
-
#effective_at ⇒ Object
The time when the billing credits become effective-when they’re eligible for use.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
The time when the billing credits expire.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
A descriptive name shown in the Dashboard.
-
#priority ⇒ Object
The desired priority for applying this credit grant.
Instance Method Summary collapse
-
#initialize(amount: nil, applicability_config: nil, category: nil, customer: nil, customer_account: nil, effective_at: nil, expand: nil, expires_at: nil, metadata: nil, name: nil, priority: nil) ⇒ CreditGrantCreateParams
constructor
A new instance of CreditGrantCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, applicability_config: nil, category: nil, customer: nil, customer_account: nil, effective_at: nil, expand: nil, expires_at: nil, metadata: nil, name: nil, priority: nil) ⇒ CreditGrantCreateParams
Returns a new instance of CreditGrantCreateParams.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 107 def initialize( amount: nil, applicability_config: nil, category: nil, customer: nil, customer_account: nil, effective_at: nil, expand: nil, expires_at: nil, metadata: nil, name: nil, priority: nil ) @amount = amount @applicability_config = applicability_config @category = category @customer = customer @customer_account = customer_account @effective_at = effective_at @expand = @expires_at = expires_at @metadata = @name = name @priority = priority end |
Instance Attribute Details
#amount ⇒ Object
Amount of this credit grant.
85 86 87 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 85 def amount @amount end |
#applicability_config ⇒ Object
Configuration specifying what this credit grant applies to. We currently only support ‘metered` prices that have a [Billing Meter](docs.stripe.com/api/billing/meter) attached to them.
87 88 89 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 87 def applicability_config @applicability_config end |
#category ⇒ Object
The category of this credit grant. It defaults to ‘paid` if not specified.
89 90 91 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 89 def category @category end |
#customer ⇒ Object
ID of the customer receiving the billing credits.
91 92 93 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 91 def customer @customer end |
#customer_account ⇒ Object
ID of the account representing the customer receiving the billing credits.
93 94 95 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 93 def customer_account @customer_account end |
#effective_at ⇒ Object
The time when the billing credits become effective-when they’re eligible for use. It defaults to the current timestamp if not specified.
95 96 97 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 95 def effective_at @effective_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
97 98 99 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 97 def @expand end |
#expires_at ⇒ Object
The time when the billing credits expire. If not specified, the billing credits don’t expire.
99 100 101 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 99 def expires_at @expires_at end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.
101 102 103 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 101 def @metadata end |
#name ⇒ Object
A descriptive name shown in the Dashboard.
103 104 105 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 103 def name @name end |
#priority ⇒ Object
The desired priority for applying this credit grant. If not specified, it will be set to the default value of 50. The highest priority is 0 and the lowest is 100.
105 106 107 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 105 def priority @priority end |