Class: Stripe::Billing::CreditGrantCreateParams::ApplicabilityConfig::Scope

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/billing/credit_grant_create_params.rb

Defined Under Namespace

Classes: BillableItem, Price

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(billable_items: nil, price_type: nil, prices: nil) ⇒ Scope

Returns a new instance of Scope.



81
82
83
84
85
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 81

def initialize(billable_items: nil, price_type: nil, prices: nil)
  @billable_items = billable_items
  @price_type = price_type
  @prices = prices
end

Instance Attribute Details

#billable_itemsObject

A list of billable items that the credit grant can apply to. We currently only support metered billable items. Cannot be used in combination with ‘price_type` or `prices`.



75
76
77
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 75

def billable_items
  @billable_items
end

#price_typeObject

The price type that credit grants can apply to. We currently only support the ‘metered` price type. Cannot be used in combination with `prices`.



77
78
79
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 77

def price_type
  @price_type
end

#pricesObject

A list of prices that the credit grant can apply to. We currently only support the ‘metered` prices. Cannot be used in combination with `price_type`.



79
80
81
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 79

def prices
  @prices
end