Class: Stripe::Billing::CreditGrantCreateParams::ApplicabilityConfig::Scope
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::CreditGrantCreateParams::ApplicabilityConfig::Scope
- Defined in:
- lib/stripe/params/billing/credit_grant_create_params.rb
Defined Under Namespace
Classes: BillableItem, Price
Instance Attribute Summary collapse
-
#billable_items ⇒ Object
A list of billable items that the credit grant can apply to.
-
#price_type ⇒ Object
The price type that credit grants can apply to.
-
#prices ⇒ Object
A list of prices that the credit grant can apply to.
Instance Method Summary collapse
-
#initialize(billable_items: nil, price_type: nil, prices: nil) ⇒ Scope
constructor
A new instance of Scope.
Methods inherited from RequestParams
Constructor Details
#initialize(billable_items: nil, price_type: nil, prices: nil) ⇒ Scope
Returns a new instance of Scope.
71 72 73 74 75 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 71 def initialize(billable_items: nil, price_type: nil, prices: nil) @billable_items = billable_items @price_type = price_type @prices = prices end |
Instance Attribute Details
#billable_items ⇒ Object
A list of billable items that the credit grant can apply to. We currently only support metered billable items. Cannot be used in combination with ‘price_type` or `prices`.
65 66 67 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 65 def billable_items @billable_items end |
#price_type ⇒ Object
The price type that credit grants can apply to. We currently only support the ‘metered` price type. Cannot be used in combination with `prices`.
67 68 69 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 67 def price_type @price_type end |
#prices ⇒ Object
A list of prices that the credit grant can apply to. We currently only support the ‘metered` prices. Cannot be used in combination with `price_type`.
69 70 71 |
# File 'lib/stripe/params/billing/credit_grant_create_params.rb', line 69 def prices @prices end |