Class: Stripe::Billing::CreditGrantService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing/credit_grant_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expires_at: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



133
134
135
136
137
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 133

def initialize(expand: nil, expires_at: nil, metadata: nil)
  @expand = expand
  @expires_at = expires_at
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



127
128
129
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 127

def expand
  @expand
end

#expires_atObject

The time when the billing credits created by this credit grant expire. If set to empty, the billing credits never expire.



129
130
131
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 129

def expires_at
  @expires_at
end

#metadataObject

Set of key-value pairs you can attach to an object. You can use this to store additional information about the object (for example, cost basis) in a structured format.



131
132
133
# File 'lib/stripe/services/billing/credit_grant_service.rb', line 131

def 
  @metadata
end