Class: Stripe::Billing::Meter::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::Meter::CreateParams
- Defined in:
- lib/stripe/resources/billing/meter.rb
Defined Under Namespace
Classes: CustomerMapping, DefaultAggregation, ValueSettings
Instance Attribute Summary collapse
-
#customer_mapping ⇒ Object
Fields that specify how to map a meter event to a customer.
-
#default_aggregation ⇒ Object
The default settings to aggregate a meter’s events with.
-
#display_name ⇒ Object
The meter’s name.
-
#event_name ⇒ Object
The name of the meter event to record usage for.
-
#event_time_window ⇒ Object
The time window to pre-aggregate meter events for, if any.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#value_settings ⇒ Object
Fields that specify how to calculate a meter event’s value.
Instance Method Summary collapse
-
#initialize(customer_mapping: nil, default_aggregation: nil, display_name: nil, event_name: nil, event_time_window: nil, expand: nil, value_settings: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_mapping: nil, default_aggregation: nil, display_name: nil, event_name: nil, event_time_window: nil, expand: nil, value_settings: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/stripe/resources/billing/meter.rb', line 130 def initialize( customer_mapping: nil, default_aggregation: nil, display_name: nil, event_name: nil, event_time_window: nil, expand: nil, value_settings: nil ) @customer_mapping = customer_mapping @default_aggregation = default_aggregation @display_name = display_name @event_name = event_name @event_time_window = event_time_window @expand = @value_settings = value_settings end |
Instance Attribute Details
#customer_mapping ⇒ Object
Fields that specify how to map a meter event to a customer.
110 111 112 |
# File 'lib/stripe/resources/billing/meter.rb', line 110 def customer_mapping @customer_mapping end |
#default_aggregation ⇒ Object
The default settings to aggregate a meter’s events with.
113 114 115 |
# File 'lib/stripe/resources/billing/meter.rb', line 113 def default_aggregation @default_aggregation end |
#display_name ⇒ Object
The meter’s name. Not visible to the customer.
116 117 118 |
# File 'lib/stripe/resources/billing/meter.rb', line 116 def display_name @display_name end |
#event_name ⇒ Object
The name of the meter event to record usage for. Corresponds with the ‘event_name` field on meter events.
119 120 121 |
# File 'lib/stripe/resources/billing/meter.rb', line 119 def event_name @event_name end |
#event_time_window ⇒ Object
The time window to pre-aggregate meter events for, if any.
122 123 124 |
# File 'lib/stripe/resources/billing/meter.rb', line 122 def event_time_window @event_time_window end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
125 126 127 |
# File 'lib/stripe/resources/billing/meter.rb', line 125 def @expand end |
#value_settings ⇒ Object
Fields that specify how to calculate a meter event’s value.
128 129 130 |
# File 'lib/stripe/resources/billing/meter.rb', line 128 def value_settings @value_settings end |