Class: Stripe::Billing::MeterEvent

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/billing/meter_event.rb

Overview

Meter events represent actions that customers take in your system. You can use meter events to bill a customer based on their usage. Meter events are associated with billing meters, which define both the contents of the event’s payload and how to aggregate those events.

Defined Under Namespace

Classes: CreateParams

Constant Summary collapse

OBJECT_NAME =
"billing.meter_event"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



36
37
38
# File 'lib/stripe/resources/billing/meter_event.rb', line 36

def created
  @created
end

#event_nameObject (readonly)

The name of the meter event. Corresponds with the ‘event_name` field on a meter.



38
39
40
# File 'lib/stripe/resources/billing/meter_event.rb', line 38

def event_name
  @event_name
end

#identifierObject (readonly)

A unique identifier for the event.



40
41
42
# File 'lib/stripe/resources/billing/meter_event.rb', line 40

def identifier
  @identifier
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



42
43
44
# File 'lib/stripe/resources/billing/meter_event.rb', line 42

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



44
45
46
# File 'lib/stripe/resources/billing/meter_event.rb', line 44

def object
  @object
end

#payloadObject (readonly)

The payload of the event. This contains the fields corresponding to a meter’s ‘customer_mapping.event_payload_key` (default is `stripe_customer_id`) and `value_settings.event_payload_key` (default is `value`). Read more about the [payload](stripe.com/docs/billing/subscriptions/usage-based/recording-usage#payload-key-overrides).



46
47
48
# File 'lib/stripe/resources/billing/meter_event.rb', line 46

def payload
  @payload
end

#timestampObject (readonly)

The timestamp passed in when creating the event. Measured in seconds since the Unix epoch.



48
49
50
# File 'lib/stripe/resources/billing/meter_event.rb', line 48

def timestamp
  @timestamp
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a billing meter event.



51
52
53
54
55
56
57
58
# File 'lib/stripe/resources/billing/meter_event.rb', line 51

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/billing/meter_events",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/billing/meter_event.rb', line 11

def self.object_name
  "billing.meter_event"
end