Class: Stripe::Billing::MeterEventAdjustmentService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Billing::MeterEventAdjustmentService::CreateParams
- Defined in:
- lib/stripe/services/billing/meter_event_adjustment_service.rb
Defined Under Namespace
Classes: Cancel
Instance Attribute Summary collapse
-
#cancel ⇒ Object
Specifies which event to cancel.
-
#event_name ⇒ Object
The name of the meter event.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#type ⇒ Object
Specifies whether to cancel a single event or a range of events for a time period.
Instance Method Summary collapse
-
#initialize(cancel: nil, event_name: nil, expand: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cancel: nil, event_name: nil, expand: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
28 29 30 31 32 33 |
# File 'lib/stripe/services/billing/meter_event_adjustment_service.rb', line 28 def initialize(cancel: nil, event_name: nil, expand: nil, type: nil) @cancel = cancel @event_name = event_name @expand = @type = type end |
Instance Attribute Details
#cancel ⇒ Object
Specifies which event to cancel.
17 18 19 |
# File 'lib/stripe/services/billing/meter_event_adjustment_service.rb', line 17 def cancel @cancel end |
#event_name ⇒ Object
The name of the meter event. Corresponds with the ‘event_name` field on a meter.
20 21 22 |
# File 'lib/stripe/services/billing/meter_event_adjustment_service.rb', line 20 def event_name @event_name end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
23 24 25 |
# File 'lib/stripe/services/billing/meter_event_adjustment_service.rb', line 23 def @expand end |
#type ⇒ Object
Specifies whether to cancel a single event or a range of events for a time period. Time period cancellation is not supported yet.
26 27 28 |
# File 'lib/stripe/services/billing/meter_event_adjustment_service.rb', line 26 def type @type end |