Class: Stripe::Billing::MeterUsageRow
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Billing::MeterUsageRow
- Defined in:
- lib/stripe/resources/billing/meter_usage_row.rb
Constant Summary collapse
- OBJECT_NAME =
"billing.meter_usage_row"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bucket_end_time ⇒ Object
readonly
Timestamp indicating the end of the bucket.
-
#bucket_start_time ⇒ Object
readonly
Timestamp indicating the start of the bucket.
-
#bucket_value ⇒ Object
readonly
The aggregated meter usage value for the specified bucket.
-
#dimensions ⇒ Object
readonly
A set of key-value pairs representing the dimensions of the meter usage.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#meter_id ⇒ Object
readonly
The unique identifier for the meter.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bucket_end_time ⇒ Object (readonly)
Timestamp indicating the end of the bucket. Measured in seconds since the Unix epoch.
13 14 15 |
# File 'lib/stripe/resources/billing/meter_usage_row.rb', line 13 def bucket_end_time @bucket_end_time end |
#bucket_start_time ⇒ Object (readonly)
Timestamp indicating the start of the bucket. Measured in seconds since the Unix epoch.
15 16 17 |
# File 'lib/stripe/resources/billing/meter_usage_row.rb', line 15 def bucket_start_time @bucket_start_time end |
#bucket_value ⇒ Object (readonly)
The aggregated meter usage value for the specified bucket.
17 18 19 |
# File 'lib/stripe/resources/billing/meter_usage_row.rb', line 17 def bucket_value @bucket_value end |
#dimensions ⇒ Object (readonly)
A set of key-value pairs representing the dimensions of the meter usage.
19 20 21 |
# File 'lib/stripe/resources/billing/meter_usage_row.rb', line 19 def dimensions @dimensions end |
#id ⇒ Object (readonly)
Unique identifier for the object.
21 22 23 |
# File 'lib/stripe/resources/billing/meter_usage_row.rb', line 21 def id @id end |
#meter_id ⇒ Object (readonly)
The unique identifier for the meter.
23 24 25 |
# File 'lib/stripe/resources/billing/meter_usage_row.rb', line 23 def meter_id @meter_id end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
25 26 27 |
# File 'lib/stripe/resources/billing/meter_usage_row.rb', line 25 def object @object end |
Class Method Details
.object_name ⇒ Object
8 9 10 |
# File 'lib/stripe/resources/billing/meter_usage_row.rb', line 8 def self.object_name "billing.meter_usage_row" end |