Class: Stripe::BillingPortal::Configuration

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Overview

A portal configuration describes the functionality and behavior of a portal session.

Defined Under Namespace

Classes: BusinessProfile, CreateParams, Features, ListParams, LoginPage, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"billing_portal.configuration"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#activeObject (readonly)

Whether the configuration is active and can be used to create portal sessions.



544
545
546
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 544

def active
  @active
end

#applicationObject (readonly)

ID of the Connect Application that created the configuration.



546
547
548
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 546

def application
  @application
end

#business_profileObject (readonly)

Attribute for field business_profile



548
549
550
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 548

def business_profile
  @business_profile
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



550
551
552
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 550

def created
  @created
end

#default_return_urlObject (readonly)

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



552
553
554
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 552

def default_return_url
  @default_return_url
end

#featuresObject (readonly)

Attribute for field features



554
555
556
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 554

def features
  @features
end

#idObject (readonly)

Unique identifier for the object.



556
557
558
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 556

def id
  @id
end

#is_defaultObject (readonly)

Whether the configuration is the default. If ‘true`, this configuration can be managed in the Dashboard and portal sessions will use this configuration unless it is overriden when creating the session.



558
559
560
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 558

def is_default
  @is_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



560
561
562
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 560

def livemode
  @livemode
end

#login_pageObject (readonly)

Attribute for field login_page



562
563
564
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 562

def 
  @login_page
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



564
565
566
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 564

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



566
567
568
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 566

def object
  @object
end

#updatedObject (readonly)

Time at which the object was last updated. Measured in seconds since the Unix epoch.



568
569
570
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 568

def updated
  @updated
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a configuration that describes the functionality and behavior of a PortalSession



571
572
573
574
575
576
577
578
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 571

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/billing_portal/configurations",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of configurations that describe the functionality of the customer portal.



581
582
583
584
585
586
587
588
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 581

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/billing_portal/configurations",
    params: params,
    opts: opts
  )
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 13

def self.object_name
  "billing_portal.configuration"
end

.update(configuration, params = {}, opts = {}) ⇒ Object

Updates a configuration that describes the functionality of the customer portal.



591
592
593
594
595
596
597
598
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 591

def self.update(configuration, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/billing_portal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }),
    params: params,
    opts: opts
  )
end