Class: Stripe::BillingPortal::Configuration::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 365

def initialize(
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil
)
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
end

Instance Attribute Details

#business_profileObject

The business information shown to customers in the portal.



348
349
350
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 348

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



351
352
353
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 351

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



354
355
356
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 354

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



357
358
359
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 357

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



360
361
362
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 360

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



363
364
365
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 363

def 
  @metadata
end