Class: Stripe::BillingPortal::Configuration::CreateParams::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::CreateParams::Features
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: CustomerUpdate, InvoiceHistory, PaymentMethodUpdate, SubscriptionCancel, SubscriptionUpdate
Instance Attribute Summary collapse
-
#customer_update ⇒ Object
Information about updating the customer details in the portal.
-
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
-
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
-
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
-
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
Instance Method Summary collapse
-
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
Returns a new instance of Features.
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 313 def initialize( customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil ) @customer_update = customer_update @invoice_history = invoice_history @payment_method_update = payment_method_update @subscription_cancel = subscription_cancel @subscription_update = subscription_update end |
Instance Attribute Details
#customer_update ⇒ Object
Information about updating the customer details in the portal.
303 304 305 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 303 def customer_update @customer_update end |
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
305 306 307 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 305 def invoice_history @invoice_history end |
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
307 308 309 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 307 def payment_method_update @payment_method_update end |
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
309 310 311 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 309 def subscription_cancel @subscription_cancel end |
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
311 312 313 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 311 def subscription_update @subscription_update end |