Class: Stripe::BillingPortal::Configuration::CreateParams::Features::SubscriptionCancel
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::CreateParams::Features::SubscriptionCancel
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: CancellationReason
Instance Attribute Summary collapse
-
#cancellation_reason ⇒ Object
Whether the cancellation reasons will be collected in the portal and which options are exposed to the customer.
-
#enabled ⇒ Object
Whether the feature is enabled.
-
#mode ⇒ Object
Whether to cancel subscriptions immediately or at the end of the billing period.
-
#proration_behavior ⇒ Object
Whether to create prorations when canceling subscriptions.
Instance Method Summary collapse
-
#initialize(cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil) ⇒ SubscriptionCancel
constructor
A new instance of SubscriptionCancel.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil) ⇒ SubscriptionCancel
Returns a new instance of SubscriptionCancel.
237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 237 def initialize( cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil ) @cancellation_reason = cancellation_reason @enabled = enabled @mode = mode @proration_behavior = proration_behavior end |
Instance Attribute Details
#cancellation_reason ⇒ Object
Whether the cancellation reasons will be collected in the portal and which options are exposed to the customer
226 227 228 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 226 def cancellation_reason @cancellation_reason end |
#enabled ⇒ Object
Whether the feature is enabled.
229 230 231 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 229 def enabled @enabled end |
#mode ⇒ Object
Whether to cancel subscriptions immediately or at the end of the billing period.
232 233 234 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 232 def mode @mode end |
#proration_behavior ⇒ Object
Whether to create prorations when canceling subscriptions. Possible values are ‘none` and `create_prorations`, which is only compatible with `mode=immediately`. No prorations are generated when canceling a subscription at the end of its natural billing period.
235 236 237 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 235 def proration_behavior @proration_behavior end |