Class: Stripe::BillingPortal::Configuration::Features::SubscriptionUpdate::Product::AdjustableQuantity

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#enabledObject (readonly)

If true, the quantity can be adjusted to any non-negative integer.



65
66
67
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 65

def enabled
  @enabled
end

#maximumObject (readonly)

The maximum quantity that can be set for the product.



67
68
69
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 67

def maximum
  @maximum
end

#minimumObject (readonly)

The minimum quantity that can be set for the product.



69
70
71
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 69

def minimum
  @minimum
end