Class: Stripe::BillingPortal::Configuration::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 569

def initialize(
  active: nil,
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil
)
  @active = active
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
end

Instance Attribute Details

#activeObject

Whether the configuration is active and can be used to create portal sessions.



555
556
557
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 555

def active
  @active
end

#business_profileObject

The business information shown to customers in the portal.



557
558
559
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 557

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



559
560
561
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 559

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



561
562
563
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 561

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



563
564
565
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 563

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



565
566
567
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 565

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



567
568
569
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 567

def 
  @metadata
end