Class: Stripe::BillingPortal::Configuration::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 525

def initialize(
  active: nil,
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil
)
  @active = active
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
end

Instance Attribute Details

#activeObject

Whether the configuration is active and can be used to create portal sessions.



511
512
513
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 511

def active
  @active
end

#business_profileObject

The business information shown to customers in the portal.



513
514
515
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 513

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



515
516
517
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 515

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



517
518
519
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 517

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



519
520
521
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 519

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



521
522
523
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 521

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



523
524
525
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 523

def 
  @metadata
end