Class: Stripe::BillingPortal::Configuration::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 599

def initialize(
  active: nil,
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil
)
  @active = active
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
end

Instance Attribute Details

#activeObject

Whether the configuration is active and can be used to create portal sessions.



579
580
581
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 579

def active
  @active
end

#business_profileObject

The business information shown to customers in the portal.



582
583
584
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 582

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



585
586
587
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 585

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



588
589
590
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 588

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



591
592
593
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 591

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



594
595
596
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 594

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



597
598
599
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 597

def 
  @metadata
end