Class: Stripe::BillingPortal::Configuration::UpdateParams::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: CustomerUpdate, InvoiceHistory, PaymentMethodUpdate, SubscriptionCancel, SubscriptionUpdate
Instance Attribute Summary collapse
-
#customer_update ⇒ Object
Information about updating the customer details in the portal.
-
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
-
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
-
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
-
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
Instance Method Summary collapse
-
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features
Returns a new instance of Features.
485 486 487 488 489 490 491 492 493 494 495 496 497 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 485 def initialize( customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil ) @customer_update = customer_update @invoice_history = invoice_history @payment_method_update = payment_method_update @subscription_cancel = subscription_cancel @subscription_update = subscription_update end |
Instance Attribute Details
#customer_update ⇒ Object
Information about updating the customer details in the portal.
475 476 477 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 475 def customer_update @customer_update end |
#invoice_history ⇒ Object
Information about showing the billing history in the portal.
477 478 479 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 477 def invoice_history @invoice_history end |
#payment_method_update ⇒ Object
Information about updating payment methods in the portal.
479 480 481 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 479 def payment_method_update @payment_method_update end |
#subscription_cancel ⇒ Object
Information about canceling subscriptions in the portal.
481 482 483 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 481 def subscription_cancel @subscription_cancel end |
#subscription_update ⇒ Object
Information about updating subscriptions in the portal.
483 484 485 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 483 def subscription_update @subscription_update end |