Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionCancel
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionCancel
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: CancellationReason
Instance Attribute Summary collapse
-
#cancellation_reason ⇒ Object
Whether the cancellation reasons will be collected in the portal and which options are exposed to the customer.
-
#enabled ⇒ Object
Whether the feature is enabled.
-
#mode ⇒ Object
Whether to cancel subscriptions immediately or at the end of the billing period.
-
#proration_behavior ⇒ Object
Whether to create prorations when canceling subscriptions.
Instance Method Summary collapse
-
#initialize(cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil) ⇒ SubscriptionCancel
constructor
A new instance of SubscriptionCancel.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil) ⇒ SubscriptionCancel
Returns a new instance of SubscriptionCancel.
416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 416 def initialize( cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil ) @cancellation_reason = cancellation_reason @enabled = enabled @mode = mode @proration_behavior = proration_behavior end |
Instance Attribute Details
#cancellation_reason ⇒ Object
Whether the cancellation reasons will be collected in the portal and which options are exposed to the customer
408 409 410 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 408 def cancellation_reason @cancellation_reason end |
#enabled ⇒ Object
Whether the feature is enabled.
410 411 412 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 410 def enabled @enabled end |
#mode ⇒ Object
Whether to cancel subscriptions immediately or at the end of the billing period.
412 413 414 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 412 def mode @mode end |
#proration_behavior ⇒ Object
Whether to create prorations when canceling subscriptions. Possible values are ‘none` and `create_prorations`, which is only compatible with `mode=immediately`. Passing `always_invoice` will result in an error. No prorations are generated when canceling a subscription at the end of its natural billing period.
414 415 416 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 414 def proration_behavior @proration_behavior end |