Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionCancel::CancellationReason
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionCancel::CancellationReason
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the feature is enabled.
-
#options ⇒ Object
Which cancellation reasons will be given as options to the customer.
Instance Method Summary collapse
-
#initialize(enabled: nil, options: nil) ⇒ CancellationReason
constructor
A new instance of CancellationReason.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, options: nil) ⇒ CancellationReason
Returns a new instance of CancellationReason.
449 450 451 452 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 449 def initialize(enabled: nil, options: nil) @enabled = enabled @options = end |
Instance Attribute Details
#enabled ⇒ Object
Whether the feature is enabled.
444 445 446 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 444 def enabled @enabled end |
#options ⇒ Object
Which cancellation reasons will be given as options to the customer.
447 448 449 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 447 def @options end |