Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: Product, ScheduleAtPeriodEnd
Instance Attribute Summary collapse
-
#default_allowed_updates ⇒ Object
The types of subscription updates that are supported.
-
#enabled ⇒ Object
Whether the feature is enabled.
-
#products ⇒ Object
The list of up to 10 products that support subscription updates.
-
#proration_behavior ⇒ Object
Determines how to handle prorations resulting from subscription updates.
-
#schedule_at_period_end ⇒ Object
Setting to control when an update should be scheduled at the end of the period instead of applying immediately.
Instance Method Summary collapse
-
#initialize(default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil) ⇒ SubscriptionUpdate
constructor
A new instance of SubscriptionUpdate.
Methods inherited from RequestParams
Constructor Details
#initialize(default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil) ⇒ SubscriptionUpdate
Returns a new instance of SubscriptionUpdate.
508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 508 def initialize( default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil ) @default_allowed_updates = default_allowed_updates @enabled = enabled @products = products @proration_behavior = proration_behavior @schedule_at_period_end = schedule_at_period_end end |
Instance Attribute Details
#default_allowed_updates ⇒ Object
The types of subscription updates that are supported. When empty, subscriptions are not updateable.
498 499 500 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 498 def default_allowed_updates @default_allowed_updates end |
#enabled ⇒ Object
Whether the feature is enabled.
500 501 502 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 500 def enabled @enabled end |
#products ⇒ Object
The list of up to 10 products that support subscription updates.
502 503 504 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 502 def products @products end |
#proration_behavior ⇒ Object
Determines how to handle prorations resulting from subscription updates. Valid values are ‘none`, `create_prorations`, and `always_invoice`.
504 505 506 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 504 def proration_behavior @proration_behavior end |
#schedule_at_period_end ⇒ Object
Setting to control when an update should be scheduled at the end of the period instead of applying immediately.
506 507 508 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 506 def schedule_at_period_end @schedule_at_period_end end |