Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: Product, ScheduleAtPeriodEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil) ⇒ SubscriptionUpdate

Returns a new instance of SubscriptionUpdate.



524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 524

def initialize(
  default_allowed_updates: nil,
  enabled: nil,
  products: nil,
  proration_behavior: nil,
  schedule_at_period_end: nil
)
  @default_allowed_updates = default_allowed_updates
  @enabled = enabled
  @products = products
  @proration_behavior = proration_behavior
  @schedule_at_period_end = schedule_at_period_end
end

Instance Attribute Details

#default_allowed_updatesObject

The types of subscription updates that are supported. When empty, subscriptions are not updateable.



510
511
512
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 510

def default_allowed_updates
  @default_allowed_updates
end

#enabledObject

Whether the feature is enabled.



513
514
515
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 513

def enabled
  @enabled
end

#productsObject

The list of up to 10 products that support subscription updates.



516
517
518
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 516

def products
  @products
end

#proration_behaviorObject

Determines how to handle prorations resulting from subscription updates. Valid values are ‘none`, `create_prorations`, and `always_invoice`.



519
520
521
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 519

def proration_behavior
  @proration_behavior
end

#schedule_at_period_endObject

Setting to control when an update should be scheduled at the end of the period instead of applying immediately.



522
523
524
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 522

def schedule_at_period_end
  @schedule_at_period_end
end