Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: Product, ScheduleAtPeriodEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil) ⇒ SubscriptionUpdate

Returns a new instance of SubscriptionUpdate.



469
470
471
472
473
474
475
476
477
478
479
480
481
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 469

def initialize(
  default_allowed_updates: nil,
  enabled: nil,
  products: nil,
  proration_behavior: nil,
  schedule_at_period_end: nil
)
  @default_allowed_updates = default_allowed_updates
  @enabled = enabled
  @products = products
  @proration_behavior = proration_behavior
  @schedule_at_period_end = schedule_at_period_end
end

Instance Attribute Details

#default_allowed_updatesObject

The types of subscription updates that are supported. When empty, subscriptions are not updateable.



459
460
461
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 459

def default_allowed_updates
  @default_allowed_updates
end

#enabledObject

Whether the feature is enabled.



461
462
463
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 461

def enabled
  @enabled
end

#productsObject

The list of up to 10 products that support subscription updates.



463
464
465
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 463

def products
  @products
end

#proration_behaviorObject

Determines how to handle prorations resulting from subscription updates. Valid values are ‘none`, `create_prorations`, and `always_invoice`.



465
466
467
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 465

def proration_behavior
  @proration_behavior
end

#schedule_at_period_endObject

Setting to control when an update should be scheduled at the end of the period instead of applying immediately.



467
468
469
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 467

def schedule_at_period_end
  @schedule_at_period_end
end