Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate::Product
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate::Product
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
Control whether the quantity of the product can be adjusted.
-
#prices ⇒ Object
The list of price IDs for the product that a subscription can be updated to.
-
#product ⇒ Object
The product id.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product
constructor
A new instance of Product.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product
Returns a new instance of Product.
584 585 586 587 588 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 584 def initialize(adjustable_quantity: nil, prices: nil, product: nil) @adjustable_quantity = adjustable_quantity @prices = prices @product = product end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
Control whether the quantity of the product can be adjusted.
578 579 580 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 578 def adjustable_quantity @adjustable_quantity end |
#prices ⇒ Object
The list of price IDs for the product that a subscription can be updated to.
580 581 582 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 580 def prices @prices end |
#product ⇒ Object
The product id.
582 583 584 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 582 def product @product end |