Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate::Product

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/billing_portal/configuration.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product

Returns a new instance of Product.



470
471
472
473
474
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 470

def initialize(adjustable_quantity: nil, prices: nil, product: nil)
  @adjustable_quantity = adjustable_quantity
  @prices = prices
  @product = product
end

Instance Attribute Details

#adjustable_quantityObject

Control whether the quantity of the product can be adjusted.



464
465
466
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 464

def adjustable_quantity
  @adjustable_quantity
end

#pricesObject

The list of price IDs for the product that a subscription can be updated to.



466
467
468
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 466

def prices
  @prices
end

#productObject

The product id.



468
469
470
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 468

def product
  @product
end