Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate::Product::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate::Product::AdjustableQuantity
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity that can be set for the product.
-
#minimum ⇒ Object
The minimum quantity that can be set for the product.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
457 458 459 460 461 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 457 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
451 452 453 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 451 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity that can be set for the product.
453 454 455 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 453 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity that can be set for the product.
455 456 457 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 455 def minimum @minimum end |