Class: Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate::ScheduleAtPeriodEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Configuration::UpdateParams::Features::SubscriptionUpdate::ScheduleAtPeriodEnd
- Defined in:
- lib/stripe/resources/billing_portal/configuration.rb
Defined Under Namespace
Classes: Condition
Instance Attribute Summary collapse
-
#conditions ⇒ Object
List of conditions.
Instance Method Summary collapse
-
#initialize(conditions: nil) ⇒ ScheduleAtPeriodEnd
constructor
A new instance of ScheduleAtPeriodEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(conditions: nil) ⇒ ScheduleAtPeriodEnd
Returns a new instance of ScheduleAtPeriodEnd.
454 455 456 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 454 def initialize(conditions: nil) @conditions = conditions end |
Instance Attribute Details
#conditions ⇒ Object
List of conditions. When any condition is true, the update will be scheduled at the end of the current period.
452 453 454 |
# File 'lib/stripe/resources/billing_portal/configuration.rb', line 452 def conditions @conditions end |