Class: Stripe::BillingPortal::ConfigurationCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationCreateParams
- Defined in:
- lib/stripe/params/billing_portal/configuration_create_params.rb
Defined Under Namespace
Classes: BusinessProfile, Features, LoginPage
Instance Attribute Summary collapse
-
#business_profile ⇒ Object
The business information shown to customers in the portal.
-
#default_return_url ⇒ Object
The default URL to redirect customers to when they click on the portal's link to return to your website.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
Information about the features available in the portal.
-
#login_page ⇒ Object
The hosted login page for this configuration.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
The name of the configuration.
Instance Method Summary collapse
-
#initialize(business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil, name: nil) ⇒ ConfigurationCreateParams
constructor
A new instance of ConfigurationCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil, name: nil) ⇒ ConfigurationCreateParams
Returns a new instance of ConfigurationCreateParams.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 216 def initialize( business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil, name: nil ) @business_profile = business_profile @default_return_url = default_return_url @expand = @features = features @login_page = login_page @metadata = @name = name end |
Instance Attribute Details
#business_profile ⇒ Object
The business information shown to customers in the portal.
202 203 204 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 202 def business_profile @business_profile end |
#default_return_url ⇒ Object
The default URL to redirect customers to when they click on the portal's link to return to your website. This can be overridden when creating the session.
204 205 206 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 204 def default_return_url @default_return_url end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
206 207 208 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 206 def @expand end |
#features ⇒ Object
Information about the features available in the portal.
208 209 210 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 208 def features @features end |
#login_page ⇒ Object
The hosted login page for this configuration. Learn more about the portal login page in our integration docs.
210 211 212 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 210 def login_page @login_page end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
212 213 214 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 212 def @metadata end |
#name ⇒ Object
The name of the configuration.
214 215 216 |
# File 'lib/stripe/params/billing_portal/configuration_create_params.rb', line 214 def name @name end |