Class: Stripe::BillingPortal::ConfigurationService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::BillingPortal::ConfigurationService
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Defined Under Namespace
Classes: CreateParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a configuration that describes the functionality and behavior of a PortalSession.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of configurations that describe the functionality of the customer portal.
-
#retrieve(configuration, params = {}, opts = {}) ⇒ Object
Retrieves a configuration that describes the functionality of the customer portal.
-
#update(configuration, params = {}, opts = {}) ⇒ Object
Updates a configuration that describes the functionality of the customer portal.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a configuration that describes the functionality and behavior of a PortalSession
452 453 454 455 456 457 458 459 460 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 452 def create(params = {}, opts = {}) request( method: :post, path: "/v1/billing_portal/configurations", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of configurations that describe the functionality of the customer portal.
463 464 465 466 467 468 469 470 471 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 463 def list(params = {}, opts = {}) request( method: :get, path: "/v1/billing_portal/configurations", params: params, opts: opts, base_address: :api ) end |
#retrieve(configuration, params = {}, opts = {}) ⇒ Object
Retrieves a configuration that describes the functionality of the customer portal.
474 475 476 477 478 479 480 481 482 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 474 def retrieve(configuration, params = {}, opts = {}) request( method: :get, path: format("/v1/billing_portal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts, base_address: :api ) end |
#update(configuration, params = {}, opts = {}) ⇒ Object
Updates a configuration that describes the functionality of the customer portal.
485 486 487 488 489 490 491 492 493 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 485 def update(configuration, params = {}, opts = {}) request( method: :post, path: format("/v1/billing_portal/configurations/%<configuration>s", { configuration: CGI.escape(configuration) }), params: params, opts: opts, base_address: :api ) end |