Class: Stripe::BillingPortal::ConfigurationService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing_portal/configuration_service.rb

Defined Under Namespace

Classes: BusinessProfile, Features, LoginPage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(business_profile: nil, default_return_url: nil, expand: nil, features: nil, login_page: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 246

def initialize(
  business_profile: nil,
  default_return_url: nil,
  expand: nil,
  features: nil,
  login_page: nil,
  metadata: nil
)
  @business_profile = business_profile
  @default_return_url = default_return_url
  @expand = expand
  @features = features
  @login_page = 
  @metadata = 
end

Instance Attribute Details

#business_profileObject

The business information shown to customers in the portal.



229
230
231
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 229

def business_profile
  @business_profile
end

#default_return_urlObject

The default URL to redirect customers to when they click on the portal’s link to return to your website. This can be [overriden](stripe.com/docs/api/customer_portal/sessions/create#create_portal_session-return_url) when creating the session.



232
233
234
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 232

def default_return_url
  @default_return_url
end

#expandObject

Specifies which fields in the response should be expanded.



235
236
237
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 235

def expand
  @expand
end

#featuresObject

Information about the features available in the portal.



238
239
240
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 238

def features
  @features
end

#login_pageObject

The hosted login page for this configuration. Learn more about the portal login page in our [integration docs](stripe.com/docs/billing/subscriptions/integrating-customer-portal#share).



241
242
243
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 241

def 
  @login_page
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



244
245
246
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 244

def 
  @metadata
end