Class: Stripe::BillingPortal::ConfigurationService::CreateParams::Features::SubscriptionUpdate::Product

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing_portal/configuration_service.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product

Returns a new instance of Product.



142
143
144
145
146
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 142

def initialize(adjustable_quantity: nil, prices: nil, product: nil)
  @adjustable_quantity = adjustable_quantity
  @prices = prices
  @product = product
end

Instance Attribute Details

#adjustable_quantityObject

Control whether the quantity of the product can be adjusted.



136
137
138
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 136

def adjustable_quantity
  @adjustable_quantity
end

#pricesObject

The list of price IDs for the product that a subscription can be updated to.



138
139
140
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 138

def prices
  @prices
end

#productObject

The product id.



140
141
142
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 140

def product
  @product
end