Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing_portal/configuration_service.rb

Defined Under Namespace

Classes: CustomerUpdate, InvoiceHistory, PaymentMethodUpdate, SubscriptionCancel, SubscriptionUpdate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer_update: nil, invoice_history: nil, payment_method_update: nil, subscription_cancel: nil, subscription_update: nil) ⇒ Features

Returns a new instance of Features.



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 426

def initialize(
  customer_update: nil,
  invoice_history: nil,
  payment_method_update: nil,
  subscription_cancel: nil,
  subscription_update: nil
)
  @customer_update = customer_update
  @invoice_history = invoice_history
  @payment_method_update = payment_method_update
  @subscription_cancel = subscription_cancel
  @subscription_update = subscription_update
end

Instance Attribute Details

#customer_updateObject

Information about updating the customer details in the portal.



416
417
418
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 416

def customer_update
  @customer_update
end

#invoice_historyObject

Information about showing the billing history in the portal.



418
419
420
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 418

def invoice_history
  @invoice_history
end

#payment_method_updateObject

Information about updating payment methods in the portal.



420
421
422
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 420

def payment_method_update
  @payment_method_update
end

#subscription_cancelObject

Information about canceling subscriptions in the portal.



422
423
424
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 422

def subscription_cancel
  @subscription_cancel
end

#subscription_updateObject

Information about updating subscriptions in the portal.



424
425
426
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 424

def subscription_update
  @subscription_update
end