Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionCancel
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionCancel
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Defined Under Namespace
Classes: CancellationReason
Instance Attribute Summary collapse
-
#cancellation_reason ⇒ Object
Whether the cancellation reasons will be collected in the portal and which options are exposed to the customer.
-
#enabled ⇒ Object
Whether the feature is enabled.
-
#mode ⇒ Object
Whether to cancel subscriptions immediately or at the end of the billing period.
-
#proration_behavior ⇒ Object
Whether to create prorations when canceling subscriptions.
Instance Method Summary collapse
-
#initialize(cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil) ⇒ SubscriptionCancel
constructor
A new instance of SubscriptionCancel.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil) ⇒ SubscriptionCancel
Returns a new instance of SubscriptionCancel.
347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 347 def initialize( cancellation_reason: nil, enabled: nil, mode: nil, proration_behavior: nil ) @cancellation_reason = cancellation_reason @enabled = enabled @mode = mode @proration_behavior = proration_behavior end |
Instance Attribute Details
#cancellation_reason ⇒ Object
Whether the cancellation reasons will be collected in the portal and which options are exposed to the customer
336 337 338 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 336 def cancellation_reason @cancellation_reason end |
#enabled ⇒ Object
Whether the feature is enabled.
339 340 341 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 339 def enabled @enabled end |
#mode ⇒ Object
Whether to cancel subscriptions immediately or at the end of the billing period.
342 343 344 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 342 def mode @mode end |
#proration_behavior ⇒ Object
Whether to create prorations when canceling subscriptions. Possible values are ‘none` and `create_prorations`, which is only compatible with `mode=immediately`. No prorations are generated when canceling a subscription at the end of its natural billing period.
345 346 347 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 345 def proration_behavior @proration_behavior end |