Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/billing_portal/configuration_service.rb

Defined Under Namespace

Classes: Product, ScheduleAtPeriodEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(default_allowed_updates: nil, enabled: nil, products: nil, proration_behavior: nil, schedule_at_period_end: nil) ⇒ SubscriptionUpdate

Returns a new instance of SubscriptionUpdate.



367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 367

def initialize(
  default_allowed_updates: nil,
  enabled: nil,
  products: nil,
  proration_behavior: nil,
  schedule_at_period_end: nil
)
  @default_allowed_updates = default_allowed_updates
  @enabled = enabled
  @products = products
  @proration_behavior = proration_behavior
  @schedule_at_period_end = schedule_at_period_end
end

Instance Attribute Details

#default_allowed_updatesObject

The types of subscription updates that are supported. When empty, subscriptions are not updateable.



357
358
359
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 357

def default_allowed_updates
  @default_allowed_updates
end

#enabledObject

Whether the feature is enabled.



359
360
361
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 359

def enabled
  @enabled
end

#productsObject

The list of up to 10 products that support subscription updates.



361
362
363
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 361

def products
  @products
end

#proration_behaviorObject

Determines how to handle prorations resulting from subscription updates. Valid values are ‘none`, `create_prorations`, and `always_invoice`.



363
364
365
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 363

def proration_behavior
  @proration_behavior
end

#schedule_at_period_endObject

Setting to control when an update should be scheduled at the end of the period instead of applying immediately.



365
366
367
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 365

def schedule_at_period_end
  @schedule_at_period_end
end