Class: Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate::Product
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::ConfigurationService::UpdateParams::Features::SubscriptionUpdate::Product
- Defined in:
- lib/stripe/services/billing_portal/configuration_service.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
Control whether the quantity of the product can be adjusted.
-
#prices ⇒ Object
The list of price IDs for the product that a subscription can be updated to.
-
#product ⇒ Object
The product id.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product
constructor
A new instance of Product.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, prices: nil, product: nil) ⇒ Product
Returns a new instance of Product.
367 368 369 370 371 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 367 def initialize(adjustable_quantity: nil, prices: nil, product: nil) @adjustable_quantity = adjustable_quantity @prices = prices @product = product end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
Control whether the quantity of the product can be adjusted.
361 362 363 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 361 def adjustable_quantity @adjustable_quantity end |
#prices ⇒ Object
The list of price IDs for the product that a subscription can be updated to.
363 364 365 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 363 def prices @prices end |
#product ⇒ Object
The product id.
365 366 367 |
# File 'lib/stripe/services/billing_portal/configuration_service.rb', line 365 def product @product end |