Class: Stripe::BillingPortal::Session::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Session::CreateParams
- Defined in:
- lib/stripe/resources/billing_portal/session.rb
Defined Under Namespace
Classes: FlowData
Instance Attribute Summary collapse
-
#configuration ⇒ Object
The ID of an existing [configuration](stripe.com/docs/api/customer_portal/configuration) to use for this session, describing its functionality and features.
-
#customer ⇒ Object
The ID of an existing customer.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#flow_data ⇒ Object
Information about a specific flow for the customer to go through.
-
#locale ⇒ Object
The IETF language tag of the locale customer portal is displayed in.
-
#on_behalf_of ⇒ Object
The ‘on_behalf_of` account to use for this session.
-
#return_url ⇒ Object
The default URL to redirect customers to when they click on the portal’s link to return to your website.
Instance Method Summary collapse
-
#initialize(configuration: nil, customer: nil, expand: nil, flow_data: nil, locale: nil, on_behalf_of: nil, return_url: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(configuration: nil, customer: nil, expand: nil, flow_data: nil, locale: nil, on_behalf_of: nil, return_url: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 290 def initialize( configuration: nil, customer: nil, expand: nil, flow_data: nil, locale: nil, on_behalf_of: nil, return_url: nil ) @configuration = configuration @customer = customer @expand = @flow_data = flow_data @locale = locale @on_behalf_of = on_behalf_of @return_url = return_url end |
Instance Attribute Details
#configuration ⇒ Object
The ID of an existing [configuration](stripe.com/docs/api/customer_portal/configuration) to use for this session, describing its functionality and features. If not specified, the session uses the default configuration.
270 271 272 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 270 def configuration @configuration end |
#customer ⇒ Object
The ID of an existing customer.
273 274 275 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 273 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
276 277 278 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 276 def @expand end |
#flow_data ⇒ Object
Information about a specific flow for the customer to go through. See the [docs](stripe.com/docs/customer-management/portal-deep-links) to learn more about using customer portal deep links and flows.
279 280 281 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 279 def flow_data @flow_data end |
#locale ⇒ Object
The IETF language tag of the locale customer portal is displayed in. If blank or auto, the customer’s ‘preferred_locales` or browser’s locale is used.
282 283 284 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 282 def locale @locale end |
#on_behalf_of ⇒ Object
The ‘on_behalf_of` account to use for this session. When specified, only subscriptions and invoices with this `on_behalf_of` account appear in the portal. For more information, see the [docs](stripe.com/docs/connect/separate-charges-and-transfers#settlement-merchant). Use the [Accounts API](stripe.com/docs/api/accounts/object#account_object-settings-branding) to modify the `on_behalf_of` account’s branding settings, which the portal displays.
285 286 287 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 285 def on_behalf_of @on_behalf_of end |
#return_url ⇒ Object
The default URL to redirect customers to when they click on the portal’s link to return to your website.
288 289 290 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 288 def return_url @return_url end |