Class: Stripe::BillingPortal::Session::CreateParams::FlowData::AfterCompletion::HostedConfirmation
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::Session::CreateParams::FlowData::AfterCompletion::HostedConfirmation
- Defined in:
- lib/stripe/resources/billing_portal/session.rb
Instance Attribute Summary collapse
-
#custom_message ⇒ Object
A custom message to display to the customer after the flow is completed.
Instance Method Summary collapse
-
#initialize(custom_message: nil) ⇒ HostedConfirmation
constructor
A new instance of HostedConfirmation.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_message: nil) ⇒ HostedConfirmation
Returns a new instance of HostedConfirmation.
204 205 206 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 204 def initialize(custom_message: nil) @custom_message = end |
Instance Attribute Details
#custom_message ⇒ Object
A custom message to display to the customer after the flow is completed.
202 203 204 |
# File 'lib/stripe/resources/billing_portal/session.rb', line 202 def @custom_message end |