Class: Stripe::BillingPortal::SessionService::CreateParams::FlowData::SubscriptionUpdateConfirm
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::BillingPortal::SessionService::CreateParams::FlowData::SubscriptionUpdateConfirm
- Defined in:
- lib/stripe/services/billing_portal/session_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupon or promotion code to apply to this subscription update.
-
#items ⇒ Object
The [subscription item](stripe.com/docs/api/subscription_items) to be updated through this flow.
-
#subscription ⇒ Object
The ID of the subscription to be updated.
Instance Method Summary collapse
-
#initialize(discounts: nil, items: nil, subscription: nil) ⇒ SubscriptionUpdateConfirm
constructor
A new instance of SubscriptionUpdateConfirm.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, items: nil, subscription: nil) ⇒ SubscriptionUpdateConfirm
Returns a new instance of SubscriptionUpdateConfirm.
124 125 126 127 128 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 124 def initialize(discounts: nil, items: nil, subscription: nil) @discounts = discounts @items = items @subscription = subscription end |
Instance Attribute Details
#discounts ⇒ Object
The coupon or promotion code to apply to this subscription update. Currently, only up to one may be specified.
116 117 118 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 116 def discounts @discounts end |
#items ⇒ Object
The [subscription item](stripe.com/docs/api/subscription_items) to be updated through this flow. Currently, only up to one may be specified and subscriptions with multiple items are not updatable.
119 120 121 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 119 def items @items end |
#subscription ⇒ Object
The ID of the subscription to be updated.
122 123 124 |
# File 'lib/stripe/services/billing_portal/session_service.rb', line 122 def subscription @subscription end |