Class: Stripe::Capability::Requirements
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Capability::Requirements
- Defined in:
- lib/stripe/resources/capability.rb
Defined Under Namespace
Classes: Alternative, Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alternatives ⇒ Object
readonly
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
-
#current_deadline ⇒ Object
readonly
Date by which the fields in ‘currently_due` must be collected to keep the capability enabled for the account.
-
#currently_due ⇒ Object
readonly
Fields that need to be collected to keep the capability enabled.
-
#disabled_reason ⇒ Object
readonly
Description of why the capability is disabled.
-
#errors ⇒ Object
readonly
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
-
#eventually_due ⇒ Object
readonly
Fields that need to be collected assuming all volume thresholds are reached.
-
#past_due ⇒ Object
readonly
Fields that weren’t collected by ‘current_deadline`.
-
#pending_verification ⇒ Object
readonly
Fields that might become required depending on the results of verification or review.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alternatives ⇒ Object (readonly)
Fields that are due and can be satisfied by providing the corresponding alternative fields instead.
80 81 82 |
# File 'lib/stripe/resources/capability.rb', line 80 def alternatives @alternatives end |
#current_deadline ⇒ Object (readonly)
Date by which the fields in ‘currently_due` must be collected to keep the capability enabled for the account. These fields may disable the capability sooner if the next threshold is reached before they are collected.
83 84 85 |
# File 'lib/stripe/resources/capability.rb', line 83 def current_deadline @current_deadline end |
#currently_due ⇒ Object (readonly)
Fields that need to be collected to keep the capability enabled. If not collected by ‘current_deadline`, these fields appear in `past_due` as well, and the capability is disabled.
86 87 88 |
# File 'lib/stripe/resources/capability.rb', line 86 def currently_due @currently_due end |
#disabled_reason ⇒ Object (readonly)
Description of why the capability is disabled. [Learn more about handling verification issues](stripe.com/docs/connect/handling-api-verification).
89 90 91 |
# File 'lib/stripe/resources/capability.rb', line 89 def disabled_reason @disabled_reason end |
#errors ⇒ Object (readonly)
Fields that are ‘currently_due` and need to be collected again because validation or verification failed.
92 93 94 |
# File 'lib/stripe/resources/capability.rb', line 92 def errors @errors end |
#eventually_due ⇒ Object (readonly)
Fields that need to be collected assuming all volume thresholds are reached. As they become required, they appear in ‘currently_due` as well, and `current_deadline` becomes set.
95 96 97 |
# File 'lib/stripe/resources/capability.rb', line 95 def eventually_due @eventually_due end |
#past_due ⇒ Object (readonly)
Fields that weren’t collected by ‘current_deadline`. These fields need to be collected to enable the capability on the account.
98 99 100 |
# File 'lib/stripe/resources/capability.rb', line 98 def past_due @past_due end |
#pending_verification ⇒ Object (readonly)
Fields that might become required depending on the results of verification or review. It’s an empty array unless an asynchronous verification is pending. If verification fails, these fields move to ‘eventually_due`, `currently_due`, or `past_due`. Fields might appear in `eventually_due`, `currently_due`, or `past_due` and in `pending_verification` if verification fails but another verification is still pending.
101 102 103 |
# File 'lib/stripe/resources/capability.rb', line 101 def pending_verification @pending_verification end |