Class: Stripe::Capital::FinancingOffer::AcceptedTerms
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Capital::FinancingOffer::AcceptedTerms
- Defined in:
- lib/stripe/resources/capital/financing_offer.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#advance_amount ⇒ Object
readonly
Amount of financing offered, in minor units.
-
#currency ⇒ Object
readonly
Currency that the financing offer is transacted in.
-
#fee_amount ⇒ Object
readonly
Fixed fee amount, in minor units.
-
#previous_financing_fee_discount_amount ⇒ Object
readonly
Populated when the ‘product_type` of the `financingoffer` is `refill`.
-
#withhold_rate ⇒ Object
readonly
Per-transaction rate at which Stripe will withhold funds to repay the financing.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#advance_amount ⇒ Object (readonly)
Amount of financing offered, in minor units.
18 19 20 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 18 def advance_amount @advance_amount end |
#currency ⇒ Object (readonly)
Currency that the financing offer is transacted in. For example, ‘usd`.
21 22 23 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 21 def currency @currency end |
#fee_amount ⇒ Object (readonly)
Fixed fee amount, in minor units.
24 25 26 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 24 def fee_amount @fee_amount end |
#previous_financing_fee_discount_amount ⇒ Object (readonly)
Populated when the ‘product_type` of the `financingoffer` is `refill`. Represents the discount amount on remaining premium for the existing loan at payout time.
28 29 30 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 28 def previous_financing_fee_discount_amount @previous_financing_fee_discount_amount end |
#withhold_rate ⇒ Object (readonly)
Per-transaction rate at which Stripe will withhold funds to repay the financing.
31 32 33 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 31 def withhold_rate @withhold_rate end |