Class: Stripe::Capital::FinancingOffer::OfferedTerms
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Capital::FinancingOffer::OfferedTerms
- Defined in:
- lib/stripe/resources/capital/financing_offer.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#advance_amount ⇒ Object
readonly
Amount of financing offered, in minor units.
-
#campaign_type ⇒ Object
readonly
Describes the type of user the offer is being extended to.
-
#currency ⇒ Object
readonly
Currency that the financing offer is transacted in.
-
#fee_amount ⇒ Object
readonly
Fixed fee amount, in minor units.
-
#previous_financing_fee_discount_rate ⇒ Object
readonly
Populated when the ‘product_type` of the `financingoffer` is `refill`.
-
#withhold_rate ⇒ Object
readonly
Per-transaction rate at which Stripe will withhold funds to repay the financing.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#advance_amount ⇒ Object (readonly)
Amount of financing offered, in minor units. For example, $1,000 USD will be represented as 100000.
32 33 34 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 32 def advance_amount @advance_amount end |
#campaign_type ⇒ Object (readonly)
Describes the type of user the offer is being extended to.
34 35 36 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 34 def campaign_type @campaign_type end |
#currency ⇒ Object (readonly)
Currency that the financing offer is transacted in. For example, ‘usd`.
36 37 38 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 36 def currency @currency end |
#fee_amount ⇒ Object (readonly)
Fixed fee amount, in minor units. For example, $100 USD will be represented as 10000.
38 39 40 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 38 def fee_amount @fee_amount end |
#previous_financing_fee_discount_rate ⇒ Object (readonly)
Populated when the ‘product_type` of the `financingoffer` is `refill`. Represents the discount rate percentage on remaining fee on the existing loan. When the `financing_offer` is paid out, the `previous_financing_fee_discount_amount` will be computed as the multiple of this rate and the remaining fee.
43 44 45 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 43 def previous_financing_fee_discount_rate @previous_financing_fee_discount_rate end |
#withhold_rate ⇒ Object (readonly)
Per-transaction rate at which Stripe will withhold funds to repay the financing.
45 46 47 |
# File 'lib/stripe/resources/capital/financing_offer.rb', line 45 def withhold_rate @withhold_rate end |