Class: Stripe::Capital::FinancingOfferService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Capital::FinancingOfferService
- Defined in:
- lib/stripe/services/capital/financing_offer_service.rb
Defined Under Namespace
Classes: ListParams, MarkDeliveredParams, RetrieveParams
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
Retrieves the financing offers available for Connected accounts that belong to your platform.
-
#mark_delivered(financing_offer, params = {}, opts = {}) ⇒ Object
Acknowledges that platform has received and delivered the financing_offer to the intended merchant recipient.
-
#retrieve(financing_offer, params = {}, opts = {}) ⇒ Object
Get the details of the financing offer.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
Retrieves the financing offers available for Connected accounts that belong to your platform.
78 79 80 81 82 83 84 85 86 |
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 78 def list(params = {}, opts = {}) request( method: :get, path: "/v1/capital/financing_offers", params: params, opts: opts, base_address: :api ) end |
#mark_delivered(financing_offer, params = {}, opts = {}) ⇒ Object
Acknowledges that platform has received and delivered the financing_offer to the intended merchant recipient.
90 91 92 93 94 95 96 97 98 |
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 90 def mark_delivered(financing_offer, params = {}, opts = {}) request( method: :post, path: format("/v1/capital/financing_offers/%<financing_offer>s/mark_delivered", { financing_offer: CGI.escape(financing_offer) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(financing_offer, params = {}, opts = {}) ⇒ Object
Get the details of the financing offer
101 102 103 104 105 106 107 108 109 |
# File 'lib/stripe/services/capital/financing_offer_service.rb', line 101 def retrieve(financing_offer, params = {}, opts = {}) request( method: :get, path: format("/v1/capital/financing_offers/%<financing_offer>s", { financing_offer: CGI.escape(financing_offer) }), params: params, opts: opts, base_address: :api ) end |