Class: Stripe::Capital::FinancingSummary::Details

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/capital/financing_summary.rb

Defined Under Namespace

Classes: CurrentRepaymentInterval

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advance_amountObject (readonly)

Amount of financing offered, in minor units. For example, $1,000 USD will be represented as 100000.



25
26
27
# File 'lib/stripe/resources/capital/financing_summary.rb', line 25

def advance_amount
  @advance_amount
end

#advance_paid_out_atObject (readonly)

The time at which the funds were paid out to the connected account’s Stripe balance. Given in milliseconds since unix epoch.



27
28
29
# File 'lib/stripe/resources/capital/financing_summary.rb', line 27

def advance_paid_out_at
  @advance_paid_out_at
end

#currencyObject (readonly)

Currency that the financing offer is transacted in. For example, ‘usd`.



29
30
31
# File 'lib/stripe/resources/capital/financing_summary.rb', line 29

def currency
  @currency
end

#current_repayment_intervalObject (readonly)

The chronologically current repayment interval for the financing offer.



31
32
33
# File 'lib/stripe/resources/capital/financing_summary.rb', line 31

def current_repayment_interval
  @current_repayment_interval
end

#fee_amountObject (readonly)

Fixed fee amount, in minor units. For example, $100 USD will be represented as 10000.



33
34
35
# File 'lib/stripe/resources/capital/financing_summary.rb', line 33

def fee_amount
  @fee_amount
end

The amount the Connected account has paid toward the financing debt so far, in minor units. For example, $1,000 USD will be represented as 100000.



35
36
37
# File 'lib/stripe/resources/capital/financing_summary.rb', line 35

def paid_amount
  @paid_amount
end

#remaining_amountObject (readonly)

The balance remaining to be paid on the financing, in minor units. For example, $1,000 USD will be represented as 100000.



37
38
39
# File 'lib/stripe/resources/capital/financing_summary.rb', line 37

def remaining_amount
  @remaining_amount
end

#repayments_begin_atObject (readonly)

The time at which Capital will begin withholding from payments. Given in seconds since unix epoch.



39
40
41
# File 'lib/stripe/resources/capital/financing_summary.rb', line 39

def repayments_begin_at
  @repayments_begin_at
end

#withhold_rateObject (readonly)

Per-transaction rate at which Stripe will withhold funds to repay the financing.



41
42
43
# File 'lib/stripe/resources/capital/financing_summary.rb', line 41

def withhold_rate
  @withhold_rate
end