Class: Stripe::Capital::FinancingSummary::Details::CurrentRepaymentInterval

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/capital/financing_summary.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#due_atObject (readonly)

The time at which the minimum payment amount will be due. If not met through withholding, the Connected account’s linked bank account or account balance will be debited. Given in seconds since unix epoch.



18
19
20
# File 'lib/stripe/resources/capital/financing_summary.rb', line 18

def due_at
  @due_at
end

The amount that has already been paid in the current repayment interval.



20
21
22
# File 'lib/stripe/resources/capital/financing_summary.rb', line 20

def paid_amount
  @paid_amount
end

#remaining_amountObject (readonly)

The amount that is yet to be paid in the current repayment interval.



22
23
24
# File 'lib/stripe/resources/capital/financing_summary.rb', line 22

def remaining_amount
  @remaining_amount
end