Class: Stripe::Capital::FinancingTransaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Capital::FinancingTransaction
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/capital/financing_transaction.rb
Overview
This is an object representing the details of a transaction on a Capital financing object.
Defined Under Namespace
Classes: Details, ListParams, RetrieveParams
Constant Summary collapse
- OBJECT_NAME =
"capital.financing_transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the merchant associated with this financing transaction.
-
#created_at ⇒ Object
readonly
Time at which the financing transaction was created.
-
#details ⇒ Object
readonly
This is an object representing a transaction on a Capital financing offer.
-
#financing_offer ⇒ Object
readonly
The Capital financing offer for this financing transaction.
-
#id ⇒ Object
readonly
A unique identifier for the financing transaction object.
-
#legacy_balance_transaction_source ⇒ Object
readonly
The Capital transaction object that predates the Financing Transactions API and corresponds with the balance transaction that was created as a result of this financing transaction.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
The object type: financing_transaction.
-
#type ⇒ Object
readonly
The type of the financing transaction.
-
#user_facing_description ⇒ Object
readonly
A human-friendly description of the financing transaction.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of financing transactions.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the merchant associated with this financing transaction.
89 90 91 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 89 def account @account end |
#created_at ⇒ Object (readonly)
Time at which the financing transaction was created. Given in seconds since unix epoch.
91 92 93 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 91 def created_at @created_at end |
#details ⇒ Object (readonly)
This is an object representing a transaction on a Capital financing offer.
93 94 95 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 93 def details @details end |
#financing_offer ⇒ Object (readonly)
The Capital financing offer for this financing transaction.
95 96 97 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 95 def financing_offer @financing_offer end |
#id ⇒ Object (readonly)
A unique identifier for the financing transaction object.
97 98 99 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 97 def id @id end |
#legacy_balance_transaction_source ⇒ Object (readonly)
The Capital transaction object that predates the Financing Transactions API and corresponds with the balance transaction that was created as a result of this financing transaction.
101 102 103 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 101 def legacy_balance_transaction_source @legacy_balance_transaction_source end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
103 104 105 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 103 def livemode @livemode end |
#object ⇒ Object (readonly)
The object type: financing_transaction
105 106 107 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 105 def object @object end |
#type ⇒ Object (readonly)
The type of the financing transaction.
107 108 109 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 107 def type @type end |
#user_facing_description ⇒ Object (readonly)
A human-friendly description of the financing transaction.
109 110 111 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 109 def user_facing_description @user_facing_description end |
Class Method Details
.list(params = {}, opts = {}) ⇒ Object
Returns a list of financing transactions. The transactions are returned in sorted order, with the most recent transactions appearing first.
113 114 115 116 117 118 119 120 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 113 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/capital/financing_transactions", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 11 def self.object_name "capital.financing_transaction" end |