Class: Stripe::Capital::FinancingTransaction::Details
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Capital::FinancingTransaction::Details
- Defined in:
- lib/stripe/resources/capital/financing_transaction.rb
Defined Under Namespace
Classes: Transaction
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#advance_amount ⇒ Object
readonly
The advance amount being repaid, paid out, or reversed in minor units.
-
#currency ⇒ Object
readonly
The currency of the financing transaction.
-
#fee_amount ⇒ Object
readonly
The fee amount being repaid, paid out, or reversed in minor units.
-
#linked_payment ⇒ Object
readonly
The linked payment for the transaction.
-
#reason ⇒ Object
readonly
The reason for the financing transaction (if applicable).
-
#reversed_transaction ⇒ Object
readonly
The reversed transaction.
-
#total_amount ⇒ Object
readonly
The advance and fee amount being repaid, paid out, or reversed in minor units.
-
#transaction ⇒ Object
readonly
This is an object representing a linked transaction on a Capital Financing Transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#advance_amount ⇒ Object (readonly)
The advance amount being repaid, paid out, or reversed in minor units.
31 32 33 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 31 def advance_amount @advance_amount end |
#currency ⇒ Object (readonly)
The currency of the financing transaction.
33 34 35 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 33 def currency @currency end |
#fee_amount ⇒ Object (readonly)
The fee amount being repaid, paid out, or reversed in minor units.
35 36 37 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 35 def fee_amount @fee_amount end |
#linked_payment ⇒ Object (readonly)
The linked payment for the transaction. This field only applies to financing transactions of type ‘paydown` and reason `automatic_withholding`.
37 38 39 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 37 def linked_payment @linked_payment end |
#reason ⇒ Object (readonly)
The reason for the financing transaction (if applicable).
39 40 41 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 39 def reason @reason end |
#reversed_transaction ⇒ Object (readonly)
The reversed transaction. This field only applies to financing transactions of type ‘reversal`.
42 43 44 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 42 def reversed_transaction @reversed_transaction end |
#total_amount ⇒ Object (readonly)
The advance and fee amount being repaid, paid out, or reversed in minor units.
44 45 46 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 44 def total_amount @total_amount end |
#transaction ⇒ Object (readonly)
This is an object representing a linked transaction on a Capital Financing Transaction.
46 47 48 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 46 def transaction @transaction end |
Class Method Details
.field_remappings ⇒ Object
52 53 54 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 52 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
48 49 50 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 48 def self.inner_class_types @inner_class_types = { transaction: Transaction } end |