Class: Stripe::Capital::FinancingTransaction::Details
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Capital::FinancingTransaction::Details
- Defined in:
- lib/stripe/resources/capital/financing_transaction.rb
Defined Under Namespace
Classes: Transaction
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#advance_amount ⇒ Object
readonly
The advance amount being repaid, paid out, or reversed in minor units.
-
#currency ⇒ Object
readonly
The currency of the financing transaction.
-
#fee_amount ⇒ Object
readonly
The fee amount being repaid, paid out, or reversed in minor units.
-
#linked_payment ⇒ Object
readonly
The linked payment for the transaction.
-
#reason ⇒ Object
readonly
The reason for the financing transaction (if applicable).
-
#reversed_transaction ⇒ Object
readonly
The reversed transaction.
-
#total_amount ⇒ Object
readonly
The advance and fee amount being repaid, paid out, or reversed in minor units.
-
#transaction ⇒ Object
readonly
This is an object representing a linked transaction on a Capital Financing Transaction.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#advance_amount ⇒ Object (readonly)
The advance amount being repaid, paid out, or reversed in minor units.
23 24 25 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 23 def advance_amount @advance_amount end |
#currency ⇒ Object (readonly)
The currency of the financing transaction.
25 26 27 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 25 def currency @currency end |
#fee_amount ⇒ Object (readonly)
The fee amount being repaid, paid out, or reversed in minor units.
27 28 29 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 27 def fee_amount @fee_amount end |
#linked_payment ⇒ Object (readonly)
The linked payment for the transaction. This field only applies to financing transactions of type ‘paydown` and reason `automatic_withholding`.
29 30 31 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 29 def linked_payment @linked_payment end |
#reason ⇒ Object (readonly)
The reason for the financing transaction (if applicable).
31 32 33 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 31 def reason @reason end |
#reversed_transaction ⇒ Object (readonly)
The reversed transaction. This field only applies to financing transactions of type ‘reversal`.
34 35 36 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 34 def reversed_transaction @reversed_transaction end |
#total_amount ⇒ Object (readonly)
The advance and fee amount being repaid, paid out, or reversed in minor units.
36 37 38 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 36 def total_amount @total_amount end |
#transaction ⇒ Object (readonly)
This is an object representing a linked transaction on a Capital Financing Transaction.
38 39 40 |
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 38 def transaction @transaction end |