Class: Stripe::Capital::FinancingTransaction::Details

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/capital/financing_transaction.rb

Defined Under Namespace

Classes: Transaction

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advance_amountObject (readonly)

The advance amount being repaid, paid out, or reversed in minor units.



24
25
26
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 24

def advance_amount
  @advance_amount
end

#currencyObject (readonly)

The currency of the financing transaction.



27
28
29
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 27

def currency
  @currency
end

#fee_amountObject (readonly)

The fee amount being repaid, paid out, or reversed in minor units.



30
31
32
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 30

def fee_amount
  @fee_amount
end

#linked_paymentObject (readonly)

The linked payment for the transaction. This field only applies to financing transactions of type ‘paydown` and reason `automatic_withholding`.



33
34
35
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 33

def linked_payment
  @linked_payment
end

#reasonObject (readonly)

The reason for the financing transaction (if applicable).



36
37
38
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 36

def reason
  @reason
end

#reversed_transactionObject (readonly)

The reversed transaction. This field only applies to financing transactions of type ‘reversal`.



40
41
42
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 40

def reversed_transaction
  @reversed_transaction
end

#total_amountObject (readonly)

The advance and fee amount being repaid, paid out, or reversed in minor units.



43
44
45
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 43

def total_amount
  @total_amount
end

#transactionObject (readonly)

This is an object representing a linked transaction on a Capital Financing Transaction.



46
47
48
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 46

def transaction
  @transaction
end