Class: Stripe::Capital::FinancingTransaction::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/capital/financing_transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(charge: nil, ending_before: nil, expand: nil, financing_offer: nil, limit: nil, reversed_transaction: nil, starting_after: nil, treasury_transaction: nil) ⇒ ListParams

Returns a new instance of ListParams.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 59

def initialize(
  charge: nil,
  ending_before: nil,
  expand: nil,
  financing_offer: nil,
  limit: nil,
  reversed_transaction: nil,
  starting_after: nil,
  treasury_transaction: nil
)
  @charge = charge
  @ending_before = ending_before
  @expand = expand
  @financing_offer = financing_offer
  @limit = limit
  @reversed_transaction = reversed_transaction
  @starting_after = starting_after
  @treasury_transaction = treasury_transaction
end

Instance Attribute Details

#chargeObject

For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this charge.



43
44
45
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 43

def charge
  @charge
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



45
46
47
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 45

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



47
48
49
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 47

def expand
  @expand
end

#financing_offerObject

Returns transactions that were created that apply to this financing offer ID.



49
50
51
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 49

def financing_offer
  @financing_offer
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



51
52
53
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 51

def limit
  @limit
end

#reversed_transactionObject

Only returns transactions that are responsible for reversing this financing transaction ID.



53
54
55
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 53

def reversed_transaction
  @reversed_transaction
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



55
56
57
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 55

def starting_after
  @starting_after
end

#treasury_transactionObject

For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this Treasury Transaction.



57
58
59
# File 'lib/stripe/resources/capital/financing_transaction.rb', line 57

def treasury_transaction
  @treasury_transaction
end