Class: Stripe::Capital::FinancingTransactionListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Capital::FinancingTransactionListParams
- Defined in:
- lib/stripe/params/capital/financing_transaction_list_params.rb
Instance Attribute Summary collapse
-
#charge ⇒ Object
For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this charge.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financing_offer ⇒ Object
Returns transactions that were created that apply to this financing offer ID.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#reversed_transaction ⇒ Object
Only returns transactions that are responsible for reversing this financing transaction ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#treasury_transaction ⇒ Object
For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this Treasury Transaction.
Instance Method Summary collapse
-
#initialize(charge: nil, ending_before: nil, expand: nil, financing_offer: nil, limit: nil, reversed_transaction: nil, starting_after: nil, treasury_transaction: nil) ⇒ FinancingTransactionListParams
constructor
A new instance of FinancingTransactionListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(charge: nil, ending_before: nil, expand: nil, financing_offer: nil, limit: nil, reversed_transaction: nil, starting_after: nil, treasury_transaction: nil) ⇒ FinancingTransactionListParams
Returns a new instance of FinancingTransactionListParams.
24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 24 def initialize( charge: nil, ending_before: nil, expand: nil, financing_offer: nil, limit: nil, reversed_transaction: nil, starting_after: nil, treasury_transaction: nil ) @charge = charge @ending_before = ending_before @expand = @financing_offer = financing_offer @limit = limit @reversed_transaction = reversed_transaction @starting_after = starting_after @treasury_transaction = treasury_transaction end |
Instance Attribute Details
#charge ⇒ Object
For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this charge.
8 9 10 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 8 def charge @charge end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
10 11 12 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 10 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
12 13 14 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 12 def @expand end |
#financing_offer ⇒ Object
Returns transactions that were created that apply to this financing offer ID.
14 15 16 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 14 def financing_offer @financing_offer end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
16 17 18 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 16 def limit @limit end |
#reversed_transaction ⇒ Object
Only returns transactions that are responsible for reversing this financing transaction ID.
18 19 20 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 18 def reversed_transaction @reversed_transaction end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
20 21 22 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 20 def starting_after @starting_after end |
#treasury_transaction ⇒ Object
For transactions of type ‘paydown` and reason `automatic_withholding` only, only returns transactions that were created as a result of this Treasury Transaction.
22 23 24 |
# File 'lib/stripe/params/capital/financing_transaction_list_params.rb', line 22 def treasury_transaction @treasury_transaction end |