Class: Stripe::Card

Inherits:
APIResource show all
Extended by:
APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/card.rb

Overview

You can store multiple cards on a customer in order to charge the customer later. You can also store multiple debit cards on a recipient in order to transfer to those cards later.

Related guide: [Card payments with Sources](stripe.com/docs/sources/cards)

Defined Under Namespace

Classes: Networks

Constant Summary collapse

OBJECT_NAME =
"card"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The account this card belongs to. This attribute will not be in the card object if the card belongs to a customer or recipient instead. This property is only available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.



25
26
27
# File 'lib/stripe/resources/card.rb', line 25

def 
  @account
end

#address_cityObject (readonly)

City/District/Suburb/Town/Village.



27
28
29
# File 'lib/stripe/resources/card.rb', line 27

def address_city
  @address_city
end

#address_countryObject (readonly)

Billing address country, if provided when creating card.



29
30
31
# File 'lib/stripe/resources/card.rb', line 29

def address_country
  @address_country
end

#address_line1Object (readonly)

Address line 1 (Street address/PO Box/Company name).



31
32
33
# File 'lib/stripe/resources/card.rb', line 31

def address_line1
  @address_line1
end

#address_line1_checkObject (readonly)

If ‘address_line1` was provided, results of the check: `pass`, `fail`, `unavailable`, or `unchecked`.



33
34
35
# File 'lib/stripe/resources/card.rb', line 33

def address_line1_check
  @address_line1_check
end

#address_line2Object (readonly)

Address line 2 (Apartment/Suite/Unit/Building).



35
36
37
# File 'lib/stripe/resources/card.rb', line 35

def address_line2
  @address_line2
end

#address_stateObject (readonly)

State/County/Province/Region.



37
38
39
# File 'lib/stripe/resources/card.rb', line 37

def address_state
  @address_state
end

#address_zipObject (readonly)

ZIP or postal code.



39
40
41
# File 'lib/stripe/resources/card.rb', line 39

def address_zip
  @address_zip
end

#address_zip_checkObject (readonly)

If ‘address_zip` was provided, results of the check: `pass`, `fail`, `unavailable`, or `unchecked`.



41
42
43
# File 'lib/stripe/resources/card.rb', line 41

def address_zip_check
  @address_zip_check
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



43
44
45
# File 'lib/stripe/resources/card.rb', line 43

def allow_redisplay
  @allow_redisplay
end

#available_payout_methodsObject (readonly)

A set of available payout methods for this card. Only values from this set should be passed as the ‘method` when creating a payout.



45
46
47
# File 'lib/stripe/resources/card.rb', line 45

def available_payout_methods
  @available_payout_methods
end

#brandObject (readonly)

Card brand. Can be ‘American Express`, `Diners Club`, `Discover`, `Eftpos Australia`, `Girocard`, `JCB`, `MasterCard`, `UnionPay`, `Visa`, or `Unknown`.



47
48
49
# File 'lib/stripe/resources/card.rb', line 47

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card. (For internal use only and not typically available in standard API requests.)



49
50
51
# File 'lib/stripe/resources/card.rb', line 49

def brand_product
  @brand_product
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



51
52
53
# File 'lib/stripe/resources/card.rb', line 51

def country
  @country
end

#currencyObject (readonly)

Three-letter [ISO code for currency](www.iso.org/iso-4217-currency-codes.html) in lowercase. Must be a [supported currency](docs.stripe.com/currencies). Only applicable on accounts (not customers or recipients). The card can be used as a transfer destination for funds in this currency. This property is only available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.



53
54
55
# File 'lib/stripe/resources/card.rb', line 53

def currency
  @currency
end

#customerObject (readonly)

The customer that this card belongs to. This attribute will not be in the card object if the card belongs to an account or recipient instead.



55
56
57
# File 'lib/stripe/resources/card.rb', line 55

def customer
  @customer
end

#cvc_checkObject (readonly)

If a CVC was provided, results of the check: ‘pass`, `fail`, `unavailable`, or `unchecked`. A result of unchecked indicates that CVC was provided but hasn’t been checked yet. Checks are typically performed when attaching a card to a Customer object, or when creating a charge. For more details, see [Check if a card is valid without a charge](support.stripe.com/questions/check-if-a-card-is-valid-without-a-charge).



57
58
59
# File 'lib/stripe/resources/card.rb', line 57

def cvc_check
  @cvc_check
end

#default_for_currencyObject (readonly)

Whether this card is the default external account for its currency. This property is only available for accounts where [controller.requirement_collection](/api/accounts/object#account_object-controller-requirement_collection) is ‘application`, which includes Custom accounts.



59
60
61
# File 'lib/stripe/resources/card.rb', line 59

def default_for_currency
  @default_for_currency
end

#deletedObject (readonly)

Always true for a deleted object



97
98
99
# File 'lib/stripe/resources/card.rb', line 97

def deleted
  @deleted
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



61
62
63
# File 'lib/stripe/resources/card.rb', line 61

def description
  @description
end

#dynamic_last4Object (readonly)

(For tokenized numbers only.) The last four digits of the device account number.



63
64
65
# File 'lib/stripe/resources/card.rb', line 63

def dynamic_last4
  @dynamic_last4
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



65
66
67
# File 'lib/stripe/resources/card.rb', line 65

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



67
68
69
# File 'lib/stripe/resources/card.rb', line 67

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



71
72
73
# File 'lib/stripe/resources/card.rb', line 71

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



73
74
75
# File 'lib/stripe/resources/card.rb', line 73

def funding
  @funding
end

#idObject (readonly)

Unique identifier for the object.



75
76
77
# File 'lib/stripe/resources/card.rb', line 75

def id
  @id
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



77
78
79
# File 'lib/stripe/resources/card.rb', line 77

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



79
80
81
# File 'lib/stripe/resources/card.rb', line 79

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



81
82
83
# File 'lib/stripe/resources/card.rb', line 81

def last4
  @last4
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



83
84
85
# File 'lib/stripe/resources/card.rb', line 83

def 
  @metadata
end

#nameObject (readonly)

Cardholder name.



85
86
87
# File 'lib/stripe/resources/card.rb', line 85

def name
  @name
end

#networksObject (readonly)

Attribute for field networks



87
88
89
# File 'lib/stripe/resources/card.rb', line 87

def networks
  @networks
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



89
90
91
# File 'lib/stripe/resources/card.rb', line 89

def object
  @object
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



91
92
93
# File 'lib/stripe/resources/card.rb', line 91

def regulated_status
  @regulated_status
end

#statusObject (readonly)

For external accounts that are cards, possible values are ‘new` and `errored`. If a payout fails, the status is set to `errored` and [scheduled payouts](stripe.com/docs/payouts#payout-schedule) are stopped until account details are updated.



93
94
95
# File 'lib/stripe/resources/card.rb', line 93

def status
  @status
end

#tokenization_methodObject (readonly)

If the card number is tokenized, this is the method that was used. Can be ‘android_pay` (includes Google Pay), `apple_pay`, `masterpass`, `visa_checkout`, or null.



95
96
97
# File 'lib/stripe/resources/card.rb', line 95

def tokenization_method
  @tokenization_method
end

Class Method Details

.delete(id, params = {}, opts = {}) ⇒ Object

Raises:

  • (NotImplementedError)


123
124
125
126
127
128
129
# File 'lib/stripe/resources/card.rb', line 123

def self.delete(id, params = {}, opts = {})
  raise NotImplementedError,
        "Card cannot be deleted without a customer ID or an account " \
        "ID. Delete a card using `Customer.delete_source(" \
        "'customer_id', 'card_id')` or " \
        "`Account.delete_external_account('account_id', 'card_id')`"
end

.list(params = {}, opts = {}) ⇒ Object

Raises:

  • (NotImplementedError)


140
141
142
143
144
145
146
# File 'lib/stripe/resources/card.rb', line 140

def self.list(params = {}, opts = {})
  raise NotImplementedError,
        "Cards cannot be listed without a customer ID or an account " \
        "ID. List cards using `Customer.list_sources(" \
        "'customer_id')` or " \
        "`Account.list_external_accounts('account_id')`"
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/card.rb', line 16

def self.object_name
  "card"
end

.retrieve(_id, _opts = nil) ⇒ Object

Raises:

  • (NotImplementedError)


115
116
117
118
119
120
121
# File 'lib/stripe/resources/card.rb', line 115

def self.retrieve(_id, _opts = nil)
  raise NotImplementedError,
        "Card cannot be retrieved without a customer ID or an account " \
        "ID. Retrieve a card using `Customer.retrieve_source(" \
        "'customer_id', 'card_id')` or " \
        "`Account.retrieve_external_account('account_id', 'card_id')`"
end

.update(_id, _params = nil, _opts = nil) ⇒ Object

Raises:

  • (NotImplementedError)


107
108
109
110
111
112
113
# File 'lib/stripe/resources/card.rb', line 107

def self.update(_id, _params = nil, _opts = nil)
  raise NotImplementedError,
        "Card cannot be updated without a customer ID or an account ID. " \
        "Update a card using `Customer.update_source('customer_id', " \
        "'card_id', update_params)` or `Account.update_external_account(" \
        "'account_id', 'card_id', update_params)`"
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object



131
132
133
134
135
136
137
138
# File 'lib/stripe/resources/card.rb', line 131

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: resource_url.to_s,
    params: params,
    opts: opts
  )
end

#resource_urlObject



99
100
101
102
103
104
105
# File 'lib/stripe/resources/card.rb', line 99

def resource_url
  if respond_to?(:customer) && !customer.nil? && !customer.empty?
    "#{Customer.resource_url}/#{CGI.escape(customer)}/sources/#{CGI.escape(id)}"
  elsif respond_to?(:account) && !.nil? && !.empty?
    "#{Account.resource_url}/#{CGI.escape()}/external_accounts/#{CGI.escape(id)}"
  end
end