Class: Stripe::Charge
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Charge
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/charge.rb
Overview
The Charge object represents a single attempt to move money into your Stripe account.
PaymentIntent confirmation is the most common way to create Charges, but Account Debits may also create Charges.
Some legacy payment flows create Charges directly, which is not recommended for new integrations.
Defined Under Namespace
Classes: BillingDetails, FraudDetails, Level3, Outcome, PaymentMethodDetails, PresentmentDetails, RadarOptions, Redaction, Shipping, TransferData
Constant Summary collapse
- OBJECT_NAME =
"charge"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount intended to be collected by this payment.
-
#amount_captured ⇒ Object
readonly
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
-
#amount_refunded ⇒ Object
readonly
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
-
#application ⇒ Object
readonly
ID of the Connect application that created the charge.
-
#application_fee ⇒ Object
readonly
The application fee (if any) for the charge.
-
#application_fee_amount ⇒ Object
readonly
The amount of the application fee (if any) requested for the charge.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#calculated_statement_descriptor ⇒ Object
readonly
The full statement descriptor that is passed to card networks, and that is displayed on your customers' credit card and bank statements.
-
#captured ⇒ Object
readonly
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#customer ⇒ Object
readonly
ID of the customer this charge is for if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#disputed ⇒ Object
readonly
Whether the charge has been disputed.
-
#failure_balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
-
#failure_code ⇒ Object
readonly
Error code explaining reason for charge failure if available (see the errors section for a list of codes).
-
#failure_message ⇒ Object
readonly
Message to user further explaining reason for charge failure if available.
-
#fraud_details ⇒ Object
readonly
Information on fraud assessments for the charge.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#level3 ⇒ Object
readonly
Attribute for field level3.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) the charge was made on behalf of without triggering an automatic transfer.
-
#outcome ⇒ Object
readonly
Details about whether the payment was accepted, and why.
-
#paid ⇒ Object
readonly
trueif the charge succeeded, or was successfully authorized for later capture. -
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent associated with this charge, if one exists.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this charge.
-
#payment_method_details ⇒ Object
readonly
Details about the payment method at the time of the transaction.
-
#presentment_details ⇒ Object
readonly
Attribute for field presentment_details.
-
#radar_options ⇒ Object
readonly
Options to configure Radar.
-
#receipt_email ⇒ Object
readonly
This is the email address that the receipt for this charge was sent to.
-
#receipt_number ⇒ Object
readonly
This is the transaction number that appears on email receipts sent for this charge.
-
#receipt_url ⇒ Object
readonly
This is the URL to view the receipt for this charge.
-
#redaction ⇒ Object
readonly
Redaction status of this charge.
-
#refunded ⇒ Object
readonly
Whether the charge has been fully refunded.
-
#refunds ⇒ Object
readonly
A list of refunds that have been applied to the charge.
-
#review ⇒ Object
readonly
ID of the review associated with this charge if one exists.
-
#shipping ⇒ Object
readonly
Shipping information for the charge.
-
#source ⇒ Object
readonly
This is a legacy field that will be removed in the future.
-
#source_transfer ⇒ Object
readonly
The transfer ID which created this charge.
-
#statement_descriptor ⇒ Object
readonly
For a non-card charge, text that appears on the customer's statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
The status of the payment is either
succeeded,pending, orfailed. -
#transfer ⇒ Object
readonly
ID of the transfer to the
destinationaccount (only applicable if the charge was created using thedestinationparameter). -
#transfer_data ⇒ Object
readonly
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
readonly
A string that identifies this transaction as part of a group.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
-
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the Payment Intents API to initiate a new payment instead.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you've previously created.
- .object_name ⇒ Object
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.update(charge, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed.
Instance Method Summary collapse
-
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount intended to be collected by this payment. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
2472 2473 2474 |
# File 'lib/stripe/resources/charge.rb', line 2472 def amount @amount end |
#amount_captured ⇒ Object (readonly)
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
2474 2475 2476 |
# File 'lib/stripe/resources/charge.rb', line 2474 def amount_captured @amount_captured end |
#amount_refunded ⇒ Object (readonly)
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
2476 2477 2478 |
# File 'lib/stripe/resources/charge.rb', line 2476 def amount_refunded @amount_refunded end |
#application ⇒ Object (readonly)
ID of the Connect application that created the charge.
2478 2479 2480 |
# File 'lib/stripe/resources/charge.rb', line 2478 def application @application end |
#application_fee ⇒ Object (readonly)
The application fee (if any) for the charge. See the Connect documentation for details.
2480 2481 2482 |
# File 'lib/stripe/resources/charge.rb', line 2480 def application_fee @application_fee end |
#application_fee_amount ⇒ Object (readonly)
The amount of the application fee (if any) requested for the charge. See the Connect documentation for details.
2482 2483 2484 |
# File 'lib/stripe/resources/charge.rb', line 2482 def application_fee_amount @application_fee_amount end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
2484 2485 2486 |
# File 'lib/stripe/resources/charge.rb', line 2484 def @authorization_code end |
#balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
2486 2487 2488 |
# File 'lib/stripe/resources/charge.rb', line 2486 def balance_transaction @balance_transaction end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
2488 2489 2490 |
# File 'lib/stripe/resources/charge.rb', line 2488 def billing_details @billing_details end |
#calculated_statement_descriptor ⇒ Object (readonly)
The full statement descriptor that is passed to card networks, and that is displayed on your customers' credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.
2490 2491 2492 |
# File 'lib/stripe/resources/charge.rb', line 2490 def calculated_statement_descriptor @calculated_statement_descriptor end |
#captured ⇒ Object (readonly)
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
2492 2493 2494 |
# File 'lib/stripe/resources/charge.rb', line 2492 def captured @captured end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
2494 2495 2496 |
# File 'lib/stripe/resources/charge.rb', line 2494 def created @created end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
2496 2497 2498 |
# File 'lib/stripe/resources/charge.rb', line 2496 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the customer this charge is for if one exists.
2498 2499 2500 |
# File 'lib/stripe/resources/charge.rb', line 2498 def customer @customer end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
2500 2501 2502 |
# File 'lib/stripe/resources/charge.rb', line 2500 def description @description end |
#disputed ⇒ Object (readonly)
Whether the charge has been disputed.
2502 2503 2504 |
# File 'lib/stripe/resources/charge.rb', line 2502 def disputed @disputed end |
#failure_balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
2504 2505 2506 |
# File 'lib/stripe/resources/charge.rb', line 2504 def failure_balance_transaction @failure_balance_transaction end |
#failure_code ⇒ Object (readonly)
Error code explaining reason for charge failure if available (see the errors section for a list of codes).
2506 2507 2508 |
# File 'lib/stripe/resources/charge.rb', line 2506 def failure_code @failure_code end |
#failure_message ⇒ Object (readonly)
Message to user further explaining reason for charge failure if available.
2508 2509 2510 |
# File 'lib/stripe/resources/charge.rb', line 2508 def @failure_message end |
#fraud_details ⇒ Object (readonly)
Information on fraud assessments for the charge.
2510 2511 2512 |
# File 'lib/stripe/resources/charge.rb', line 2510 def fraud_details @fraud_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2512 2513 2514 |
# File 'lib/stripe/resources/charge.rb', line 2512 def id @id end |
#level3 ⇒ Object (readonly)
Attribute for field level3
2514 2515 2516 |
# File 'lib/stripe/resources/charge.rb', line 2514 def level3 @level3 end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
2516 2517 2518 |
# File 'lib/stripe/resources/charge.rb', line 2516 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2518 2519 2520 |
# File 'lib/stripe/resources/charge.rb', line 2518 def @metadata end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
2520 2521 2522 |
# File 'lib/stripe/resources/charge.rb', line 2520 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the Connect documentation for details.
2522 2523 2524 |
# File 'lib/stripe/resources/charge.rb', line 2522 def on_behalf_of @on_behalf_of end |
#outcome ⇒ Object (readonly)
Details about whether the payment was accepted, and why. See understanding declines for details.
2524 2525 2526 |
# File 'lib/stripe/resources/charge.rb', line 2524 def outcome @outcome end |
#paid ⇒ Object (readonly)
true if the charge succeeded, or was successfully authorized for later capture.
2526 2527 2528 |
# File 'lib/stripe/resources/charge.rb', line 2526 def paid @paid end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent associated with this charge, if one exists.
2528 2529 2530 |
# File 'lib/stripe/resources/charge.rb', line 2528 def payment_intent @payment_intent end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this charge.
2530 2531 2532 |
# File 'lib/stripe/resources/charge.rb', line 2530 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Details about the payment method at the time of the transaction.
2532 2533 2534 |
# File 'lib/stripe/resources/charge.rb', line 2532 def payment_method_details @payment_method_details end |
#presentment_details ⇒ Object (readonly)
Attribute for field presentment_details
2534 2535 2536 |
# File 'lib/stripe/resources/charge.rb', line 2534 def presentment_details @presentment_details end |
#radar_options ⇒ Object (readonly)
Options to configure Radar. See Radar Session for more information.
2536 2537 2538 |
# File 'lib/stripe/resources/charge.rb', line 2536 def @radar_options end |
#receipt_email ⇒ Object (readonly)
This is the email address that the receipt for this charge was sent to.
2538 2539 2540 |
# File 'lib/stripe/resources/charge.rb', line 2538 def receipt_email @receipt_email end |
#receipt_number ⇒ Object (readonly)
This is the transaction number that appears on email receipts sent for this charge. This attribute will be null until a receipt has been sent.
2540 2541 2542 |
# File 'lib/stripe/resources/charge.rb', line 2540 def receipt_number @receipt_number end |
#receipt_url ⇒ Object (readonly)
This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.
2542 2543 2544 |
# File 'lib/stripe/resources/charge.rb', line 2542 def receipt_url @receipt_url end |
#redaction ⇒ Object (readonly)
Redaction status of this charge. If not null, this charge is associated to a redaction job.
2544 2545 2546 |
# File 'lib/stripe/resources/charge.rb', line 2544 def redaction @redaction end |
#refunded ⇒ Object (readonly)
Whether the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.
2546 2547 2548 |
# File 'lib/stripe/resources/charge.rb', line 2546 def refunded @refunded end |
#refunds ⇒ Object (readonly)
A list of refunds that have been applied to the charge.
2548 2549 2550 |
# File 'lib/stripe/resources/charge.rb', line 2548 def refunds @refunds end |
#review ⇒ Object (readonly)
ID of the review associated with this charge if one exists.
2550 2551 2552 |
# File 'lib/stripe/resources/charge.rb', line 2550 def review @review end |
#shipping ⇒ Object (readonly)
Shipping information for the charge.
2552 2553 2554 |
# File 'lib/stripe/resources/charge.rb', line 2552 def shipping @shipping end |
#source ⇒ Object (readonly)
This is a legacy field that will be removed in the future. It contains the Source, Card, or BankAccount object used for the charge. For details about the payment method used for this charge, refer to payment_method or payment_method_details instead.
2554 2555 2556 |
# File 'lib/stripe/resources/charge.rb', line 2554 def source @source end |
#source_transfer ⇒ Object (readonly)
The transfer ID which created this charge. Only present if the charge came from another Stripe account. See the Connect documentation for details.
2556 2557 2558 |
# File 'lib/stripe/resources/charge.rb', line 2556 def source_transfer @source_transfer end |
#statement_descriptor ⇒ Object (readonly)
For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.
For a card charge, this value is ignored unless you don't specify a statement_descriptor_suffix, in which case this value is used as the suffix.
2560 2561 2562 |
# File 'lib/stripe/resources/charge.rb', line 2560 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the account's statement descriptor.
2562 2563 2564 |
# File 'lib/stripe/resources/charge.rb', line 2562 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
The status of the payment is either succeeded, pending, or failed.
2564 2565 2566 |
# File 'lib/stripe/resources/charge.rb', line 2564 def status @status end |
#transfer ⇒ Object (readonly)
ID of the transfer to the destination account (only applicable if the charge was created using the destination parameter).
2566 2567 2568 |
# File 'lib/stripe/resources/charge.rb', line 2566 def transfer @transfer end |
#transfer_data ⇒ Object (readonly)
An optional dictionary including the account to automatically transfer to as part of a destination charge. See the Connect documentation for details.
2568 2569 2570 |
# File 'lib/stripe/resources/charge.rb', line 2568 def transfer_data @transfer_data end |
#transfer_group ⇒ Object (readonly)
A string that identifies this transaction as part of a group. See the Connect documentation for details.
2570 2571 2572 |
# File 'lib/stripe/resources/charge.rb', line 2570 def transfer_group @transfer_group end |
Class Method Details
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created (7 by default), after which they are marked as refunded and capture attempts will fail.
Don't use this method to capture a PaymentIntent-initiated charge. Use Capture a PaymentIntent.
2591 2592 2593 2594 2595 2596 2597 2598 |
# File 'lib/stripe/resources/charge.rb', line 2591 def self.capture(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the Payment Intents API to initiate a new payment instead. Confirmation of the PaymentIntent creates the Charge object used to request payment.
2603 2604 2605 |
# File 'lib/stripe/resources/charge.rb', line 2603 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/charges", params: params, opts: opts) end |
.field_remappings ⇒ Object
2645 2646 2647 |
# File 'lib/stripe/resources/charge.rb', line 2645 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 |
# File 'lib/stripe/resources/charge.rb', line 2630 def self.inner_class_types @inner_class_types = { billing_details: BillingDetails, fraud_details: FraudDetails, level3: Level3, outcome: Outcome, payment_method_details: PaymentMethodDetails, presentment_details: PresentmentDetails, radar_options: RadarOptions, redaction: Redaction, shipping: Shipping, transfer_data: TransferData, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you've previously created. The charges are returned in sorted order, with the most recent charges appearing first.
2608 2609 2610 |
# File 'lib/stripe/resources/charge.rb', line 2608 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges", params: params, opts: opts) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/charge.rb', line 16 def self.object_name "charge" end |
.search(params = {}, opts = {}) ⇒ Object
2612 2613 2614 |
# File 'lib/stripe/resources/charge.rb', line 2612 def self.search(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges/search", params: params, opts: opts) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
2616 2617 2618 |
# File 'lib/stripe/resources/charge.rb', line 2616 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.update(charge, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
2621 2622 2623 2624 2625 2626 2627 2628 |
# File 'lib/stripe/resources/charge.rb', line 2621 def self.update(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
Instance Method Details
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created (7 by default), after which they are marked as refunded and capture attempts will fail.
Don't use this method to capture a PaymentIntent-initiated charge. Use Capture a PaymentIntent.
2577 2578 2579 2580 2581 2582 2583 2584 |
# File 'lib/stripe/resources/charge.rb', line 2577 def capture(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(self["id"]) }), params: params, opts: opts ) end |