Class: Stripe::Charge
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Charge
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/charge.rb
Overview
The Charge object represents a single attempt to move money into your Stripe account.
PaymentIntent confirmation is the most common way to create Charges, but Account Debits may also create Charges.
Some legacy payment flows create Charges directly, which is not recommended for new integrations.
Defined Under Namespace
Classes: BillingDetails, FraudDetails, Level3, Outcome, PaymentMethodDetails, PresentmentDetails, RadarOptions, Redaction, Shipping, TransferData
Constant Summary collapse
- OBJECT_NAME =
"charge"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#allocated_funds ⇒ Object
readonly
Funds that are in transit and destined for another balance or another connected account.
-
#amount ⇒ Object
readonly
Amount intended to be collected by this payment.
-
#amount_captured ⇒ Object
readonly
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
-
#amount_refunded ⇒ Object
readonly
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
-
#application ⇒ Object
readonly
ID of the Connect application that created the charge.
-
#application_fee ⇒ Object
readonly
The application fee (if any) for the charge.
-
#application_fee_amount ⇒ Object
readonly
The amount of the application fee (if any) requested for the charge.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#calculated_statement_descriptor ⇒ Object
readonly
The full statement descriptor that is passed to card networks, and that is displayed on your customers' credit card and bank statements.
-
#captured ⇒ Object
readonly
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#customer ⇒ Object
readonly
ID of the customer this charge is for if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#disputed ⇒ Object
readonly
Whether the charge has been disputed.
-
#failure_balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
-
#failure_code ⇒ Object
readonly
Error code explaining reason for charge failure if available (see the errors section for a list of codes).
-
#failure_message ⇒ Object
readonly
Message to user further explaining reason for charge failure if available.
-
#fraud_details ⇒ Object
readonly
Information on fraud assessments for the charge.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#level3 ⇒ Object
readonly
Attribute for field level3.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) the charge was made on behalf of without triggering an automatic transfer.
-
#outcome ⇒ Object
readonly
Details about whether the payment was accepted, and why.
-
#paid ⇒ Object
readonly
trueif the charge succeeded, or was successfully authorized for later capture. -
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent associated with this charge, if one exists.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this charge.
-
#payment_method_details ⇒ Object
readonly
Details about the payment method at the time of the transaction.
-
#presentment_details ⇒ Object
readonly
Attribute for field presentment_details.
-
#radar_options ⇒ Object
readonly
Options to configure Radar.
-
#receipt_email ⇒ Object
readonly
This is the email address that the receipt for this charge was sent to.
-
#receipt_number ⇒ Object
readonly
This is the transaction number that appears on email receipts sent for this charge.
-
#receipt_url ⇒ Object
readonly
This is the URL to view the receipt for this charge.
-
#redaction ⇒ Object
readonly
Redaction status of this charge.
-
#refunded ⇒ Object
readonly
Whether the charge has been fully refunded.
-
#refunds ⇒ Object
readonly
A list of refunds that have been applied to the charge.
-
#review ⇒ Object
readonly
ID of the review associated with this charge if one exists.
-
#shipping ⇒ Object
readonly
Shipping information for the charge.
-
#source ⇒ Object
readonly
This is a legacy field that will be removed in the future.
-
#source_transfer ⇒ Object
readonly
The transfer ID which created this charge.
-
#statement_descriptor ⇒ Object
readonly
For a non-card charge, text that appears on the customer's statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
The status of the payment is either
succeeded,pending, orfailed. -
#transfer ⇒ Object
readonly
ID of the transfer to the
destinationaccount (only applicable if the charge was created using thedestinationparameter). -
#transfer_data ⇒ Object
readonly
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
readonly
A string that identifies this transaction as part of a group.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
-
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the Payment Intents API to initiate a new payment instead.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you've previously created.
- .object_name ⇒ Object
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.update(charge, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed.
Instance Method Summary collapse
-
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#allocated_funds ⇒ Object (readonly)
Funds that are in transit and destined for another balance or another connected account.
2659 2660 2661 |
# File 'lib/stripe/resources/charge.rb', line 2659 def allocated_funds @allocated_funds end |
#amount ⇒ Object (readonly)
Amount intended to be collected by this payment. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
2661 2662 2663 |
# File 'lib/stripe/resources/charge.rb', line 2661 def amount @amount end |
#amount_captured ⇒ Object (readonly)
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
2663 2664 2665 |
# File 'lib/stripe/resources/charge.rb', line 2663 def amount_captured @amount_captured end |
#amount_refunded ⇒ Object (readonly)
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
2665 2666 2667 |
# File 'lib/stripe/resources/charge.rb', line 2665 def amount_refunded @amount_refunded end |
#application ⇒ Object (readonly)
ID of the Connect application that created the charge.
2667 2668 2669 |
# File 'lib/stripe/resources/charge.rb', line 2667 def application @application end |
#application_fee ⇒ Object (readonly)
The application fee (if any) for the charge. See the Connect documentation for details.
2669 2670 2671 |
# File 'lib/stripe/resources/charge.rb', line 2669 def application_fee @application_fee end |
#application_fee_amount ⇒ Object (readonly)
The amount of the application fee (if any) requested for the charge. See the Connect documentation for details.
2671 2672 2673 |
# File 'lib/stripe/resources/charge.rb', line 2671 def application_fee_amount @application_fee_amount end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
2673 2674 2675 |
# File 'lib/stripe/resources/charge.rb', line 2673 def @authorization_code end |
#balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
2675 2676 2677 |
# File 'lib/stripe/resources/charge.rb', line 2675 def balance_transaction @balance_transaction end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
2677 2678 2679 |
# File 'lib/stripe/resources/charge.rb', line 2677 def billing_details @billing_details end |
#calculated_statement_descriptor ⇒ Object (readonly)
The full statement descriptor that is passed to card networks, and that is displayed on your customers' credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.
2679 2680 2681 |
# File 'lib/stripe/resources/charge.rb', line 2679 def calculated_statement_descriptor @calculated_statement_descriptor end |
#captured ⇒ Object (readonly)
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
2681 2682 2683 |
# File 'lib/stripe/resources/charge.rb', line 2681 def captured @captured end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
2683 2684 2685 |
# File 'lib/stripe/resources/charge.rb', line 2683 def created @created end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
2685 2686 2687 |
# File 'lib/stripe/resources/charge.rb', line 2685 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the customer this charge is for if one exists.
2687 2688 2689 |
# File 'lib/stripe/resources/charge.rb', line 2687 def customer @customer end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
2689 2690 2691 |
# File 'lib/stripe/resources/charge.rb', line 2689 def description @description end |
#disputed ⇒ Object (readonly)
Whether the charge has been disputed.
2691 2692 2693 |
# File 'lib/stripe/resources/charge.rb', line 2691 def disputed @disputed end |
#failure_balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
2693 2694 2695 |
# File 'lib/stripe/resources/charge.rb', line 2693 def failure_balance_transaction @failure_balance_transaction end |
#failure_code ⇒ Object (readonly)
Error code explaining reason for charge failure if available (see the errors section for a list of codes).
2695 2696 2697 |
# File 'lib/stripe/resources/charge.rb', line 2695 def failure_code @failure_code end |
#failure_message ⇒ Object (readonly)
Message to user further explaining reason for charge failure if available.
2697 2698 2699 |
# File 'lib/stripe/resources/charge.rb', line 2697 def @failure_message end |
#fraud_details ⇒ Object (readonly)
Information on fraud assessments for the charge.
2699 2700 2701 |
# File 'lib/stripe/resources/charge.rb', line 2699 def fraud_details @fraud_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2701 2702 2703 |
# File 'lib/stripe/resources/charge.rb', line 2701 def id @id end |
#level3 ⇒ Object (readonly)
Attribute for field level3
2703 2704 2705 |
# File 'lib/stripe/resources/charge.rb', line 2703 def level3 @level3 end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
2705 2706 2707 |
# File 'lib/stripe/resources/charge.rb', line 2705 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2707 2708 2709 |
# File 'lib/stripe/resources/charge.rb', line 2707 def @metadata end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
2709 2710 2711 |
# File 'lib/stripe/resources/charge.rb', line 2709 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the Connect documentation for details.
2711 2712 2713 |
# File 'lib/stripe/resources/charge.rb', line 2711 def on_behalf_of @on_behalf_of end |
#outcome ⇒ Object (readonly)
Details about whether the payment was accepted, and why. See understanding declines for details.
2713 2714 2715 |
# File 'lib/stripe/resources/charge.rb', line 2713 def outcome @outcome end |
#paid ⇒ Object (readonly)
true if the charge succeeded, or was successfully authorized for later capture.
2715 2716 2717 |
# File 'lib/stripe/resources/charge.rb', line 2715 def paid @paid end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent associated with this charge, if one exists.
2717 2718 2719 |
# File 'lib/stripe/resources/charge.rb', line 2717 def payment_intent @payment_intent end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this charge.
2719 2720 2721 |
# File 'lib/stripe/resources/charge.rb', line 2719 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Details about the payment method at the time of the transaction.
2721 2722 2723 |
# File 'lib/stripe/resources/charge.rb', line 2721 def payment_method_details @payment_method_details end |
#presentment_details ⇒ Object (readonly)
Attribute for field presentment_details
2723 2724 2725 |
# File 'lib/stripe/resources/charge.rb', line 2723 def presentment_details @presentment_details end |
#radar_options ⇒ Object (readonly)
Options to configure Radar. See Radar Session for more information.
2725 2726 2727 |
# File 'lib/stripe/resources/charge.rb', line 2725 def @radar_options end |
#receipt_email ⇒ Object (readonly)
This is the email address that the receipt for this charge was sent to.
2727 2728 2729 |
# File 'lib/stripe/resources/charge.rb', line 2727 def receipt_email @receipt_email end |
#receipt_number ⇒ Object (readonly)
This is the transaction number that appears on email receipts sent for this charge. This attribute will be null until a receipt has been sent.
2729 2730 2731 |
# File 'lib/stripe/resources/charge.rb', line 2729 def receipt_number @receipt_number end |
#receipt_url ⇒ Object (readonly)
This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.
2731 2732 2733 |
# File 'lib/stripe/resources/charge.rb', line 2731 def receipt_url @receipt_url end |
#redaction ⇒ Object (readonly)
Redaction status of this charge. If not null, this charge is associated to a redaction job.
2733 2734 2735 |
# File 'lib/stripe/resources/charge.rb', line 2733 def redaction @redaction end |
#refunded ⇒ Object (readonly)
Whether the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.
2735 2736 2737 |
# File 'lib/stripe/resources/charge.rb', line 2735 def refunded @refunded end |
#refunds ⇒ Object (readonly)
A list of refunds that have been applied to the charge.
2737 2738 2739 |
# File 'lib/stripe/resources/charge.rb', line 2737 def refunds @refunds end |
#review ⇒ Object (readonly)
ID of the review associated with this charge if one exists.
2739 2740 2741 |
# File 'lib/stripe/resources/charge.rb', line 2739 def review @review end |
#shipping ⇒ Object (readonly)
Shipping information for the charge.
2741 2742 2743 |
# File 'lib/stripe/resources/charge.rb', line 2741 def shipping @shipping end |
#source ⇒ Object (readonly)
This is a legacy field that will be removed in the future. It contains the Source, Card, or BankAccount object used for the charge. For details about the payment method used for this charge, refer to payment_method or payment_method_details instead.
2743 2744 2745 |
# File 'lib/stripe/resources/charge.rb', line 2743 def source @source end |
#source_transfer ⇒ Object (readonly)
The transfer ID which created this charge. Only present if the charge came from another Stripe account. See the Connect documentation for details.
2745 2746 2747 |
# File 'lib/stripe/resources/charge.rb', line 2745 def source_transfer @source_transfer end |
#statement_descriptor ⇒ Object (readonly)
For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.
For a card charge, this value is ignored unless you don't specify a statement_descriptor_suffix, in which case this value is used as the suffix.
2749 2750 2751 |
# File 'lib/stripe/resources/charge.rb', line 2749 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the account's statement descriptor.
2751 2752 2753 |
# File 'lib/stripe/resources/charge.rb', line 2751 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
The status of the payment is either succeeded, pending, or failed.
2753 2754 2755 |
# File 'lib/stripe/resources/charge.rb', line 2753 def status @status end |
#transfer ⇒ Object (readonly)
ID of the transfer to the destination account (only applicable if the charge was created using the destination parameter).
2755 2756 2757 |
# File 'lib/stripe/resources/charge.rb', line 2755 def transfer @transfer end |
#transfer_data ⇒ Object (readonly)
An optional dictionary including the account to automatically transfer to as part of a destination charge. See the Connect documentation for details.
2757 2758 2759 |
# File 'lib/stripe/resources/charge.rb', line 2757 def transfer_data @transfer_data end |
#transfer_group ⇒ Object (readonly)
A string that identifies this transaction as part of a group. See the Connect documentation for details.
2759 2760 2761 |
# File 'lib/stripe/resources/charge.rb', line 2759 def transfer_group @transfer_group end |
Class Method Details
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created (7 by default), after which they are marked as refunded and capture attempts will fail.
Don't use this method to capture a PaymentIntent-initiated charge. Use Capture a PaymentIntent.
2780 2781 2782 2783 2784 2785 2786 2787 |
# File 'lib/stripe/resources/charge.rb', line 2780 def self.capture(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the Payment Intents API to initiate a new payment instead. Confirmation of the PaymentIntent creates the Charge object used to request payment.
2792 2793 2794 |
# File 'lib/stripe/resources/charge.rb', line 2792 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/charges", params: params, opts: opts) end |
.field_remappings ⇒ Object
2834 2835 2836 |
# File 'lib/stripe/resources/charge.rb', line 2834 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 |
# File 'lib/stripe/resources/charge.rb', line 2819 def self.inner_class_types @inner_class_types = { billing_details: BillingDetails, fraud_details: FraudDetails, level3: Level3, outcome: Outcome, payment_method_details: PaymentMethodDetails, presentment_details: PresentmentDetails, radar_options: RadarOptions, redaction: Redaction, shipping: Shipping, transfer_data: TransferData, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you've previously created. The charges are returned in sorted order, with the most recent charges appearing first.
2797 2798 2799 |
# File 'lib/stripe/resources/charge.rb', line 2797 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges", params: params, opts: opts) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/charge.rb', line 16 def self.object_name "charge" end |
.search(params = {}, opts = {}) ⇒ Object
2801 2802 2803 |
# File 'lib/stripe/resources/charge.rb', line 2801 def self.search(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges/search", params: params, opts: opts) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
2805 2806 2807 |
# File 'lib/stripe/resources/charge.rb', line 2805 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.update(charge, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
2810 2811 2812 2813 2814 2815 2816 2817 |
# File 'lib/stripe/resources/charge.rb', line 2810 def self.update(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
Instance Method Details
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created (7 by default), after which they are marked as refunded and capture attempts will fail.
Don't use this method to capture a PaymentIntent-initiated charge. Use Capture a PaymentIntent.
2766 2767 2768 2769 2770 2771 2772 2773 |
# File 'lib/stripe/resources/charge.rb', line 2766 def capture(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(self["id"]) }), params: params, opts: opts ) end |