Class: Stripe::Charge

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/charge.rb

Overview

The ‘Charge` object represents a single attempt to move money into your Stripe account. PaymentIntent confirmation is the most common way to create Charges, but [Account Debits](docs.stripe.com/connect/account-debits) may also create Charges. Some legacy payment flows create Charges directly, which is not recommended for new integrations.

Defined Under Namespace

Classes: BillingDetails, FraudDetails, Level3, Outcome, PaymentMethodDetails, PresentmentDetails, RadarOptions, Shipping, TransferData

Constant Summary collapse

OBJECT_NAME =
"charge"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allocated_fundsObject (readonly)

Funds that are in transit and destined for another balance or another connected account.



2505
2506
2507
# File 'lib/stripe/resources/charge.rb', line 2505

def allocated_funds
  @allocated_funds
end

#amountObject (readonly)

Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



2507
2508
2509
# File 'lib/stripe/resources/charge.rb', line 2507

def amount
  @amount
end

#amount_capturedObject (readonly)

Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).



2509
2510
2511
# File 'lib/stripe/resources/charge.rb', line 2509

def amount_captured
  @amount_captured
end

#amount_refundedObject (readonly)

Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).



2511
2512
2513
# File 'lib/stripe/resources/charge.rb', line 2511

def amount_refunded
  @amount_refunded
end

#applicationObject (readonly)

ID of the Connect application that created the charge.



2513
2514
2515
# File 'lib/stripe/resources/charge.rb', line 2513

def application
  @application
end

#application_feeObject (readonly)

The application fee (if any) for the charge. [See the Connect documentation](docs.stripe.com/connect/direct-charges#collect-fees) for details.



2515
2516
2517
# File 'lib/stripe/resources/charge.rb', line 2515

def application_fee
  @application_fee
end

#application_fee_amountObject (readonly)

The amount of the application fee (if any) requested for the charge. [See the Connect documentation](docs.stripe.com/connect/direct-charges#collect-fees) for details.



2517
2518
2519
# File 'lib/stripe/resources/charge.rb', line 2517

def application_fee_amount
  @application_fee_amount
end

#authorization_codeObject (readonly)

Authorization code on the charge.



2519
2520
2521
# File 'lib/stripe/resources/charge.rb', line 2519

def authorization_code
  @authorization_code
end

#balance_transactionObject (readonly)

ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).



2521
2522
2523
# File 'lib/stripe/resources/charge.rb', line 2521

def balance_transaction
  @balance_transaction
end

#billing_detailsObject (readonly)

Attribute for field billing_details



2523
2524
2525
# File 'lib/stripe/resources/charge.rb', line 2523

def billing_details
  @billing_details
end

#calculated_statement_descriptorObject (readonly)

The full statement descriptor that is passed to card networks, and that is displayed on your customers’ credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.



2525
2526
2527
# File 'lib/stripe/resources/charge.rb', line 2525

def calculated_statement_descriptor
  @calculated_statement_descriptor
end

#capturedObject (readonly)

If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.



2527
2528
2529
# File 'lib/stripe/resources/charge.rb', line 2527

def captured
  @captured
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2529
2530
2531
# File 'lib/stripe/resources/charge.rb', line 2529

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2531
2532
2533
# File 'lib/stripe/resources/charge.rb', line 2531

def currency
  @currency
end

#customerObject (readonly)

ID of the customer this charge is for if one exists.



2533
2534
2535
# File 'lib/stripe/resources/charge.rb', line 2533

def customer
  @customer
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



2535
2536
2537
# File 'lib/stripe/resources/charge.rb', line 2535

def description
  @description
end

#disputedObject (readonly)

Whether the charge has been disputed.



2537
2538
2539
# File 'lib/stripe/resources/charge.rb', line 2537

def disputed
  @disputed
end

#failure_balance_transactionObject (readonly)

ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.



2539
2540
2541
# File 'lib/stripe/resources/charge.rb', line 2539

def failure_balance_transaction
  @failure_balance_transaction
end

#failure_codeObject (readonly)

Error code explaining reason for charge failure if available (see [the errors section](docs.stripe.com/error-codes) for a list of codes).



2541
2542
2543
# File 'lib/stripe/resources/charge.rb', line 2541

def failure_code
  @failure_code
end

#failure_messageObject (readonly)

Message to user further explaining reason for charge failure if available.



2543
2544
2545
# File 'lib/stripe/resources/charge.rb', line 2543

def failure_message
  @failure_message
end

#fraud_detailsObject (readonly)

Information on fraud assessments for the charge.



2545
2546
2547
# File 'lib/stripe/resources/charge.rb', line 2545

def fraud_details
  @fraud_details
end

#idObject (readonly)

Unique identifier for the object.



2547
2548
2549
# File 'lib/stripe/resources/charge.rb', line 2547

def id
  @id
end

#level3Object (readonly)

Attribute for field level3



2549
2550
2551
# File 'lib/stripe/resources/charge.rb', line 2549

def level3
  @level3
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



2551
2552
2553
# File 'lib/stripe/resources/charge.rb', line 2551

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2553
2554
2555
# File 'lib/stripe/resources/charge.rb', line 2553

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2555
2556
2557
# File 'lib/stripe/resources/charge.rb', line 2555

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the [Connect documentation](docs.stripe.com/connect/separate-charges-and-transfers) for details.



2557
2558
2559
# File 'lib/stripe/resources/charge.rb', line 2557

def on_behalf_of
  @on_behalf_of
end

#outcomeObject (readonly)

Details about whether the payment was accepted, and why. See [understanding declines](docs.stripe.com/declines) for details.



2559
2560
2561
# File 'lib/stripe/resources/charge.rb', line 2559

def outcome
  @outcome
end

‘true` if the charge succeeded, or was successfully authorized for later capture.



2561
2562
2563
# File 'lib/stripe/resources/charge.rb', line 2561

def paid
  @paid
end

#payment_intentObject (readonly)

ID of the PaymentIntent associated with this charge, if one exists.



2563
2564
2565
# File 'lib/stripe/resources/charge.rb', line 2563

def payment_intent
  @payment_intent
end

#payment_methodObject (readonly)

ID of the payment method used in this charge.



2565
2566
2567
# File 'lib/stripe/resources/charge.rb', line 2565

def payment_method
  @payment_method
end

#payment_method_detailsObject (readonly)

Details about the payment method at the time of the transaction.



2567
2568
2569
# File 'lib/stripe/resources/charge.rb', line 2567

def payment_method_details
  @payment_method_details
end

#presentment_detailsObject (readonly)

Attribute for field presentment_details



2569
2570
2571
# File 'lib/stripe/resources/charge.rb', line 2569

def presentment_details
  @presentment_details
end

#radar_optionsObject (readonly)

Options to configure Radar. See [Radar Session](docs.stripe.com/radar/radar-session) for more information.



2571
2572
2573
# File 'lib/stripe/resources/charge.rb', line 2571

def radar_options
  @radar_options
end

#receipt_emailObject (readonly)

This is the email address that the receipt for this charge was sent to.



2573
2574
2575
# File 'lib/stripe/resources/charge.rb', line 2573

def receipt_email
  @receipt_email
end

#receipt_numberObject (readonly)

This is the transaction number that appears on email receipts sent for this charge. This attribute will be ‘null` until a receipt has been sent.



2575
2576
2577
# File 'lib/stripe/resources/charge.rb', line 2575

def receipt_number
  @receipt_number
end

#receipt_urlObject (readonly)

This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.



2577
2578
2579
# File 'lib/stripe/resources/charge.rb', line 2577

def receipt_url
  @receipt_url
end

#refundedObject (readonly)

Whether the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.



2579
2580
2581
# File 'lib/stripe/resources/charge.rb', line 2579

def refunded
  @refunded
end

#refundsObject (readonly)

A list of refunds that have been applied to the charge.



2581
2582
2583
# File 'lib/stripe/resources/charge.rb', line 2581

def refunds
  @refunds
end

#reviewObject (readonly)

ID of the review associated with this charge if one exists.



2583
2584
2585
# File 'lib/stripe/resources/charge.rb', line 2583

def review
  @review
end

#shippingObject (readonly)

Shipping information for the charge.



2585
2586
2587
# File 'lib/stripe/resources/charge.rb', line 2585

def shipping
  @shipping
end

#sourceObject (readonly)

This is a legacy field that will be removed in the future. It contains the Source, Card, or BankAccount object used for the charge. For details about the payment method used for this charge, refer to ‘payment_method` or `payment_method_details` instead.



2587
2588
2589
# File 'lib/stripe/resources/charge.rb', line 2587

def source
  @source
end

#source_transferObject (readonly)

The transfer ID which created this charge. Only present if the charge came from another Stripe account. [See the Connect documentation](docs.stripe.com/connect/destination-charges) for details.



2589
2590
2591
# File 'lib/stripe/resources/charge.rb', line 2589

def source_transfer
  @source_transfer
end

#statement_descriptorObject (readonly)

For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.



2593
2594
2595
# File 'lib/stripe/resources/charge.rb', line 2593

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.



2595
2596
2597
# File 'lib/stripe/resources/charge.rb', line 2595

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#statusObject (readonly)

The status of the payment is either ‘succeeded`, `pending`, or `failed`.



2597
2598
2599
# File 'lib/stripe/resources/charge.rb', line 2597

def status
  @status
end

#transferObject (readonly)

ID of the transfer to the ‘destination` account (only applicable if the charge was created using the `destination` parameter).



2599
2600
2601
# File 'lib/stripe/resources/charge.rb', line 2599

def transfer
  @transfer
end

#transfer_dataObject (readonly)

An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](docs.stripe.com/connect/destination-charges) for details.



2601
2602
2603
# File 'lib/stripe/resources/charge.rb', line 2601

def transfer_data
  @transfer_data
end

#transfer_groupObject (readonly)

A string that identifies this transaction as part of a group. See the [Connect documentation](docs.stripe.com/connect/separate-charges-and-transfers#transfer-options) for details.



2603
2604
2605
# File 'lib/stripe/resources/charge.rb', line 2603

def transfer_group
  @transfer_group
end

Class Method Details

.capture(charge, params = {}, opts = {}) ⇒ Object

Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.

Uncaptured payments expire a set number of days after they are created ([7 by default](docs.stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.

Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](docs.stripe.com/docs/api/payment_intents/capture).



2624
2625
2626
2627
2628
2629
2630
2631
# File 'lib/stripe/resources/charge.rb', line 2624

def self.capture(charge, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(charge) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

This method is no longer recommended—use the [Payment Intents API](docs.stripe.com/docs/api/payment_intents) to initiate a new payment instead. Confirmation of the PaymentIntent creates the Charge object used to request payment.



2636
2637
2638
# File 'lib/stripe/resources/charge.rb', line 2636

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/charges", params: params, opts: opts)
end

.field_remappingsObject



2677
2678
2679
# File 'lib/stripe/resources/charge.rb', line 2677

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2663
2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
2675
# File 'lib/stripe/resources/charge.rb', line 2663

def self.inner_class_types
  @inner_class_types = {
    billing_details: BillingDetails,
    fraud_details: FraudDetails,
    level3: Level3,
    outcome: Outcome,
    payment_method_details: PaymentMethodDetails,
    presentment_details: PresentmentDetails,
    radar_options: RadarOptions,
    shipping: Shipping,
    transfer_data: TransferData,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of charges you’ve previously created. The charges are returned in sorted order, with the most recent charges appearing first.



2641
2642
2643
# File 'lib/stripe/resources/charge.rb', line 2641

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/charges", params: params, opts: opts)
end

.object_nameObject



16
17
18
# File 'lib/stripe/resources/charge.rb', line 16

def self.object_name
  "charge"
end

.search(params = {}, opts = {}) ⇒ Object



2645
2646
2647
# File 'lib/stripe/resources/charge.rb', line 2645

def self.search(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/charges/search", params: params, opts: opts)
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



2649
2650
2651
# File 'lib/stripe/resources/charge.rb', line 2649

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.update(charge, params = {}, opts = {}) ⇒ Object

Updates the specified charge by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



2654
2655
2656
2657
2658
2659
2660
2661
# File 'lib/stripe/resources/charge.rb', line 2654

def self.update(charge, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/charges/%<charge>s", { charge: CGI.escape(charge) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#capture(params = {}, opts = {}) ⇒ Object

Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.

Uncaptured payments expire a set number of days after they are created ([7 by default](docs.stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.

Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](docs.stripe.com/docs/api/payment_intents/capture).



2610
2611
2612
2613
2614
2615
2616
2617
# File 'lib/stripe/resources/charge.rb', line 2610

def capture(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end