Class: Stripe::Charge
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Charge
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/charge.rb
Overview
The ‘Charge` object represents a single attempt to move money into your Stripe account. PaymentIntent confirmation is the most common way to create Charges, but transferring money to a different Stripe account through Connect also creates Charges. Some legacy payment flows create Charges directly, which is not recommended for new integrations.
Defined Under Namespace
Classes: BillingDetails, CaptureParams, CreateParams, FraudDetails, Level3, ListParams, Outcome, PaymentMethodDetails, PresentmentDetails, RadarOptions, SearchParams, Shipping, TransferData, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"charge"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount intended to be collected by this payment.
-
#amount_captured ⇒ Object
readonly
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
-
#amount_refunded ⇒ Object
readonly
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
-
#application ⇒ Object
readonly
ID of the Connect application that created the charge.
-
#application_fee ⇒ Object
readonly
The application fee (if any) for the charge.
-
#application_fee_amount ⇒ Object
readonly
The amount of the application fee (if any) requested for the charge.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#calculated_statement_descriptor ⇒ Object
readonly
The full statement descriptor that is passed to card networks, and that is displayed on your customers’ credit card and bank statements.
-
#captured ⇒ Object
readonly
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
ID of the customer this charge is for if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#disputed ⇒ Object
readonly
Whether the charge has been disputed.
-
#failure_balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
-
#failure_code ⇒ Object
readonly
Error code explaining reason for charge failure if available (see [the errors section](stripe.com/docs/error-codes) for a list of codes).
-
#failure_message ⇒ Object
readonly
Message to user further explaining reason for charge failure if available.
-
#fraud_details ⇒ Object
readonly
Information on fraud assessments for the charge.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#level3 ⇒ Object
readonly
Attribute for field level3.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) the charge was made on behalf of without triggering an automatic transfer.
-
#outcome ⇒ Object
readonly
Details about whether the payment was accepted, and why.
-
#paid ⇒ Object
readonly
‘true` if the charge succeeded, or was successfully authorized for later capture.
-
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent associated with this charge, if one exists.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this charge.
-
#payment_method_details ⇒ Object
readonly
Details about the payment method at the time of the transaction.
-
#presentment_details ⇒ Object
readonly
Attribute for field presentment_details.
-
#radar_options ⇒ Object
readonly
Options to configure Radar.
-
#receipt_email ⇒ Object
readonly
This is the email address that the receipt for this charge was sent to.
-
#receipt_number ⇒ Object
readonly
This is the transaction number that appears on email receipts sent for this charge.
-
#receipt_url ⇒ Object
readonly
This is the URL to view the receipt for this charge.
-
#refunded ⇒ Object
readonly
Whether the charge has been fully refunded.
-
#refunds ⇒ Object
readonly
A list of refunds that have been applied to the charge.
-
#review ⇒ Object
readonly
ID of the review associated with this charge if one exists.
-
#shipping ⇒ Object
readonly
Shipping information for the charge.
-
#source ⇒ Object
readonly
This is a legacy field that will be removed in the future.
-
#source_transfer ⇒ Object
readonly
The transfer ID which created this charge.
-
#statement_descriptor ⇒ Object
readonly
For a non-card charge, text that appears on the customer’s statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
The status of the payment is either ‘succeeded`, `pending`, or `failed`.
-
#transfer ⇒ Object
readonly
ID of the transfer to the ‘destination` account (only applicable if the charge was created using the `destination` parameter).
-
#transfer_data ⇒ Object
readonly
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
readonly
A string that identifies this transaction as part of a group.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
-
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the [Payment Intents API](docs.stripe.com/docs/api/payment_intents) to initiate a new payment instead.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you’ve previously created.
- .object_name ⇒ Object
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.update(charge, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed.
Instance Method Summary collapse
-
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
3100 3101 3102 |
# File 'lib/stripe/resources/charge.rb', line 3100 def amount @amount end |
#amount_captured ⇒ Object (readonly)
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
3102 3103 3104 |
# File 'lib/stripe/resources/charge.rb', line 3102 def amount_captured @amount_captured end |
#amount_refunded ⇒ Object (readonly)
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
3104 3105 3106 |
# File 'lib/stripe/resources/charge.rb', line 3104 def amount_refunded @amount_refunded end |
#application ⇒ Object (readonly)
ID of the Connect application that created the charge.
3106 3107 3108 |
# File 'lib/stripe/resources/charge.rb', line 3106 def application @application end |
#application_fee ⇒ Object (readonly)
The application fee (if any) for the charge. [See the Connect documentation](stripe.com/docs/connect/direct-charges#collect-fees) for details.
3108 3109 3110 |
# File 'lib/stripe/resources/charge.rb', line 3108 def application_fee @application_fee end |
#application_fee_amount ⇒ Object (readonly)
The amount of the application fee (if any) requested for the charge. [See the Connect documentation](stripe.com/docs/connect/direct-charges#collect-fees) for details.
3110 3111 3112 |
# File 'lib/stripe/resources/charge.rb', line 3110 def application_fee_amount @application_fee_amount end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
3112 3113 3114 |
# File 'lib/stripe/resources/charge.rb', line 3112 def @authorization_code end |
#balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
3114 3115 3116 |
# File 'lib/stripe/resources/charge.rb', line 3114 def balance_transaction @balance_transaction end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
3116 3117 3118 |
# File 'lib/stripe/resources/charge.rb', line 3116 def billing_details @billing_details end |
#calculated_statement_descriptor ⇒ Object (readonly)
The full statement descriptor that is passed to card networks, and that is displayed on your customers’ credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.
3118 3119 3120 |
# File 'lib/stripe/resources/charge.rb', line 3118 def calculated_statement_descriptor @calculated_statement_descriptor end |
#captured ⇒ Object (readonly)
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
3120 3121 3122 |
# File 'lib/stripe/resources/charge.rb', line 3120 def captured @captured end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
3122 3123 3124 |
# File 'lib/stripe/resources/charge.rb', line 3122 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3124 3125 3126 |
# File 'lib/stripe/resources/charge.rb', line 3124 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the customer this charge is for if one exists.
3126 3127 3128 |
# File 'lib/stripe/resources/charge.rb', line 3126 def customer @customer end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
3128 3129 3130 |
# File 'lib/stripe/resources/charge.rb', line 3128 def description @description end |
#disputed ⇒ Object (readonly)
Whether the charge has been disputed.
3130 3131 3132 |
# File 'lib/stripe/resources/charge.rb', line 3130 def disputed @disputed end |
#failure_balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
3132 3133 3134 |
# File 'lib/stripe/resources/charge.rb', line 3132 def failure_balance_transaction @failure_balance_transaction end |
#failure_code ⇒ Object (readonly)
Error code explaining reason for charge failure if available (see [the errors section](stripe.com/docs/error-codes) for a list of codes).
3134 3135 3136 |
# File 'lib/stripe/resources/charge.rb', line 3134 def failure_code @failure_code end |
#failure_message ⇒ Object (readonly)
Message to user further explaining reason for charge failure if available.
3136 3137 3138 |
# File 'lib/stripe/resources/charge.rb', line 3136 def @failure_message end |
#fraud_details ⇒ Object (readonly)
Information on fraud assessments for the charge.
3138 3139 3140 |
# File 'lib/stripe/resources/charge.rb', line 3138 def fraud_details @fraud_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
3140 3141 3142 |
# File 'lib/stripe/resources/charge.rb', line 3140 def id @id end |
#level3 ⇒ Object (readonly)
Attribute for field level3
3142 3143 3144 |
# File 'lib/stripe/resources/charge.rb', line 3142 def level3 @level3 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
3144 3145 3146 |
# File 'lib/stripe/resources/charge.rb', line 3144 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3146 3147 3148 |
# File 'lib/stripe/resources/charge.rb', line 3146 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
3148 3149 3150 |
# File 'lib/stripe/resources/charge.rb', line 3148 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers) for details.
3150 3151 3152 |
# File 'lib/stripe/resources/charge.rb', line 3150 def on_behalf_of @on_behalf_of end |
#outcome ⇒ Object (readonly)
Details about whether the payment was accepted, and why. See [understanding declines](stripe.com/docs/declines) for details.
3152 3153 3154 |
# File 'lib/stripe/resources/charge.rb', line 3152 def outcome @outcome end |
#paid ⇒ Object (readonly)
‘true` if the charge succeeded, or was successfully authorized for later capture.
3154 3155 3156 |
# File 'lib/stripe/resources/charge.rb', line 3154 def paid @paid end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent associated with this charge, if one exists.
3156 3157 3158 |
# File 'lib/stripe/resources/charge.rb', line 3156 def payment_intent @payment_intent end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this charge.
3158 3159 3160 |
# File 'lib/stripe/resources/charge.rb', line 3158 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Details about the payment method at the time of the transaction.
3160 3161 3162 |
# File 'lib/stripe/resources/charge.rb', line 3160 def payment_method_details @payment_method_details end |
#presentment_details ⇒ Object (readonly)
Attribute for field presentment_details
3162 3163 3164 |
# File 'lib/stripe/resources/charge.rb', line 3162 def presentment_details @presentment_details end |
#radar_options ⇒ Object (readonly)
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
3164 3165 3166 |
# File 'lib/stripe/resources/charge.rb', line 3164 def @radar_options end |
#receipt_email ⇒ Object (readonly)
This is the email address that the receipt for this charge was sent to.
3166 3167 3168 |
# File 'lib/stripe/resources/charge.rb', line 3166 def receipt_email @receipt_email end |
#receipt_number ⇒ Object (readonly)
This is the transaction number that appears on email receipts sent for this charge. This attribute will be ‘null` until a receipt has been sent.
3168 3169 3170 |
# File 'lib/stripe/resources/charge.rb', line 3168 def receipt_number @receipt_number end |
#receipt_url ⇒ Object (readonly)
This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.
3170 3171 3172 |
# File 'lib/stripe/resources/charge.rb', line 3170 def receipt_url @receipt_url end |
#refunded ⇒ Object (readonly)
Whether the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.
3172 3173 3174 |
# File 'lib/stripe/resources/charge.rb', line 3172 def refunded @refunded end |
#refunds ⇒ Object (readonly)
A list of refunds that have been applied to the charge.
3174 3175 3176 |
# File 'lib/stripe/resources/charge.rb', line 3174 def refunds @refunds end |
#review ⇒ Object (readonly)
ID of the review associated with this charge if one exists.
3176 3177 3178 |
# File 'lib/stripe/resources/charge.rb', line 3176 def review @review end |
#shipping ⇒ Object (readonly)
Shipping information for the charge.
3178 3179 3180 |
# File 'lib/stripe/resources/charge.rb', line 3178 def shipping @shipping end |
#source ⇒ Object (readonly)
This is a legacy field that will be removed in the future. It contains the Source, Card, or BankAccount object used for the charge. For details about the payment method used for this charge, refer to ‘payment_method` or `payment_method_details` instead.
3180 3181 3182 |
# File 'lib/stripe/resources/charge.rb', line 3180 def source @source end |
#source_transfer ⇒ Object (readonly)
The transfer ID which created this charge. Only present if the charge came from another Stripe account. [See the Connect documentation](docs.stripe.com/connect/destination-charges) for details.
3182 3183 3184 |
# File 'lib/stripe/resources/charge.rb', line 3182 def source_transfer @source_transfer end |
#statement_descriptor ⇒ Object (readonly)
For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.
3186 3187 3188 |
# File 'lib/stripe/resources/charge.rb', line 3186 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.
3188 3189 3190 |
# File 'lib/stripe/resources/charge.rb', line 3188 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
The status of the payment is either ‘succeeded`, `pending`, or `failed`.
3190 3191 3192 |
# File 'lib/stripe/resources/charge.rb', line 3190 def status @status end |
#transfer ⇒ Object (readonly)
ID of the transfer to the ‘destination` account (only applicable if the charge was created using the `destination` parameter).
3192 3193 3194 |
# File 'lib/stripe/resources/charge.rb', line 3192 def transfer @transfer end |
#transfer_data ⇒ Object (readonly)
An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.
3194 3195 3196 |
# File 'lib/stripe/resources/charge.rb', line 3194 def transfer_data @transfer_data end |
#transfer_group ⇒ Object (readonly)
A string that identifies this transaction as part of a group. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
3196 3197 3198 |
# File 'lib/stripe/resources/charge.rb', line 3196 def transfer_group @transfer_group end |
Class Method Details
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created ([7 by default](docs.stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.
Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](docs.stripe.com/docs/api/payment_intents/capture).
3217 3218 3219 3220 3221 3222 3223 3224 |
# File 'lib/stripe/resources/charge.rb', line 3217 def self.capture(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the [Payment Intents API](docs.stripe.com/docs/api/payment_intents) to initiate a new payment instead. Confirmation of the PaymentIntent creates the Charge object used to request payment.
3229 3230 3231 |
# File 'lib/stripe/resources/charge.rb', line 3229 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/charges", params: params, opts: opts) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you’ve previously created. The charges are returned in sorted order, with the most recent charges appearing first.
3234 3235 3236 |
# File 'lib/stripe/resources/charge.rb', line 3234 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges", params: params, opts: opts) end |
.object_name ⇒ Object
17 18 19 |
# File 'lib/stripe/resources/charge.rb', line 17 def self.object_name "charge" end |
.search(params = {}, opts = {}) ⇒ Object
3238 3239 3240 |
# File 'lib/stripe/resources/charge.rb', line 3238 def self.search(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges/search", params: params, opts: opts) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
3242 3243 3244 |
# File 'lib/stripe/resources/charge.rb', line 3242 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.update(charge, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
3247 3248 3249 3250 3251 3252 3253 3254 |
# File 'lib/stripe/resources/charge.rb', line 3247 def self.update(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
Instance Method Details
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created ([7 by default](docs.stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.
Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](docs.stripe.com/docs/api/payment_intents/capture).
3203 3204 3205 3206 3207 3208 3209 3210 |
# File 'lib/stripe/resources/charge.rb', line 3203 def capture(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(self["id"]) }), params: params, opts: opts ) end |