Class: Stripe::Charge

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/charge.rb

Overview

The ‘Charge` object represents a single attempt to move money into your Stripe account. PaymentIntent confirmation is the most common way to create Charges, but transferring money to a different Stripe account through Connect also creates Charges. Some legacy payment flows create Charges directly, which is not recommended for new integrations.

Defined Under Namespace

Classes: BillingDetails, CaptureParams, CreateParams, FraudDetails, Level3, ListParams, Outcome, PaymentMethodDetails, PresentmentDetails, RadarOptions, SearchParams, Shipping, TransferData, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"charge"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



1547
1548
1549
# File 'lib/stripe/resources/charge.rb', line 1547

def amount
  @amount
end

#amount_capturedObject (readonly)

Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).



1549
1550
1551
# File 'lib/stripe/resources/charge.rb', line 1549

def amount_captured
  @amount_captured
end

#amount_refundedObject (readonly)

Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).



1551
1552
1553
# File 'lib/stripe/resources/charge.rb', line 1551

def amount_refunded
  @amount_refunded
end

#applicationObject (readonly)

ID of the Connect application that created the charge.



1553
1554
1555
# File 'lib/stripe/resources/charge.rb', line 1553

def application
  @application
end

#application_feeObject (readonly)

The application fee (if any) for the charge. [See the Connect documentation](stripe.com/docs/connect/direct-charges#collect-fees) for details.



1555
1556
1557
# File 'lib/stripe/resources/charge.rb', line 1555

def application_fee
  @application_fee
end

#application_fee_amountObject (readonly)

The amount of the application fee (if any) requested for the charge. [See the Connect documentation](stripe.com/docs/connect/direct-charges#collect-fees) for details.



1557
1558
1559
# File 'lib/stripe/resources/charge.rb', line 1557

def application_fee_amount
  @application_fee_amount
end

#authorization_codeObject (readonly)

Authorization code on the charge.



1559
1560
1561
# File 'lib/stripe/resources/charge.rb', line 1559

def authorization_code
  @authorization_code
end

#balance_transactionObject (readonly)

ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).



1561
1562
1563
# File 'lib/stripe/resources/charge.rb', line 1561

def balance_transaction
  @balance_transaction
end

#billing_detailsObject (readonly)

Attribute for field billing_details



1563
1564
1565
# File 'lib/stripe/resources/charge.rb', line 1563

def billing_details
  @billing_details
end

#calculated_statement_descriptorObject (readonly)

The full statement descriptor that is passed to card networks, and that is displayed on your customers’ credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.



1565
1566
1567
# File 'lib/stripe/resources/charge.rb', line 1565

def calculated_statement_descriptor
  @calculated_statement_descriptor
end

#capturedObject (readonly)

If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.



1567
1568
1569
# File 'lib/stripe/resources/charge.rb', line 1567

def captured
  @captured
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1569
1570
1571
# File 'lib/stripe/resources/charge.rb', line 1569

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1571
1572
1573
# File 'lib/stripe/resources/charge.rb', line 1571

def currency
  @currency
end

#customerObject (readonly)

ID of the customer this charge is for if one exists.



1573
1574
1575
# File 'lib/stripe/resources/charge.rb', line 1573

def customer
  @customer
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



1575
1576
1577
# File 'lib/stripe/resources/charge.rb', line 1575

def description
  @description
end

#disputedObject (readonly)

Whether the charge has been disputed.



1577
1578
1579
# File 'lib/stripe/resources/charge.rb', line 1577

def disputed
  @disputed
end

#failure_balance_transactionObject (readonly)

ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.



1579
1580
1581
# File 'lib/stripe/resources/charge.rb', line 1579

def failure_balance_transaction
  @failure_balance_transaction
end

#failure_codeObject (readonly)

Error code explaining reason for charge failure if available (see [the errors section](stripe.com/docs/error-codes) for a list of codes).



1581
1582
1583
# File 'lib/stripe/resources/charge.rb', line 1581

def failure_code
  @failure_code
end

#failure_messageObject (readonly)

Message to user further explaining reason for charge failure if available.



1583
1584
1585
# File 'lib/stripe/resources/charge.rb', line 1583

def failure_message
  @failure_message
end

#fraud_detailsObject (readonly)

Information on fraud assessments for the charge.



1585
1586
1587
# File 'lib/stripe/resources/charge.rb', line 1585

def fraud_details
  @fraud_details
end

#idObject (readonly)

Unique identifier for the object.



1587
1588
1589
# File 'lib/stripe/resources/charge.rb', line 1587

def id
  @id
end

#level3Object (readonly)

Attribute for field level3



1589
1590
1591
# File 'lib/stripe/resources/charge.rb', line 1589

def level3
  @level3
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1591
1592
1593
# File 'lib/stripe/resources/charge.rb', line 1591

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1593
1594
1595
# File 'lib/stripe/resources/charge.rb', line 1593

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1595
1596
1597
# File 'lib/stripe/resources/charge.rb', line 1595

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers) for details.



1597
1598
1599
# File 'lib/stripe/resources/charge.rb', line 1597

def on_behalf_of
  @on_behalf_of
end

#outcomeObject (readonly)

Details about whether the payment was accepted, and why. See [understanding declines](stripe.com/docs/declines) for details.



1599
1600
1601
# File 'lib/stripe/resources/charge.rb', line 1599

def outcome
  @outcome
end

‘true` if the charge succeeded, or was successfully authorized for later capture.



1601
1602
1603
# File 'lib/stripe/resources/charge.rb', line 1601

def paid
  @paid
end

#payment_intentObject (readonly)

ID of the PaymentIntent associated with this charge, if one exists.



1603
1604
1605
# File 'lib/stripe/resources/charge.rb', line 1603

def payment_intent
  @payment_intent
end

#payment_methodObject (readonly)

ID of the payment method used in this charge.



1605
1606
1607
# File 'lib/stripe/resources/charge.rb', line 1605

def payment_method
  @payment_method
end

#payment_method_detailsObject (readonly)

Details about the payment method at the time of the transaction.



1607
1608
1609
# File 'lib/stripe/resources/charge.rb', line 1607

def payment_method_details
  @payment_method_details
end

#presentment_detailsObject (readonly)

Attribute for field presentment_details



1609
1610
1611
# File 'lib/stripe/resources/charge.rb', line 1609

def presentment_details
  @presentment_details
end

#radar_optionsObject (readonly)

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



1611
1612
1613
# File 'lib/stripe/resources/charge.rb', line 1611

def radar_options
  @radar_options
end

#receipt_emailObject (readonly)

This is the email address that the receipt for this charge was sent to.



1613
1614
1615
# File 'lib/stripe/resources/charge.rb', line 1613

def receipt_email
  @receipt_email
end

#receipt_numberObject (readonly)

This is the transaction number that appears on email receipts sent for this charge. This attribute will be ‘null` until a receipt has been sent.



1615
1616
1617
# File 'lib/stripe/resources/charge.rb', line 1615

def receipt_number
  @receipt_number
end

#receipt_urlObject (readonly)

This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.



1617
1618
1619
# File 'lib/stripe/resources/charge.rb', line 1617

def receipt_url
  @receipt_url
end

#refundedObject (readonly)

Whether the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.



1619
1620
1621
# File 'lib/stripe/resources/charge.rb', line 1619

def refunded
  @refunded
end

#refundsObject (readonly)

A list of refunds that have been applied to the charge.



1621
1622
1623
# File 'lib/stripe/resources/charge.rb', line 1621

def refunds
  @refunds
end

#reviewObject (readonly)

ID of the review associated with this charge if one exists.



1623
1624
1625
# File 'lib/stripe/resources/charge.rb', line 1623

def review
  @review
end

#shippingObject (readonly)

Shipping information for the charge.



1625
1626
1627
# File 'lib/stripe/resources/charge.rb', line 1625

def shipping
  @shipping
end

#sourceObject (readonly)

This is a legacy field that will be removed in the future. It contains the Source, Card, or BankAccount object used for the charge. For details about the payment method used for this charge, refer to ‘payment_method` or `payment_method_details` instead.



1627
1628
1629
# File 'lib/stripe/resources/charge.rb', line 1627

def source
  @source
end

#source_transferObject (readonly)

The transfer ID which created this charge. Only present if the charge came from another Stripe account. [See the Connect documentation](docs.stripe.com/connect/destination-charges) for details.



1629
1630
1631
# File 'lib/stripe/resources/charge.rb', line 1629

def source_transfer
  @source_transfer
end

#statement_descriptorObject (readonly)

For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.



1633
1634
1635
# File 'lib/stripe/resources/charge.rb', line 1633

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.



1635
1636
1637
# File 'lib/stripe/resources/charge.rb', line 1635

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#statusObject (readonly)

The status of the payment is either ‘succeeded`, `pending`, or `failed`.



1637
1638
1639
# File 'lib/stripe/resources/charge.rb', line 1637

def status
  @status
end

#transferObject (readonly)

ID of the transfer to the ‘destination` account (only applicable if the charge was created using the `destination` parameter).



1639
1640
1641
# File 'lib/stripe/resources/charge.rb', line 1639

def transfer
  @transfer
end

#transfer_dataObject (readonly)

An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.



1641
1642
1643
# File 'lib/stripe/resources/charge.rb', line 1641

def transfer_data
  @transfer_data
end

#transfer_groupObject (readonly)

A string that identifies this transaction as part of a group. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.



1643
1644
1645
# File 'lib/stripe/resources/charge.rb', line 1643

def transfer_group
  @transfer_group
end

Class Method Details

.capture(charge, params = {}, opts = {}) ⇒ Object

Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.

Uncaptured payments expire a set number of days after they are created ([7 by default](docs.stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.

Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](docs.stripe.com/docs/api/payment_intents/capture).



1664
1665
1666
1667
1668
1669
1670
1671
# File 'lib/stripe/resources/charge.rb', line 1664

def self.capture(charge, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(charge) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

This method is no longer recommended—use the [Payment Intents API](docs.stripe.com/docs/api/payment_intents) to initiate a new payment instead. Confirmation of the PaymentIntent creates the Charge object used to request payment.



1676
1677
1678
# File 'lib/stripe/resources/charge.rb', line 1676

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/charges", params: params, opts: opts)
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of charges you’ve previously created. The charges are returned in sorted order, with the most recent charges appearing first.



1681
1682
1683
# File 'lib/stripe/resources/charge.rb', line 1681

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/charges", params: params, opts: opts)
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/charge.rb', line 17

def self.object_name
  "charge"
end

.search(params = {}, opts = {}) ⇒ Object



1685
1686
1687
# File 'lib/stripe/resources/charge.rb', line 1685

def self.search(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/charges/search", params: params, opts: opts)
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



1689
1690
1691
# File 'lib/stripe/resources/charge.rb', line 1689

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.update(charge, params = {}, opts = {}) ⇒ Object

Updates the specified charge by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



1694
1695
1696
1697
1698
1699
1700
1701
# File 'lib/stripe/resources/charge.rb', line 1694

def self.update(charge, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/charges/%<charge>s", { charge: CGI.escape(charge) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#capture(params = {}, opts = {}) ⇒ Object

Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.

Uncaptured payments expire a set number of days after they are created ([7 by default](docs.stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.

Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](docs.stripe.com/docs/api/payment_intents/capture).



1650
1651
1652
1653
1654
1655
1656
1657
# File 'lib/stripe/resources/charge.rb', line 1650

def capture(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end