Class: Stripe::Charge
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Charge
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/charge.rb
Overview
The ‘Charge` object represents a single attempt to move money into your Stripe account. PaymentIntent confirmation is the most common way to create Charges, but transferring money to a different Stripe account through Connect also creates Charges. Some legacy payment flows create Charges directly, which is not recommended for new integrations.
Defined Under Namespace
Classes: BillingDetails, CaptureParams, CreateParams, FraudDetails, Level3, ListParams, Outcome, PaymentMethodDetails, RadarOptions, RetrieveParams, SearchParams, Shipping, TransferData, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"charge"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount intended to be collected by this payment.
-
#amount_captured ⇒ Object
readonly
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
-
#amount_refunded ⇒ Object
readonly
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
-
#application ⇒ Object
readonly
ID of the Connect application that created the charge.
-
#application_fee ⇒ Object
readonly
The application fee (if any) for the charge.
-
#application_fee_amount ⇒ Object
readonly
The amount of the application fee (if any) requested for the charge.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#calculated_statement_descriptor ⇒ Object
readonly
The full statement descriptor that is passed to card networks, and that is displayed on your customers’ credit card and bank statements.
-
#captured ⇒ Object
readonly
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
ID of the customer this charge is for if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#disputed ⇒ Object
readonly
Whether the charge has been disputed.
-
#failure_balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
-
#failure_code ⇒ Object
readonly
Error code explaining reason for charge failure if available (see [the errors section](stripe.com/docs/error-codes) for a list of codes).
-
#failure_message ⇒ Object
readonly
Message to user further explaining reason for charge failure if available.
-
#fraud_details ⇒ Object
readonly
Information on fraud assessments for the charge.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice ⇒ Object
readonly
ID of the invoice this charge is for if one exists.
-
#level3 ⇒ Object
readonly
Attribute for field level3.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) the charge was made on behalf of without triggering an automatic transfer.
-
#outcome ⇒ Object
readonly
Details about whether the payment was accepted, and why.
-
#paid ⇒ Object
readonly
‘true` if the charge succeeded, or was successfully authorized for later capture.
-
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent associated with this charge, if one exists.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this charge.
-
#payment_method_details ⇒ Object
readonly
Details about the payment method at the time of the transaction.
-
#radar_options ⇒ Object
readonly
Options to configure Radar.
-
#receipt_email ⇒ Object
readonly
This is the email address that the receipt for this charge was sent to.
-
#receipt_number ⇒ Object
readonly
This is the transaction number that appears on email receipts sent for this charge.
-
#receipt_url ⇒ Object
readonly
This is the URL to view the receipt for this charge.
-
#refunded ⇒ Object
readonly
Whether the charge has been fully refunded.
-
#refunds ⇒ Object
readonly
A list of refunds that have been applied to the charge.
-
#review ⇒ Object
readonly
ID of the review associated with this charge if one exists.
-
#shipping ⇒ Object
readonly
Shipping information for the charge.
-
#source ⇒ Object
readonly
This is a legacy field that will be removed in the future.
-
#source_transfer ⇒ Object
readonly
The transfer ID which created this charge.
-
#statement_descriptor ⇒ Object
readonly
For a non-card charge, text that appears on the customer’s statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
The status of the payment is either ‘succeeded`, `pending`, or `failed`.
-
#transfer ⇒ Object
readonly
ID of the transfer to the ‘destination` account (only applicable if the charge was created using the `destination` parameter).
-
#transfer_data ⇒ Object
readonly
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
readonly
A string that identifies this transaction as part of a group.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
-
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the [Payment Intents API](stripe.com/docs/api/payment_intents) to initiate a new payment instead.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you’ve previously created.
- .object_name ⇒ Object
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed.
Instance Method Summary collapse
-
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
3565 3566 3567 |
# File 'lib/stripe/resources/charge.rb', line 3565 def amount @amount end |
#amount_captured ⇒ Object (readonly)
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
3568 3569 3570 |
# File 'lib/stripe/resources/charge.rb', line 3568 def amount_captured @amount_captured end |
#amount_refunded ⇒ Object (readonly)
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
3571 3572 3573 |
# File 'lib/stripe/resources/charge.rb', line 3571 def amount_refunded @amount_refunded end |
#application ⇒ Object (readonly)
ID of the Connect application that created the charge.
3574 3575 3576 |
# File 'lib/stripe/resources/charge.rb', line 3574 def application @application end |
#application_fee ⇒ Object (readonly)
The application fee (if any) for the charge. [See the Connect documentation](stripe.com/docs/connect/direct-charges#collect-fees) for details.
3577 3578 3579 |
# File 'lib/stripe/resources/charge.rb', line 3577 def application_fee @application_fee end |
#application_fee_amount ⇒ Object (readonly)
The amount of the application fee (if any) requested for the charge. [See the Connect documentation](stripe.com/docs/connect/direct-charges#collect-fees) for details.
3580 3581 3582 |
# File 'lib/stripe/resources/charge.rb', line 3580 def application_fee_amount @application_fee_amount end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
3583 3584 3585 |
# File 'lib/stripe/resources/charge.rb', line 3583 def @authorization_code end |
#balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
3586 3587 3588 |
# File 'lib/stripe/resources/charge.rb', line 3586 def balance_transaction @balance_transaction end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
3589 3590 3591 |
# File 'lib/stripe/resources/charge.rb', line 3589 def billing_details @billing_details end |
#calculated_statement_descriptor ⇒ Object (readonly)
The full statement descriptor that is passed to card networks, and that is displayed on your customers’ credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.
3592 3593 3594 |
# File 'lib/stripe/resources/charge.rb', line 3592 def calculated_statement_descriptor @calculated_statement_descriptor end |
#captured ⇒ Object (readonly)
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
3595 3596 3597 |
# File 'lib/stripe/resources/charge.rb', line 3595 def captured @captured end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
3598 3599 3600 |
# File 'lib/stripe/resources/charge.rb', line 3598 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3601 3602 3603 |
# File 'lib/stripe/resources/charge.rb', line 3601 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the customer this charge is for if one exists.
3604 3605 3606 |
# File 'lib/stripe/resources/charge.rb', line 3604 def customer @customer end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
3607 3608 3609 |
# File 'lib/stripe/resources/charge.rb', line 3607 def description @description end |
#disputed ⇒ Object (readonly)
Whether the charge has been disputed.
3610 3611 3612 |
# File 'lib/stripe/resources/charge.rb', line 3610 def disputed @disputed end |
#failure_balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
3613 3614 3615 |
# File 'lib/stripe/resources/charge.rb', line 3613 def failure_balance_transaction @failure_balance_transaction end |
#failure_code ⇒ Object (readonly)
Error code explaining reason for charge failure if available (see [the errors section](stripe.com/docs/error-codes) for a list of codes).
3616 3617 3618 |
# File 'lib/stripe/resources/charge.rb', line 3616 def failure_code @failure_code end |
#failure_message ⇒ Object (readonly)
Message to user further explaining reason for charge failure if available.
3619 3620 3621 |
# File 'lib/stripe/resources/charge.rb', line 3619 def @failure_message end |
#fraud_details ⇒ Object (readonly)
Information on fraud assessments for the charge.
3622 3623 3624 |
# File 'lib/stripe/resources/charge.rb', line 3622 def fraud_details @fraud_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
3625 3626 3627 |
# File 'lib/stripe/resources/charge.rb', line 3625 def id @id end |
#invoice ⇒ Object (readonly)
ID of the invoice this charge is for if one exists.
3628 3629 3630 |
# File 'lib/stripe/resources/charge.rb', line 3628 def invoice @invoice end |
#level3 ⇒ Object (readonly)
Attribute for field level3
3631 3632 3633 |
# File 'lib/stripe/resources/charge.rb', line 3631 def level3 @level3 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
3634 3635 3636 |
# File 'lib/stripe/resources/charge.rb', line 3634 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
3637 3638 3639 |
# File 'lib/stripe/resources/charge.rb', line 3637 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
3640 3641 3642 |
# File 'lib/stripe/resources/charge.rb', line 3640 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers) for details.
3643 3644 3645 |
# File 'lib/stripe/resources/charge.rb', line 3643 def on_behalf_of @on_behalf_of end |
#outcome ⇒ Object (readonly)
Details about whether the payment was accepted, and why. See [understanding declines](stripe.com/docs/declines) for details.
3646 3647 3648 |
# File 'lib/stripe/resources/charge.rb', line 3646 def outcome @outcome end |
#paid ⇒ Object (readonly)
‘true` if the charge succeeded, or was successfully authorized for later capture.
3649 3650 3651 |
# File 'lib/stripe/resources/charge.rb', line 3649 def paid @paid end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent associated with this charge, if one exists.
3652 3653 3654 |
# File 'lib/stripe/resources/charge.rb', line 3652 def payment_intent @payment_intent end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this charge.
3655 3656 3657 |
# File 'lib/stripe/resources/charge.rb', line 3655 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Details about the payment method at the time of the transaction.
3658 3659 3660 |
# File 'lib/stripe/resources/charge.rb', line 3658 def payment_method_details @payment_method_details end |
#radar_options ⇒ Object (readonly)
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
3661 3662 3663 |
# File 'lib/stripe/resources/charge.rb', line 3661 def @radar_options end |
#receipt_email ⇒ Object (readonly)
This is the email address that the receipt for this charge was sent to.
3664 3665 3666 |
# File 'lib/stripe/resources/charge.rb', line 3664 def receipt_email @receipt_email end |
#receipt_number ⇒ Object (readonly)
This is the transaction number that appears on email receipts sent for this charge. This attribute will be ‘null` until a receipt has been sent.
3667 3668 3669 |
# File 'lib/stripe/resources/charge.rb', line 3667 def receipt_number @receipt_number end |
#receipt_url ⇒ Object (readonly)
This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.
3670 3671 3672 |
# File 'lib/stripe/resources/charge.rb', line 3670 def receipt_url @receipt_url end |
#refunded ⇒ Object (readonly)
Whether the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.
3673 3674 3675 |
# File 'lib/stripe/resources/charge.rb', line 3673 def refunded @refunded end |
#refunds ⇒ Object (readonly)
A list of refunds that have been applied to the charge.
3676 3677 3678 |
# File 'lib/stripe/resources/charge.rb', line 3676 def refunds @refunds end |
#review ⇒ Object (readonly)
ID of the review associated with this charge if one exists.
3679 3680 3681 |
# File 'lib/stripe/resources/charge.rb', line 3679 def review @review end |
#shipping ⇒ Object (readonly)
Shipping information for the charge.
3682 3683 3684 |
# File 'lib/stripe/resources/charge.rb', line 3682 def shipping @shipping end |
#source ⇒ Object (readonly)
This is a legacy field that will be removed in the future. It contains the Source, Card, or BankAccount object used for the charge. For details about the payment method used for this charge, refer to ‘payment_method` or `payment_method_details` instead.
3685 3686 3687 |
# File 'lib/stripe/resources/charge.rb', line 3685 def source @source end |
#source_transfer ⇒ Object (readonly)
The transfer ID which created this charge. Only present if the charge came from another Stripe account. [See the Connect documentation](docs.stripe.com/connect/destination-charges) for details.
3688 3689 3690 |
# File 'lib/stripe/resources/charge.rb', line 3688 def source_transfer @source_transfer end |
#statement_descriptor ⇒ Object (readonly)
For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.
3693 3694 3695 |
# File 'lib/stripe/resources/charge.rb', line 3693 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.
3696 3697 3698 |
# File 'lib/stripe/resources/charge.rb', line 3696 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
The status of the payment is either ‘succeeded`, `pending`, or `failed`.
3699 3700 3701 |
# File 'lib/stripe/resources/charge.rb', line 3699 def status @status end |
#transfer ⇒ Object (readonly)
ID of the transfer to the ‘destination` account (only applicable if the charge was created using the `destination` parameter).
3702 3703 3704 |
# File 'lib/stripe/resources/charge.rb', line 3702 def transfer @transfer end |
#transfer_data ⇒ Object (readonly)
An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.
3705 3706 3707 |
# File 'lib/stripe/resources/charge.rb', line 3705 def transfer_data @transfer_data end |
#transfer_group ⇒ Object (readonly)
A string that identifies this transaction as part of a group. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
3708 3709 3710 |
# File 'lib/stripe/resources/charge.rb', line 3708 def transfer_group @transfer_group end |
Class Method Details
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created ([7 by default](stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.
Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](stripe.com/docs/api/payment_intents/capture).
3729 3730 3731 3732 3733 3734 3735 3736 |
# File 'lib/stripe/resources/charge.rb', line 3729 def self.capture(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the [Payment Intents API](stripe.com/docs/api/payment_intents) to initiate a new payment instead. Confirmation of the PaymentIntent creates the Charge object used to request payment.
3741 3742 3743 |
# File 'lib/stripe/resources/charge.rb', line 3741 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/charges", params: params, opts: opts) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you’ve previously created. The charges are returned in sorted order, with the most recent charges appearing first.
3746 3747 3748 |
# File 'lib/stripe/resources/charge.rb', line 3746 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges", params: params, opts: opts) end |
.object_name ⇒ Object
17 18 19 |
# File 'lib/stripe/resources/charge.rb', line 17 def self.object_name "charge" end |
.search(params = {}, opts = {}) ⇒ Object
3750 3751 3752 |
# File 'lib/stripe/resources/charge.rb', line 3750 def self.search(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges/search", params: params, opts: opts) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
3754 3755 3756 |
# File 'lib/stripe/resources/charge.rb', line 3754 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
3759 3760 3761 3762 3763 3764 3765 3766 |
# File 'lib/stripe/resources/charge.rb', line 3759 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created ([7 by default](stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.
Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](stripe.com/docs/api/payment_intents/capture).
3715 3716 3717 3718 3719 3720 3721 3722 |
# File 'lib/stripe/resources/charge.rb', line 3715 def capture(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(self["id"]) }), params: params, opts: opts ) end |