Class: Stripe::Charge
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Charge
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/charge.rb
Overview
The Charge object represents a single attempt to move money into your Stripe account. PaymentIntent confirmation is the most common way to create Charges, but [Account Debits](docs.stripe.com/connect/account-debits) may also create Charges. Some legacy payment flows create Charges directly, which is not recommended for new integrations.
Defined Under Namespace
Classes: BillingDetails, FraudDetails, Level3, Outcome, PaymentMethodDetails, PresentmentDetails, RadarOptions, Shipping, TransferData
Constant Summary collapse
- OBJECT_NAME =
"charge"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount intended to be collected by this payment.
-
#amount_captured ⇒ Object
readonly
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
-
#amount_refunded ⇒ Object
readonly
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
-
#application ⇒ Object
readonly
ID of the Connect application that created the charge.
-
#application_fee ⇒ Object
readonly
The application fee (if any) for the charge.
-
#application_fee_amount ⇒ Object
readonly
The amount of the application fee (if any) requested for the charge.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#calculated_statement_descriptor ⇒ Object
readonly
The full statement descriptor that is passed to card networks, and that is displayed on your customers’ credit card and bank statements.
-
#captured ⇒ Object
readonly
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
ID of the customer this charge is for if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#disputed ⇒ Object
readonly
Whether the charge has been disputed.
-
#failure_balance_transaction ⇒ Object
readonly
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
-
#failure_code ⇒ Object
readonly
Error code explaining reason for charge failure if available (see [the errors section](docs.stripe.com/error-codes) for a list of codes).
-
#failure_message ⇒ Object
readonly
Message to user further explaining reason for charge failure if available.
-
#fraud_details ⇒ Object
readonly
Information on fraud assessments for the charge.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#level3 ⇒ Object
readonly
Attribute for field level3.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) the charge was made on behalf of without triggering an automatic transfer.
-
#outcome ⇒ Object
readonly
Details about whether the payment was accepted, and why.
-
#paid ⇒ Object
readonly
trueif the charge succeeded, or was successfully authorized for later capture. -
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent associated with this charge, if one exists.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this charge.
-
#payment_method_details ⇒ Object
readonly
Details about the payment method at the time of the transaction.
-
#presentment_details ⇒ Object
readonly
Attribute for field presentment_details.
-
#radar_options ⇒ Object
readonly
Options to configure Radar.
-
#receipt_email ⇒ Object
readonly
This is the email address that the receipt for this charge was sent to.
-
#receipt_number ⇒ Object
readonly
This is the transaction number that appears on email receipts sent for this charge.
-
#receipt_url ⇒ Object
readonly
This is the URL to view the receipt for this charge.
-
#refunded ⇒ Object
readonly
Whether the charge has been fully refunded.
-
#refunds ⇒ Object
readonly
A list of refunds that have been applied to the charge.
-
#review ⇒ Object
readonly
ID of the review associated with this charge if one exists.
-
#shipping ⇒ Object
readonly
Shipping information for the charge.
-
#source ⇒ Object
readonly
This is a legacy field that will be removed in the future.
-
#source_transfer ⇒ Object
readonly
The transfer ID which created this charge.
-
#statement_descriptor ⇒ Object
readonly
For a non-card charge, text that appears on the customer’s statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
The status of the payment is either
succeeded,pending, orfailed. -
#transfer ⇒ Object
readonly
ID of the transfer to the
destinationaccount (only applicable if the charge was created using thedestinationparameter). -
#transfer_data ⇒ Object
readonly
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
readonly
A string that identifies this transaction as part of a group.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
-
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the [Payment Intents API](docs.stripe.com/docs/api/payment_intents) to initiate a new payment instead.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you’ve previously created.
- .object_name ⇒ Object
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.update(charge, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed.
Instance Method Summary collapse
-
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
2165 2166 2167 |
# File 'lib/stripe/resources/charge.rb', line 2165 def amount @amount end |
#amount_captured ⇒ Object (readonly)
Amount in cents (or local equivalent) captured (can be less than the amount attribute on the charge if a partial capture was made).
2167 2168 2169 |
# File 'lib/stripe/resources/charge.rb', line 2167 def amount_captured @amount_captured end |
#amount_refunded ⇒ Object (readonly)
Amount in cents (or local equivalent) refunded (can be less than the amount attribute on the charge if a partial refund was issued).
2169 2170 2171 |
# File 'lib/stripe/resources/charge.rb', line 2169 def amount_refunded @amount_refunded end |
#application ⇒ Object (readonly)
ID of the Connect application that created the charge.
2171 2172 2173 |
# File 'lib/stripe/resources/charge.rb', line 2171 def application @application end |
#application_fee ⇒ Object (readonly)
The application fee (if any) for the charge. [See the Connect documentation](docs.stripe.com/connect/direct-charges#collect-fees) for details.
2173 2174 2175 |
# File 'lib/stripe/resources/charge.rb', line 2173 def application_fee @application_fee end |
#application_fee_amount ⇒ Object (readonly)
The amount of the application fee (if any) requested for the charge. [See the Connect documentation](docs.stripe.com/connect/direct-charges#collect-fees) for details.
2175 2176 2177 |
# File 'lib/stripe/resources/charge.rb', line 2175 def application_fee_amount @application_fee_amount end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
2177 2178 2179 |
# File 'lib/stripe/resources/charge.rb', line 2177 def end |
#balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the impact of this charge on your account balance (not including refunds or disputes).
2179 2180 2181 |
# File 'lib/stripe/resources/charge.rb', line 2179 def balance_transaction @balance_transaction end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
2181 2182 2183 |
# File 'lib/stripe/resources/charge.rb', line 2181 def billing_details @billing_details end |
#calculated_statement_descriptor ⇒ Object (readonly)
The full statement descriptor that is passed to card networks, and that is displayed on your customers’ credit card and bank statements. Allows you to see what the statement descriptor looks like after the static and dynamic portions are combined. This value only exists for card payments.
2183 2184 2185 |
# File 'lib/stripe/resources/charge.rb', line 2183 def calculated_statement_descriptor @calculated_statement_descriptor end |
#captured ⇒ Object (readonly)
If the charge was created without capturing, this Boolean represents whether it is still uncaptured or has since been captured.
2185 2186 2187 |
# File 'lib/stripe/resources/charge.rb', line 2185 def captured @captured end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
2187 2188 2189 |
# File 'lib/stripe/resources/charge.rb', line 2187 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2189 2190 2191 |
# File 'lib/stripe/resources/charge.rb', line 2189 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the customer this charge is for if one exists.
2191 2192 2193 |
# File 'lib/stripe/resources/charge.rb', line 2191 def customer @customer end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
2193 2194 2195 |
# File 'lib/stripe/resources/charge.rb', line 2193 def description @description end |
#disputed ⇒ Object (readonly)
Whether the charge has been disputed.
2195 2196 2197 |
# File 'lib/stripe/resources/charge.rb', line 2195 def disputed @disputed end |
#failure_balance_transaction ⇒ Object (readonly)
ID of the balance transaction that describes the reversal of the balance on your account due to payment failure.
2197 2198 2199 |
# File 'lib/stripe/resources/charge.rb', line 2197 def failure_balance_transaction @failure_balance_transaction end |
#failure_code ⇒ Object (readonly)
Error code explaining reason for charge failure if available (see [the errors section](docs.stripe.com/error-codes) for a list of codes).
2199 2200 2201 |
# File 'lib/stripe/resources/charge.rb', line 2199 def failure_code @failure_code end |
#failure_message ⇒ Object (readonly)
Message to user further explaining reason for charge failure if available.
2201 2202 2203 |
# File 'lib/stripe/resources/charge.rb', line 2201 def end |
#fraud_details ⇒ Object (readonly)
Information on fraud assessments for the charge.
2203 2204 2205 |
# File 'lib/stripe/resources/charge.rb', line 2203 def fraud_details @fraud_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2205 2206 2207 |
# File 'lib/stripe/resources/charge.rb', line 2205 def id @id end |
#level3 ⇒ Object (readonly)
Attribute for field level3
2207 2208 2209 |
# File 'lib/stripe/resources/charge.rb', line 2207 def level3 @level3 end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
2209 2210 2211 |
# File 'lib/stripe/resources/charge.rb', line 2209 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2211 2212 2213 |
# File 'lib/stripe/resources/charge.rb', line 2211 def end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
2213 2214 2215 |
# File 'lib/stripe/resources/charge.rb', line 2213 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) the charge was made on behalf of without triggering an automatic transfer. See the [Connect documentation](docs.stripe.com/connect/separate-charges-and-transfers) for details.
2215 2216 2217 |
# File 'lib/stripe/resources/charge.rb', line 2215 def on_behalf_of @on_behalf_of end |
#outcome ⇒ Object (readonly)
Details about whether the payment was accepted, and why. See [understanding declines](docs.stripe.com/declines) for details.
2217 2218 2219 |
# File 'lib/stripe/resources/charge.rb', line 2217 def outcome @outcome end |
#paid ⇒ Object (readonly)
true if the charge succeeded, or was successfully authorized for later capture.
2219 2220 2221 |
# File 'lib/stripe/resources/charge.rb', line 2219 def paid @paid end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent associated with this charge, if one exists.
2221 2222 2223 |
# File 'lib/stripe/resources/charge.rb', line 2221 def payment_intent @payment_intent end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this charge.
2223 2224 2225 |
# File 'lib/stripe/resources/charge.rb', line 2223 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Details about the payment method at the time of the transaction.
2225 2226 2227 |
# File 'lib/stripe/resources/charge.rb', line 2225 def payment_method_details @payment_method_details end |
#presentment_details ⇒ Object (readonly)
Attribute for field presentment_details
2227 2228 2229 |
# File 'lib/stripe/resources/charge.rb', line 2227 def presentment_details @presentment_details end |
#radar_options ⇒ Object (readonly)
Options to configure Radar. See [Radar Session](docs.stripe.com/radar/radar-session) for more information.
2229 2230 2231 |
# File 'lib/stripe/resources/charge.rb', line 2229 def end |
#receipt_email ⇒ Object (readonly)
This is the email address that the receipt for this charge was sent to.
2231 2232 2233 |
# File 'lib/stripe/resources/charge.rb', line 2231 def receipt_email @receipt_email end |
#receipt_number ⇒ Object (readonly)
This is the transaction number that appears on email receipts sent for this charge. This attribute will be null until a receipt has been sent.
2233 2234 2235 |
# File 'lib/stripe/resources/charge.rb', line 2233 def receipt_number @receipt_number end |
#receipt_url ⇒ Object (readonly)
This is the URL to view the receipt for this charge. The receipt is kept up-to-date to the latest state of the charge, including any refunds. If the charge is for an Invoice, the receipt will be stylized as an Invoice receipt.
2235 2236 2237 |
# File 'lib/stripe/resources/charge.rb', line 2235 def receipt_url @receipt_url end |
#refunded ⇒ Object (readonly)
Whether the charge has been fully refunded. If the charge is only partially refunded, this attribute will still be false.
2237 2238 2239 |
# File 'lib/stripe/resources/charge.rb', line 2237 def refunded @refunded end |
#refunds ⇒ Object (readonly)
A list of refunds that have been applied to the charge.
2239 2240 2241 |
# File 'lib/stripe/resources/charge.rb', line 2239 def refunds @refunds end |
#review ⇒ Object (readonly)
ID of the review associated with this charge if one exists.
2241 2242 2243 |
# File 'lib/stripe/resources/charge.rb', line 2241 def review @review end |
#shipping ⇒ Object (readonly)
Shipping information for the charge.
2243 2244 2245 |
# File 'lib/stripe/resources/charge.rb', line 2243 def shipping @shipping end |
#source ⇒ Object (readonly)
This is a legacy field that will be removed in the future. It contains the Source, Card, or BankAccount object used for the charge. For details about the payment method used for this charge, refer to payment_method or payment_method_details instead.
2245 2246 2247 |
# File 'lib/stripe/resources/charge.rb', line 2245 def source @source end |
#source_transfer ⇒ Object (readonly)
The transfer ID which created this charge. Only present if the charge came from another Stripe account. [See the Connect documentation](docs.stripe.com/connect/destination-charges) for details.
2247 2248 2249 |
# File 'lib/stripe/resources/charge.rb', line 2247 def source_transfer @source_transfer end |
#statement_descriptor ⇒ Object (readonly)
For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
For a card charge, this value is ignored unless you don’t specify a statement_descriptor_suffix, in which case this value is used as the suffix.
2251 2252 2253 |
# File 'lib/stripe/resources/charge.rb', line 2251 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.
2253 2254 2255 |
# File 'lib/stripe/resources/charge.rb', line 2253 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
The status of the payment is either succeeded, pending, or failed.
2255 2256 2257 |
# File 'lib/stripe/resources/charge.rb', line 2255 def status @status end |
#transfer ⇒ Object (readonly)
ID of the transfer to the destination account (only applicable if the charge was created using the destination parameter).
2257 2258 2259 |
# File 'lib/stripe/resources/charge.rb', line 2257 def transfer @transfer end |
#transfer_data ⇒ Object (readonly)
An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](docs.stripe.com/connect/destination-charges) for details.
2259 2260 2261 |
# File 'lib/stripe/resources/charge.rb', line 2259 def transfer_data @transfer_data end |
#transfer_group ⇒ Object (readonly)
A string that identifies this transaction as part of a group. See the [Connect documentation](docs.stripe.com/connect/separate-charges-and-transfers#transfer-options) for details.
2261 2262 2263 |
# File 'lib/stripe/resources/charge.rb', line 2261 def transfer_group @transfer_group end |
Class Method Details
.capture(charge, params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created ([7 by default](docs.stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.
Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](docs.stripe.com/docs/api/payment_intents/capture).
2282 2283 2284 2285 2286 2287 2288 2289 |
# File 'lib/stripe/resources/charge.rb', line 2282 def self.capture(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
This method is no longer recommended—use the [Payment Intents API](docs.stripe.com/docs/api/payment_intents) to initiate a new payment instead. Confirmation of the PaymentIntent creates the Charge object used to request payment.
2294 2295 2296 |
# File 'lib/stripe/resources/charge.rb', line 2294 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/charges", params: params, opts: opts) end |
.field_remappings ⇒ Object
2335 2336 2337 |
# File 'lib/stripe/resources/charge.rb', line 2335 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 |
# File 'lib/stripe/resources/charge.rb', line 2321 def self.inner_class_types @inner_class_types = { billing_details: BillingDetails, fraud_details: FraudDetails, level3: Level3, outcome: Outcome, payment_method_details: PaymentMethodDetails, presentment_details: PresentmentDetails, radar_options: RadarOptions, shipping: Shipping, transfer_data: TransferData, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of charges you’ve previously created. The charges are returned in sorted order, with the most recent charges appearing first.
2299 2300 2301 |
# File 'lib/stripe/resources/charge.rb', line 2299 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges", params: params, opts: opts) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/charge.rb', line 16 def self.object_name "charge" end |
.search(params = {}, opts = {}) ⇒ Object
2303 2304 2305 |
# File 'lib/stripe/resources/charge.rb', line 2303 def self.search(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/charges/search", params: params, opts: opts) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
2307 2308 2309 |
# File 'lib/stripe/resources/charge.rb', line 2307 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.update(charge, params = {}, opts = {}) ⇒ Object
Updates the specified charge by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/stripe/resources/charge.rb', line 2312 def self.update(charge, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s", { charge: CGI.escape(charge) }), params: params, opts: opts ) end |
Instance Method Details
#capture(params = {}, opts = {}) ⇒ Object
Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.
Uncaptured payments expire a set number of days after they are created ([7 by default](docs.stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.
Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](docs.stripe.com/docs/api/payment_intents/capture).
2268 2269 2270 2271 2272 2273 2274 2275 |
# File 'lib/stripe/resources/charge.rb', line 2268 def capture(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(self["id"]) }), params: params, opts: opts ) end |