Class: Stripe::Charge::CaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: PaymentDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
-
#application_fee ⇒ Object
An application fee to add on to this charge.
-
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#receipt_email ⇒ Object
The email address to send this charge’s receipt to.
-
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams
constructor
A new instance of CaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams
Returns a new instance of CaptureParams.
4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 |
# File 'lib/stripe/resources/charge.rb', line 4124 def initialize( amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @amount = amount @application_fee = application_fee @application_fee_amount = application_fee_amount @expand = @payment_details = payment_details @receipt_email = receipt_email @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
4102 4103 4104 |
# File 'lib/stripe/resources/charge.rb', line 4102 def amount @amount end |
#application_fee ⇒ Object
An application fee to add on to this charge.
4104 4105 4106 |
# File 'lib/stripe/resources/charge.rb', line 4104 def application_fee @application_fee end |
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
4106 4107 4108 |
# File 'lib/stripe/resources/charge.rb', line 4106 def application_fee_amount @application_fee_amount end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
4108 4109 4110 |
# File 'lib/stripe/resources/charge.rb', line 4108 def @expand end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
4110 4111 4112 |
# File 'lib/stripe/resources/charge.rb', line 4110 def payment_details @payment_details end |
#receipt_email ⇒ Object
The email address to send this charge’s receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.
4112 4113 4114 |
# File 'lib/stripe/resources/charge.rb', line 4112 def receipt_email @receipt_email end |
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.
4116 4117 4118 |
# File 'lib/stripe/resources/charge.rb', line 4116 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.
4118 4119 4120 |
# File 'lib/stripe/resources/charge.rb', line 4118 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.
4120 4121 4122 |
# File 'lib/stripe/resources/charge.rb', line 4120 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
4122 4123 4124 |
# File 'lib/stripe/resources/charge.rb', line 4122 def transfer_group @transfer_group end |