Class: Stripe::Charge::CaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: PaymentDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
-
#application_fee ⇒ Object
An application fee to add on to this charge.
-
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#receipt_email ⇒ Object
The email address to send this charge’s receipt to.
-
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams
constructor
A new instance of CaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams
Returns a new instance of CaptureParams.
3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 3095 3096 3097 |
# File 'lib/stripe/resources/charge.rb', line 3075 def initialize( amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @amount = amount @application_fee = application_fee @application_fee_amount = application_fee_amount @expand = @payment_details = payment_details @receipt_email = receipt_email @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
3053 3054 3055 |
# File 'lib/stripe/resources/charge.rb', line 3053 def amount @amount end |
#application_fee ⇒ Object
An application fee to add on to this charge.
3055 3056 3057 |
# File 'lib/stripe/resources/charge.rb', line 3055 def application_fee @application_fee end |
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
3057 3058 3059 |
# File 'lib/stripe/resources/charge.rb', line 3057 def application_fee_amount @application_fee_amount end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3059 3060 3061 |
# File 'lib/stripe/resources/charge.rb', line 3059 def @expand end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
3061 3062 3063 |
# File 'lib/stripe/resources/charge.rb', line 3061 def payment_details @payment_details end |
#receipt_email ⇒ Object
The email address to send this charge’s receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.
3063 3064 3065 |
# File 'lib/stripe/resources/charge.rb', line 3063 def receipt_email @receipt_email end |
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.
3067 3068 3069 |
# File 'lib/stripe/resources/charge.rb', line 3067 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.
3069 3070 3071 |
# File 'lib/stripe/resources/charge.rb', line 3069 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.
3071 3072 3073 |
# File 'lib/stripe/resources/charge.rb', line 3071 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
3073 3074 3075 |
# File 'lib/stripe/resources/charge.rb', line 3073 def transfer_group @transfer_group end |