Class: Stripe::Charge::CaptureParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams

Returns a new instance of CaptureParams.



3060
3061
3062
3063
3064
3065
3066
3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
3077
3078
3079
3080
3081
3082
# File 'lib/stripe/resources/charge.rb', line 3060

def initialize(
  amount: nil,
  application_fee: nil,
  application_fee_amount: nil,
  expand: nil,
  payment_details: nil,
  receipt_email: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @amount = amount
  @application_fee = application_fee
  @application_fee_amount = application_fee_amount
  @expand = expand
  @payment_details = payment_details
  @receipt_email = receipt_email
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#amountObject

The amount to capture, which must be less than or equal to the original amount.



3038
3039
3040
# File 'lib/stripe/resources/charge.rb', line 3038

def amount
  @amount
end

#application_feeObject

An application fee to add on to this charge.



3040
3041
3042
# File 'lib/stripe/resources/charge.rb', line 3040

def application_fee
  @application_fee
end

#application_fee_amountObject

An application fee amount to add on to this charge, which must be less than or equal to the original amount.



3042
3043
3044
# File 'lib/stripe/resources/charge.rb', line 3042

def application_fee_amount
  @application_fee_amount
end

#expandObject

Specifies which fields in the response should be expanded.



3044
3045
3046
# File 'lib/stripe/resources/charge.rb', line 3044

def expand
  @expand
end

#payment_detailsObject

Provides industry-specific information about the charge.



3046
3047
3048
# File 'lib/stripe/resources/charge.rb', line 3046

def payment_details
  @payment_details
end

#receipt_emailObject

The email address to send this charge’s receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.



3048
3049
3050
# File 'lib/stripe/resources/charge.rb', line 3048

def receipt_email
  @receipt_email
end

#statement_descriptorObject

For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.



3052
3053
3054
# File 'lib/stripe/resources/charge.rb', line 3052

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.



3054
3055
3056
# File 'lib/stripe/resources/charge.rb', line 3054

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.



3056
3057
3058
# File 'lib/stripe/resources/charge.rb', line 3056

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.



3058
3059
3060
# File 'lib/stripe/resources/charge.rb', line 3058

def transfer_group
  @transfer_group
end