Class: Stripe::Charge::CaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: PaymentDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
-
#application_fee ⇒ Object
An application fee to add on to this charge.
-
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#receipt_email ⇒ Object
The email address to send this charge’s receipt to.
-
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams
constructor
A new instance of CaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams
Returns a new instance of CaptureParams.
3540 3541 3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 3561 3562 |
# File 'lib/stripe/resources/charge.rb', line 3540 def initialize( amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @amount = amount @application_fee = application_fee @application_fee_amount = application_fee_amount @expand = @payment_details = payment_details @receipt_email = receipt_email @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount. Any additional amount will be automatically refunded.
3509 3510 3511 |
# File 'lib/stripe/resources/charge.rb', line 3509 def amount @amount end |
#application_fee ⇒ Object
An application fee to add on to this charge.
3512 3513 3514 |
# File 'lib/stripe/resources/charge.rb', line 3512 def application_fee @application_fee end |
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
3515 3516 3517 |
# File 'lib/stripe/resources/charge.rb', line 3515 def application_fee_amount @application_fee_amount end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3518 3519 3520 |
# File 'lib/stripe/resources/charge.rb', line 3518 def @expand end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
3521 3522 3523 |
# File 'lib/stripe/resources/charge.rb', line 3521 def payment_details @payment_details end |
#receipt_email ⇒ Object
The email address to send this charge’s receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.
3524 3525 3526 |
# File 'lib/stripe/resources/charge.rb', line 3524 def receipt_email @receipt_email end |
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.
3529 3530 3531 |
# File 'lib/stripe/resources/charge.rb', line 3529 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.
3532 3533 3534 |
# File 'lib/stripe/resources/charge.rb', line 3532 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.
3535 3536 3537 |
# File 'lib/stripe/resources/charge.rb', line 3535 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
3538 3539 3540 |
# File 'lib/stripe/resources/charge.rb', line 3538 def transfer_group @transfer_group end |