Class: Stripe::Charge::CaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



3023
3024
3025
3026
3027
3028
3029
3030
3031
3032
3033
3034
3035
3036
3037
3038
3039
# File 'lib/stripe/resources/charge.rb', line 3023

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



3009
3010
3011
# File 'lib/stripe/resources/charge.rb', line 3009

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



3011
3012
3013
# File 'lib/stripe/resources/charge.rb', line 3011

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



3013
3014
3015
# File 'lib/stripe/resources/charge.rb', line 3013

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



3015
3016
3017
# File 'lib/stripe/resources/charge.rb', line 3015

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



3017
3018
3019
# File 'lib/stripe/resources/charge.rb', line 3017

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



3019
3020
3021
# File 'lib/stripe/resources/charge.rb', line 3019

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



3021
3022
3023
# File 'lib/stripe/resources/charge.rb', line 3021

def subscription
  @subscription
end