Class: Stripe::Charge::CaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 |
# File 'lib/stripe/resources/charge.rb', line 2934 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
2920 2921 2922 |
# File 'lib/stripe/resources/charge.rb', line 2920 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
2922 2923 2924 |
# File 'lib/stripe/resources/charge.rb', line 2922 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
2924 2925 2926 |
# File 'lib/stripe/resources/charge.rb', line 2924 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
2926 2927 2928 |
# File 'lib/stripe/resources/charge.rb', line 2926 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
2928 2929 2930 |
# File 'lib/stripe/resources/charge.rb', line 2928 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
2930 2931 2932 |
# File 'lib/stripe/resources/charge.rb', line 2930 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
2932 2933 2934 |
# File 'lib/stripe/resources/charge.rb', line 2932 def subscription @subscription end |