Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 |
# File 'lib/stripe/resources/charge.rb', line 3562 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
3514 3515 3516 |
# File 'lib/stripe/resources/charge.rb', line 3514 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
3516 3517 3518 |
# File 'lib/stripe/resources/charge.rb', line 3516 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
3518 3519 3520 |
# File 'lib/stripe/resources/charge.rb', line 3518 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
3520 3521 3522 |
# File 'lib/stripe/resources/charge.rb', line 3520 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
3522 3523 3524 |
# File 'lib/stripe/resources/charge.rb', line 3522 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
3524 3525 3526 |
# File 'lib/stripe/resources/charge.rb', line 3524 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
3526 3527 3528 |
# File 'lib/stripe/resources/charge.rb', line 3526 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
3528 3529 3530 |
# File 'lib/stripe/resources/charge.rb', line 3528 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
3530 3531 3532 |
# File 'lib/stripe/resources/charge.rb', line 3530 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
3532 3533 3534 |
# File 'lib/stripe/resources/charge.rb', line 3532 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
3534 3535 3536 |
# File 'lib/stripe/resources/charge.rb', line 3534 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
3536 3537 3538 |
# File 'lib/stripe/resources/charge.rb', line 3536 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
3538 3539 3540 |
# File 'lib/stripe/resources/charge.rb', line 3538 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
3540 3541 3542 |
# File 'lib/stripe/resources/charge.rb', line 3540 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
3542 3543 3544 |
# File 'lib/stripe/resources/charge.rb', line 3542 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
3544 3545 3546 |
# File 'lib/stripe/resources/charge.rb', line 3544 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
3546 3547 3548 |
# File 'lib/stripe/resources/charge.rb', line 3546 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
3548 3549 3550 |
# File 'lib/stripe/resources/charge.rb', line 3548 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
3550 3551 3552 |
# File 'lib/stripe/resources/charge.rb', line 3550 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
3552 3553 3554 |
# File 'lib/stripe/resources/charge.rb', line 3552 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
3554 3555 3556 |
# File 'lib/stripe/resources/charge.rb', line 3554 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
3556 3557 3558 |
# File 'lib/stripe/resources/charge.rb', line 3556 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
3558 3559 3560 |
# File 'lib/stripe/resources/charge.rb', line 3558 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
3560 3561 3562 |
# File 'lib/stripe/resources/charge.rb', line 3560 def vehicle_identification_number @vehicle_identification_number end |