Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
# File 'lib/stripe/resources/charge.rb', line 2511

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



2463
2464
2465
# File 'lib/stripe/resources/charge.rb', line 2463

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



2465
2466
2467
# File 'lib/stripe/resources/charge.rb', line 2465

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



2467
2468
2469
# File 'lib/stripe/resources/charge.rb', line 2467

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



2469
2470
2471
# File 'lib/stripe/resources/charge.rb', line 2469

def car_make
  @car_make
end

#car_modelObject

Model of the car.



2471
2472
2473
# File 'lib/stripe/resources/charge.rb', line 2471

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



2473
2474
2475
# File 'lib/stripe/resources/charge.rb', line 2473

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



2475
2476
2477
# File 'lib/stripe/resources/charge.rb', line 2475

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



2477
2478
2479
# File 'lib/stripe/resources/charge.rb', line 2477

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



2479
2480
2481
# File 'lib/stripe/resources/charge.rb', line 2479

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



2481
2482
2483
# File 'lib/stripe/resources/charge.rb', line 2481

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



2483
2484
2485
# File 'lib/stripe/resources/charge.rb', line 2483

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



2485
2486
2487
# File 'lib/stripe/resources/charge.rb', line 2485

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



2487
2488
2489
# File 'lib/stripe/resources/charge.rb', line 2487

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



2489
2490
2491
# File 'lib/stripe/resources/charge.rb', line 2489

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



2491
2492
2493
# File 'lib/stripe/resources/charge.rb', line 2491

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



2493
2494
2495
# File 'lib/stripe/resources/charge.rb', line 2493

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



2495
2496
2497
# File 'lib/stripe/resources/charge.rb', line 2495

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



2497
2498
2499
# File 'lib/stripe/resources/charge.rb', line 2497

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



2499
2500
2501
# File 'lib/stripe/resources/charge.rb', line 2499

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



2501
2502
2503
# File 'lib/stripe/resources/charge.rb', line 2501

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



2503
2504
2505
# File 'lib/stripe/resources/charge.rb', line 2503

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



2505
2506
2507
# File 'lib/stripe/resources/charge.rb', line 2505

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



2507
2508
2509
# File 'lib/stripe/resources/charge.rb', line 2507

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



2509
2510
2511
# File 'lib/stripe/resources/charge.rb', line 2509

def vehicle_identification_number
  @vehicle_identification_number
end