Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 |
# File 'lib/stripe/resources/charge.rb', line 2430 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
2390 2391 2392 |
# File 'lib/stripe/resources/charge.rb', line 2390 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
2392 2393 2394 |
# File 'lib/stripe/resources/charge.rb', line 2392 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
2394 2395 2396 |
# File 'lib/stripe/resources/charge.rb', line 2394 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
2396 2397 2398 |
# File 'lib/stripe/resources/charge.rb', line 2396 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
2398 2399 2400 |
# File 'lib/stripe/resources/charge.rb', line 2398 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
2400 2401 2402 |
# File 'lib/stripe/resources/charge.rb', line 2400 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
2402 2403 2404 |
# File 'lib/stripe/resources/charge.rb', line 2402 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
2404 2405 2406 |
# File 'lib/stripe/resources/charge.rb', line 2404 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
2406 2407 2408 |
# File 'lib/stripe/resources/charge.rb', line 2406 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
2408 2409 2410 |
# File 'lib/stripe/resources/charge.rb', line 2408 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
2410 2411 2412 |
# File 'lib/stripe/resources/charge.rb', line 2410 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
2412 2413 2414 |
# File 'lib/stripe/resources/charge.rb', line 2412 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
2414 2415 2416 |
# File 'lib/stripe/resources/charge.rb', line 2414 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
2416 2417 2418 |
# File 'lib/stripe/resources/charge.rb', line 2416 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
2418 2419 2420 |
# File 'lib/stripe/resources/charge.rb', line 2418 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
2420 2421 2422 |
# File 'lib/stripe/resources/charge.rb', line 2420 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
2422 2423 2424 |
# File 'lib/stripe/resources/charge.rb', line 2422 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
2424 2425 2426 |
# File 'lib/stripe/resources/charge.rb', line 2424 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
2426 2427 2428 |
# File 'lib/stripe/resources/charge.rb', line 2426 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
2428 2429 2430 |
# File 'lib/stripe/resources/charge.rb', line 2428 def tax_exempt @tax_exempt end |