Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



2420
2421
2422
2423
2424
2425
2426
2427
2428
2429
2430
2431
2432
2433
2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
# File 'lib/stripe/resources/charge.rb', line 2420

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



2380
2381
2382
# File 'lib/stripe/resources/charge.rb', line 2380

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



2382
2383
2384
# File 'lib/stripe/resources/charge.rb', line 2382

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



2384
2385
2386
# File 'lib/stripe/resources/charge.rb', line 2384

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



2386
2387
2388
# File 'lib/stripe/resources/charge.rb', line 2386

def car_make
  @car_make
end

#car_modelObject

Model of the car.



2388
2389
2390
# File 'lib/stripe/resources/charge.rb', line 2388

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



2390
2391
2392
# File 'lib/stripe/resources/charge.rb', line 2390

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



2392
2393
2394
# File 'lib/stripe/resources/charge.rb', line 2392

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



2394
2395
2396
# File 'lib/stripe/resources/charge.rb', line 2394

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



2396
2397
2398
# File 'lib/stripe/resources/charge.rb', line 2396

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



2398
2399
2400
# File 'lib/stripe/resources/charge.rb', line 2398

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



2400
2401
2402
# File 'lib/stripe/resources/charge.rb', line 2400

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



2402
2403
2404
# File 'lib/stripe/resources/charge.rb', line 2402

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



2404
2405
2406
# File 'lib/stripe/resources/charge.rb', line 2404

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



2406
2407
2408
# File 'lib/stripe/resources/charge.rb', line 2406

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



2408
2409
2410
# File 'lib/stripe/resources/charge.rb', line 2408

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



2410
2411
2412
# File 'lib/stripe/resources/charge.rb', line 2410

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



2412
2413
2414
# File 'lib/stripe/resources/charge.rb', line 2412

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



2414
2415
2416
# File 'lib/stripe/resources/charge.rb', line 2414

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



2416
2417
2418
# File 'lib/stripe/resources/charge.rb', line 2416

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



2418
2419
2420
# File 'lib/stripe/resources/charge.rb', line 2418

def tax_exempt
  @tax_exempt
end