Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 |
# File 'lib/stripe/resources/charge.rb', line 2388 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
2348 2349 2350 |
# File 'lib/stripe/resources/charge.rb', line 2348 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
2350 2351 2352 |
# File 'lib/stripe/resources/charge.rb', line 2350 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
2352 2353 2354 |
# File 'lib/stripe/resources/charge.rb', line 2352 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
2354 2355 2356 |
# File 'lib/stripe/resources/charge.rb', line 2354 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
2356 2357 2358 |
# File 'lib/stripe/resources/charge.rb', line 2356 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
2358 2359 2360 |
# File 'lib/stripe/resources/charge.rb', line 2358 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
2360 2361 2362 |
# File 'lib/stripe/resources/charge.rb', line 2360 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
2362 2363 2364 |
# File 'lib/stripe/resources/charge.rb', line 2362 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
2364 2365 2366 |
# File 'lib/stripe/resources/charge.rb', line 2364 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
2366 2367 2368 |
# File 'lib/stripe/resources/charge.rb', line 2366 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
2368 2369 2370 |
# File 'lib/stripe/resources/charge.rb', line 2368 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
2370 2371 2372 |
# File 'lib/stripe/resources/charge.rb', line 2370 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
2372 2373 2374 |
# File 'lib/stripe/resources/charge.rb', line 2372 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
2374 2375 2376 |
# File 'lib/stripe/resources/charge.rb', line 2374 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
2376 2377 2378 |
# File 'lib/stripe/resources/charge.rb', line 2376 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
2378 2379 2380 |
# File 'lib/stripe/resources/charge.rb', line 2378 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
2380 2381 2382 |
# File 'lib/stripe/resources/charge.rb', line 2380 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
2382 2383 2384 |
# File 'lib/stripe/resources/charge.rb', line 2382 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
2384 2385 2386 |
# File 'lib/stripe/resources/charge.rb', line 2384 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
2386 2387 2388 |
# File 'lib/stripe/resources/charge.rb', line 2386 def tax_exempt @tax_exempt end |