Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/stripe/resources/charge.rb', line 2380

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



2340
2341
2342
# File 'lib/stripe/resources/charge.rb', line 2340

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



2342
2343
2344
# File 'lib/stripe/resources/charge.rb', line 2342

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



2344
2345
2346
# File 'lib/stripe/resources/charge.rb', line 2344

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



2346
2347
2348
# File 'lib/stripe/resources/charge.rb', line 2346

def car_make
  @car_make
end

#car_modelObject

Model of the car.



2348
2349
2350
# File 'lib/stripe/resources/charge.rb', line 2348

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



2350
2351
2352
# File 'lib/stripe/resources/charge.rb', line 2350

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



2352
2353
2354
# File 'lib/stripe/resources/charge.rb', line 2352

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



2354
2355
2356
# File 'lib/stripe/resources/charge.rb', line 2354

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



2356
2357
2358
# File 'lib/stripe/resources/charge.rb', line 2356

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



2358
2359
2360
# File 'lib/stripe/resources/charge.rb', line 2358

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



2360
2361
2362
# File 'lib/stripe/resources/charge.rb', line 2360

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



2362
2363
2364
# File 'lib/stripe/resources/charge.rb', line 2362

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



2364
2365
2366
# File 'lib/stripe/resources/charge.rb', line 2364

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



2366
2367
2368
# File 'lib/stripe/resources/charge.rb', line 2366

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



2368
2369
2370
# File 'lib/stripe/resources/charge.rb', line 2368

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



2370
2371
2372
# File 'lib/stripe/resources/charge.rb', line 2370

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



2372
2373
2374
# File 'lib/stripe/resources/charge.rb', line 2372

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



2374
2375
2376
# File 'lib/stripe/resources/charge.rb', line 2374

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



2376
2377
2378
# File 'lib/stripe/resources/charge.rb', line 2376

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



2378
2379
2380
# File 'lib/stripe/resources/charge.rb', line 2378

def tax_exempt
  @tax_exempt
end