Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
# File 'lib/stripe/resources/charge.rb', line 2914

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



2855
2856
2857
# File 'lib/stripe/resources/charge.rb', line 2855

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



2858
2859
2860
# File 'lib/stripe/resources/charge.rb', line 2858

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



2861
2862
2863
# File 'lib/stripe/resources/charge.rb', line 2861

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



2864
2865
2866
# File 'lib/stripe/resources/charge.rb', line 2864

def car_make
  @car_make
end

#car_modelObject

Model of the car.



2867
2868
2869
# File 'lib/stripe/resources/charge.rb', line 2867

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



2870
2871
2872
# File 'lib/stripe/resources/charge.rb', line 2870

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



2873
2874
2875
# File 'lib/stripe/resources/charge.rb', line 2873

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



2876
2877
2878
# File 'lib/stripe/resources/charge.rb', line 2876

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



2879
2880
2881
# File 'lib/stripe/resources/charge.rb', line 2879

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



2882
2883
2884
# File 'lib/stripe/resources/charge.rb', line 2882

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



2885
2886
2887
# File 'lib/stripe/resources/charge.rb', line 2885

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



2888
2889
2890
# File 'lib/stripe/resources/charge.rb', line 2888

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



2891
2892
2893
# File 'lib/stripe/resources/charge.rb', line 2891

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



2894
2895
2896
# File 'lib/stripe/resources/charge.rb', line 2894

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



2897
2898
2899
# File 'lib/stripe/resources/charge.rb', line 2897

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



2900
2901
2902
# File 'lib/stripe/resources/charge.rb', line 2900

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



2903
2904
2905
# File 'lib/stripe/resources/charge.rb', line 2903

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



2906
2907
2908
# File 'lib/stripe/resources/charge.rb', line 2906

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



2909
2910
2911
# File 'lib/stripe/resources/charge.rb', line 2909

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



2912
2913
2914
# File 'lib/stripe/resources/charge.rb', line 2912

def tax_exempt
  @tax_exempt
end