Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2344 2345 2346 2347 2348 |
# File 'lib/stripe/resources/charge.rb', line 2344 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2338 2339 2340 |
# File 'lib/stripe/resources/charge.rb', line 2338 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2340 2341 2342 |
# File 'lib/stripe/resources/charge.rb', line 2340 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2342 2343 2344 |
# File 'lib/stripe/resources/charge.rb', line 2342 def phone @phone end |