Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2292
2293
2294
2295
2296
# File 'lib/stripe/resources/charge.rb', line 2292

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2286
2287
2288
# File 'lib/stripe/resources/charge.rb', line 2286

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2288
2289
2290
# File 'lib/stripe/resources/charge.rb', line 2288

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2290
2291
2292
# File 'lib/stripe/resources/charge.rb', line 2290

def phone
  @phone
end