Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2302
2303
2304
2305
2306
# File 'lib/stripe/resources/charge.rb', line 2302

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2296
2297
2298
# File 'lib/stripe/resources/charge.rb', line 2296

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2298
2299
2300
# File 'lib/stripe/resources/charge.rb', line 2298

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2300
2301
2302
# File 'lib/stripe/resources/charge.rb', line 2300

def phone
  @phone
end