Class: Stripe::Charge::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2256
2257
2258
2259
2260
# File 'lib/stripe/resources/charge.rb', line 2256

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2250
2251
2252
# File 'lib/stripe/resources/charge.rb', line 2250

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2252
2253
2254
# File 'lib/stripe/resources/charge.rb', line 2252

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2254
2255
2256
# File 'lib/stripe/resources/charge.rb', line 2254

def phone
  @phone
end