Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 |
# File 'lib/stripe/resources/charge.rb', line 2651 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
2633 2634 2635 |
# File 'lib/stripe/resources/charge.rb', line 2633 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
2635 2636 2637 |
# File 'lib/stripe/resources/charge.rb', line 2635 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2637 2638 2639 |
# File 'lib/stripe/resources/charge.rb', line 2637 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
2639 2640 2641 |
# File 'lib/stripe/resources/charge.rb', line 2639 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
2641 2642 2643 |
# File 'lib/stripe/resources/charge.rb', line 2641 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
2643 2644 2645 |
# File 'lib/stripe/resources/charge.rb', line 2643 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
2645 2646 2647 |
# File 'lib/stripe/resources/charge.rb', line 2645 def genre @genre end |
#name ⇒ Object
The name of the event.
2647 2648 2649 |
# File 'lib/stripe/resources/charge.rb', line 2647 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
2649 2650 2651 |
# File 'lib/stripe/resources/charge.rb', line 2649 def starts_at @starts_at end |