Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 2567 2568 2569 2570 |
# File 'lib/stripe/resources/charge.rb', line 2550 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
2532 2533 2534 |
# File 'lib/stripe/resources/charge.rb', line 2532 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
2534 2535 2536 |
# File 'lib/stripe/resources/charge.rb', line 2534 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2536 2537 2538 |
# File 'lib/stripe/resources/charge.rb', line 2536 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
2538 2539 2540 |
# File 'lib/stripe/resources/charge.rb', line 2538 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
2540 2541 2542 |
# File 'lib/stripe/resources/charge.rb', line 2540 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
2542 2543 2544 |
# File 'lib/stripe/resources/charge.rb', line 2542 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
2544 2545 2546 |
# File 'lib/stripe/resources/charge.rb', line 2544 def genre @genre end |
#name ⇒ Object
The name of the event.
2546 2547 2548 |
# File 'lib/stripe/resources/charge.rb', line 2546 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
2548 2549 2550 |
# File 'lib/stripe/resources/charge.rb', line 2548 def starts_at @starts_at end |