Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 |
# File 'lib/stripe/resources/charge.rb', line 2518 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
2500 2501 2502 |
# File 'lib/stripe/resources/charge.rb', line 2500 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
2502 2503 2504 |
# File 'lib/stripe/resources/charge.rb', line 2502 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2504 2505 2506 |
# File 'lib/stripe/resources/charge.rb', line 2504 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
2506 2507 2508 |
# File 'lib/stripe/resources/charge.rb', line 2506 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
2508 2509 2510 |
# File 'lib/stripe/resources/charge.rb', line 2508 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
2510 2511 2512 |
# File 'lib/stripe/resources/charge.rb', line 2510 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
2512 2513 2514 |
# File 'lib/stripe/resources/charge.rb', line 2512 def genre @genre end |
#name ⇒ Object
The name of the event.
2514 2515 2516 |
# File 'lib/stripe/resources/charge.rb', line 2514 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
2516 2517 2518 |
# File 'lib/stripe/resources/charge.rb', line 2516 def starts_at @starts_at end |