Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Affiliate
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
2587 2588 2589 |
# File 'lib/stripe/resources/charge.rb', line 2587 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
2585 2586 2587 |
# File 'lib/stripe/resources/charge.rb', line 2585 def name @name end |