Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Affiliate
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
2465 2466 2467 |
# File 'lib/stripe/resources/charge.rb', line 2465 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
2463 2464 2465 |
# File 'lib/stripe/resources/charge.rb', line 2463 def name @name end |