Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3665 3666 3667 3668 3669 |
# File 'lib/stripe/resources/charge.rb', line 3665 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3659 3660 3661 |
# File 'lib/stripe/resources/charge.rb', line 3659 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3661 3662 3663 |
# File 'lib/stripe/resources/charge.rb', line 3661 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3663 3664 3665 |
# File 'lib/stripe/resources/charge.rb', line 3663 def phone @phone end |