Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2614 2615 2616 2617 2618 |
# File 'lib/stripe/resources/charge.rb', line 2614 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2608 2609 2610 |
# File 'lib/stripe/resources/charge.rb', line 2608 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2610 2611 2612 |
# File 'lib/stripe/resources/charge.rb', line 2610 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2612 2613 2614 |
# File 'lib/stripe/resources/charge.rb', line 2612 def phone @phone end |