Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2601 2602 2603 2604 2605 |
# File 'lib/stripe/resources/charge.rb', line 2601 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2595 2596 2597 |
# File 'lib/stripe/resources/charge.rb', line 2595 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2597 2598 2599 |
# File 'lib/stripe/resources/charge.rb', line 2597 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2599 2600 2601 |
# File 'lib/stripe/resources/charge.rb', line 2599 def phone @phone end |