Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2483
2484
2485
2486
2487
# File 'lib/stripe/resources/charge.rb', line 2483

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2477
2478
2479
# File 'lib/stripe/resources/charge.rb', line 2477

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2479
2480
2481
# File 'lib/stripe/resources/charge.rb', line 2479

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2481
2482
2483
# File 'lib/stripe/resources/charge.rb', line 2481

def phone
  @phone
end