Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2479 2480 2481 2482 2483 |
# File 'lib/stripe/resources/charge.rb', line 2479 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2473 2474 2475 |
# File 'lib/stripe/resources/charge.rb', line 2473 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2475 2476 2477 |
# File 'lib/stripe/resources/charge.rb', line 2475 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2477 2478 2479 |
# File 'lib/stripe/resources/charge.rb', line 2477 def phone @phone end |