Class: Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3016 3017 3018 3019 3020 |
# File 'lib/stripe/resources/charge.rb', line 3016 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3008 3009 3010 |
# File 'lib/stripe/resources/charge.rb', line 3008 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3011 3012 3013 |
# File 'lib/stripe/resources/charge.rb', line 3011 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3014 3015 3016 |
# File 'lib/stripe/resources/charge.rb', line 3014 def phone @phone end |