Class: Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2693 2694 2695 2696 2697 |
# File 'lib/stripe/resources/charge.rb', line 2693 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2687 2688 2689 |
# File 'lib/stripe/resources/charge.rb', line 2687 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2689 2690 2691 |
# File 'lib/stripe/resources/charge.rb', line 2689 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2691 2692 2693 |
# File 'lib/stripe/resources/charge.rb', line 2691 def phone @phone end |