Class: Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2678
2679
2680
2681
2682
# File 'lib/stripe/resources/charge.rb', line 2678

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2672
2673
2674
# File 'lib/stripe/resources/charge.rb', line 2672

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2674
2675
2676
# File 'lib/stripe/resources/charge.rb', line 2674

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2676
2677
2678
# File 'lib/stripe/resources/charge.rb', line 2676

def phone
  @phone
end