Class: Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2602
2603
2604
2605
2606
# File 'lib/stripe/resources/charge.rb', line 2602

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2596
2597
2598
# File 'lib/stripe/resources/charge.rb', line 2596

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2598
2599
2600
# File 'lib/stripe/resources/charge.rb', line 2598

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2600
2601
2602
# File 'lib/stripe/resources/charge.rb', line 2600

def phone
  @phone
end