Class: Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2592 2593 2594 2595 2596 |
# File 'lib/stripe/resources/charge.rb', line 2592 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2586 2587 2588 |
# File 'lib/stripe/resources/charge.rb', line 2586 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2588 2589 2590 |
# File 'lib/stripe/resources/charge.rb', line 2588 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2590 2591 2592 |
# File 'lib/stripe/resources/charge.rb', line 2590 def phone @phone end |