Class: Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2560 2561 2562 2563 2564 |
# File 'lib/stripe/resources/charge.rb', line 2560 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2554 2555 2556 |
# File 'lib/stripe/resources/charge.rb', line 2554 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2556 2557 2558 |
# File 'lib/stripe/resources/charge.rb', line 2556 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2558 2559 2560 |
# File 'lib/stripe/resources/charge.rb', line 2558 def phone @phone end |