Class: Stripe::Charge::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



3104
3105
3106
3107
3108
# File 'lib/stripe/resources/charge.rb', line 3104

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



3096
3097
3098
# File 'lib/stripe/resources/charge.rb', line 3096

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



3099
3100
3101
# File 'lib/stripe/resources/charge.rb', line 3099

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



3102
3103
3104
# File 'lib/stripe/resources/charge.rb', line 3102

def phone
  @phone
end