Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2913 2914 2915 2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 2931 2932 2933 2934 2935 2936 2937 2938 2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 2955 2956 2957 |
# File 'lib/stripe/resources/charge.rb', line 2913 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2871 2872 2873 |
# File 'lib/stripe/resources/charge.rb', line 2871 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2873 2874 2875 |
# File 'lib/stripe/resources/charge.rb', line 2873 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2875 2876 2877 |
# File 'lib/stripe/resources/charge.rb', line 2875 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2877 2878 2879 |
# File 'lib/stripe/resources/charge.rb', line 2877 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2879 2880 2881 |
# File 'lib/stripe/resources/charge.rb', line 2879 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
2881 2882 2883 |
# File 'lib/stripe/resources/charge.rb', line 2881 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2883 2884 2885 |
# File 'lib/stripe/resources/charge.rb', line 2883 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2885 2886 2887 |
# File 'lib/stripe/resources/charge.rb', line 2885 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2887 2888 2889 |
# File 'lib/stripe/resources/charge.rb', line 2887 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2889 2890 2891 |
# File 'lib/stripe/resources/charge.rb', line 2889 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2891 2892 2893 |
# File 'lib/stripe/resources/charge.rb', line 2891 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2893 2894 2895 |
# File 'lib/stripe/resources/charge.rb', line 2893 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2895 2896 2897 |
# File 'lib/stripe/resources/charge.rb', line 2895 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2897 2898 2899 |
# File 'lib/stripe/resources/charge.rb', line 2897 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2899 2900 2901 |
# File 'lib/stripe/resources/charge.rb', line 2899 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2901 2902 2903 |
# File 'lib/stripe/resources/charge.rb', line 2901 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2903 2904 2905 |
# File 'lib/stripe/resources/charge.rb', line 2903 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2905 2906 2907 |
# File 'lib/stripe/resources/charge.rb', line 2905 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2907 2908 2909 |
# File 'lib/stripe/resources/charge.rb', line 2907 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2909 2910 2911 |
# File 'lib/stripe/resources/charge.rb', line 2909 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2911 2912 2913 |
# File 'lib/stripe/resources/charge.rb', line 2911 def total_tax_amount @total_tax_amount end |