Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
2917
2918
2919
2920
2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
2942
# File 'lib/stripe/resources/charge.rb', line 2898

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



2856
2857
2858
# File 'lib/stripe/resources/charge.rb', line 2856

def address
  @address
end

#adultsObject

The number of adults on the booking



2858
2859
2860
# File 'lib/stripe/resources/charge.rb', line 2858

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



2860
2861
2862
# File 'lib/stripe/resources/charge.rb', line 2860

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



2862
2863
2864
# File 'lib/stripe/resources/charge.rb', line 2862

def booking_number
  @booking_number
end

#categoryObject

The lodging category



2864
2865
2866
# File 'lib/stripe/resources/charge.rb', line 2864

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



2866
2867
2868
# File 'lib/stripe/resources/charge.rb', line 2866

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



2868
2869
2870
# File 'lib/stripe/resources/charge.rb', line 2868

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



2870
2871
2872
# File 'lib/stripe/resources/charge.rb', line 2870

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



2872
2873
2874
# File 'lib/stripe/resources/charge.rb', line 2872

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



2874
2875
2876
# File 'lib/stripe/resources/charge.rb', line 2874

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



2876
2877
2878
# File 'lib/stripe/resources/charge.rb', line 2876

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



2878
2879
2880
# File 'lib/stripe/resources/charge.rb', line 2878

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



2880
2881
2882
# File 'lib/stripe/resources/charge.rb', line 2880

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



2882
2883
2884
# File 'lib/stripe/resources/charge.rb', line 2882

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



2884
2885
2886
# File 'lib/stripe/resources/charge.rb', line 2884

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



2886
2887
2888
# File 'lib/stripe/resources/charge.rb', line 2886

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



2888
2889
2890
# File 'lib/stripe/resources/charge.rb', line 2888

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



2890
2891
2892
# File 'lib/stripe/resources/charge.rb', line 2890

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



2892
2893
2894
# File 'lib/stripe/resources/charge.rb', line 2892

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



2894
2895
2896
# File 'lib/stripe/resources/charge.rb', line 2894

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



2896
2897
2898
# File 'lib/stripe/resources/charge.rb', line 2896

def total_tax_amount
  @total_tax_amount
end