Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
# File 'lib/stripe/resources/charge.rb', line 2812

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



2770
2771
2772
# File 'lib/stripe/resources/charge.rb', line 2770

def address
  @address
end

#adultsObject

The number of adults on the booking



2772
2773
2774
# File 'lib/stripe/resources/charge.rb', line 2772

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



2774
2775
2776
# File 'lib/stripe/resources/charge.rb', line 2774

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



2776
2777
2778
# File 'lib/stripe/resources/charge.rb', line 2776

def booking_number
  @booking_number
end

#categoryObject

The lodging category



2778
2779
2780
# File 'lib/stripe/resources/charge.rb', line 2778

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



2780
2781
2782
# File 'lib/stripe/resources/charge.rb', line 2780

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



2782
2783
2784
# File 'lib/stripe/resources/charge.rb', line 2782

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



2784
2785
2786
# File 'lib/stripe/resources/charge.rb', line 2784

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



2786
2787
2788
# File 'lib/stripe/resources/charge.rb', line 2786

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



2788
2789
2790
# File 'lib/stripe/resources/charge.rb', line 2788

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



2790
2791
2792
# File 'lib/stripe/resources/charge.rb', line 2790

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



2792
2793
2794
# File 'lib/stripe/resources/charge.rb', line 2792

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



2794
2795
2796
# File 'lib/stripe/resources/charge.rb', line 2794

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



2796
2797
2798
# File 'lib/stripe/resources/charge.rb', line 2796

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



2798
2799
2800
# File 'lib/stripe/resources/charge.rb', line 2798

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



2800
2801
2802
# File 'lib/stripe/resources/charge.rb', line 2800

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



2802
2803
2804
# File 'lib/stripe/resources/charge.rb', line 2802

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



2804
2805
2806
# File 'lib/stripe/resources/charge.rb', line 2804

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



2806
2807
2808
# File 'lib/stripe/resources/charge.rb', line 2806

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



2808
2809
2810
# File 'lib/stripe/resources/charge.rb', line 2808

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



2810
2811
2812
# File 'lib/stripe/resources/charge.rb', line 2810

def total_tax_amount
  @total_tax_amount
end