Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
# File 'lib/stripe/resources/charge.rb', line 2780

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



2738
2739
2740
# File 'lib/stripe/resources/charge.rb', line 2738

def address
  @address
end

#adultsObject

The number of adults on the booking



2740
2741
2742
# File 'lib/stripe/resources/charge.rb', line 2740

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



2742
2743
2744
# File 'lib/stripe/resources/charge.rb', line 2742

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



2744
2745
2746
# File 'lib/stripe/resources/charge.rb', line 2744

def booking_number
  @booking_number
end

#categoryObject

The lodging category



2746
2747
2748
# File 'lib/stripe/resources/charge.rb', line 2746

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



2748
2749
2750
# File 'lib/stripe/resources/charge.rb', line 2748

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



2750
2751
2752
# File 'lib/stripe/resources/charge.rb', line 2750

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



2752
2753
2754
# File 'lib/stripe/resources/charge.rb', line 2752

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



2754
2755
2756
# File 'lib/stripe/resources/charge.rb', line 2754

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



2756
2757
2758
# File 'lib/stripe/resources/charge.rb', line 2756

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



2758
2759
2760
# File 'lib/stripe/resources/charge.rb', line 2758

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



2760
2761
2762
# File 'lib/stripe/resources/charge.rb', line 2760

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



2762
2763
2764
# File 'lib/stripe/resources/charge.rb', line 2762

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



2764
2765
2766
# File 'lib/stripe/resources/charge.rb', line 2764

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



2766
2767
2768
# File 'lib/stripe/resources/charge.rb', line 2766

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



2768
2769
2770
# File 'lib/stripe/resources/charge.rb', line 2768

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



2770
2771
2772
# File 'lib/stripe/resources/charge.rb', line 2770

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



2772
2773
2774
# File 'lib/stripe/resources/charge.rb', line 2772

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



2774
2775
2776
# File 'lib/stripe/resources/charge.rb', line 2774

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



2776
2777
2778
# File 'lib/stripe/resources/charge.rb', line 2776

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



2778
2779
2780
# File 'lib/stripe/resources/charge.rb', line 2778

def total_tax_amount
  @total_tax_amount
end