Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 |
# File 'lib/stripe/resources/charge.rb', line 2776 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2734 2735 2736 |
# File 'lib/stripe/resources/charge.rb', line 2734 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2736 2737 2738 |
# File 'lib/stripe/resources/charge.rb', line 2736 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2738 2739 2740 |
# File 'lib/stripe/resources/charge.rb', line 2738 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2740 2741 2742 |
# File 'lib/stripe/resources/charge.rb', line 2740 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2742 2743 2744 |
# File 'lib/stripe/resources/charge.rb', line 2742 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
2744 2745 2746 |
# File 'lib/stripe/resources/charge.rb', line 2744 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2746 2747 2748 |
# File 'lib/stripe/resources/charge.rb', line 2746 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2748 2749 2750 |
# File 'lib/stripe/resources/charge.rb', line 2748 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2750 2751 2752 |
# File 'lib/stripe/resources/charge.rb', line 2750 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2752 2753 2754 |
# File 'lib/stripe/resources/charge.rb', line 2752 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2754 2755 2756 |
# File 'lib/stripe/resources/charge.rb', line 2754 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2756 2757 2758 |
# File 'lib/stripe/resources/charge.rb', line 2756 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2758 2759 2760 |
# File 'lib/stripe/resources/charge.rb', line 2758 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2760 2761 2762 |
# File 'lib/stripe/resources/charge.rb', line 2760 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2762 2763 2764 |
# File 'lib/stripe/resources/charge.rb', line 2762 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2764 2765 2766 |
# File 'lib/stripe/resources/charge.rb', line 2764 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2766 2767 2768 |
# File 'lib/stripe/resources/charge.rb', line 2766 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2768 2769 2770 |
# File 'lib/stripe/resources/charge.rb', line 2768 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2770 2771 2772 |
# File 'lib/stripe/resources/charge.rb', line 2770 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2772 2773 2774 |
# File 'lib/stripe/resources/charge.rb', line 2772 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2774 2775 2776 |
# File 'lib/stripe/resources/charge.rb', line 2774 def total_tax_amount @total_tax_amount end |