Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
3367 3368 3369 3370 3371 3372 3373 3374 3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/stripe/resources/charge.rb', line 3367 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
3305 3306 3307 |
# File 'lib/stripe/resources/charge.rb', line 3305 def address @address end |
#adults ⇒ Object
The number of adults on the booking
3308 3309 3310 |
# File 'lib/stripe/resources/charge.rb', line 3308 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
3311 3312 3313 |
# File 'lib/stripe/resources/charge.rb', line 3311 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
3314 3315 3316 |
# File 'lib/stripe/resources/charge.rb', line 3314 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
3317 3318 3319 |
# File 'lib/stripe/resources/charge.rb', line 3317 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
3320 3321 3322 |
# File 'lib/stripe/resources/charge.rb', line 3320 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
3323 3324 3325 |
# File 'lib/stripe/resources/charge.rb', line 3323 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
3326 3327 3328 |
# File 'lib/stripe/resources/charge.rb', line 3326 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
3329 3330 3331 |
# File 'lib/stripe/resources/charge.rb', line 3329 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
3332 3333 3334 |
# File 'lib/stripe/resources/charge.rb', line 3332 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
3335 3336 3337 |
# File 'lib/stripe/resources/charge.rb', line 3335 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
3338 3339 3340 |
# File 'lib/stripe/resources/charge.rb', line 3338 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
3341 3342 3343 |
# File 'lib/stripe/resources/charge.rb', line 3341 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
3344 3345 3346 |
# File 'lib/stripe/resources/charge.rb', line 3344 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
3347 3348 3349 |
# File 'lib/stripe/resources/charge.rb', line 3347 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
3350 3351 3352 |
# File 'lib/stripe/resources/charge.rb', line 3350 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
3353 3354 3355 |
# File 'lib/stripe/resources/charge.rb', line 3353 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
3356 3357 3358 |
# File 'lib/stripe/resources/charge.rb', line 3356 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
3359 3360 3361 |
# File 'lib/stripe/resources/charge.rb', line 3359 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
3362 3363 3364 |
# File 'lib/stripe/resources/charge.rb', line 3362 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
3365 3366 3367 |
# File 'lib/stripe/resources/charge.rb', line 3365 def total_tax_amount @total_tax_amount end |