Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Affiliate
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
2816 2817 2818 |
# File 'lib/stripe/resources/charge.rb', line 2816 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
2814 2815 2816 |
# File 'lib/stripe/resources/charge.rb', line 2814 def name @name end |