Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2876
2877
2878
2879
2880
# File 'lib/stripe/resources/charge.rb', line 2876

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2870
2871
2872
# File 'lib/stripe/resources/charge.rb', line 2870

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2872
2873
2874
# File 'lib/stripe/resources/charge.rb', line 2872

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2874
2875
2876
# File 'lib/stripe/resources/charge.rb', line 2874

def phone
  @phone
end