Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2830
2831
2832
2833
2834
# File 'lib/stripe/resources/charge.rb', line 2830

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2824
2825
2826
# File 'lib/stripe/resources/charge.rb', line 2824

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2826
2827
2828
# File 'lib/stripe/resources/charge.rb', line 2826

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2828
2829
2830
# File 'lib/stripe/resources/charge.rb', line 2828

def phone
  @phone
end