Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2744
2745
2746
2747
2748
# File 'lib/stripe/resources/charge.rb', line 2744

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2738
2739
2740
# File 'lib/stripe/resources/charge.rb', line 2738

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2740
2741
2742
# File 'lib/stripe/resources/charge.rb', line 2740

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2742
2743
2744
# File 'lib/stripe/resources/charge.rb', line 2742

def phone
  @phone
end