Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2712
2713
2714
2715
2716
# File 'lib/stripe/resources/charge.rb', line 2712

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2706
2707
2708
# File 'lib/stripe/resources/charge.rb', line 2706

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2708
2709
2710
# File 'lib/stripe/resources/charge.rb', line 2708

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2710
2711
2712
# File 'lib/stripe/resources/charge.rb', line 2710

def phone
  @phone
end