Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
3278 3279 3280 3281 3282 |
# File 'lib/stripe/resources/charge.rb', line 3278 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
3270 3271 3272 |
# File 'lib/stripe/resources/charge.rb', line 3270 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
3273 3274 3275 |
# File 'lib/stripe/resources/charge.rb', line 3273 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
3276 3277 3278 |
# File 'lib/stripe/resources/charge.rb', line 3276 def phone @phone end |