Class: Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2708 2709 2710 2711 2712 |
# File 'lib/stripe/resources/charge.rb', line 2708 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2702 2703 2704 |
# File 'lib/stripe/resources/charge.rb', line 2702 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2704 2705 2706 |
# File 'lib/stripe/resources/charge.rb', line 2704 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2706 2707 2708 |
# File 'lib/stripe/resources/charge.rb', line 2706 def phone @phone end |