Class: Stripe::Charge::CaptureParams::PaymentDetails::Subscription::BillingInterval
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::PaymentDetails::Subscription::BillingInterval
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
The number of intervals, as an whole number greater than 0.
-
#interval ⇒ Object
Specifies a type of interval unit.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil) ⇒ BillingInterval
constructor
A new instance of BillingInterval.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil) ⇒ BillingInterval
Returns a new instance of BillingInterval.
2875 2876 2877 2878 |
# File 'lib/stripe/resources/charge.rb', line 2875 def initialize(count: nil, interval: nil) @count = count @interval = interval end |
Instance Attribute Details
#count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
2871 2872 2873 |
# File 'lib/stripe/resources/charge.rb', line 2871 def count @count end |
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
2873 2874 2875 |
# File 'lib/stripe/resources/charge.rb', line 2873 def interval @interval end |