Class: Stripe::Charge::CaptureParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CaptureParams::TransferData
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount transferred to the destination account, if specified.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ TransferData
Returns a new instance of TransferData.
2939 2940 2941 |
# File 'lib/stripe/resources/charge.rb', line 2939 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.
2937 2938 2939 |
# File 'lib/stripe/resources/charge.rb', line 2937 def amount @amount end |