Class: Stripe::Charge::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Destination, RadarOptions, Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, capture: nil, currency: nil, customer: nil, description: nil, destination: nil, expand: nil, metadata: nil, on_behalf_of: nil, radar_options: nil, receipt_email: nil, shipping: nil, source: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'lib/stripe/resources/charge.rb', line 1383

def initialize(
  amount: nil,
  application_fee: nil,
  application_fee_amount: nil,
  capture: nil,
  currency: nil,
  customer: nil,
  description: nil,
  destination: nil,
  expand: nil,
  metadata: nil,
  on_behalf_of: nil,
  radar_options: nil,
  receipt_email: nil,
  shipping: nil,
  source: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @amount = amount
  @application_fee = application_fee
  @application_fee_amount = application_fee_amount
  @capture = capture
  @currency = currency
  @customer = customer
  @description = description
  @destination = destination
  @expand = expand
  @metadata = 
  @on_behalf_of = on_behalf_of
  @radar_options = radar_options
  @receipt_email = receipt_email
  @shipping = shipping
  @source = source
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#amountObject

Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



1343
1344
1345
# File 'lib/stripe/resources/charge.rb', line 1343

def amount
  @amount
end

#application_feeObject

Attribute for param field application_fee



1345
1346
1347
# File 'lib/stripe/resources/charge.rb', line 1345

def application_fee
  @application_fee
end

#application_fee_amountObject

A fee in cents (or local equivalent) that will be applied to the charge and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the ‘Stripe-Account` header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/connect/direct-charges#collect-fees).



1347
1348
1349
# File 'lib/stripe/resources/charge.rb', line 1347

def application_fee_amount
  @application_fee_amount
end

#captureObject

Whether to immediately capture the charge. Defaults to ‘true`. When `false`, the charge issues an authorization (or pre-authorization), and will need to be [captured](stripe.com/docs/api#capture_charge) later. Uncaptured charges expire after a set number of days (7 by default). For more information, see the [authorizing charges and settling later](stripe.com/docs/charges/placing-a-hold) documentation.



1349
1350
1351
# File 'lib/stripe/resources/charge.rb', line 1349

def capture
  @capture
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1351
1352
1353
# File 'lib/stripe/resources/charge.rb', line 1351

def currency
  @currency
end

#customerObject

The ID of an existing customer that will be charged in this request.



1353
1354
1355
# File 'lib/stripe/resources/charge.rb', line 1353

def customer
  @customer
end

#descriptionObject

An arbitrary string which you can attach to a ‘Charge` object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the `description` of the charge(s) that they are describing.



1355
1356
1357
# File 'lib/stripe/resources/charge.rb', line 1355

def description
  @description
end

#destinationObject

Attribute for param field destination



1357
1358
1359
# File 'lib/stripe/resources/charge.rb', line 1357

def destination
  @destination
end

#expandObject

Specifies which fields in the response should be expanded.



1359
1360
1361
# File 'lib/stripe/resources/charge.rb', line 1359

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1361
1362
1363
# File 'lib/stripe/resources/charge.rb', line 1361

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID for which these funds are intended. Automatically set if you use the ‘destination` parameter. For details, see [Creating Separate Charges and Transfers](stripe.com/docs/connect/separate-charges-and-transfers#settlement-merchant).



1363
1364
1365
# File 'lib/stripe/resources/charge.rb', line 1363

def on_behalf_of
  @on_behalf_of
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



1365
1366
1367
# File 'lib/stripe/resources/charge.rb', line 1365

def radar_options
  @radar_options
end

#receipt_emailObject

The email address to which this charge’s [receipt](stripe.com/docs/dashboard/receipts) will be sent. The receipt will not be sent until the charge is paid, and no receipts will be sent for test mode charges. If this charge is for a [Customer](stripe.com/docs/api/customers/object), the email address specified here will override the customer’s email address. If ‘receipt_email` is specified for a charge in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



1367
1368
1369
# File 'lib/stripe/resources/charge.rb', line 1367

def receipt_email
  @receipt_email
end

#shippingObject

Shipping information for the charge. Helps prevent fraud on charges for physical goods.



1369
1370
1371
# File 'lib/stripe/resources/charge.rb', line 1369

def shipping
  @shipping
end

#sourceObject

A payment source to be charged. This can be the ID of a [card](stripe.com/docs/api#cards) (i.e., credit or debit card), a [bank account](stripe.com/docs/api#bank_accounts), a [source](stripe.com/docs/api#sources), a [token](stripe.com/docs/api#tokens), or a [connected account](stripe.com/docs/connect/account-debits#charging-a-connected-account). For certain sources—namely, [cards](stripe.com/docs/api#cards), [bank accounts](stripe.com/docs/api#bank_accounts), and attached [sources](stripe.com/docs/api#sources)—you must also pass the ID of the associated customer.



1371
1372
1373
# File 'lib/stripe/resources/charge.rb', line 1371

def source
  @source
end

#statement_descriptorObject

For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.



1375
1376
1377
# File 'lib/stripe/resources/charge.rb', line 1375

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.



1377
1378
1379
# File 'lib/stripe/resources/charge.rb', line 1377

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.



1379
1380
1381
# File 'lib/stripe/resources/charge.rb', line 1379

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies this transaction as part of a group. For details, see [Grouping transactions](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options).



1381
1382
1383
# File 'lib/stripe/resources/charge.rb', line 1381

def transfer_group
  @transfer_group
end