Class: Stripe::Charge::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CreateParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Destination, RadarOptions, Shipping, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount intended to be collected by this payment.
-
#application_fee ⇒ Object
Attribute for param field application_fee.
-
#application_fee_amount ⇒ Object
A fee in cents (or local equivalent) that will be applied to the charge and transferred to the application owner’s Stripe account.
-
#capture ⇒ Object
Whether to immediately capture the charge.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The ID of an existing customer that will be charged in this request.
-
#description ⇒ Object
An arbitrary string which you can attach to a ‘Charge` object.
-
#destination ⇒ Object
Attribute for param field destination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The Stripe account ID for which these funds are intended.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#receipt_email ⇒ Object
The email address to which this charge’s [receipt](stripe.com/docs/dashboard/receipts) will be sent.
-
#shipping ⇒ Object
Shipping information for the charge.
-
#source ⇒ Object
A payment source to be charged.
-
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, capture: nil, currency: nil, customer: nil, description: nil, destination: nil, expand: nil, metadata: nil, on_behalf_of: nil, radar_options: nil, receipt_email: nil, shipping: nil, source: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, capture: nil, currency: nil, customer: nil, description: nil, destination: nil, expand: nil, metadata: nil, on_behalf_of: nil, radar_options: nil, receipt_email: nil, shipping: nil, source: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 |
# File 'lib/stripe/resources/charge.rb', line 1775 def initialize( amount: nil, application_fee: nil, application_fee_amount: nil, capture: nil, currency: nil, customer: nil, description: nil, destination: nil, expand: nil, metadata: nil, on_behalf_of: nil, radar_options: nil, receipt_email: nil, shipping: nil, source: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @amount = amount @application_fee = application_fee @application_fee_amount = application_fee_amount @capture = capture @currency = currency @customer = customer @description = description @destination = destination @expand = @metadata = @on_behalf_of = on_behalf_of @radar_options = @receipt_email = receipt_email @shipping = shipping @source = source @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
Amount intended to be collected by this payment. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
1717 1718 1719 |
# File 'lib/stripe/resources/charge.rb', line 1717 def amount @amount end |
#application_fee ⇒ Object
Attribute for param field application_fee
1720 1721 1722 |
# File 'lib/stripe/resources/charge.rb', line 1720 def application_fee @application_fee end |
#application_fee_amount ⇒ Object
A fee in cents (or local equivalent) that will be applied to the charge and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the ‘Stripe-Account` header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/connect/direct-charges#collect-fees).
1723 1724 1725 |
# File 'lib/stripe/resources/charge.rb', line 1723 def application_fee_amount @application_fee_amount end |
#capture ⇒ Object
Whether to immediately capture the charge. Defaults to ‘true`. When `false`, the charge issues an authorization (or pre-authorization), and will need to be [captured](stripe.com/docs/api#capture_charge) later. Uncaptured charges expire after a set number of days (7 by default). For more information, see the [authorizing charges and settling later](stripe.com/docs/charges/placing-a-hold) documentation.
1726 1727 1728 |
# File 'lib/stripe/resources/charge.rb', line 1726 def capture @capture end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1729 1730 1731 |
# File 'lib/stripe/resources/charge.rb', line 1729 def currency @currency end |
#customer ⇒ Object
The ID of an existing customer that will be charged in this request.
1732 1733 1734 |
# File 'lib/stripe/resources/charge.rb', line 1732 def customer @customer end |
#description ⇒ Object
An arbitrary string which you can attach to a ‘Charge` object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the `description` of the charge(s) that they are describing.
1735 1736 1737 |
# File 'lib/stripe/resources/charge.rb', line 1735 def description @description end |
#destination ⇒ Object
Attribute for param field destination
1738 1739 1740 |
# File 'lib/stripe/resources/charge.rb', line 1738 def destination @destination end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1741 1742 1743 |
# File 'lib/stripe/resources/charge.rb', line 1741 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1744 1745 1746 |
# File 'lib/stripe/resources/charge.rb', line 1744 def @metadata end |
#on_behalf_of ⇒ Object
The Stripe account ID for which these funds are intended. Automatically set if you use the ‘destination` parameter. For details, see [Creating Separate Charges and Transfers](stripe.com/docs/connect/separate-charges-and-transfers#settlement-merchant).
1747 1748 1749 |
# File 'lib/stripe/resources/charge.rb', line 1747 def on_behalf_of @on_behalf_of end |
#radar_options ⇒ Object
Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.
1750 1751 1752 |
# File 'lib/stripe/resources/charge.rb', line 1750 def @radar_options end |
#receipt_email ⇒ Object
The email address to which this charge’s [receipt](stripe.com/docs/dashboard/receipts) will be sent. The receipt will not be sent until the charge is paid, and no receipts will be sent for test mode charges. If this charge is for a [Customer](stripe.com/docs/api/customers/object), the email address specified here will override the customer’s email address. If ‘receipt_email` is specified for a charge in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
1753 1754 1755 |
# File 'lib/stripe/resources/charge.rb', line 1753 def receipt_email @receipt_email end |
#shipping ⇒ Object
Shipping information for the charge. Helps prevent fraud on charges for physical goods.
1756 1757 1758 |
# File 'lib/stripe/resources/charge.rb', line 1756 def shipping @shipping end |
#source ⇒ Object
A payment source to be charged. This can be the ID of a [card](stripe.com/docs/api#cards) (i.e., credit or debit card), a [bank account](stripe.com/docs/api#bank_accounts), a [source](stripe.com/docs/api#sources), a [token](stripe.com/docs/api#tokens), or a [connected account](stripe.com/docs/connect/account-debits#charging-a-connected-account). For certain sources—namely, [cards](stripe.com/docs/api#cards), [bank accounts](stripe.com/docs/api#bank_accounts), and attached [sources](stripe.com/docs/api#sources)—you must also pass the ID of the associated customer.
1759 1760 1761 |
# File 'lib/stripe/resources/charge.rb', line 1759 def source @source end |
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.
1764 1765 1766 |
# File 'lib/stripe/resources/charge.rb', line 1764 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.
1767 1768 1769 |
# File 'lib/stripe/resources/charge.rb', line 1767 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.
1770 1771 1772 |
# File 'lib/stripe/resources/charge.rb', line 1770 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. For details, see [Grouping transactions](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options).
1773 1774 1775 |
# File 'lib/stripe/resources/charge.rb', line 1773 def transfer_group @transfer_group end |