Class: Stripe::Charge::CreateParams::Destination
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::CreateParams::Destination
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
ID of an existing, connected Stripe account.
-
#amount ⇒ Object
The amount to transfer to the destination account without creating an ‘Application Fee` object.
Instance Method Summary collapse
-
#initialize(account: nil, amount: nil) ⇒ Destination
constructor
A new instance of Destination.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, amount: nil) ⇒ Destination
Returns a new instance of Destination.
2401 2402 2403 2404 |
# File 'lib/stripe/resources/charge.rb', line 2401 def initialize(account: nil, amount: nil) @account = account @amount = amount end |
Instance Attribute Details
#account ⇒ Object
ID of an existing, connected Stripe account.
2397 2398 2399 |
# File 'lib/stripe/resources/charge.rb', line 2397 def account @account end |
#amount ⇒ Object
The amount to transfer to the destination account without creating an ‘Application Fee` object. Cannot be combined with the `application_fee` parameter. Must be less than or equal to the charge amount.
2399 2400 2401 |
# File 'lib/stripe/resources/charge.rb', line 2399 def amount @amount end |