Class: Stripe::Charge::CreateParams::Destination

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, amount: nil) ⇒ Destination

Returns a new instance of Destination.



1337
1338
1339
1340
# File 'lib/stripe/resources/charge.rb', line 1337

def initialize(account: nil, amount: nil)
  @account = 
  @amount = amount
end

Instance Attribute Details

#accountObject

ID of an existing, connected Stripe account.



1333
1334
1335
# File 'lib/stripe/resources/charge.rb', line 1333

def 
  @account
end

#amountObject

The amount to transfer to the destination account without creating an ‘Application Fee` object. Cannot be combined with the `application_fee` parameter. Must be less than or equal to the charge amount.



1335
1336
1337
# File 'lib/stripe/resources/charge.rb', line 1335

def amount
  @amount
end