Class: Stripe::Charge::CreateParams::Destination

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, amount: nil) ⇒ Destination

Returns a new instance of Destination.



1278
1279
1280
1281
# File 'lib/stripe/resources/charge.rb', line 1278

def initialize(account: nil, amount: nil)
  @account = 
  @amount = amount
end

Instance Attribute Details

#accountObject

ID of an existing, connected Stripe account.



1274
1275
1276
# File 'lib/stripe/resources/charge.rb', line 1274

def 
  @account
end

#amountObject

The amount to transfer to the destination account without creating an ‘Application Fee` object. Cannot be combined with the `application_fee` parameter. Must be less than or equal to the charge amount.



1276
1277
1278
# File 'lib/stripe/resources/charge.rb', line 1276

def amount
  @amount
end