Class: Stripe::Charge::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams

Returns a new instance of ListParams.



2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
# File 'lib/stripe/resources/charge.rb', line 2373

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil,
  transfer_group: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
  @transfer_group = transfer_group
end

Instance Attribute Details

#createdObject

Only return charges that were created during the given date interval.



2357
2358
2359
# File 'lib/stripe/resources/charge.rb', line 2357

def created
  @created
end

#customerObject

Only return charges for the customer specified by this customer ID.



2359
2360
2361
# File 'lib/stripe/resources/charge.rb', line 2359

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



2361
2362
2363
# File 'lib/stripe/resources/charge.rb', line 2361

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



2363
2364
2365
# File 'lib/stripe/resources/charge.rb', line 2363

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



2365
2366
2367
# File 'lib/stripe/resources/charge.rb', line 2365

def limit
  @limit
end

#payment_intentObject

Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.



2367
2368
2369
# File 'lib/stripe/resources/charge.rb', line 2367

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



2369
2370
2371
# File 'lib/stripe/resources/charge.rb', line 2369

def starting_after
  @starting_after
end

#transfer_groupObject

Only return charges for this transfer group, limited to 100.



2371
2372
2373
# File 'lib/stripe/resources/charge.rb', line 2371

def transfer_group
  @transfer_group
end