Class: Stripe::Charge::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams

Returns a new instance of ListParams.



1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
1252
1253
1254
1255
# File 'lib/stripe/resources/charge.rb', line 1237

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil,
  transfer_group: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
  @transfer_group = transfer_group
end

Instance Attribute Details

#createdObject

Only return charges that were created during the given date interval.



1221
1222
1223
# File 'lib/stripe/resources/charge.rb', line 1221

def created
  @created
end

#customerObject

Only return charges for the customer specified by this customer ID.



1223
1224
1225
# File 'lib/stripe/resources/charge.rb', line 1223

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1225
1226
1227
# File 'lib/stripe/resources/charge.rb', line 1225

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1227
1228
1229
# File 'lib/stripe/resources/charge.rb', line 1227

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1229
1230
1231
# File 'lib/stripe/resources/charge.rb', line 1229

def limit
  @limit
end

#payment_intentObject

Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.



1231
1232
1233
# File 'lib/stripe/resources/charge.rb', line 1231

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1233
1234
1235
# File 'lib/stripe/resources/charge.rb', line 1233

def starting_after
  @starting_after
end

#transfer_groupObject

Only return charges for this transfer group, limited to 100.



1235
1236
1237
# File 'lib/stripe/resources/charge.rb', line 1235

def transfer_group
  @transfer_group
end