Class: Stripe::Charge::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams

Returns a new instance of ListParams.



1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
# File 'lib/stripe/resources/charge.rb', line 1324

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil,
  transfer_group: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
  @transfer_group = transfer_group
end

Instance Attribute Details

#createdObject

Only return charges that were created during the given date interval.



1308
1309
1310
# File 'lib/stripe/resources/charge.rb', line 1308

def created
  @created
end

#customerObject

Only return charges for the customer specified by this customer ID.



1310
1311
1312
# File 'lib/stripe/resources/charge.rb', line 1310

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1312
1313
1314
# File 'lib/stripe/resources/charge.rb', line 1312

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1314
1315
1316
# File 'lib/stripe/resources/charge.rb', line 1314

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1316
1317
1318
# File 'lib/stripe/resources/charge.rb', line 1316

def limit
  @limit
end

#payment_intentObject

Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.



1318
1319
1320
# File 'lib/stripe/resources/charge.rb', line 1318

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1320
1321
1322
# File 'lib/stripe/resources/charge.rb', line 1320

def starting_after
  @starting_after
end

#transfer_groupObject

Only return charges for this transfer group, limited to 100.



1322
1323
1324
# File 'lib/stripe/resources/charge.rb', line 1322

def transfer_group
  @transfer_group
end