Class: Stripe::Charge::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::ListParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return charges that were created during the given date interval.
-
#customer ⇒ Object
Only return charges for the customer specified by this customer ID.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#transfer_group ⇒ Object
Only return charges for this transfer group, limited to 100.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams
Returns a new instance of ListParams.
1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 |
# File 'lib/stripe/resources/charge.rb', line 1189 def initialize( created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil ) @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @starting_after = starting_after @transfer_group = transfer_group end |
Instance Attribute Details
#created ⇒ Object
Only return charges that were created during the given date interval.
1173 1174 1175 |
# File 'lib/stripe/resources/charge.rb', line 1173 def created @created end |
#customer ⇒ Object
Only return charges for the customer specified by this customer ID.
1175 1176 1177 |
# File 'lib/stripe/resources/charge.rb', line 1175 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1177 1178 1179 |
# File 'lib/stripe/resources/charge.rb', line 1177 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1179 1180 1181 |
# File 'lib/stripe/resources/charge.rb', line 1179 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1181 1182 1183 |
# File 'lib/stripe/resources/charge.rb', line 1181 def limit @limit end |
#payment_intent ⇒ Object
Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.
1183 1184 1185 |
# File 'lib/stripe/resources/charge.rb', line 1183 def payment_intent @payment_intent end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1185 1186 1187 |
# File 'lib/stripe/resources/charge.rb', line 1185 def starting_after @starting_after end |
#transfer_group ⇒ Object
Only return charges for this transfer group, limited to 100.
1187 1188 1189 |
# File 'lib/stripe/resources/charge.rb', line 1187 def transfer_group @transfer_group end |