Class: Stripe::Charge::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::ListParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return charges that were created during the given date interval.
-
#customer ⇒ Object
Only return charges for the customer specified by this customer ID.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#transfer_group ⇒ Object
Only return charges for this transfer group, limited to 100.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams
Returns a new instance of ListParams.
1299 1300 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 |
# File 'lib/stripe/resources/charge.rb', line 1299 def initialize( created: nil, customer: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil, transfer_group: nil ) @created = created @customer = customer @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @starting_after = starting_after @transfer_group = transfer_group end |
Instance Attribute Details
#created ⇒ Object
Only return charges that were created during the given date interval.
1283 1284 1285 |
# File 'lib/stripe/resources/charge.rb', line 1283 def created @created end |
#customer ⇒ Object
Only return charges for the customer specified by this customer ID.
1285 1286 1287 |
# File 'lib/stripe/resources/charge.rb', line 1285 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1287 1288 1289 |
# File 'lib/stripe/resources/charge.rb', line 1287 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1289 1290 1291 |
# File 'lib/stripe/resources/charge.rb', line 1289 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1291 1292 1293 |
# File 'lib/stripe/resources/charge.rb', line 1291 def limit @limit end |
#payment_intent ⇒ Object
Only return charges that were created by the PaymentIntent specified by this PaymentIntent ID.
1293 1294 1295 |
# File 'lib/stripe/resources/charge.rb', line 1293 def payment_intent @payment_intent end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1295 1296 1297 |
# File 'lib/stripe/resources/charge.rb', line 1295 def starting_after @starting_after end |
#transfer_group ⇒ Object
Only return charges for this transfer group, limited to 100.
1297 1298 1299 |
# File 'lib/stripe/resources/charge.rb', line 1297 def transfer_group @transfer_group end |