Class: Stripe::Charge::Outcome
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::Outcome
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Rule
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#network_advice_code ⇒ Object
readonly
For charges declined by the network, a 2 digit code which indicates the advice returned by the network on how to proceed with an error.
-
#network_decline_code ⇒ Object
readonly
For charges declined by the network, a brand specific 2, 3, or 4 digit code which indicates the reason the authorization failed.
-
#network_status ⇒ Object
readonly
Possible values are ‘approved_by_network`, `declined_by_network`, `not_sent_to_network`, and `reversed_after_approval`.
-
#reason ⇒ Object
readonly
An enumerated value providing a more detailed explanation of the outcome’s ‘type`.
-
#risk_level ⇒ Object
readonly
Stripe Radar’s evaluation of the riskiness of the payment.
-
#risk_score ⇒ Object
readonly
Stripe Radar’s evaluation of the riskiness of the payment.
-
#rule ⇒ Object
readonly
The ID of the Radar rule that matched the payment, if applicable.
-
#seller_message ⇒ Object
readonly
A human-readable description of the outcome type and reason, designed for you (the recipient of the payment), not your customer.
-
#type ⇒ Object
readonly
Possible values are ‘authorized`, `manual_review`, `issuer_declined`, `blocked`, and `invalid`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#network_advice_code ⇒ Object (readonly)
For charges declined by the network, a 2 digit code which indicates the advice returned by the network on how to proceed with an error.
115 116 117 |
# File 'lib/stripe/resources/charge.rb', line 115 def network_advice_code @network_advice_code end |
#network_decline_code ⇒ Object (readonly)
For charges declined by the network, a brand specific 2, 3, or 4 digit code which indicates the reason the authorization failed.
118 119 120 |
# File 'lib/stripe/resources/charge.rb', line 118 def network_decline_code @network_decline_code end |
#network_status ⇒ Object (readonly)
Possible values are ‘approved_by_network`, `declined_by_network`, `not_sent_to_network`, and `reversed_after_approval`. The value `reversed_after_approval` indicates the payment was [blocked by Stripe](stripe.com/docs/declines#blocked-payments) after bank authorization, and may temporarily appear as “pending” on a cardholder’s statement.
121 122 123 |
# File 'lib/stripe/resources/charge.rb', line 121 def network_status @network_status end |
#reason ⇒ Object (readonly)
An enumerated value providing a more detailed explanation of the outcome’s ‘type`. Charges blocked by Radar’s default block rule have the value ‘highest_risk_level`. Charges placed in review by Radar’s default review rule have the value ‘elevated_risk_level`. Charges authorized, blocked, or placed in review by custom rules have the value `rule`. See [understanding declines](stripe.com/docs/declines) for more details.
124 125 126 |
# File 'lib/stripe/resources/charge.rb', line 124 def reason @reason end |
#risk_level ⇒ Object (readonly)
Stripe Radar’s evaluation of the riskiness of the payment. Possible values for evaluated payments are ‘normal`, `elevated`, `highest`. For non-card payments, and card-based payments predating the public assignment of risk levels, this field will have the value `not_assessed`. In the event of an error in the evaluation, this field will have the value `unknown`. This field is only available with Radar.
127 128 129 |
# File 'lib/stripe/resources/charge.rb', line 127 def risk_level @risk_level end |
#risk_score ⇒ Object (readonly)
Stripe Radar’s evaluation of the riskiness of the payment. Possible values for evaluated payments are between 0 and 100. For non-card payments, card-based payments predating the public assignment of risk scores, or in the event of an error during evaluation, this field will not be present. This field is only available with Radar for Fraud Teams.
130 131 132 |
# File 'lib/stripe/resources/charge.rb', line 130 def risk_score @risk_score end |
#rule ⇒ Object (readonly)
The ID of the Radar rule that matched the payment, if applicable.
133 134 135 |
# File 'lib/stripe/resources/charge.rb', line 133 def rule @rule end |
#seller_message ⇒ Object (readonly)
A human-readable description of the outcome type and reason, designed for you (the recipient of the payment), not your customer.
136 137 138 |
# File 'lib/stripe/resources/charge.rb', line 136 def @seller_message end |
#type ⇒ Object (readonly)
Possible values are ‘authorized`, `manual_review`, `issuer_declined`, `blocked`, and `invalid`. See [understanding declines](stripe.com/docs/declines) and [Radar reviews](stripe.com/docs/radar/reviews) for details.
139 140 141 |
# File 'lib/stripe/resources/charge.rb', line 139 def type @type end |