Class: Stripe::Charge::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaCreditTransfer, SepaDebit, Sequra, Shopeepay, Sofort, StripeAccount, StripeBalance, Sunbit, Swish, Tamara, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



2333
2334
2335
# File 'lib/stripe/resources/charge.rb', line 2333

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



2335
2336
2337
# File 'lib/stripe/resources/charge.rb', line 2335

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



2337
2338
2339
# File 'lib/stripe/resources/charge.rb', line 2337

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



2339
2340
2341
# File 'lib/stripe/resources/charge.rb', line 2339

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2341
2342
2343
# File 'lib/stripe/resources/charge.rb', line 2341

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2343
2344
2345
# File 'lib/stripe/resources/charge.rb', line 2343

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2345
2346
2347
# File 'lib/stripe/resources/charge.rb', line 2345

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2347
2348
2349
# File 'lib/stripe/resources/charge.rb', line 2347

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2349
2350
2351
# File 'lib/stripe/resources/charge.rb', line 2349

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2351
2352
2353
# File 'lib/stripe/resources/charge.rb', line 2351

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2353
2354
2355
# File 'lib/stripe/resources/charge.rb', line 2353

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2355
2356
2357
# File 'lib/stripe/resources/charge.rb', line 2355

def billie
  @billie
end

#bizumObject (readonly)

Attribute for field bizum



2357
2358
2359
# File 'lib/stripe/resources/charge.rb', line 2357

def bizum
  @bizum
end

#blikObject (readonly)

Attribute for field blik



2359
2360
2361
# File 'lib/stripe/resources/charge.rb', line 2359

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2361
2362
2363
# File 'lib/stripe/resources/charge.rb', line 2361

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2363
2364
2365
# File 'lib/stripe/resources/charge.rb', line 2363

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



2365
2366
2367
# File 'lib/stripe/resources/charge.rb', line 2365

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



2367
2368
2369
# File 'lib/stripe/resources/charge.rb', line 2367

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



2369
2370
2371
# File 'lib/stripe/resources/charge.rb', line 2369

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2371
2372
2373
# File 'lib/stripe/resources/charge.rb', line 2371

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2373
2374
2375
# File 'lib/stripe/resources/charge.rb', line 2373

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2375
2376
2377
# File 'lib/stripe/resources/charge.rb', line 2375

def fpx
  @fpx
end

#gift_cardObject (readonly)

Attribute for field gift_card



2377
2378
2379
# File 'lib/stripe/resources/charge.rb', line 2377

def gift_card
  @gift_card
end

#giropayObject (readonly)

Attribute for field giropay



2379
2380
2381
# File 'lib/stripe/resources/charge.rb', line 2379

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



2381
2382
2383
# File 'lib/stripe/resources/charge.rb', line 2381

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2383
2384
2385
# File 'lib/stripe/resources/charge.rb', line 2383

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2385
2386
2387
# File 'lib/stripe/resources/charge.rb', line 2385

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2387
2388
2389
# File 'lib/stripe/resources/charge.rb', line 2387

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



2389
2390
2391
# File 'lib/stripe/resources/charge.rb', line 2389

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



2391
2392
2393
# File 'lib/stripe/resources/charge.rb', line 2391

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



2393
2394
2395
# File 'lib/stripe/resources/charge.rb', line 2393

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2395
2396
2397
# File 'lib/stripe/resources/charge.rb', line 2395

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



2397
2398
2399
# File 'lib/stripe/resources/charge.rb', line 2397

def kr_card
  @kr_card
end

Attribute for field link



2399
2400
2401
# File 'lib/stripe/resources/charge.rb', line 2399

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



2401
2402
2403
# File 'lib/stripe/resources/charge.rb', line 2401

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2403
2404
2405
# File 'lib/stripe/resources/charge.rb', line 2403

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2405
2406
2407
# File 'lib/stripe/resources/charge.rb', line 2405

def multibanco
  @multibanco
end

Attribute for field naver_pay



2407
2408
2409
# File 'lib/stripe/resources/charge.rb', line 2407

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2409
2410
2411
# File 'lib/stripe/resources/charge.rb', line 2409

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



2411
2412
2413
# File 'lib/stripe/resources/charge.rb', line 2411

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2413
2414
2415
# File 'lib/stripe/resources/charge.rb', line 2413

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2415
2416
2417
# File 'lib/stripe/resources/charge.rb', line 2415

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2417
2418
2419
# File 'lib/stripe/resources/charge.rb', line 2417

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



2419
2420
2421
# File 'lib/stripe/resources/charge.rb', line 2419

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2421
2422
2423
# File 'lib/stripe/resources/charge.rb', line 2421

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



2423
2424
2425
# File 'lib/stripe/resources/charge.rb', line 2423

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



2425
2426
2427
# File 'lib/stripe/resources/charge.rb', line 2425

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2427
2428
2429
# File 'lib/stripe/resources/charge.rb', line 2427

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2429
2430
2431
# File 'lib/stripe/resources/charge.rb', line 2429

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2431
2432
2433
# File 'lib/stripe/resources/charge.rb', line 2431

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



2433
2434
2435
# File 'lib/stripe/resources/charge.rb', line 2433

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2435
2436
2437
# File 'lib/stripe/resources/charge.rb', line 2435

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2437
2438
2439
# File 'lib/stripe/resources/charge.rb', line 2437

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2439
2440
2441
# File 'lib/stripe/resources/charge.rb', line 2439

def satispay
  @satispay
end

#scalapayObject (readonly)

Attribute for field scalapay



2441
2442
2443
# File 'lib/stripe/resources/charge.rb', line 2441

def scalapay
  @scalapay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



2443
2444
2445
# File 'lib/stripe/resources/charge.rb', line 2443

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2445
2446
2447
# File 'lib/stripe/resources/charge.rb', line 2445

def sepa_debit
  @sepa_debit
end

#sequraObject (readonly)

Attribute for field sequra



2447
2448
2449
# File 'lib/stripe/resources/charge.rb', line 2447

def sequra
  @sequra
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2449
2450
2451
# File 'lib/stripe/resources/charge.rb', line 2449

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2451
2452
2453
# File 'lib/stripe/resources/charge.rb', line 2451

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



2453
2454
2455
# File 'lib/stripe/resources/charge.rb', line 2453

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



2455
2456
2457
# File 'lib/stripe/resources/charge.rb', line 2455

def stripe_balance
  @stripe_balance
end

#sunbitObject (readonly)

Attribute for field sunbit



2457
2458
2459
# File 'lib/stripe/resources/charge.rb', line 2457

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



2459
2460
2461
# File 'lib/stripe/resources/charge.rb', line 2459

def swish
  @swish
end

#tamaraObject (readonly)

Attribute for field tamara



2461
2462
2463
# File 'lib/stripe/resources/charge.rb', line 2461

def tamara
  @tamara
end

#twintObject (readonly)

Attribute for field twint



2463
2464
2465
# File 'lib/stripe/resources/charge.rb', line 2463

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See PaymentMethod.type for the full list of possible types. An additional hash is included on payment_method_details with a name matching this value. It contains information specific to the payment method.



2467
2468
2469
# File 'lib/stripe/resources/charge.rb', line 2467

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



2469
2470
2471
# File 'lib/stripe/resources/charge.rb', line 2469

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2471
2472
2473
# File 'lib/stripe/resources/charge.rb', line 2471

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



2473
2474
2475
# File 'lib/stripe/resources/charge.rb', line 2473

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2475
2476
2477
# File 'lib/stripe/resources/charge.rb', line 2475

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2477
2478
2479
# File 'lib/stripe/resources/charge.rb', line 2477

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2555
2556
2557
# File 'lib/stripe/resources/charge.rb', line 2555

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
2498
2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
# File 'lib/stripe/resources/charge.rb', line 2479

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    gift_card: GiftCard,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    sequra: Sequra,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    sunbit: Sunbit,
    swish: Swish,
    tamara: Tamara,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end