Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#bizum ⇒ Object
readonly
Attribute for field bizum.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#gift_card ⇒ Object
readonly
Attribute for field gift_card.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#scalapay ⇒ Object
readonly
Attribute for field scalapay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#sunbit ⇒ Object
readonly
Attribute for field sunbit.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
2255 2256 2257 |
# File 'lib/stripe/resources/charge.rb', line 2255 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
2257 2258 2259 |
# File 'lib/stripe/resources/charge.rb', line 2257 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
2259 2260 2261 |
# File 'lib/stripe/resources/charge.rb', line 2259 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
2261 2262 2263 |
# File 'lib/stripe/resources/charge.rb', line 2261 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
2263 2264 2265 |
# File 'lib/stripe/resources/charge.rb', line 2263 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
2265 2266 2267 |
# File 'lib/stripe/resources/charge.rb', line 2265 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
2267 2268 2269 |
# File 'lib/stripe/resources/charge.rb', line 2267 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
2269 2270 2271 |
# File 'lib/stripe/resources/charge.rb', line 2269 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
2271 2272 2273 |
# File 'lib/stripe/resources/charge.rb', line 2271 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
2273 2274 2275 |
# File 'lib/stripe/resources/charge.rb', line 2273 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
2275 2276 2277 |
# File 'lib/stripe/resources/charge.rb', line 2275 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
2277 2278 2279 |
# File 'lib/stripe/resources/charge.rb', line 2277 def billie @billie end |
#bizum ⇒ Object (readonly)
Attribute for field bizum
2279 2280 2281 |
# File 'lib/stripe/resources/charge.rb', line 2279 def bizum @bizum end |
#blik ⇒ Object (readonly)
Attribute for field blik
2281 2282 2283 |
# File 'lib/stripe/resources/charge.rb', line 2281 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
2283 2284 2285 |
# File 'lib/stripe/resources/charge.rb', line 2283 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
2285 2286 2287 |
# File 'lib/stripe/resources/charge.rb', line 2285 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
2287 2288 2289 |
# File 'lib/stripe/resources/charge.rb', line 2287 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
2289 2290 2291 |
# File 'lib/stripe/resources/charge.rb', line 2289 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
2291 2292 2293 |
# File 'lib/stripe/resources/charge.rb', line 2291 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
2293 2294 2295 |
# File 'lib/stripe/resources/charge.rb', line 2293 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
2295 2296 2297 |
# File 'lib/stripe/resources/charge.rb', line 2295 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
2297 2298 2299 |
# File 'lib/stripe/resources/charge.rb', line 2297 def fpx @fpx end |
#gift_card ⇒ Object (readonly)
Attribute for field gift_card
2299 2300 2301 |
# File 'lib/stripe/resources/charge.rb', line 2299 def gift_card @gift_card end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
2301 2302 2303 |
# File 'lib/stripe/resources/charge.rb', line 2301 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
2303 2304 2305 |
# File 'lib/stripe/resources/charge.rb', line 2303 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
2305 2306 2307 |
# File 'lib/stripe/resources/charge.rb', line 2305 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
2307 2308 2309 |
# File 'lib/stripe/resources/charge.rb', line 2307 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
2309 2310 2311 |
# File 'lib/stripe/resources/charge.rb', line 2309 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
2311 2312 2313 |
# File 'lib/stripe/resources/charge.rb', line 2311 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
2313 2314 2315 |
# File 'lib/stripe/resources/charge.rb', line 2313 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
2315 2316 2317 |
# File 'lib/stripe/resources/charge.rb', line 2315 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
2317 2318 2319 |
# File 'lib/stripe/resources/charge.rb', line 2317 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
2319 2320 2321 |
# File 'lib/stripe/resources/charge.rb', line 2319 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
2321 2322 2323 |
# File 'lib/stripe/resources/charge.rb', line 2321 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
2323 2324 2325 |
# File 'lib/stripe/resources/charge.rb', line 2323 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
2325 2326 2327 |
# File 'lib/stripe/resources/charge.rb', line 2325 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
2327 2328 2329 |
# File 'lib/stripe/resources/charge.rb', line 2327 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
2329 2330 2331 |
# File 'lib/stripe/resources/charge.rb', line 2329 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
2331 2332 2333 |
# File 'lib/stripe/resources/charge.rb', line 2331 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
2333 2334 2335 |
# File 'lib/stripe/resources/charge.rb', line 2333 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
2335 2336 2337 |
# File 'lib/stripe/resources/charge.rb', line 2335 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
2337 2338 2339 |
# File 'lib/stripe/resources/charge.rb', line 2337 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
2339 2340 2341 |
# File 'lib/stripe/resources/charge.rb', line 2339 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
2341 2342 2343 |
# File 'lib/stripe/resources/charge.rb', line 2341 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
2343 2344 2345 |
# File 'lib/stripe/resources/charge.rb', line 2343 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
2345 2346 2347 |
# File 'lib/stripe/resources/charge.rb', line 2345 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
2347 2348 2349 |
# File 'lib/stripe/resources/charge.rb', line 2347 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
2349 2350 2351 |
# File 'lib/stripe/resources/charge.rb', line 2349 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
2351 2352 2353 |
# File 'lib/stripe/resources/charge.rb', line 2351 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
2353 2354 2355 |
# File 'lib/stripe/resources/charge.rb', line 2353 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
2355 2356 2357 |
# File 'lib/stripe/resources/charge.rb', line 2355 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
2357 2358 2359 |
# File 'lib/stripe/resources/charge.rb', line 2357 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
2359 2360 2361 |
# File 'lib/stripe/resources/charge.rb', line 2359 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
2361 2362 2363 |
# File 'lib/stripe/resources/charge.rb', line 2361 def satispay @satispay end |
#scalapay ⇒ Object (readonly)
Attribute for field scalapay
2363 2364 2365 |
# File 'lib/stripe/resources/charge.rb', line 2363 def scalapay @scalapay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
2365 2366 2367 |
# File 'lib/stripe/resources/charge.rb', line 2365 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
2367 2368 2369 |
# File 'lib/stripe/resources/charge.rb', line 2367 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
2369 2370 2371 |
# File 'lib/stripe/resources/charge.rb', line 2369 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
2371 2372 2373 |
# File 'lib/stripe/resources/charge.rb', line 2371 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
2373 2374 2375 |
# File 'lib/stripe/resources/charge.rb', line 2373 def stripe_account @stripe_account end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
2375 2376 2377 |
# File 'lib/stripe/resources/charge.rb', line 2375 def stripe_balance @stripe_balance end |
#sunbit ⇒ Object (readonly)
Attribute for field sunbit
2377 2378 2379 |
# File 'lib/stripe/resources/charge.rb', line 2377 def sunbit @sunbit end |
#swish ⇒ Object (readonly)
Attribute for field swish
2379 2380 2381 |
# File 'lib/stripe/resources/charge.rb', line 2379 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
2381 2382 2383 |
# File 'lib/stripe/resources/charge.rb', line 2381 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
2385 2386 2387 |
# File 'lib/stripe/resources/charge.rb', line 2385 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
2387 2388 2389 |
# File 'lib/stripe/resources/charge.rb', line 2387 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
2389 2390 2391 |
# File 'lib/stripe/resources/charge.rb', line 2389 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
2391 2392 2393 |
# File 'lib/stripe/resources/charge.rb', line 2391 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
2393 2394 2395 |
# File 'lib/stripe/resources/charge.rb', line 2393 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
2395 2396 2397 |
# File 'lib/stripe/resources/charge.rb', line 2395 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
2471 2472 2473 |
# File 'lib/stripe/resources/charge.rb', line 2471 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 2466 2467 2468 2469 |
# File 'lib/stripe/resources/charge.rb', line 2397 def self.inner_class_types @inner_class_types = { ach_credit_transfer: AchCreditTransfer, ach_debit: AchDebit, acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, bizum: Bizum, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, gift_card: GiftCard, giropay: Giropay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, rechnung: Rechnung, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, scalapay: Scalapay, sepa_credit_transfer: SepaCreditTransfer, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, stripe_account: StripeAccount, stripe_balance: StripeBalance, sunbit: Sunbit, swish: Swish, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, wechat: Wechat, wechat_pay: WechatPay, zip: Zip, } end |