Class: Stripe::Charge::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



2207
2208
2209
# File 'lib/stripe/resources/charge.rb', line 2207

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



2209
2210
2211
# File 'lib/stripe/resources/charge.rb', line 2209

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



2211
2212
2213
# File 'lib/stripe/resources/charge.rb', line 2211

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



2213
2214
2215
# File 'lib/stripe/resources/charge.rb', line 2213

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2215
2216
2217
# File 'lib/stripe/resources/charge.rb', line 2215

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2217
2218
2219
# File 'lib/stripe/resources/charge.rb', line 2217

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2219
2220
2221
# File 'lib/stripe/resources/charge.rb', line 2219

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2221
2222
2223
# File 'lib/stripe/resources/charge.rb', line 2221

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2223
2224
2225
# File 'lib/stripe/resources/charge.rb', line 2223

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2225
2226
2227
# File 'lib/stripe/resources/charge.rb', line 2225

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2227
2228
2229
# File 'lib/stripe/resources/charge.rb', line 2227

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2229
2230
2231
# File 'lib/stripe/resources/charge.rb', line 2229

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



2231
2232
2233
# File 'lib/stripe/resources/charge.rb', line 2231

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2233
2234
2235
# File 'lib/stripe/resources/charge.rb', line 2233

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2235
2236
2237
# File 'lib/stripe/resources/charge.rb', line 2235

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



2237
2238
2239
# File 'lib/stripe/resources/charge.rb', line 2237

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



2239
2240
2241
# File 'lib/stripe/resources/charge.rb', line 2239

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



2241
2242
2243
# File 'lib/stripe/resources/charge.rb', line 2241

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2243
2244
2245
# File 'lib/stripe/resources/charge.rb', line 2243

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2245
2246
2247
# File 'lib/stripe/resources/charge.rb', line 2245

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2247
2248
2249
# File 'lib/stripe/resources/charge.rb', line 2247

def fpx
  @fpx
end

#gift_cardObject (readonly)

Attribute for field gift_card



2249
2250
2251
# File 'lib/stripe/resources/charge.rb', line 2249

def gift_card
  @gift_card
end

#giropayObject (readonly)

Attribute for field giropay



2251
2252
2253
# File 'lib/stripe/resources/charge.rb', line 2251

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



2253
2254
2255
# File 'lib/stripe/resources/charge.rb', line 2253

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2255
2256
2257
# File 'lib/stripe/resources/charge.rb', line 2255

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2257
2258
2259
# File 'lib/stripe/resources/charge.rb', line 2257

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2259
2260
2261
# File 'lib/stripe/resources/charge.rb', line 2259

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



2261
2262
2263
# File 'lib/stripe/resources/charge.rb', line 2261

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



2263
2264
2265
# File 'lib/stripe/resources/charge.rb', line 2263

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



2265
2266
2267
# File 'lib/stripe/resources/charge.rb', line 2265

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2267
2268
2269
# File 'lib/stripe/resources/charge.rb', line 2267

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



2269
2270
2271
# File 'lib/stripe/resources/charge.rb', line 2269

def kr_card
  @kr_card
end

Attribute for field link



2271
2272
2273
# File 'lib/stripe/resources/charge.rb', line 2271

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



2273
2274
2275
# File 'lib/stripe/resources/charge.rb', line 2273

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2275
2276
2277
# File 'lib/stripe/resources/charge.rb', line 2275

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2277
2278
2279
# File 'lib/stripe/resources/charge.rb', line 2277

def multibanco
  @multibanco
end

Attribute for field naver_pay



2279
2280
2281
# File 'lib/stripe/resources/charge.rb', line 2279

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2281
2282
2283
# File 'lib/stripe/resources/charge.rb', line 2281

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



2283
2284
2285
# File 'lib/stripe/resources/charge.rb', line 2283

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2285
2286
2287
# File 'lib/stripe/resources/charge.rb', line 2285

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2287
2288
2289
# File 'lib/stripe/resources/charge.rb', line 2287

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2289
2290
2291
# File 'lib/stripe/resources/charge.rb', line 2289

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



2291
2292
2293
# File 'lib/stripe/resources/charge.rb', line 2291

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2293
2294
2295
# File 'lib/stripe/resources/charge.rb', line 2293

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



2295
2296
2297
# File 'lib/stripe/resources/charge.rb', line 2295

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



2297
2298
2299
# File 'lib/stripe/resources/charge.rb', line 2297

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2299
2300
2301
# File 'lib/stripe/resources/charge.rb', line 2299

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2301
2302
2303
# File 'lib/stripe/resources/charge.rb', line 2301

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2303
2304
2305
# File 'lib/stripe/resources/charge.rb', line 2303

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



2305
2306
2307
# File 'lib/stripe/resources/charge.rb', line 2305

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2307
2308
2309
# File 'lib/stripe/resources/charge.rb', line 2307

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2309
2310
2311
# File 'lib/stripe/resources/charge.rb', line 2309

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2311
2312
2313
# File 'lib/stripe/resources/charge.rb', line 2311

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



2313
2314
2315
# File 'lib/stripe/resources/charge.rb', line 2313

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2315
2316
2317
# File 'lib/stripe/resources/charge.rb', line 2315

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2317
2318
2319
# File 'lib/stripe/resources/charge.rb', line 2317

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2319
2320
2321
# File 'lib/stripe/resources/charge.rb', line 2319

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



2321
2322
2323
# File 'lib/stripe/resources/charge.rb', line 2321

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



2323
2324
2325
# File 'lib/stripe/resources/charge.rb', line 2323

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



2325
2326
2327
# File 'lib/stripe/resources/charge.rb', line 2325

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2327
2328
2329
# File 'lib/stripe/resources/charge.rb', line 2327

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



2331
2332
2333
# File 'lib/stripe/resources/charge.rb', line 2331

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



2333
2334
2335
# File 'lib/stripe/resources/charge.rb', line 2333

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2335
2336
2337
# File 'lib/stripe/resources/charge.rb', line 2335

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



2337
2338
2339
# File 'lib/stripe/resources/charge.rb', line 2337

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2339
2340
2341
# File 'lib/stripe/resources/charge.rb', line 2339

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2341
2342
2343
# File 'lib/stripe/resources/charge.rb', line 2341

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2414
2415
2416
# File 'lib/stripe/resources/charge.rb', line 2414

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
# File 'lib/stripe/resources/charge.rb', line 2343

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    gift_card: GiftCard,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end