Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#gift_card ⇒ Object
readonly
Attribute for field gift_card.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#sunbit ⇒ Object
readonly
Attribute for field sunbit.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
2226 2227 2228 |
# File 'lib/stripe/resources/charge.rb', line 2226 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
2228 2229 2230 |
# File 'lib/stripe/resources/charge.rb', line 2228 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
2230 2231 2232 |
# File 'lib/stripe/resources/charge.rb', line 2230 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
2232 2233 2234 |
# File 'lib/stripe/resources/charge.rb', line 2232 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
2234 2235 2236 |
# File 'lib/stripe/resources/charge.rb', line 2234 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
2236 2237 2238 |
# File 'lib/stripe/resources/charge.rb', line 2236 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
2238 2239 2240 |
# File 'lib/stripe/resources/charge.rb', line 2238 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
2240 2241 2242 |
# File 'lib/stripe/resources/charge.rb', line 2240 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
2242 2243 2244 |
# File 'lib/stripe/resources/charge.rb', line 2242 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
2244 2245 2246 |
# File 'lib/stripe/resources/charge.rb', line 2244 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
2246 2247 2248 |
# File 'lib/stripe/resources/charge.rb', line 2246 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
2248 2249 2250 |
# File 'lib/stripe/resources/charge.rb', line 2248 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
2250 2251 2252 |
# File 'lib/stripe/resources/charge.rb', line 2250 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
2252 2253 2254 |
# File 'lib/stripe/resources/charge.rb', line 2252 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
2254 2255 2256 |
# File 'lib/stripe/resources/charge.rb', line 2254 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
2256 2257 2258 |
# File 'lib/stripe/resources/charge.rb', line 2256 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
2258 2259 2260 |
# File 'lib/stripe/resources/charge.rb', line 2258 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
2260 2261 2262 |
# File 'lib/stripe/resources/charge.rb', line 2260 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
2262 2263 2264 |
# File 'lib/stripe/resources/charge.rb', line 2262 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
2264 2265 2266 |
# File 'lib/stripe/resources/charge.rb', line 2264 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
2266 2267 2268 |
# File 'lib/stripe/resources/charge.rb', line 2266 def fpx @fpx end |
#gift_card ⇒ Object (readonly)
Attribute for field gift_card
2268 2269 2270 |
# File 'lib/stripe/resources/charge.rb', line 2268 def gift_card @gift_card end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
2270 2271 2272 |
# File 'lib/stripe/resources/charge.rb', line 2270 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
2272 2273 2274 |
# File 'lib/stripe/resources/charge.rb', line 2272 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
2274 2275 2276 |
# File 'lib/stripe/resources/charge.rb', line 2274 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
2276 2277 2278 |
# File 'lib/stripe/resources/charge.rb', line 2276 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
2278 2279 2280 |
# File 'lib/stripe/resources/charge.rb', line 2278 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
2280 2281 2282 |
# File 'lib/stripe/resources/charge.rb', line 2280 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
2282 2283 2284 |
# File 'lib/stripe/resources/charge.rb', line 2282 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
2284 2285 2286 |
# File 'lib/stripe/resources/charge.rb', line 2284 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
2286 2287 2288 |
# File 'lib/stripe/resources/charge.rb', line 2286 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
2288 2289 2290 |
# File 'lib/stripe/resources/charge.rb', line 2288 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
2290 2291 2292 |
# File 'lib/stripe/resources/charge.rb', line 2290 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
2292 2293 2294 |
# File 'lib/stripe/resources/charge.rb', line 2292 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
2294 2295 2296 |
# File 'lib/stripe/resources/charge.rb', line 2294 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
2296 2297 2298 |
# File 'lib/stripe/resources/charge.rb', line 2296 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
2298 2299 2300 |
# File 'lib/stripe/resources/charge.rb', line 2298 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
2300 2301 2302 |
# File 'lib/stripe/resources/charge.rb', line 2300 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
2302 2303 2304 |
# File 'lib/stripe/resources/charge.rb', line 2302 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
2304 2305 2306 |
# File 'lib/stripe/resources/charge.rb', line 2304 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
2306 2307 2308 |
# File 'lib/stripe/resources/charge.rb', line 2306 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
2308 2309 2310 |
# File 'lib/stripe/resources/charge.rb', line 2308 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
2310 2311 2312 |
# File 'lib/stripe/resources/charge.rb', line 2310 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
2312 2313 2314 |
# File 'lib/stripe/resources/charge.rb', line 2312 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
2314 2315 2316 |
# File 'lib/stripe/resources/charge.rb', line 2314 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
2316 2317 2318 |
# File 'lib/stripe/resources/charge.rb', line 2316 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
2318 2319 2320 |
# File 'lib/stripe/resources/charge.rb', line 2318 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
2320 2321 2322 |
# File 'lib/stripe/resources/charge.rb', line 2320 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
2322 2323 2324 |
# File 'lib/stripe/resources/charge.rb', line 2322 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
2324 2325 2326 |
# File 'lib/stripe/resources/charge.rb', line 2324 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
2326 2327 2328 |
# File 'lib/stripe/resources/charge.rb', line 2326 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
2328 2329 2330 |
# File 'lib/stripe/resources/charge.rb', line 2328 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
2330 2331 2332 |
# File 'lib/stripe/resources/charge.rb', line 2330 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
2332 2333 2334 |
# File 'lib/stripe/resources/charge.rb', line 2332 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
2334 2335 2336 |
# File 'lib/stripe/resources/charge.rb', line 2334 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
2336 2337 2338 |
# File 'lib/stripe/resources/charge.rb', line 2336 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
2338 2339 2340 |
# File 'lib/stripe/resources/charge.rb', line 2338 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
2340 2341 2342 |
# File 'lib/stripe/resources/charge.rb', line 2340 def stripe_account @stripe_account end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
2342 2343 2344 |
# File 'lib/stripe/resources/charge.rb', line 2342 def stripe_balance @stripe_balance end |
#sunbit ⇒ Object (readonly)
Attribute for field sunbit
2344 2345 2346 |
# File 'lib/stripe/resources/charge.rb', line 2344 def sunbit @sunbit end |
#swish ⇒ Object (readonly)
Attribute for field swish
2346 2347 2348 |
# File 'lib/stripe/resources/charge.rb', line 2346 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
2348 2349 2350 |
# File 'lib/stripe/resources/charge.rb', line 2348 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
2352 2353 2354 |
# File 'lib/stripe/resources/charge.rb', line 2352 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
2354 2355 2356 |
# File 'lib/stripe/resources/charge.rb', line 2354 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
2356 2357 2358 |
# File 'lib/stripe/resources/charge.rb', line 2356 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
2358 2359 2360 |
# File 'lib/stripe/resources/charge.rb', line 2358 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
2360 2361 2362 |
# File 'lib/stripe/resources/charge.rb', line 2360 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
2362 2363 2364 |
# File 'lib/stripe/resources/charge.rb', line 2362 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
2436 2437 2438 |
# File 'lib/stripe/resources/charge.rb', line 2436 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2364 2365 2366 2367 2368 2369 2370 2371 2372 2373 2374 2375 2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 |
# File 'lib/stripe/resources/charge.rb', line 2364 def self.inner_class_types @inner_class_types = { ach_credit_transfer: AchCreditTransfer, ach_debit: AchDebit, acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, gift_card: GiftCard, giropay: Giropay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, rechnung: Rechnung, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_credit_transfer: SepaCreditTransfer, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, stripe_account: StripeAccount, stripe_balance: StripeBalance, sunbit: Sunbit, swish: Swish, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, wechat: Wechat, wechat_pay: WechatPay, zip: Zip, } end |