Class: Stripe::Charge::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



2115
2116
2117
# File 'lib/stripe/resources/charge.rb', line 2115

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



2117
2118
2119
# File 'lib/stripe/resources/charge.rb', line 2117

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



2119
2120
2121
# File 'lib/stripe/resources/charge.rb', line 2119

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



2121
2122
2123
# File 'lib/stripe/resources/charge.rb', line 2121

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2123
2124
2125
# File 'lib/stripe/resources/charge.rb', line 2123

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2125
2126
2127
# File 'lib/stripe/resources/charge.rb', line 2125

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2127
2128
2129
# File 'lib/stripe/resources/charge.rb', line 2127

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2129
2130
2131
# File 'lib/stripe/resources/charge.rb', line 2129

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2131
2132
2133
# File 'lib/stripe/resources/charge.rb', line 2131

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2133
2134
2135
# File 'lib/stripe/resources/charge.rb', line 2133

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2135
2136
2137
# File 'lib/stripe/resources/charge.rb', line 2135

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2137
2138
2139
# File 'lib/stripe/resources/charge.rb', line 2137

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



2139
2140
2141
# File 'lib/stripe/resources/charge.rb', line 2139

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2141
2142
2143
# File 'lib/stripe/resources/charge.rb', line 2141

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2143
2144
2145
# File 'lib/stripe/resources/charge.rb', line 2143

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



2145
2146
2147
# File 'lib/stripe/resources/charge.rb', line 2145

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



2147
2148
2149
# File 'lib/stripe/resources/charge.rb', line 2147

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



2149
2150
2151
# File 'lib/stripe/resources/charge.rb', line 2149

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2151
2152
2153
# File 'lib/stripe/resources/charge.rb', line 2151

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2153
2154
2155
# File 'lib/stripe/resources/charge.rb', line 2153

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2155
2156
2157
# File 'lib/stripe/resources/charge.rb', line 2155

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



2157
2158
2159
# File 'lib/stripe/resources/charge.rb', line 2157

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



2159
2160
2161
# File 'lib/stripe/resources/charge.rb', line 2159

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2161
2162
2163
# File 'lib/stripe/resources/charge.rb', line 2161

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2163
2164
2165
# File 'lib/stripe/resources/charge.rb', line 2163

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2165
2166
2167
# File 'lib/stripe/resources/charge.rb', line 2165

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



2167
2168
2169
# File 'lib/stripe/resources/charge.rb', line 2167

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



2169
2170
2171
# File 'lib/stripe/resources/charge.rb', line 2169

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



2171
2172
2173
# File 'lib/stripe/resources/charge.rb', line 2171

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2173
2174
2175
# File 'lib/stripe/resources/charge.rb', line 2173

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



2175
2176
2177
# File 'lib/stripe/resources/charge.rb', line 2175

def kr_card
  @kr_card
end

Attribute for field link



2177
2178
2179
# File 'lib/stripe/resources/charge.rb', line 2177

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



2179
2180
2181
# File 'lib/stripe/resources/charge.rb', line 2179

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2181
2182
2183
# File 'lib/stripe/resources/charge.rb', line 2181

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2183
2184
2185
# File 'lib/stripe/resources/charge.rb', line 2183

def multibanco
  @multibanco
end

Attribute for field naver_pay



2185
2186
2187
# File 'lib/stripe/resources/charge.rb', line 2185

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2187
2188
2189
# File 'lib/stripe/resources/charge.rb', line 2187

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



2189
2190
2191
# File 'lib/stripe/resources/charge.rb', line 2189

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2191
2192
2193
# File 'lib/stripe/resources/charge.rb', line 2191

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2193
2194
2195
# File 'lib/stripe/resources/charge.rb', line 2193

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2195
2196
2197
# File 'lib/stripe/resources/charge.rb', line 2195

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



2197
2198
2199
# File 'lib/stripe/resources/charge.rb', line 2197

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2199
2200
2201
# File 'lib/stripe/resources/charge.rb', line 2199

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



2201
2202
2203
# File 'lib/stripe/resources/charge.rb', line 2201

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



2203
2204
2205
# File 'lib/stripe/resources/charge.rb', line 2203

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2205
2206
2207
# File 'lib/stripe/resources/charge.rb', line 2205

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2207
2208
2209
# File 'lib/stripe/resources/charge.rb', line 2207

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2209
2210
2211
# File 'lib/stripe/resources/charge.rb', line 2209

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



2211
2212
2213
# File 'lib/stripe/resources/charge.rb', line 2211

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2213
2214
2215
# File 'lib/stripe/resources/charge.rb', line 2213

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2215
2216
2217
# File 'lib/stripe/resources/charge.rb', line 2215

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2217
2218
2219
# File 'lib/stripe/resources/charge.rb', line 2217

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



2219
2220
2221
# File 'lib/stripe/resources/charge.rb', line 2219

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2221
2222
2223
# File 'lib/stripe/resources/charge.rb', line 2221

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2223
2224
2225
# File 'lib/stripe/resources/charge.rb', line 2223

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2225
2226
2227
# File 'lib/stripe/resources/charge.rb', line 2225

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



2227
2228
2229
# File 'lib/stripe/resources/charge.rb', line 2227

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



2229
2230
2231
# File 'lib/stripe/resources/charge.rb', line 2229

def stripe_balance
  @stripe_balance
end

#sunbitObject (readonly)

Attribute for field sunbit



2231
2232
2233
# File 'lib/stripe/resources/charge.rb', line 2231

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



2233
2234
2235
# File 'lib/stripe/resources/charge.rb', line 2233

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2235
2236
2237
# File 'lib/stripe/resources/charge.rb', line 2235

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



2239
2240
2241
# File 'lib/stripe/resources/charge.rb', line 2239

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



2241
2242
2243
# File 'lib/stripe/resources/charge.rb', line 2241

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2243
2244
2245
# File 'lib/stripe/resources/charge.rb', line 2243

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



2245
2246
2247
# File 'lib/stripe/resources/charge.rb', line 2245

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2247
2248
2249
# File 'lib/stripe/resources/charge.rb', line 2247

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2249
2250
2251
# File 'lib/stripe/resources/charge.rb', line 2249

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2322
2323
2324
# File 'lib/stripe/resources/charge.rb', line 2322

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
# File 'lib/stripe/resources/charge.rb', line 2251

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end