Class: Stripe::Charge::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



2154
2155
2156
# File 'lib/stripe/resources/charge.rb', line 2154

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



2156
2157
2158
# File 'lib/stripe/resources/charge.rb', line 2156

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



2158
2159
2160
# File 'lib/stripe/resources/charge.rb', line 2158

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



2160
2161
2162
# File 'lib/stripe/resources/charge.rb', line 2160

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2162
2163
2164
# File 'lib/stripe/resources/charge.rb', line 2162

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2164
2165
2166
# File 'lib/stripe/resources/charge.rb', line 2164

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2166
2167
2168
# File 'lib/stripe/resources/charge.rb', line 2166

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2168
2169
2170
# File 'lib/stripe/resources/charge.rb', line 2168

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2170
2171
2172
# File 'lib/stripe/resources/charge.rb', line 2170

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2172
2173
2174
# File 'lib/stripe/resources/charge.rb', line 2172

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2174
2175
2176
# File 'lib/stripe/resources/charge.rb', line 2174

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2176
2177
2178
# File 'lib/stripe/resources/charge.rb', line 2176

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



2178
2179
2180
# File 'lib/stripe/resources/charge.rb', line 2178

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2180
2181
2182
# File 'lib/stripe/resources/charge.rb', line 2180

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2182
2183
2184
# File 'lib/stripe/resources/charge.rb', line 2182

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



2184
2185
2186
# File 'lib/stripe/resources/charge.rb', line 2184

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



2186
2187
2188
# File 'lib/stripe/resources/charge.rb', line 2186

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



2188
2189
2190
# File 'lib/stripe/resources/charge.rb', line 2188

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2190
2191
2192
# File 'lib/stripe/resources/charge.rb', line 2190

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2192
2193
2194
# File 'lib/stripe/resources/charge.rb', line 2192

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2194
2195
2196
# File 'lib/stripe/resources/charge.rb', line 2194

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



2196
2197
2198
# File 'lib/stripe/resources/charge.rb', line 2196

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



2198
2199
2200
# File 'lib/stripe/resources/charge.rb', line 2198

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2200
2201
2202
# File 'lib/stripe/resources/charge.rb', line 2200

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2202
2203
2204
# File 'lib/stripe/resources/charge.rb', line 2202

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2204
2205
2206
# File 'lib/stripe/resources/charge.rb', line 2204

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



2206
2207
2208
# File 'lib/stripe/resources/charge.rb', line 2206

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



2208
2209
2210
# File 'lib/stripe/resources/charge.rb', line 2208

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



2210
2211
2212
# File 'lib/stripe/resources/charge.rb', line 2210

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2212
2213
2214
# File 'lib/stripe/resources/charge.rb', line 2212

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



2214
2215
2216
# File 'lib/stripe/resources/charge.rb', line 2214

def kr_card
  @kr_card
end

Attribute for field link



2216
2217
2218
# File 'lib/stripe/resources/charge.rb', line 2216

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



2218
2219
2220
# File 'lib/stripe/resources/charge.rb', line 2218

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2220
2221
2222
# File 'lib/stripe/resources/charge.rb', line 2220

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2222
2223
2224
# File 'lib/stripe/resources/charge.rb', line 2222

def multibanco
  @multibanco
end

Attribute for field naver_pay



2224
2225
2226
# File 'lib/stripe/resources/charge.rb', line 2224

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2226
2227
2228
# File 'lib/stripe/resources/charge.rb', line 2226

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



2228
2229
2230
# File 'lib/stripe/resources/charge.rb', line 2228

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2230
2231
2232
# File 'lib/stripe/resources/charge.rb', line 2230

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2232
2233
2234
# File 'lib/stripe/resources/charge.rb', line 2232

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2234
2235
2236
# File 'lib/stripe/resources/charge.rb', line 2234

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



2236
2237
2238
# File 'lib/stripe/resources/charge.rb', line 2236

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2238
2239
2240
# File 'lib/stripe/resources/charge.rb', line 2238

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



2240
2241
2242
# File 'lib/stripe/resources/charge.rb', line 2240

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



2242
2243
2244
# File 'lib/stripe/resources/charge.rb', line 2242

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2244
2245
2246
# File 'lib/stripe/resources/charge.rb', line 2244

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2246
2247
2248
# File 'lib/stripe/resources/charge.rb', line 2246

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2248
2249
2250
# File 'lib/stripe/resources/charge.rb', line 2248

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



2250
2251
2252
# File 'lib/stripe/resources/charge.rb', line 2250

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2252
2253
2254
# File 'lib/stripe/resources/charge.rb', line 2252

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2254
2255
2256
# File 'lib/stripe/resources/charge.rb', line 2254

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2256
2257
2258
# File 'lib/stripe/resources/charge.rb', line 2256

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



2258
2259
2260
# File 'lib/stripe/resources/charge.rb', line 2258

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2260
2261
2262
# File 'lib/stripe/resources/charge.rb', line 2260

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2262
2263
2264
# File 'lib/stripe/resources/charge.rb', line 2262

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2264
2265
2266
# File 'lib/stripe/resources/charge.rb', line 2264

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



2266
2267
2268
# File 'lib/stripe/resources/charge.rb', line 2266

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



2268
2269
2270
# File 'lib/stripe/resources/charge.rb', line 2268

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



2270
2271
2272
# File 'lib/stripe/resources/charge.rb', line 2270

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2272
2273
2274
# File 'lib/stripe/resources/charge.rb', line 2272

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



2276
2277
2278
# File 'lib/stripe/resources/charge.rb', line 2276

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



2278
2279
2280
# File 'lib/stripe/resources/charge.rb', line 2278

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2280
2281
2282
# File 'lib/stripe/resources/charge.rb', line 2280

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



2282
2283
2284
# File 'lib/stripe/resources/charge.rb', line 2282

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2284
2285
2286
# File 'lib/stripe/resources/charge.rb', line 2284

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2286
2287
2288
# File 'lib/stripe/resources/charge.rb', line 2286

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2358
2359
2360
# File 'lib/stripe/resources/charge.rb', line 2358

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
2337
2338
2339
2340
2341
2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
# File 'lib/stripe/resources/charge.rb', line 2288

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end