Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Sofort, StripeAccount, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1907 1908 1909 |
# File 'lib/stripe/resources/charge.rb', line 1907 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1909 1910 1911 |
# File 'lib/stripe/resources/charge.rb', line 1909 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1911 1912 1913 |
# File 'lib/stripe/resources/charge.rb', line 1911 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1913 1914 1915 |
# File 'lib/stripe/resources/charge.rb', line 1913 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1915 1916 1917 |
# File 'lib/stripe/resources/charge.rb', line 1915 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1917 1918 1919 |
# File 'lib/stripe/resources/charge.rb', line 1917 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1919 1920 1921 |
# File 'lib/stripe/resources/charge.rb', line 1919 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1921 1922 1923 |
# File 'lib/stripe/resources/charge.rb', line 1921 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1923 1924 1925 |
# File 'lib/stripe/resources/charge.rb', line 1923 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1925 1926 1927 |
# File 'lib/stripe/resources/charge.rb', line 1925 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1927 1928 1929 |
# File 'lib/stripe/resources/charge.rb', line 1927 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1929 1930 1931 |
# File 'lib/stripe/resources/charge.rb', line 1929 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
1931 1932 1933 |
# File 'lib/stripe/resources/charge.rb', line 1931 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1933 1934 1935 |
# File 'lib/stripe/resources/charge.rb', line 1933 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1935 1936 1937 |
# File 'lib/stripe/resources/charge.rb', line 1935 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1937 1938 1939 |
# File 'lib/stripe/resources/charge.rb', line 1937 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1939 1940 1941 |
# File 'lib/stripe/resources/charge.rb', line 1939 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1941 1942 1943 |
# File 'lib/stripe/resources/charge.rb', line 1941 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1943 1944 1945 |
# File 'lib/stripe/resources/charge.rb', line 1943 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1945 1946 1947 |
# File 'lib/stripe/resources/charge.rb', line 1945 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1947 1948 1949 |
# File 'lib/stripe/resources/charge.rb', line 1947 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1949 1950 1951 |
# File 'lib/stripe/resources/charge.rb', line 1949 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1951 1952 1953 |
# File 'lib/stripe/resources/charge.rb', line 1951 def grabpay @grabpay end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1953 1954 1955 |
# File 'lib/stripe/resources/charge.rb', line 1953 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1955 1956 1957 |
# File 'lib/stripe/resources/charge.rb', line 1955 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1957 1958 1959 |
# File 'lib/stripe/resources/charge.rb', line 1957 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1959 1960 1961 |
# File 'lib/stripe/resources/charge.rb', line 1959 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1961 1962 1963 |
# File 'lib/stripe/resources/charge.rb', line 1961 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1963 1964 1965 |
# File 'lib/stripe/resources/charge.rb', line 1963 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1965 1966 1967 |
# File 'lib/stripe/resources/charge.rb', line 1965 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1967 1968 1969 |
# File 'lib/stripe/resources/charge.rb', line 1967 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1969 1970 1971 |
# File 'lib/stripe/resources/charge.rb', line 1969 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1971 1972 1973 |
# File 'lib/stripe/resources/charge.rb', line 1971 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1973 1974 1975 |
# File 'lib/stripe/resources/charge.rb', line 1973 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1975 1976 1977 |
# File 'lib/stripe/resources/charge.rb', line 1975 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1977 1978 1979 |
# File 'lib/stripe/resources/charge.rb', line 1977 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1979 1980 1981 |
# File 'lib/stripe/resources/charge.rb', line 1979 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1981 1982 1983 |
# File 'lib/stripe/resources/charge.rb', line 1981 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1983 1984 1985 |
# File 'lib/stripe/resources/charge.rb', line 1983 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1985 1986 1987 |
# File 'lib/stripe/resources/charge.rb', line 1985 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1987 1988 1989 |
# File 'lib/stripe/resources/charge.rb', line 1987 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1989 1990 1991 |
# File 'lib/stripe/resources/charge.rb', line 1989 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1991 1992 1993 |
# File 'lib/stripe/resources/charge.rb', line 1991 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1993 1994 1995 |
# File 'lib/stripe/resources/charge.rb', line 1993 def promptpay @promptpay end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1995 1996 1997 |
# File 'lib/stripe/resources/charge.rb', line 1995 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1997 1998 1999 |
# File 'lib/stripe/resources/charge.rb', line 1997 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1999 2000 2001 |
# File 'lib/stripe/resources/charge.rb', line 1999 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
2001 2002 2003 |
# File 'lib/stripe/resources/charge.rb', line 2001 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
2003 2004 2005 |
# File 'lib/stripe/resources/charge.rb', line 2003 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
2005 2006 2007 |
# File 'lib/stripe/resources/charge.rb', line 2005 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
2007 2008 2009 |
# File 'lib/stripe/resources/charge.rb', line 2007 def stripe_account @stripe_account end |
#swish ⇒ Object (readonly)
Attribute for field swish
2009 2010 2011 |
# File 'lib/stripe/resources/charge.rb', line 2009 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
2011 2012 2013 |
# File 'lib/stripe/resources/charge.rb', line 2011 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
2015 2016 2017 |
# File 'lib/stripe/resources/charge.rb', line 2015 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
2017 2018 2019 |
# File 'lib/stripe/resources/charge.rb', line 2017 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
2019 2020 2021 |
# File 'lib/stripe/resources/charge.rb', line 2019 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
2021 2022 2023 |
# File 'lib/stripe/resources/charge.rb', line 2021 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
2023 2024 2025 |
# File 'lib/stripe/resources/charge.rb', line 2023 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
2025 2026 2027 |
# File 'lib/stripe/resources/charge.rb', line 2025 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
2090 2091 2092 |
# File 'lib/stripe/resources/charge.rb', line 2090 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 |
# File 'lib/stripe/resources/charge.rb', line 2027 def self.inner_class_types @inner_class_types = { ach_credit_transfer: AchCreditTransfer, ach_debit: AchDebit, acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, grabpay: Grabpay, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, payto: Payto, pix: Pix, promptpay: Promptpay, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_credit_transfer: SepaCreditTransfer, sepa_debit: SepaDebit, sofort: Sofort, stripe_account: StripeAccount, swish: Swish, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, wechat: Wechat, wechat_pay: WechatPay, zip: Zip, } end |