Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#paypay ⇒ Object
readonly
Attribute for field paypay.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
2078 2079 2080 |
# File 'lib/stripe/resources/charge.rb', line 2078 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
2080 2081 2082 |
# File 'lib/stripe/resources/charge.rb', line 2080 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
2082 2083 2084 |
# File 'lib/stripe/resources/charge.rb', line 2082 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
2084 2085 2086 |
# File 'lib/stripe/resources/charge.rb', line 2084 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
2086 2087 2088 |
# File 'lib/stripe/resources/charge.rb', line 2086 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
2088 2089 2090 |
# File 'lib/stripe/resources/charge.rb', line 2088 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
2090 2091 2092 |
# File 'lib/stripe/resources/charge.rb', line 2090 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
2092 2093 2094 |
# File 'lib/stripe/resources/charge.rb', line 2092 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
2094 2095 2096 |
# File 'lib/stripe/resources/charge.rb', line 2094 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
2096 2097 2098 |
# File 'lib/stripe/resources/charge.rb', line 2096 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
2098 2099 2100 |
# File 'lib/stripe/resources/charge.rb', line 2098 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
2100 2101 2102 |
# File 'lib/stripe/resources/charge.rb', line 2100 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
2102 2103 2104 |
# File 'lib/stripe/resources/charge.rb', line 2102 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
2104 2105 2106 |
# File 'lib/stripe/resources/charge.rb', line 2104 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
2106 2107 2108 |
# File 'lib/stripe/resources/charge.rb', line 2106 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
2108 2109 2110 |
# File 'lib/stripe/resources/charge.rb', line 2108 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
2110 2111 2112 |
# File 'lib/stripe/resources/charge.rb', line 2110 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
2112 2113 2114 |
# File 'lib/stripe/resources/charge.rb', line 2112 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
2114 2115 2116 |
# File 'lib/stripe/resources/charge.rb', line 2114 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
2116 2117 2118 |
# File 'lib/stripe/resources/charge.rb', line 2116 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
2118 2119 2120 |
# File 'lib/stripe/resources/charge.rb', line 2118 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
2120 2121 2122 |
# File 'lib/stripe/resources/charge.rb', line 2120 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
2122 2123 2124 |
# File 'lib/stripe/resources/charge.rb', line 2122 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
2124 2125 2126 |
# File 'lib/stripe/resources/charge.rb', line 2124 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
2126 2127 2128 |
# File 'lib/stripe/resources/charge.rb', line 2126 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
2128 2129 2130 |
# File 'lib/stripe/resources/charge.rb', line 2128 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
2130 2131 2132 |
# File 'lib/stripe/resources/charge.rb', line 2130 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
2132 2133 2134 |
# File 'lib/stripe/resources/charge.rb', line 2132 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
2134 2135 2136 |
# File 'lib/stripe/resources/charge.rb', line 2134 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
2136 2137 2138 |
# File 'lib/stripe/resources/charge.rb', line 2136 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
2138 2139 2140 |
# File 'lib/stripe/resources/charge.rb', line 2138 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
2140 2141 2142 |
# File 'lib/stripe/resources/charge.rb', line 2140 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
2142 2143 2144 |
# File 'lib/stripe/resources/charge.rb', line 2142 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
2144 2145 2146 |
# File 'lib/stripe/resources/charge.rb', line 2144 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
2146 2147 2148 |
# File 'lib/stripe/resources/charge.rb', line 2146 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
2148 2149 2150 |
# File 'lib/stripe/resources/charge.rb', line 2148 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
2150 2151 2152 |
# File 'lib/stripe/resources/charge.rb', line 2150 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
2152 2153 2154 |
# File 'lib/stripe/resources/charge.rb', line 2152 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
2154 2155 2156 |
# File 'lib/stripe/resources/charge.rb', line 2154 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
2156 2157 2158 |
# File 'lib/stripe/resources/charge.rb', line 2156 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
2158 2159 2160 |
# File 'lib/stripe/resources/charge.rb', line 2158 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
2160 2161 2162 |
# File 'lib/stripe/resources/charge.rb', line 2160 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
2162 2163 2164 |
# File 'lib/stripe/resources/charge.rb', line 2162 def paypal @paypal end |
#paypay ⇒ Object (readonly)
Attribute for field paypay
2164 2165 2166 |
# File 'lib/stripe/resources/charge.rb', line 2164 def paypay @paypay end |
#payto ⇒ Object (readonly)
Attribute for field payto
2166 2167 2168 |
# File 'lib/stripe/resources/charge.rb', line 2166 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
2168 2169 2170 |
# File 'lib/stripe/resources/charge.rb', line 2168 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
2170 2171 2172 |
# File 'lib/stripe/resources/charge.rb', line 2170 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
2172 2173 2174 |
# File 'lib/stripe/resources/charge.rb', line 2172 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
2174 2175 2176 |
# File 'lib/stripe/resources/charge.rb', line 2174 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
2176 2177 2178 |
# File 'lib/stripe/resources/charge.rb', line 2176 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
2178 2179 2180 |
# File 'lib/stripe/resources/charge.rb', line 2178 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
2180 2181 2182 |
# File 'lib/stripe/resources/charge.rb', line 2180 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
2182 2183 2184 |
# File 'lib/stripe/resources/charge.rb', line 2182 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
2184 2185 2186 |
# File 'lib/stripe/resources/charge.rb', line 2184 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
2186 2187 2188 |
# File 'lib/stripe/resources/charge.rb', line 2186 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
2188 2189 2190 |
# File 'lib/stripe/resources/charge.rb', line 2188 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
2190 2191 2192 |
# File 'lib/stripe/resources/charge.rb', line 2190 def stripe_account @stripe_account end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
2192 2193 2194 |
# File 'lib/stripe/resources/charge.rb', line 2192 def stripe_balance @stripe_balance end |
#swish ⇒ Object (readonly)
Attribute for field swish
2194 2195 2196 |
# File 'lib/stripe/resources/charge.rb', line 2194 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
2196 2197 2198 |
# File 'lib/stripe/resources/charge.rb', line 2196 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
2200 2201 2202 |
# File 'lib/stripe/resources/charge.rb', line 2200 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
2202 2203 2204 |
# File 'lib/stripe/resources/charge.rb', line 2202 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
2204 2205 2206 |
# File 'lib/stripe/resources/charge.rb', line 2204 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
2206 2207 2208 |
# File 'lib/stripe/resources/charge.rb', line 2206 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
2208 2209 2210 |
# File 'lib/stripe/resources/charge.rb', line 2208 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
2279 2280 2281 |
# File 'lib/stripe/resources/charge.rb', line 2279 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 2243 2244 2245 2246 2247 2248 2249 2250 2251 2252 2253 2254 2255 2256 2257 2258 2259 2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 |
# File 'lib/stripe/resources/charge.rb', line 2210 def self.inner_class_types @inner_class_types = { ach_credit_transfer: AchCreditTransfer, ach_debit: AchDebit, acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, paypay: Paypay, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, rechnung: Rechnung, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_credit_transfer: SepaCreditTransfer, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, stripe_account: StripeAccount, stripe_balance: StripeBalance, swish: Swish, twint: Twint, us_bank_account: UsBankAccount, wechat: Wechat, wechat_pay: WechatPay, zip: Zip, } end |