Class: Stripe::Charge::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



2062
2063
2064
# File 'lib/stripe/resources/charge.rb', line 2062

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



2064
2065
2066
# File 'lib/stripe/resources/charge.rb', line 2064

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



2066
2067
2068
# File 'lib/stripe/resources/charge.rb', line 2066

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



2068
2069
2070
# File 'lib/stripe/resources/charge.rb', line 2068

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2070
2071
2072
# File 'lib/stripe/resources/charge.rb', line 2070

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2072
2073
2074
# File 'lib/stripe/resources/charge.rb', line 2072

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2074
2075
2076
# File 'lib/stripe/resources/charge.rb', line 2074

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2076
2077
2078
# File 'lib/stripe/resources/charge.rb', line 2076

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2078
2079
2080
# File 'lib/stripe/resources/charge.rb', line 2078

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2080
2081
2082
# File 'lib/stripe/resources/charge.rb', line 2080

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2082
2083
2084
# File 'lib/stripe/resources/charge.rb', line 2082

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2084
2085
2086
# File 'lib/stripe/resources/charge.rb', line 2084

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



2086
2087
2088
# File 'lib/stripe/resources/charge.rb', line 2086

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2088
2089
2090
# File 'lib/stripe/resources/charge.rb', line 2088

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2090
2091
2092
# File 'lib/stripe/resources/charge.rb', line 2090

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



2092
2093
2094
# File 'lib/stripe/resources/charge.rb', line 2092

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



2094
2095
2096
# File 'lib/stripe/resources/charge.rb', line 2094

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



2096
2097
2098
# File 'lib/stripe/resources/charge.rb', line 2096

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2098
2099
2100
# File 'lib/stripe/resources/charge.rb', line 2098

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2100
2101
2102
# File 'lib/stripe/resources/charge.rb', line 2100

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2102
2103
2104
# File 'lib/stripe/resources/charge.rb', line 2102

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



2104
2105
2106
# File 'lib/stripe/resources/charge.rb', line 2104

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



2106
2107
2108
# File 'lib/stripe/resources/charge.rb', line 2106

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2108
2109
2110
# File 'lib/stripe/resources/charge.rb', line 2108

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2110
2111
2112
# File 'lib/stripe/resources/charge.rb', line 2110

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2112
2113
2114
# File 'lib/stripe/resources/charge.rb', line 2112

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



2114
2115
2116
# File 'lib/stripe/resources/charge.rb', line 2114

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



2116
2117
2118
# File 'lib/stripe/resources/charge.rb', line 2116

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



2118
2119
2120
# File 'lib/stripe/resources/charge.rb', line 2118

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2120
2121
2122
# File 'lib/stripe/resources/charge.rb', line 2120

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



2122
2123
2124
# File 'lib/stripe/resources/charge.rb', line 2122

def kr_card
  @kr_card
end

Attribute for field link



2124
2125
2126
# File 'lib/stripe/resources/charge.rb', line 2124

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



2126
2127
2128
# File 'lib/stripe/resources/charge.rb', line 2126

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2128
2129
2130
# File 'lib/stripe/resources/charge.rb', line 2128

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2130
2131
2132
# File 'lib/stripe/resources/charge.rb', line 2130

def multibanco
  @multibanco
end

Attribute for field naver_pay



2132
2133
2134
# File 'lib/stripe/resources/charge.rb', line 2132

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2134
2135
2136
# File 'lib/stripe/resources/charge.rb', line 2134

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



2136
2137
2138
# File 'lib/stripe/resources/charge.rb', line 2136

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2138
2139
2140
# File 'lib/stripe/resources/charge.rb', line 2138

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2140
2141
2142
# File 'lib/stripe/resources/charge.rb', line 2140

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2142
2143
2144
# File 'lib/stripe/resources/charge.rb', line 2142

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



2144
2145
2146
# File 'lib/stripe/resources/charge.rb', line 2144

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2146
2147
2148
# File 'lib/stripe/resources/charge.rb', line 2146

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



2148
2149
2150
# File 'lib/stripe/resources/charge.rb', line 2148

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



2150
2151
2152
# File 'lib/stripe/resources/charge.rb', line 2150

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2152
2153
2154
# File 'lib/stripe/resources/charge.rb', line 2152

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2154
2155
2156
# File 'lib/stripe/resources/charge.rb', line 2154

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2156
2157
2158
# File 'lib/stripe/resources/charge.rb', line 2156

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



2158
2159
2160
# File 'lib/stripe/resources/charge.rb', line 2158

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2160
2161
2162
# File 'lib/stripe/resources/charge.rb', line 2160

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2162
2163
2164
# File 'lib/stripe/resources/charge.rb', line 2162

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2164
2165
2166
# File 'lib/stripe/resources/charge.rb', line 2164

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



2166
2167
2168
# File 'lib/stripe/resources/charge.rb', line 2166

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2168
2169
2170
# File 'lib/stripe/resources/charge.rb', line 2168

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2170
2171
2172
# File 'lib/stripe/resources/charge.rb', line 2170

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2172
2173
2174
# File 'lib/stripe/resources/charge.rb', line 2172

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



2174
2175
2176
# File 'lib/stripe/resources/charge.rb', line 2174

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



2176
2177
2178
# File 'lib/stripe/resources/charge.rb', line 2176

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



2178
2179
2180
# File 'lib/stripe/resources/charge.rb', line 2178

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2180
2181
2182
# File 'lib/stripe/resources/charge.rb', line 2180

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



2184
2185
2186
# File 'lib/stripe/resources/charge.rb', line 2184

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2186
2187
2188
# File 'lib/stripe/resources/charge.rb', line 2186

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



2188
2189
2190
# File 'lib/stripe/resources/charge.rb', line 2188

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2190
2191
2192
# File 'lib/stripe/resources/charge.rb', line 2190

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2192
2193
2194
# File 'lib/stripe/resources/charge.rb', line 2192

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2263
2264
2265
# File 'lib/stripe/resources/charge.rb', line 2263

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
# File 'lib/stripe/resources/charge.rb', line 2194

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    swish: Swish,
    twint: Twint,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end