Class: Stripe::Charge::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



2049
2050
2051
# File 'lib/stripe/resources/charge.rb', line 2049

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



2051
2052
2053
# File 'lib/stripe/resources/charge.rb', line 2051

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



2053
2054
2055
# File 'lib/stripe/resources/charge.rb', line 2053

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



2055
2056
2057
# File 'lib/stripe/resources/charge.rb', line 2055

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



2057
2058
2059
# File 'lib/stripe/resources/charge.rb', line 2057

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



2059
2060
2061
# File 'lib/stripe/resources/charge.rb', line 2059

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



2061
2062
2063
# File 'lib/stripe/resources/charge.rb', line 2061

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



2063
2064
2065
# File 'lib/stripe/resources/charge.rb', line 2063

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



2065
2066
2067
# File 'lib/stripe/resources/charge.rb', line 2065

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



2067
2068
2069
# File 'lib/stripe/resources/charge.rb', line 2067

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



2069
2070
2071
# File 'lib/stripe/resources/charge.rb', line 2069

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



2071
2072
2073
# File 'lib/stripe/resources/charge.rb', line 2071

def billie
  @billie
end

#blikObject (readonly)

Attribute for field blik



2073
2074
2075
# File 'lib/stripe/resources/charge.rb', line 2073

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



2075
2076
2077
# File 'lib/stripe/resources/charge.rb', line 2075

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



2077
2078
2079
# File 'lib/stripe/resources/charge.rb', line 2077

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



2079
2080
2081
# File 'lib/stripe/resources/charge.rb', line 2079

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



2081
2082
2083
# File 'lib/stripe/resources/charge.rb', line 2081

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



2083
2084
2085
# File 'lib/stripe/resources/charge.rb', line 2083

def crypto
  @crypto
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



2085
2086
2087
# File 'lib/stripe/resources/charge.rb', line 2085

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



2087
2088
2089
# File 'lib/stripe/resources/charge.rb', line 2087

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



2089
2090
2091
# File 'lib/stripe/resources/charge.rb', line 2089

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



2091
2092
2093
# File 'lib/stripe/resources/charge.rb', line 2091

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



2093
2094
2095
# File 'lib/stripe/resources/charge.rb', line 2093

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



2095
2096
2097
# File 'lib/stripe/resources/charge.rb', line 2095

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



2097
2098
2099
# File 'lib/stripe/resources/charge.rb', line 2097

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



2099
2100
2101
# File 'lib/stripe/resources/charge.rb', line 2099

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



2101
2102
2103
# File 'lib/stripe/resources/charge.rb', line 2101

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



2103
2104
2105
# File 'lib/stripe/resources/charge.rb', line 2103

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



2105
2106
2107
# File 'lib/stripe/resources/charge.rb', line 2105

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



2107
2108
2109
# File 'lib/stripe/resources/charge.rb', line 2107

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



2109
2110
2111
# File 'lib/stripe/resources/charge.rb', line 2109

def kr_card
  @kr_card
end

Attribute for field link



2111
2112
2113
# File 'lib/stripe/resources/charge.rb', line 2111

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



2113
2114
2115
# File 'lib/stripe/resources/charge.rb', line 2113

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



2115
2116
2117
# File 'lib/stripe/resources/charge.rb', line 2115

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



2117
2118
2119
# File 'lib/stripe/resources/charge.rb', line 2117

def multibanco
  @multibanco
end

Attribute for field naver_pay



2119
2120
2121
# File 'lib/stripe/resources/charge.rb', line 2119

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



2121
2122
2123
# File 'lib/stripe/resources/charge.rb', line 2121

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



2123
2124
2125
# File 'lib/stripe/resources/charge.rb', line 2123

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



2125
2126
2127
# File 'lib/stripe/resources/charge.rb', line 2125

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



2127
2128
2129
# File 'lib/stripe/resources/charge.rb', line 2127

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



2129
2130
2131
# File 'lib/stripe/resources/charge.rb', line 2129

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



2131
2132
2133
# File 'lib/stripe/resources/charge.rb', line 2131

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



2133
2134
2135
# File 'lib/stripe/resources/charge.rb', line 2133

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



2135
2136
2137
# File 'lib/stripe/resources/charge.rb', line 2135

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



2137
2138
2139
# File 'lib/stripe/resources/charge.rb', line 2137

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



2139
2140
2141
# File 'lib/stripe/resources/charge.rb', line 2139

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



2141
2142
2143
# File 'lib/stripe/resources/charge.rb', line 2141

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



2143
2144
2145
# File 'lib/stripe/resources/charge.rb', line 2143

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



2145
2146
2147
# File 'lib/stripe/resources/charge.rb', line 2145

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



2147
2148
2149
# File 'lib/stripe/resources/charge.rb', line 2147

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2149
2150
2151
# File 'lib/stripe/resources/charge.rb', line 2149

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



2151
2152
2153
# File 'lib/stripe/resources/charge.rb', line 2151

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2153
2154
2155
# File 'lib/stripe/resources/charge.rb', line 2153

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2155
2156
2157
# File 'lib/stripe/resources/charge.rb', line 2155

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2157
2158
2159
# File 'lib/stripe/resources/charge.rb', line 2157

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



2159
2160
2161
# File 'lib/stripe/resources/charge.rb', line 2159

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



2161
2162
2163
# File 'lib/stripe/resources/charge.rb', line 2161

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



2163
2164
2165
# File 'lib/stripe/resources/charge.rb', line 2163

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2165
2166
2167
# File 'lib/stripe/resources/charge.rb', line 2165

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



2169
2170
2171
# File 'lib/stripe/resources/charge.rb', line 2169

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2171
2172
2173
# File 'lib/stripe/resources/charge.rb', line 2171

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



2173
2174
2175
# File 'lib/stripe/resources/charge.rb', line 2173

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2175
2176
2177
# File 'lib/stripe/resources/charge.rb', line 2175

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2177
2178
2179
# File 'lib/stripe/resources/charge.rb', line 2177

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2247
2248
2249
# File 'lib/stripe/resources/charge.rb', line 2247

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
2205
2206
2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
# File 'lib/stripe/resources/charge.rb', line 2179

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    swish: Swish,
    twint: Twint,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end