Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1143 1144 1145 |
# File 'lib/stripe/resources/charge.rb', line 1143 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1145 1146 1147 |
# File 'lib/stripe/resources/charge.rb', line 1145 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1147 1148 1149 |
# File 'lib/stripe/resources/charge.rb', line 1147 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1149 1150 1151 |
# File 'lib/stripe/resources/charge.rb', line 1149 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1151 1152 1153 |
# File 'lib/stripe/resources/charge.rb', line 1151 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1153 1154 1155 |
# File 'lib/stripe/resources/charge.rb', line 1153 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1155 1156 1157 |
# File 'lib/stripe/resources/charge.rb', line 1155 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1157 1158 1159 |
# File 'lib/stripe/resources/charge.rb', line 1157 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1159 1160 1161 |
# File 'lib/stripe/resources/charge.rb', line 1159 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1161 1162 1163 |
# File 'lib/stripe/resources/charge.rb', line 1161 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1163 1164 1165 |
# File 'lib/stripe/resources/charge.rb', line 1163 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1165 1166 1167 |
# File 'lib/stripe/resources/charge.rb', line 1165 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
1167 1168 1169 |
# File 'lib/stripe/resources/charge.rb', line 1167 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1169 1170 1171 |
# File 'lib/stripe/resources/charge.rb', line 1169 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1171 1172 1173 |
# File 'lib/stripe/resources/charge.rb', line 1171 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1173 1174 1175 |
# File 'lib/stripe/resources/charge.rb', line 1173 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1175 1176 1177 |
# File 'lib/stripe/resources/charge.rb', line 1175 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1177 1178 1179 |
# File 'lib/stripe/resources/charge.rb', line 1177 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1179 1180 1181 |
# File 'lib/stripe/resources/charge.rb', line 1179 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1181 1182 1183 |
# File 'lib/stripe/resources/charge.rb', line 1181 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1183 1184 1185 |
# File 'lib/stripe/resources/charge.rb', line 1183 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1185 1186 1187 |
# File 'lib/stripe/resources/charge.rb', line 1185 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1187 1188 1189 |
# File 'lib/stripe/resources/charge.rb', line 1187 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1189 1190 1191 |
# File 'lib/stripe/resources/charge.rb', line 1189 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1191 1192 1193 |
# File 'lib/stripe/resources/charge.rb', line 1191 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1193 1194 1195 |
# File 'lib/stripe/resources/charge.rb', line 1193 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1195 1196 1197 |
# File 'lib/stripe/resources/charge.rb', line 1195 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1197 1198 1199 |
# File 'lib/stripe/resources/charge.rb', line 1197 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1199 1200 1201 |
# File 'lib/stripe/resources/charge.rb', line 1199 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1201 1202 1203 |
# File 'lib/stripe/resources/charge.rb', line 1201 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1203 1204 1205 |
# File 'lib/stripe/resources/charge.rb', line 1203 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1205 1206 1207 |
# File 'lib/stripe/resources/charge.rb', line 1205 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1207 1208 1209 |
# File 'lib/stripe/resources/charge.rb', line 1207 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1209 1210 1211 |
# File 'lib/stripe/resources/charge.rb', line 1209 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1211 1212 1213 |
# File 'lib/stripe/resources/charge.rb', line 1211 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1213 1214 1215 |
# File 'lib/stripe/resources/charge.rb', line 1213 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1215 1216 1217 |
# File 'lib/stripe/resources/charge.rb', line 1215 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1217 1218 1219 |
# File 'lib/stripe/resources/charge.rb', line 1217 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1219 1220 1221 |
# File 'lib/stripe/resources/charge.rb', line 1219 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1221 1222 1223 |
# File 'lib/stripe/resources/charge.rb', line 1221 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1223 1224 1225 |
# File 'lib/stripe/resources/charge.rb', line 1223 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1225 1226 1227 |
# File 'lib/stripe/resources/charge.rb', line 1225 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1227 1228 1229 |
# File 'lib/stripe/resources/charge.rb', line 1227 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1229 1230 1231 |
# File 'lib/stripe/resources/charge.rb', line 1229 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1231 1232 1233 |
# File 'lib/stripe/resources/charge.rb', line 1231 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1233 1234 1235 |
# File 'lib/stripe/resources/charge.rb', line 1233 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1235 1236 1237 |
# File 'lib/stripe/resources/charge.rb', line 1235 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1237 1238 1239 |
# File 'lib/stripe/resources/charge.rb', line 1237 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1239 1240 1241 |
# File 'lib/stripe/resources/charge.rb', line 1239 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1241 1242 1243 |
# File 'lib/stripe/resources/charge.rb', line 1241 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1243 1244 1245 |
# File 'lib/stripe/resources/charge.rb', line 1243 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1245 1246 1247 |
# File 'lib/stripe/resources/charge.rb', line 1245 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1247 1248 1249 |
# File 'lib/stripe/resources/charge.rb', line 1247 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1249 1250 1251 |
# File 'lib/stripe/resources/charge.rb', line 1249 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1251 1252 1253 |
# File 'lib/stripe/resources/charge.rb', line 1251 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1253 1254 1255 |
# File 'lib/stripe/resources/charge.rb', line 1253 def stripe_account @stripe_account end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
1255 1256 1257 |
# File 'lib/stripe/resources/charge.rb', line 1255 def stripe_balance @stripe_balance end |
#swish ⇒ Object (readonly)
Attribute for field swish
1257 1258 1259 |
# File 'lib/stripe/resources/charge.rb', line 1257 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1259 1260 1261 |
# File 'lib/stripe/resources/charge.rb', line 1259 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
1263 1264 1265 |
# File 'lib/stripe/resources/charge.rb', line 1263 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1265 1266 1267 |
# File 'lib/stripe/resources/charge.rb', line 1265 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1267 1268 1269 |
# File 'lib/stripe/resources/charge.rb', line 1267 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1269 1270 1271 |
# File 'lib/stripe/resources/charge.rb', line 1269 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1271 1272 1273 |
# File 'lib/stripe/resources/charge.rb', line 1271 def zip @zip end |