Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Sofort, StripeAccount, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1041 1042 1043 |
# File 'lib/stripe/resources/charge.rb', line 1041 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1043 1044 1045 |
# File 'lib/stripe/resources/charge.rb', line 1043 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1045 1046 1047 |
# File 'lib/stripe/resources/charge.rb', line 1045 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1047 1048 1049 |
# File 'lib/stripe/resources/charge.rb', line 1047 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1049 1050 1051 |
# File 'lib/stripe/resources/charge.rb', line 1049 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1051 1052 1053 |
# File 'lib/stripe/resources/charge.rb', line 1051 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1053 1054 1055 |
# File 'lib/stripe/resources/charge.rb', line 1053 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1055 1056 1057 |
# File 'lib/stripe/resources/charge.rb', line 1055 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1057 1058 1059 |
# File 'lib/stripe/resources/charge.rb', line 1057 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1059 1060 1061 |
# File 'lib/stripe/resources/charge.rb', line 1059 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1061 1062 1063 |
# File 'lib/stripe/resources/charge.rb', line 1061 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1063 1064 1065 |
# File 'lib/stripe/resources/charge.rb', line 1063 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
1065 1066 1067 |
# File 'lib/stripe/resources/charge.rb', line 1065 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1067 1068 1069 |
# File 'lib/stripe/resources/charge.rb', line 1067 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1069 1070 1071 |
# File 'lib/stripe/resources/charge.rb', line 1069 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1071 1072 1073 |
# File 'lib/stripe/resources/charge.rb', line 1071 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1073 1074 1075 |
# File 'lib/stripe/resources/charge.rb', line 1073 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1075 1076 1077 |
# File 'lib/stripe/resources/charge.rb', line 1075 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1077 1078 1079 |
# File 'lib/stripe/resources/charge.rb', line 1077 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1079 1080 1081 |
# File 'lib/stripe/resources/charge.rb', line 1079 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1081 1082 1083 |
# File 'lib/stripe/resources/charge.rb', line 1081 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1083 1084 1085 |
# File 'lib/stripe/resources/charge.rb', line 1083 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1085 1086 1087 |
# File 'lib/stripe/resources/charge.rb', line 1085 def grabpay @grabpay end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1087 1088 1089 |
# File 'lib/stripe/resources/charge.rb', line 1087 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1089 1090 1091 |
# File 'lib/stripe/resources/charge.rb', line 1089 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1091 1092 1093 |
# File 'lib/stripe/resources/charge.rb', line 1091 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1093 1094 1095 |
# File 'lib/stripe/resources/charge.rb', line 1093 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1095 1096 1097 |
# File 'lib/stripe/resources/charge.rb', line 1095 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1097 1098 1099 |
# File 'lib/stripe/resources/charge.rb', line 1097 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1099 1100 1101 |
# File 'lib/stripe/resources/charge.rb', line 1099 def link @link end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1101 1102 1103 |
# File 'lib/stripe/resources/charge.rb', line 1101 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1103 1104 1105 |
# File 'lib/stripe/resources/charge.rb', line 1103 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1105 1106 1107 |
# File 'lib/stripe/resources/charge.rb', line 1105 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1107 1108 1109 |
# File 'lib/stripe/resources/charge.rb', line 1107 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1109 1110 1111 |
# File 'lib/stripe/resources/charge.rb', line 1109 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1111 1112 1113 |
# File 'lib/stripe/resources/charge.rb', line 1111 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1113 1114 1115 |
# File 'lib/stripe/resources/charge.rb', line 1113 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1115 1116 1117 |
# File 'lib/stripe/resources/charge.rb', line 1115 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1117 1118 1119 |
# File 'lib/stripe/resources/charge.rb', line 1117 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1119 1120 1121 |
# File 'lib/stripe/resources/charge.rb', line 1119 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
1121 1122 1123 |
# File 'lib/stripe/resources/charge.rb', line 1121 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1123 1124 1125 |
# File 'lib/stripe/resources/charge.rb', line 1123 def promptpay @promptpay end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1125 1126 1127 |
# File 'lib/stripe/resources/charge.rb', line 1125 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1127 1128 1129 |
# File 'lib/stripe/resources/charge.rb', line 1127 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1129 1130 1131 |
# File 'lib/stripe/resources/charge.rb', line 1129 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1131 1132 1133 |
# File 'lib/stripe/resources/charge.rb', line 1131 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1133 1134 1135 |
# File 'lib/stripe/resources/charge.rb', line 1133 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1135 1136 1137 |
# File 'lib/stripe/resources/charge.rb', line 1135 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1137 1138 1139 |
# File 'lib/stripe/resources/charge.rb', line 1137 def stripe_account @stripe_account end |
#swish ⇒ Object (readonly)
Attribute for field swish
1139 1140 1141 |
# File 'lib/stripe/resources/charge.rb', line 1139 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1141 1142 1143 |
# File 'lib/stripe/resources/charge.rb', line 1141 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
1145 1146 1147 |
# File 'lib/stripe/resources/charge.rb', line 1145 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1147 1148 1149 |
# File 'lib/stripe/resources/charge.rb', line 1147 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1149 1150 1151 |
# File 'lib/stripe/resources/charge.rb', line 1149 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1151 1152 1153 |
# File 'lib/stripe/resources/charge.rb', line 1151 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1153 1154 1155 |
# File 'lib/stripe/resources/charge.rb', line 1153 def zip @zip end |