Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Sofort, StripeAccount, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1008 1009 1010 |
# File 'lib/stripe/resources/charge.rb', line 1008 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1010 1011 1012 |
# File 'lib/stripe/resources/charge.rb', line 1010 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1012 1013 1014 |
# File 'lib/stripe/resources/charge.rb', line 1012 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1014 1015 1016 |
# File 'lib/stripe/resources/charge.rb', line 1014 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1016 1017 1018 |
# File 'lib/stripe/resources/charge.rb', line 1016 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1018 1019 1020 |
# File 'lib/stripe/resources/charge.rb', line 1018 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1020 1021 1022 |
# File 'lib/stripe/resources/charge.rb', line 1020 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1022 1023 1024 |
# File 'lib/stripe/resources/charge.rb', line 1022 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1024 1025 1026 |
# File 'lib/stripe/resources/charge.rb', line 1024 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1026 1027 1028 |
# File 'lib/stripe/resources/charge.rb', line 1026 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1028 1029 1030 |
# File 'lib/stripe/resources/charge.rb', line 1028 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1030 1031 1032 |
# File 'lib/stripe/resources/charge.rb', line 1030 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
1032 1033 1034 |
# File 'lib/stripe/resources/charge.rb', line 1032 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1034 1035 1036 |
# File 'lib/stripe/resources/charge.rb', line 1034 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1036 1037 1038 |
# File 'lib/stripe/resources/charge.rb', line 1036 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1038 1039 1040 |
# File 'lib/stripe/resources/charge.rb', line 1038 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1040 1041 1042 |
# File 'lib/stripe/resources/charge.rb', line 1040 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1042 1043 1044 |
# File 'lib/stripe/resources/charge.rb', line 1042 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1044 1045 1046 |
# File 'lib/stripe/resources/charge.rb', line 1044 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1046 1047 1048 |
# File 'lib/stripe/resources/charge.rb', line 1046 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1048 1049 1050 |
# File 'lib/stripe/resources/charge.rb', line 1048 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1050 1051 1052 |
# File 'lib/stripe/resources/charge.rb', line 1050 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1052 1053 1054 |
# File 'lib/stripe/resources/charge.rb', line 1052 def grabpay @grabpay end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1054 1055 1056 |
# File 'lib/stripe/resources/charge.rb', line 1054 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1056 1057 1058 |
# File 'lib/stripe/resources/charge.rb', line 1056 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1058 1059 1060 |
# File 'lib/stripe/resources/charge.rb', line 1058 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1060 1061 1062 |
# File 'lib/stripe/resources/charge.rb', line 1060 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1062 1063 1064 |
# File 'lib/stripe/resources/charge.rb', line 1062 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1064 1065 1066 |
# File 'lib/stripe/resources/charge.rb', line 1064 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1066 1067 1068 |
# File 'lib/stripe/resources/charge.rb', line 1066 def link @link end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1068 1069 1070 |
# File 'lib/stripe/resources/charge.rb', line 1068 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1070 1071 1072 |
# File 'lib/stripe/resources/charge.rb', line 1070 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1072 1073 1074 |
# File 'lib/stripe/resources/charge.rb', line 1072 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1074 1075 1076 |
# File 'lib/stripe/resources/charge.rb', line 1074 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1076 1077 1078 |
# File 'lib/stripe/resources/charge.rb', line 1076 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1078 1079 1080 |
# File 'lib/stripe/resources/charge.rb', line 1078 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1080 1081 1082 |
# File 'lib/stripe/resources/charge.rb', line 1080 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1082 1083 1084 |
# File 'lib/stripe/resources/charge.rb', line 1082 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1084 1085 1086 |
# File 'lib/stripe/resources/charge.rb', line 1084 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1086 1087 1088 |
# File 'lib/stripe/resources/charge.rb', line 1086 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
1088 1089 1090 |
# File 'lib/stripe/resources/charge.rb', line 1088 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1090 1091 1092 |
# File 'lib/stripe/resources/charge.rb', line 1090 def promptpay @promptpay end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1092 1093 1094 |
# File 'lib/stripe/resources/charge.rb', line 1092 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1094 1095 1096 |
# File 'lib/stripe/resources/charge.rb', line 1094 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1096 1097 1098 |
# File 'lib/stripe/resources/charge.rb', line 1096 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1098 1099 1100 |
# File 'lib/stripe/resources/charge.rb', line 1098 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1100 1101 1102 |
# File 'lib/stripe/resources/charge.rb', line 1100 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1102 1103 1104 |
# File 'lib/stripe/resources/charge.rb', line 1102 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1104 1105 1106 |
# File 'lib/stripe/resources/charge.rb', line 1104 def stripe_account @stripe_account end |
#swish ⇒ Object (readonly)
Attribute for field swish
1106 1107 1108 |
# File 'lib/stripe/resources/charge.rb', line 1106 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1108 1109 1110 |
# File 'lib/stripe/resources/charge.rb', line 1108 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
1112 1113 1114 |
# File 'lib/stripe/resources/charge.rb', line 1112 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1114 1115 1116 |
# File 'lib/stripe/resources/charge.rb', line 1114 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1116 1117 1118 |
# File 'lib/stripe/resources/charge.rb', line 1116 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1118 1119 1120 |
# File 'lib/stripe/resources/charge.rb', line 1118 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1120 1121 1122 |
# File 'lib/stripe/resources/charge.rb', line 1120 def zip @zip end |