Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1110 1111 1112 |
# File 'lib/stripe/resources/charge.rb', line 1110 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1112 1113 1114 |
# File 'lib/stripe/resources/charge.rb', line 1112 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1114 1115 1116 |
# File 'lib/stripe/resources/charge.rb', line 1114 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1116 1117 1118 |
# File 'lib/stripe/resources/charge.rb', line 1116 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1118 1119 1120 |
# File 'lib/stripe/resources/charge.rb', line 1118 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1120 1121 1122 |
# File 'lib/stripe/resources/charge.rb', line 1120 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1122 1123 1124 |
# File 'lib/stripe/resources/charge.rb', line 1122 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1124 1125 1126 |
# File 'lib/stripe/resources/charge.rb', line 1124 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1126 1127 1128 |
# File 'lib/stripe/resources/charge.rb', line 1126 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1128 1129 1130 |
# File 'lib/stripe/resources/charge.rb', line 1128 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1130 1131 1132 |
# File 'lib/stripe/resources/charge.rb', line 1130 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1132 1133 1134 |
# File 'lib/stripe/resources/charge.rb', line 1132 def billie @billie end |
#blik ⇒ Object (readonly)
Attribute for field blik
1134 1135 1136 |
# File 'lib/stripe/resources/charge.rb', line 1134 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1136 1137 1138 |
# File 'lib/stripe/resources/charge.rb', line 1136 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1138 1139 1140 |
# File 'lib/stripe/resources/charge.rb', line 1138 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1140 1141 1142 |
# File 'lib/stripe/resources/charge.rb', line 1140 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1142 1143 1144 |
# File 'lib/stripe/resources/charge.rb', line 1142 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1144 1145 1146 |
# File 'lib/stripe/resources/charge.rb', line 1144 def crypto @crypto end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1146 1147 1148 |
# File 'lib/stripe/resources/charge.rb', line 1146 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1148 1149 1150 |
# File 'lib/stripe/resources/charge.rb', line 1148 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1150 1151 1152 |
# File 'lib/stripe/resources/charge.rb', line 1150 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1152 1153 1154 |
# File 'lib/stripe/resources/charge.rb', line 1152 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1154 1155 1156 |
# File 'lib/stripe/resources/charge.rb', line 1154 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1156 1157 1158 |
# File 'lib/stripe/resources/charge.rb', line 1156 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1158 1159 1160 |
# File 'lib/stripe/resources/charge.rb', line 1158 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1160 1161 1162 |
# File 'lib/stripe/resources/charge.rb', line 1160 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1162 1163 1164 |
# File 'lib/stripe/resources/charge.rb', line 1162 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1164 1165 1166 |
# File 'lib/stripe/resources/charge.rb', line 1164 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1166 1167 1168 |
# File 'lib/stripe/resources/charge.rb', line 1166 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1168 1169 1170 |
# File 'lib/stripe/resources/charge.rb', line 1168 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1170 1171 1172 |
# File 'lib/stripe/resources/charge.rb', line 1170 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1172 1173 1174 |
# File 'lib/stripe/resources/charge.rb', line 1172 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1174 1175 1176 |
# File 'lib/stripe/resources/charge.rb', line 1174 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1176 1177 1178 |
# File 'lib/stripe/resources/charge.rb', line 1176 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1178 1179 1180 |
# File 'lib/stripe/resources/charge.rb', line 1178 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1180 1181 1182 |
# File 'lib/stripe/resources/charge.rb', line 1180 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1182 1183 1184 |
# File 'lib/stripe/resources/charge.rb', line 1182 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1184 1185 1186 |
# File 'lib/stripe/resources/charge.rb', line 1184 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1186 1187 1188 |
# File 'lib/stripe/resources/charge.rb', line 1186 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1188 1189 1190 |
# File 'lib/stripe/resources/charge.rb', line 1188 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1190 1191 1192 |
# File 'lib/stripe/resources/charge.rb', line 1190 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1192 1193 1194 |
# File 'lib/stripe/resources/charge.rb', line 1192 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1194 1195 1196 |
# File 'lib/stripe/resources/charge.rb', line 1194 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1196 1197 1198 |
# File 'lib/stripe/resources/charge.rb', line 1196 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1198 1199 1200 |
# File 'lib/stripe/resources/charge.rb', line 1198 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1200 1201 1202 |
# File 'lib/stripe/resources/charge.rb', line 1200 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1202 1203 1204 |
# File 'lib/stripe/resources/charge.rb', line 1202 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1204 1205 1206 |
# File 'lib/stripe/resources/charge.rb', line 1204 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1206 1207 1208 |
# File 'lib/stripe/resources/charge.rb', line 1206 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1208 1209 1210 |
# File 'lib/stripe/resources/charge.rb', line 1208 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1210 1211 1212 |
# File 'lib/stripe/resources/charge.rb', line 1210 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1212 1213 1214 |
# File 'lib/stripe/resources/charge.rb', line 1212 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1214 1215 1216 |
# File 'lib/stripe/resources/charge.rb', line 1214 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1216 1217 1218 |
# File 'lib/stripe/resources/charge.rb', line 1216 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1218 1219 1220 |
# File 'lib/stripe/resources/charge.rb', line 1218 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1220 1221 1222 |
# File 'lib/stripe/resources/charge.rb', line 1220 def stripe_account @stripe_account end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
1222 1223 1224 |
# File 'lib/stripe/resources/charge.rb', line 1222 def stripe_balance @stripe_balance end |
#swish ⇒ Object (readonly)
Attribute for field swish
1224 1225 1226 |
# File 'lib/stripe/resources/charge.rb', line 1224 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1226 1227 1228 |
# File 'lib/stripe/resources/charge.rb', line 1226 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
1230 1231 1232 |
# File 'lib/stripe/resources/charge.rb', line 1230 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1232 1233 1234 |
# File 'lib/stripe/resources/charge.rb', line 1232 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1234 1235 1236 |
# File 'lib/stripe/resources/charge.rb', line 1234 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1236 1237 1238 |
# File 'lib/stripe/resources/charge.rb', line 1236 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1238 1239 1240 |
# File 'lib/stripe/resources/charge.rb', line 1238 def zip @zip end |