Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment, one of ‘ach_credit_transfer`, `ach_debit`, `acss_debit`, `alipay`, `au_becs_debit`, `bancontact`, `card`, `card_present`, `eps`, `giropay`, `ideal`, `klarna`, `multibanco`, `p24`, `sepa_debit`, `sofort`, `stripe_account`, or `wechat`.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1063 1064 1065 |
# File 'lib/stripe/resources/charge.rb', line 1063 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1065 1066 1067 |
# File 'lib/stripe/resources/charge.rb', line 1065 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1067 1068 1069 |
# File 'lib/stripe/resources/charge.rb', line 1067 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1069 1070 1071 |
# File 'lib/stripe/resources/charge.rb', line 1069 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1071 1072 1073 |
# File 'lib/stripe/resources/charge.rb', line 1071 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1073 1074 1075 |
# File 'lib/stripe/resources/charge.rb', line 1073 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1075 1076 1077 |
# File 'lib/stripe/resources/charge.rb', line 1075 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1077 1078 1079 |
# File 'lib/stripe/resources/charge.rb', line 1077 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1079 1080 1081 |
# File 'lib/stripe/resources/charge.rb', line 1079 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1081 1082 1083 |
# File 'lib/stripe/resources/charge.rb', line 1081 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1083 1084 1085 |
# File 'lib/stripe/resources/charge.rb', line 1083 def bancontact @bancontact end |
#blik ⇒ Object (readonly)
Attribute for field blik
1085 1086 1087 |
# File 'lib/stripe/resources/charge.rb', line 1085 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1087 1088 1089 |
# File 'lib/stripe/resources/charge.rb', line 1087 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1089 1090 1091 |
# File 'lib/stripe/resources/charge.rb', line 1089 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1091 1092 1093 |
# File 'lib/stripe/resources/charge.rb', line 1091 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1093 1094 1095 |
# File 'lib/stripe/resources/charge.rb', line 1093 def cashapp @cashapp end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1095 1096 1097 |
# File 'lib/stripe/resources/charge.rb', line 1095 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1097 1098 1099 |
# File 'lib/stripe/resources/charge.rb', line 1097 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1099 1100 1101 |
# File 'lib/stripe/resources/charge.rb', line 1099 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1101 1102 1103 |
# File 'lib/stripe/resources/charge.rb', line 1101 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1103 1104 1105 |
# File 'lib/stripe/resources/charge.rb', line 1103 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1105 1106 1107 |
# File 'lib/stripe/resources/charge.rb', line 1105 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1107 1108 1109 |
# File 'lib/stripe/resources/charge.rb', line 1107 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1109 1110 1111 |
# File 'lib/stripe/resources/charge.rb', line 1109 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1111 1112 1113 |
# File 'lib/stripe/resources/charge.rb', line 1111 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1113 1114 1115 |
# File 'lib/stripe/resources/charge.rb', line 1113 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1115 1116 1117 |
# File 'lib/stripe/resources/charge.rb', line 1115 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1117 1118 1119 |
# File 'lib/stripe/resources/charge.rb', line 1117 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1119 1120 1121 |
# File 'lib/stripe/resources/charge.rb', line 1119 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1121 1122 1123 |
# File 'lib/stripe/resources/charge.rb', line 1121 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1123 1124 1125 |
# File 'lib/stripe/resources/charge.rb', line 1123 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1125 1126 1127 |
# File 'lib/stripe/resources/charge.rb', line 1125 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1127 1128 1129 |
# File 'lib/stripe/resources/charge.rb', line 1127 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1129 1130 1131 |
# File 'lib/stripe/resources/charge.rb', line 1129 def naver_pay @naver_pay end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1131 1132 1133 |
# File 'lib/stripe/resources/charge.rb', line 1131 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1133 1134 1135 |
# File 'lib/stripe/resources/charge.rb', line 1133 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1135 1136 1137 |
# File 'lib/stripe/resources/charge.rb', line 1135 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1137 1138 1139 |
# File 'lib/stripe/resources/charge.rb', line 1137 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1139 1140 1141 |
# File 'lib/stripe/resources/charge.rb', line 1139 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1141 1142 1143 |
# File 'lib/stripe/resources/charge.rb', line 1141 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1143 1144 1145 |
# File 'lib/stripe/resources/charge.rb', line 1143 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1145 1146 1147 |
# File 'lib/stripe/resources/charge.rb', line 1145 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1147 1148 1149 |
# File 'lib/stripe/resources/charge.rb', line 1147 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1149 1150 1151 |
# File 'lib/stripe/resources/charge.rb', line 1149 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1151 1152 1153 |
# File 'lib/stripe/resources/charge.rb', line 1151 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1153 1154 1155 |
# File 'lib/stripe/resources/charge.rb', line 1153 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1155 1156 1157 |
# File 'lib/stripe/resources/charge.rb', line 1155 def samsung_pay @samsung_pay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1157 1158 1159 |
# File 'lib/stripe/resources/charge.rb', line 1157 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1159 1160 1161 |
# File 'lib/stripe/resources/charge.rb', line 1159 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1161 1162 1163 |
# File 'lib/stripe/resources/charge.rb', line 1161 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1163 1164 1165 |
# File 'lib/stripe/resources/charge.rb', line 1163 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1165 1166 1167 |
# File 'lib/stripe/resources/charge.rb', line 1165 def stripe_account @stripe_account end |
#swish ⇒ Object (readonly)
Attribute for field swish
1167 1168 1169 |
# File 'lib/stripe/resources/charge.rb', line 1167 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1169 1170 1171 |
# File 'lib/stripe/resources/charge.rb', line 1169 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment, one of ‘ach_credit_transfer`, `ach_debit`, `acss_debit`, `alipay`, `au_becs_debit`, `bancontact`, `card`, `card_present`, `eps`, `giropay`, `ideal`, `klarna`, `multibanco`, `p24`, `sepa_debit`, `sofort`, `stripe_account`, or `wechat`. An additional hash is included on `payment_method_details` with a name matching this value. It contains information specific to the payment method.
1173 1174 1175 |
# File 'lib/stripe/resources/charge.rb', line 1173 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1175 1176 1177 |
# File 'lib/stripe/resources/charge.rb', line 1175 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1177 1178 1179 |
# File 'lib/stripe/resources/charge.rb', line 1177 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1179 1180 1181 |
# File 'lib/stripe/resources/charge.rb', line 1179 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1181 1182 1183 |
# File 'lib/stripe/resources/charge.rb', line 1181 def zip @zip end |