Class: Stripe::Charge::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment, one of ‘ach_credit_transfer`, `ach_debit`, `acss_debit`, `alipay`, `au_becs_debit`, `bancontact`, `card`, `card_present`, `eps`, `giropay`, `ideal`, `klarna`, `multibanco`, `p24`, `sepa_debit`, `sofort`, `stripe_account`, or `wechat`.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1330 1331 1332 |
# File 'lib/stripe/resources/charge.rb', line 1330 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1333 1334 1335 |
# File 'lib/stripe/resources/charge.rb', line 1333 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1336 1337 1338 |
# File 'lib/stripe/resources/charge.rb', line 1336 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1339 1340 1341 |
# File 'lib/stripe/resources/charge.rb', line 1339 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1342 1343 1344 |
# File 'lib/stripe/resources/charge.rb', line 1342 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1345 1346 1347 |
# File 'lib/stripe/resources/charge.rb', line 1345 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1348 1349 1350 |
# File 'lib/stripe/resources/charge.rb', line 1348 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1351 1352 1353 |
# File 'lib/stripe/resources/charge.rb', line 1351 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1354 1355 1356 |
# File 'lib/stripe/resources/charge.rb', line 1354 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1357 1358 1359 |
# File 'lib/stripe/resources/charge.rb', line 1357 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1360 1361 1362 |
# File 'lib/stripe/resources/charge.rb', line 1360 def bancontact @bancontact end |
#blik ⇒ Object (readonly)
Attribute for field blik
1363 1364 1365 |
# File 'lib/stripe/resources/charge.rb', line 1363 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1366 1367 1368 |
# File 'lib/stripe/resources/charge.rb', line 1366 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1369 1370 1371 |
# File 'lib/stripe/resources/charge.rb', line 1369 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1372 1373 1374 |
# File 'lib/stripe/resources/charge.rb', line 1372 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1375 1376 1377 |
# File 'lib/stripe/resources/charge.rb', line 1375 def cashapp @cashapp end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1378 1379 1380 |
# File 'lib/stripe/resources/charge.rb', line 1378 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1381 1382 1383 |
# File 'lib/stripe/resources/charge.rb', line 1381 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1384 1385 1386 |
# File 'lib/stripe/resources/charge.rb', line 1384 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1387 1388 1389 |
# File 'lib/stripe/resources/charge.rb', line 1387 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1390 1391 1392 |
# File 'lib/stripe/resources/charge.rb', line 1390 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1393 1394 1395 |
# File 'lib/stripe/resources/charge.rb', line 1393 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1396 1397 1398 |
# File 'lib/stripe/resources/charge.rb', line 1396 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1399 1400 1401 |
# File 'lib/stripe/resources/charge.rb', line 1399 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1402 1403 1404 |
# File 'lib/stripe/resources/charge.rb', line 1402 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1405 1406 1407 |
# File 'lib/stripe/resources/charge.rb', line 1405 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1408 1409 1410 |
# File 'lib/stripe/resources/charge.rb', line 1408 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1411 1412 1413 |
# File 'lib/stripe/resources/charge.rb', line 1411 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1414 1415 1416 |
# File 'lib/stripe/resources/charge.rb', line 1414 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1417 1418 1419 |
# File 'lib/stripe/resources/charge.rb', line 1417 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1420 1421 1422 |
# File 'lib/stripe/resources/charge.rb', line 1420 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1423 1424 1425 |
# File 'lib/stripe/resources/charge.rb', line 1423 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1426 1427 1428 |
# File 'lib/stripe/resources/charge.rb', line 1426 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1429 1430 1431 |
# File 'lib/stripe/resources/charge.rb', line 1429 def naver_pay @naver_pay end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1432 1433 1434 |
# File 'lib/stripe/resources/charge.rb', line 1432 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1435 1436 1437 |
# File 'lib/stripe/resources/charge.rb', line 1435 def p24 @p24 end |
#payco ⇒ Object (readonly)
Attribute for field payco
1438 1439 1440 |
# File 'lib/stripe/resources/charge.rb', line 1438 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1441 1442 1443 |
# File 'lib/stripe/resources/charge.rb', line 1441 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1444 1445 1446 |
# File 'lib/stripe/resources/charge.rb', line 1444 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1447 1448 1449 |
# File 'lib/stripe/resources/charge.rb', line 1447 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1450 1451 1452 |
# File 'lib/stripe/resources/charge.rb', line 1450 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1453 1454 1455 |
# File 'lib/stripe/resources/charge.rb', line 1453 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1456 1457 1458 |
# File 'lib/stripe/resources/charge.rb', line 1456 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1459 1460 1461 |
# File 'lib/stripe/resources/charge.rb', line 1459 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1462 1463 1464 |
# File 'lib/stripe/resources/charge.rb', line 1462 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1465 1466 1467 |
# File 'lib/stripe/resources/charge.rb', line 1465 def samsung_pay @samsung_pay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1468 1469 1470 |
# File 'lib/stripe/resources/charge.rb', line 1468 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1471 1472 1473 |
# File 'lib/stripe/resources/charge.rb', line 1471 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1474 1475 1476 |
# File 'lib/stripe/resources/charge.rb', line 1474 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1477 1478 1479 |
# File 'lib/stripe/resources/charge.rb', line 1477 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1480 1481 1482 |
# File 'lib/stripe/resources/charge.rb', line 1480 def stripe_account @stripe_account end |
#swish ⇒ Object (readonly)
Attribute for field swish
1483 1484 1485 |
# File 'lib/stripe/resources/charge.rb', line 1483 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1486 1487 1488 |
# File 'lib/stripe/resources/charge.rb', line 1486 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment, one of ‘ach_credit_transfer`, `ach_debit`, `acss_debit`, `alipay`, `au_becs_debit`, `bancontact`, `card`, `card_present`, `eps`, `giropay`, `ideal`, `klarna`, `multibanco`, `p24`, `sepa_debit`, `sofort`, `stripe_account`, or `wechat`. An additional hash is included on `payment_method_details` with a name matching this value. It contains information specific to the payment method.
1491 1492 1493 |
# File 'lib/stripe/resources/charge.rb', line 1491 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1494 1495 1496 |
# File 'lib/stripe/resources/charge.rb', line 1494 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1497 1498 1499 |
# File 'lib/stripe/resources/charge.rb', line 1497 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1500 1501 1502 |
# File 'lib/stripe/resources/charge.rb', line 1500 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1503 1504 1505 |
# File 'lib/stripe/resources/charge.rb', line 1503 def zip @zip end |