Class: Stripe::Charge::PaymentMethodDetails::AchCreditTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::AchCreditTransfer
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number to transfer funds to.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the routing number.
-
#routing_number ⇒ Object
readonly
Routing transit number for the bank account to transfer funds to.
-
#swift_code ⇒ Object
readonly
SWIFT code of the bank associated with the routing number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number to transfer funds to.
176 177 178 |
# File 'lib/stripe/resources/charge.rb', line 176 def account_number @account_number end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the routing number.
178 179 180 |
# File 'lib/stripe/resources/charge.rb', line 178 def bank_name @bank_name end |
#routing_number ⇒ Object (readonly)
Routing transit number for the bank account to transfer funds to.
180 181 182 |
# File 'lib/stripe/resources/charge.rb', line 180 def routing_number @routing_number end |
#swift_code ⇒ Object (readonly)
SWIFT code of the bank associated with the routing number.
182 183 184 |
# File 'lib/stripe/resources/charge.rb', line 182 def swift_code @swift_code end |
Class Method Details
.field_remappings ⇒ Object
188 189 190 |
# File 'lib/stripe/resources/charge.rb', line 188 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
184 185 186 |
# File 'lib/stripe/resources/charge.rb', line 184 def self.inner_class_types @inner_class_types = {} end |