Class: Stripe::Charge::PaymentMethodDetails::AchCreditTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::AchCreditTransfer
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number to transfer funds to.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the routing number.
-
#routing_number ⇒ Object
readonly
Routing transit number for the bank account to transfer funds to.
-
#swift_code ⇒ Object
readonly
SWIFT code of the bank associated with the routing number.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number to transfer funds to.
145 146 147 |
# File 'lib/stripe/resources/charge.rb', line 145 def account_number @account_number end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the routing number.
148 149 150 |
# File 'lib/stripe/resources/charge.rb', line 148 def bank_name @bank_name end |
#routing_number ⇒ Object (readonly)
Routing transit number for the bank account to transfer funds to.
151 152 153 |
# File 'lib/stripe/resources/charge.rb', line 151 def routing_number @routing_number end |
#swift_code ⇒ Object (readonly)
SWIFT code of the bank associated with the routing number.
154 155 156 |
# File 'lib/stripe/resources/charge.rb', line 154 def swift_code @swift_code end |