Class: Stripe::Charge::PaymentMethodDetails::AchDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Type of entity that holds the account. This can be either ‘individual` or `company`.



159
160
161
# File 'lib/stripe/resources/charge.rb', line 159

def 
  @account_holder_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



162
163
164
# File 'lib/stripe/resources/charge.rb', line 162

def bank_name
  @bank_name
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



165
166
167
# File 'lib/stripe/resources/charge.rb', line 165

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



168
169
170
# File 'lib/stripe/resources/charge.rb', line 168

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



171
172
173
# File 'lib/stripe/resources/charge.rb', line 171

def last4
  @last4
end

#routing_numberObject (readonly)

Routing transit number of the bank account.



174
175
176
# File 'lib/stripe/resources/charge.rb', line 174

def routing_number
  @routing_number
end