Class: Stripe::Charge::PaymentMethodDetails::AcssDebit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::AcssDebit
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#institution_number ⇒ Object
readonly
Institution number of the bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#transit_number ⇒ Object
readonly
Transit number of the bank account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
146 147 148 |
# File 'lib/stripe/resources/charge.rb', line 146 def bank_name @bank_name end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
148 149 150 |
# File 'lib/stripe/resources/charge.rb', line 148 def fingerprint @fingerprint end |
#institution_number ⇒ Object (readonly)
Institution number of the bank account
150 151 152 |
# File 'lib/stripe/resources/charge.rb', line 150 def institution_number @institution_number end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
152 153 154 |
# File 'lib/stripe/resources/charge.rb', line 152 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
154 155 156 |
# File 'lib/stripe/resources/charge.rb', line 154 def mandate @mandate end |
#transit_number ⇒ Object (readonly)
Transit number of the bank account.
156 157 158 |
# File 'lib/stripe/resources/charge.rb', line 156 def transit_number @transit_number end |