Class: Stripe::Charge::PaymentMethodDetails::BacsDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



270
271
272
# File 'lib/stripe/resources/charge.rb', line 270

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



273
274
275
# File 'lib/stripe/resources/charge.rb', line 273

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



276
277
278
# File 'lib/stripe/resources/charge.rb', line 276

def mandate
  @mandate
end

#sort_codeObject (readonly)

Sort code of the bank account. (e.g., ‘10-20-30`)



279
280
281
# File 'lib/stripe/resources/charge.rb', line 279

def sort_code
  @sort_code
end