Class: Stripe::Charge::PaymentMethodDetails::Bancontact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Bancontact
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#generated_sepa_debit ⇒ Object
readonly
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#generated_sepa_debit_mandate ⇒ Object
readonly
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#iban_last4 ⇒ Object
readonly
Last four characters of the IBAN.
-
#preferred_language ⇒ Object
readonly
Preferred language of the Bancontact authorization page that the customer is redirected to.
-
#verified_name ⇒ Object
readonly
Owner’s verified full name.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
408 409 410 |
# File 'lib/stripe/resources/charge.rb', line 408 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
410 411 412 |
# File 'lib/stripe/resources/charge.rb', line 410 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
412 413 414 |
# File 'lib/stripe/resources/charge.rb', line 412 def bic @bic end |
#generated_sepa_debit ⇒ Object (readonly)
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
414 415 416 |
# File 'lib/stripe/resources/charge.rb', line 414 def generated_sepa_debit @generated_sepa_debit end |
#generated_sepa_debit_mandate ⇒ Object (readonly)
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
416 417 418 |
# File 'lib/stripe/resources/charge.rb', line 416 def generated_sepa_debit_mandate @generated_sepa_debit_mandate end |
#iban_last4 ⇒ Object (readonly)
Last four characters of the IBAN.
418 419 420 |
# File 'lib/stripe/resources/charge.rb', line 418 def iban_last4 @iban_last4 end |
#preferred_language ⇒ Object (readonly)
Preferred language of the Bancontact authorization page that the customer is redirected to. Can be one of ‘en`, `de`, `fr`, or `nl`
421 422 423 |
# File 'lib/stripe/resources/charge.rb', line 421 def preferred_language @preferred_language end |
#verified_name ⇒ Object (readonly)
Owner’s verified full name. Values are verified or provided by Bancontact directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
424 425 426 |
# File 'lib/stripe/resources/charge.rb', line 424 def verified_name @verified_name end |
Class Method Details
.field_remappings ⇒ Object
430 431 432 |
# File 'lib/stripe/resources/charge.rb', line 430 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
426 427 428 |
# File 'lib/stripe/resources/charge.rb', line 426 def self.inner_class_types @inner_class_types = {} end |