Class: Stripe::Charge::PaymentMethodDetails::Bancontact

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



229
230
231
# File 'lib/stripe/resources/charge.rb', line 229

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



231
232
233
# File 'lib/stripe/resources/charge.rb', line 231

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



233
234
235
# File 'lib/stripe/resources/charge.rb', line 233

def bic
  @bic
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



235
236
237
# File 'lib/stripe/resources/charge.rb', line 235

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



237
238
239
# File 'lib/stripe/resources/charge.rb', line 237

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



239
240
241
# File 'lib/stripe/resources/charge.rb', line 239

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the Bancontact authorization page that the customer is redirected to. Can be one of ‘en`, `de`, `fr`, or `nl`



242
243
244
# File 'lib/stripe/resources/charge.rb', line 242

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by Bancontact directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



245
246
247
# File 'lib/stripe/resources/charge.rb', line 245

def verified_name
  @verified_name
end