Class: Stripe::Charge::PaymentMethodDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Checks, DecrementalAuthorization, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, PartialAuthorization, ThreeDSecure, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount.



890
891
892
# File 'lib/stripe/resources/charge.rb', line 890

def amount_authorized
  @amount_authorized
end

#amount_requestedObject (readonly)

The latest amount intended to be authorized by this charge.



892
893
894
# File 'lib/stripe/resources/charge.rb', line 892

def amount_requested
  @amount_requested
end

#authorization_codeObject (readonly)

Authorization code on the charge.



894
895
896
# File 'lib/stripe/resources/charge.rb', line 894

def authorization_code
  @authorization_code
end

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



896
897
898
# File 'lib/stripe/resources/charge.rb', line 896

def brand
  @brand
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.



898
899
900
# File 'lib/stripe/resources/charge.rb', line 898

def capture_before
  @capture_before
end

#checksObject (readonly)

Check results by Card networks on Card address and CVC at time of payment.



900
901
902
# File 'lib/stripe/resources/charge.rb', line 900

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



902
903
904
# File 'lib/stripe/resources/charge.rb', line 902

def country
  @country
end

#decremental_authorizationObject (readonly)

Attribute for field decremental_authorization



904
905
906
# File 'lib/stripe/resources/charge.rb', line 904

def decremental_authorization
  @decremental_authorization
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



906
907
908
# File 'lib/stripe/resources/charge.rb', line 906

def description
  @description
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



908
909
910
# File 'lib/stripe/resources/charge.rb', line 908

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



910
911
912
# File 'lib/stripe/resources/charge.rb', line 910

def exp_year
  @exp_year
end

#extended_authorizationObject (readonly)

Attribute for field extended_authorization



912
913
914
# File 'lib/stripe/resources/charge.rb', line 912

def extended_authorization
  @extended_authorization
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.



916
917
918
# File 'lib/stripe/resources/charge.rb', line 916

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



918
919
920
# File 'lib/stripe/resources/charge.rb', line 918

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



920
921
922
# File 'lib/stripe/resources/charge.rb', line 920

def iin
  @iin
end

#incremental_authorizationObject (readonly)

Attribute for field incremental_authorization



922
923
924
# File 'lib/stripe/resources/charge.rb', line 922

def incremental_authorization
  @incremental_authorization
end

#installmentsObject (readonly)

Installment details for this payment.

For more information, see the installments integration guide.



926
927
928
# File 'lib/stripe/resources/charge.rb', line 926

def installments
  @installments
end

#issuerObject (readonly)

The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)



928
929
930
# File 'lib/stripe/resources/charge.rb', line 928

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



930
931
932
# File 'lib/stripe/resources/charge.rb', line 930

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment or created by it.



932
933
934
# File 'lib/stripe/resources/charge.rb', line 932

def mandate
  @mandate
end

#motoObject (readonly)

True if this payment was marked as MOTO and out of scope for SCA.



934
935
936
# File 'lib/stripe/resources/charge.rb', line 934

def moto
  @moto
end

#multicaptureObject (readonly)

Attribute for field multicapture



936
937
938
# File 'lib/stripe/resources/charge.rb', line 936

def multicapture
  @multicapture
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.



938
939
940
# File 'lib/stripe/resources/charge.rb', line 938

def network
  @network
end

#network_tokenObject (readonly)

If this card has network token credentials, this contains the details of the network token credentials.



940
941
942
# File 'lib/stripe/resources/charge.rb', line 940

def network_token
  @network_token
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



942
943
944
# File 'lib/stripe/resources/charge.rb', line 942

def network_transaction_id
  @network_transaction_id
end

#overcaptureObject (readonly)

Attribute for field overcapture



944
945
946
# File 'lib/stripe/resources/charge.rb', line 944

def overcapture
  @overcapture
end

#partial_authorizationObject (readonly)

Attribute for field partial_authorization



946
947
948
# File 'lib/stripe/resources/charge.rb', line 946

def partial_authorization
  @partial_authorization
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



948
949
950
# File 'lib/stripe/resources/charge.rb', line 948

def regulated_status
  @regulated_status
end

#three_d_secureObject (readonly)

Populated if this transaction used 3D Secure authentication.



950
951
952
# File 'lib/stripe/resources/charge.rb', line 950

def three_d_secure
  @three_d_secure
end

Transaction Link ID (TLID) is a unique identifier for a transaction. This is used by some card networks, such as Mastercard, for transaction linking, in addition to Network Transaction IDs. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



952
953
954
# File 'lib/stripe/resources/charge.rb', line 952

def transaction_link_id
  @transaction_link_id
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



954
955
956
# File 'lib/stripe/resources/charge.rb', line 954

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



972
973
974
# File 'lib/stripe/resources/charge.rb', line 972

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
# File 'lib/stripe/resources/charge.rb', line 956

def self.inner_class_types
  @inner_class_types = {
    checks: Checks,
    decremental_authorization: DecrementalAuthorization,
    extended_authorization: ExtendedAuthorization,
    incremental_authorization: IncrementalAuthorization,
    installments: Installments,
    multicapture: Multicapture,
    network_token: NetworkToken,
    overcapture: Overcapture,
    partial_authorization: PartialAuthorization,
    three_d_secure: ThreeDSecure,
    wallet: Wallet,
  }
end