Class: Stripe::Charge::PaymentMethodDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AccountFunding, Benefits, Checks, DecrementalAuthorization, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, PartialAuthorization, Reauthorization, ThreeDSecure, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_fundingObject (readonly)

Attribute for field account_funding



940
941
942
# File 'lib/stripe/resources/charge.rb', line 940

def 
  @account_funding
end

#amount_authorizedObject (readonly)

The authorized amount.



942
943
944
# File 'lib/stripe/resources/charge.rb', line 942

def amount_authorized
  @amount_authorized
end

#amount_requestedObject (readonly)

The latest amount intended to be authorized by this charge.



944
945
946
# File 'lib/stripe/resources/charge.rb', line 944

def amount_requested
  @amount_requested
end

#authorization_codeObject (readonly)

Authorization code on the charge.



946
947
948
# File 'lib/stripe/resources/charge.rb', line 946

def authorization_code
  @authorization_code
end

#benefitsObject (readonly)

Attribute for field benefits



948
949
950
# File 'lib/stripe/resources/charge.rb', line 948

def benefits
  @benefits
end

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



950
951
952
# File 'lib/stripe/resources/charge.rb', line 950

def brand
  @brand
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.



952
953
954
# File 'lib/stripe/resources/charge.rb', line 952

def capture_before
  @capture_before
end

#checksObject (readonly)

Check results by Card networks on Card address and CVC at time of payment.



954
955
956
# File 'lib/stripe/resources/charge.rb', line 954

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



956
957
958
# File 'lib/stripe/resources/charge.rb', line 956

def country
  @country
end

#decremental_authorizationObject (readonly)

Attribute for field decremental_authorization



958
959
960
# File 'lib/stripe/resources/charge.rb', line 958

def decremental_authorization
  @decremental_authorization
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



960
961
962
# File 'lib/stripe/resources/charge.rb', line 960

def description
  @description
end

#electronic_commerce_indicatorObject (readonly)

The Electronic Commerce Indicator (ECI) returned by the card network in the authorization response. Indicates the level of authentication used. Only populated for Visa and Mastercard transactions. The response value is the source of truth; it may differ from the request value if the network downgraded the transaction.



962
963
964
# File 'lib/stripe/resources/charge.rb', line 962

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



964
965
966
# File 'lib/stripe/resources/charge.rb', line 964

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



966
967
968
# File 'lib/stripe/resources/charge.rb', line 966

def exp_year
  @exp_year
end

#extended_authorizationObject (readonly)

Attribute for field extended_authorization



968
969
970
# File 'lib/stripe/resources/charge.rb', line 968

def extended_authorization
  @extended_authorization
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.



972
973
974
# File 'lib/stripe/resources/charge.rb', line 972

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



974
975
976
# File 'lib/stripe/resources/charge.rb', line 974

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



976
977
978
# File 'lib/stripe/resources/charge.rb', line 976

def iin
  @iin
end

#incremental_authorizationObject (readonly)

Attribute for field incremental_authorization



978
979
980
# File 'lib/stripe/resources/charge.rb', line 978

def incremental_authorization
  @incremental_authorization
end

#installmentsObject (readonly)

Installment details for this payment.

For more information, see the installments integration guide.



982
983
984
# File 'lib/stripe/resources/charge.rb', line 982

def installments
  @installments
end

#issuerObject (readonly)

The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)



984
985
986
# File 'lib/stripe/resources/charge.rb', line 984

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



986
987
988
# File 'lib/stripe/resources/charge.rb', line 986

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment or created by it.



988
989
990
# File 'lib/stripe/resources/charge.rb', line 988

def mandate
  @mandate
end

#motoObject (readonly)

True if this payment was marked as MOTO and out of scope for SCA.



990
991
992
# File 'lib/stripe/resources/charge.rb', line 990

def moto
  @moto
end

#multicaptureObject (readonly)

Attribute for field multicapture



992
993
994
# File 'lib/stripe/resources/charge.rb', line 992

def multicapture
  @multicapture
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.



994
995
996
# File 'lib/stripe/resources/charge.rb', line 994

def network
  @network
end

#network_tokenObject (readonly)

If this card has network token credentials, this contains the details of the network token credentials.



996
997
998
# File 'lib/stripe/resources/charge.rb', line 996

def network_token
  @network_token
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



998
999
1000
# File 'lib/stripe/resources/charge.rb', line 998

def network_transaction_id
  @network_transaction_id
end

#overcaptureObject (readonly)

Attribute for field overcapture



1000
1001
1002
# File 'lib/stripe/resources/charge.rb', line 1000

def overcapture
  @overcapture
end

#partial_authorizationObject (readonly)

Attribute for field partial_authorization



1002
1003
1004
# File 'lib/stripe/resources/charge.rb', line 1002

def partial_authorization
  @partial_authorization
end

#reauthorizationObject (readonly)

Whether the PaymentIntent can be reauthorized or not.



1004
1005
1006
# File 'lib/stripe/resources/charge.rb', line 1004

def reauthorization
  @reauthorization
end

#reauthorize_beforeObject (readonly)

The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.



1006
1007
1008
# File 'lib/stripe/resources/charge.rb', line 1006

def reauthorize_before
  @reauthorize_before
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



1008
1009
1010
# File 'lib/stripe/resources/charge.rb', line 1008

def regulated_status
  @regulated_status
end

#three_d_secureObject (readonly)

Populated if this transaction used 3D Secure authentication.



1010
1011
1012
# File 'lib/stripe/resources/charge.rb', line 1010

def three_d_secure
  @three_d_secure
end

Transaction Link ID (TLID) is a unique identifier for a transaction. This is used by some card networks, such as Mastercard, for transaction linking, in addition to Network Transaction IDs. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



1012
1013
1014
# File 'lib/stripe/resources/charge.rb', line 1012

def transaction_link_id
  @transaction_link_id
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



1014
1015
1016
# File 'lib/stripe/resources/charge.rb', line 1014

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



1035
1036
1037
# File 'lib/stripe/resources/charge.rb', line 1035

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
# File 'lib/stripe/resources/charge.rb', line 1016

def self.inner_class_types
  @inner_class_types = {
    account_funding: AccountFunding,
    benefits: Benefits,
    checks: Checks,
    decremental_authorization: DecrementalAuthorization,
    extended_authorization: ExtendedAuthorization,
    incremental_authorization: IncrementalAuthorization,
    installments: Installments,
    multicapture: Multicapture,
    network_token: NetworkToken,
    overcapture: Overcapture,
    partial_authorization: PartialAuthorization,
    reauthorization: Reauthorization,
    three_d_secure: ThreeDSecure,
    wallet: Wallet,
  }
end