Class: Stripe::Charge::PaymentMethodDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Checks, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, ThreeDSecure, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount.



859
860
861
# File 'lib/stripe/resources/charge.rb', line 859

def amount_authorized
  @amount_authorized
end

#authorization_codeObject (readonly)

Authorization code on the charge.



861
862
863
# File 'lib/stripe/resources/charge.rb', line 861

def authorization_code
  @authorization_code
end

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



863
864
865
# File 'lib/stripe/resources/charge.rb', line 863

def brand
  @brand
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.



865
866
867
# File 'lib/stripe/resources/charge.rb', line 865

def capture_before
  @capture_before
end

#checksObject (readonly)

Check results by Card networks on Card address and CVC at time of payment.



867
868
869
# File 'lib/stripe/resources/charge.rb', line 867

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



869
870
871
# File 'lib/stripe/resources/charge.rb', line 869

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



871
872
873
# File 'lib/stripe/resources/charge.rb', line 871

def description
  @description
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



873
874
875
# File 'lib/stripe/resources/charge.rb', line 873

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



875
876
877
# File 'lib/stripe/resources/charge.rb', line 875

def exp_year
  @exp_year
end

#extended_authorizationObject (readonly)

Attribute for field extended_authorization



877
878
879
# File 'lib/stripe/resources/charge.rb', line 877

def extended_authorization
  @extended_authorization
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.



881
882
883
# File 'lib/stripe/resources/charge.rb', line 881

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



883
884
885
# File 'lib/stripe/resources/charge.rb', line 883

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



885
886
887
# File 'lib/stripe/resources/charge.rb', line 885

def iin
  @iin
end

#incremental_authorizationObject (readonly)

Attribute for field incremental_authorization



887
888
889
# File 'lib/stripe/resources/charge.rb', line 887

def incremental_authorization
  @incremental_authorization
end

#installmentsObject (readonly)

Installment details for this payment.

For more information, see the installments integration guide.



891
892
893
# File 'lib/stripe/resources/charge.rb', line 891

def installments
  @installments
end

#issuerObject (readonly)

The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)



893
894
895
# File 'lib/stripe/resources/charge.rb', line 893

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



895
896
897
# File 'lib/stripe/resources/charge.rb', line 895

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment or created by it.



897
898
899
# File 'lib/stripe/resources/charge.rb', line 897

def mandate
  @mandate
end

#motoObject (readonly)

True if this payment was marked as MOTO and out of scope for SCA.



899
900
901
# File 'lib/stripe/resources/charge.rb', line 899

def moto
  @moto
end

#multicaptureObject (readonly)

Attribute for field multicapture



901
902
903
# File 'lib/stripe/resources/charge.rb', line 901

def multicapture
  @multicapture
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.



903
904
905
# File 'lib/stripe/resources/charge.rb', line 903

def network
  @network
end

#network_tokenObject (readonly)

If this card has network token credentials, this contains the details of the network token credentials.



905
906
907
# File 'lib/stripe/resources/charge.rb', line 905

def network_token
  @network_token
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



907
908
909
# File 'lib/stripe/resources/charge.rb', line 907

def network_transaction_id
  @network_transaction_id
end

#overcaptureObject (readonly)

Attribute for field overcapture



909
910
911
# File 'lib/stripe/resources/charge.rb', line 909

def overcapture
  @overcapture
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



911
912
913
# File 'lib/stripe/resources/charge.rb', line 911

def regulated_status
  @regulated_status
end

#three_d_secureObject (readonly)

Populated if this transaction used 3D Secure authentication.



913
914
915
# File 'lib/stripe/resources/charge.rb', line 913

def three_d_secure
  @three_d_secure
end

Transaction Link ID (TLID) is a unique identifier for a transaction. This is used by some card networks, such as Mastercard, for transaction linking, in addition to Network Transaction IDs. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



915
916
917
# File 'lib/stripe/resources/charge.rb', line 915

def transaction_link_id
  @transaction_link_id
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



917
918
919
# File 'lib/stripe/resources/charge.rb', line 917

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



933
934
935
# File 'lib/stripe/resources/charge.rb', line 933

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



919
920
921
922
923
924
925
926
927
928
929
930
931
# File 'lib/stripe/resources/charge.rb', line 919

def self.inner_class_types
  @inner_class_types = {
    checks: Checks,
    extended_authorization: ExtendedAuthorization,
    incremental_authorization: IncrementalAuthorization,
    installments: Installments,
    multicapture: Multicapture,
    network_token: NetworkToken,
    overcapture: Overcapture,
    three_d_secure: ThreeDSecure,
    wallet: Wallet,
  }
end