Class: Stripe::Charge::PaymentMethodDetails::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Checks, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, ThreeDSecure, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#brand ⇒ Object
readonly
Card brand.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
-
#checks ⇒ Object
readonly
Check results by Card networks on Card address and CVC at time of payment.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#extended_authorization ⇒ Object
readonly
Attribute for field extended_authorization.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization ⇒ Object
readonly
Attribute for field incremental_authorization.
-
#installments ⇒ Object
readonly
Installment details for this payment.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment or created by it.
-
#moto ⇒ Object
readonly
True if this payment was marked as MOTO and out of scope for SCA.
-
#multicapture ⇒ Object
readonly
Attribute for field multicapture.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_token ⇒ Object
readonly
If this card has network token credentials, this contains the details of the network token credentials.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#overcapture ⇒ Object
readonly
Attribute for field overcapture.
-
#regulated_status ⇒ Object
readonly
Status of a card based on the card issuer.
-
#three_d_secure ⇒ Object
readonly
Populated if this transaction used 3D Secure authentication.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount.
857 858 859 |
# File 'lib/stripe/resources/charge.rb', line 857 def @amount_authorized end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
859 860 861 |
# File 'lib/stripe/resources/charge.rb', line 859 def @authorization_code end |
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.
861 862 863 |
# File 'lib/stripe/resources/charge.rb', line 861 def brand @brand end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
863 864 865 |
# File 'lib/stripe/resources/charge.rb', line 863 def capture_before @capture_before end |
#checks ⇒ Object (readonly)
Check results by Card networks on Card address and CVC at time of payment.
865 866 867 |
# File 'lib/stripe/resources/charge.rb', line 865 def checks @checks end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
867 868 869 |
# File 'lib/stripe/resources/charge.rb', line 867 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
869 870 871 |
# File 'lib/stripe/resources/charge.rb', line 869 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
871 872 873 |
# File 'lib/stripe/resources/charge.rb', line 871 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
873 874 875 |
# File 'lib/stripe/resources/charge.rb', line 873 def exp_year @exp_year end |
#extended_authorization ⇒ Object (readonly)
Attribute for field extended_authorization
875 876 877 |
# File 'lib/stripe/resources/charge.rb', line 875 def @extended_authorization end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
879 880 881 |
# File 'lib/stripe/resources/charge.rb', line 879 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
881 882 883 |
# File 'lib/stripe/resources/charge.rb', line 881 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
883 884 885 |
# File 'lib/stripe/resources/charge.rb', line 883 def iin @iin end |
#incremental_authorization ⇒ Object (readonly)
Attribute for field incremental_authorization
885 886 887 |
# File 'lib/stripe/resources/charge.rb', line 885 def @incremental_authorization end |
#installments ⇒ Object (readonly)
Installment details for this payment.
For more information, see the [installments integration guide](docs.stripe.com/payments/installments).
889 890 891 |
# File 'lib/stripe/resources/charge.rb', line 889 def installments @installments end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
891 892 893 |
# File 'lib/stripe/resources/charge.rb', line 891 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
893 894 895 |
# File 'lib/stripe/resources/charge.rb', line 893 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment or created by it.
895 896 897 |
# File 'lib/stripe/resources/charge.rb', line 895 def mandate @mandate end |
#moto ⇒ Object (readonly)
True if this payment was marked as MOTO and out of scope for SCA.
897 898 899 |
# File 'lib/stripe/resources/charge.rb', line 897 def moto @moto end |
#multicapture ⇒ Object (readonly)
Attribute for field multicapture
899 900 901 |
# File 'lib/stripe/resources/charge.rb', line 899 def multicapture @multicapture end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
901 902 903 |
# File 'lib/stripe/resources/charge.rb', line 901 def network @network end |
#network_token ⇒ Object (readonly)
If this card has network token credentials, this contains the details of the network token credentials.
903 904 905 |
# File 'lib/stripe/resources/charge.rb', line 903 def network_token @network_token end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
905 906 907 |
# File 'lib/stripe/resources/charge.rb', line 905 def network_transaction_id @network_transaction_id end |
#overcapture ⇒ Object (readonly)
Attribute for field overcapture
907 908 909 |
# File 'lib/stripe/resources/charge.rb', line 907 def overcapture @overcapture end |
#regulated_status ⇒ Object (readonly)
Status of a card based on the card issuer.
909 910 911 |
# File 'lib/stripe/resources/charge.rb', line 909 def regulated_status @regulated_status end |
#three_d_secure ⇒ Object (readonly)
Populated if this transaction used 3D Secure authentication.
911 912 913 |
# File 'lib/stripe/resources/charge.rb', line 911 def three_d_secure @three_d_secure end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
913 914 915 |
# File 'lib/stripe/resources/charge.rb', line 913 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
929 930 931 |
# File 'lib/stripe/resources/charge.rb', line 929 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/stripe/resources/charge.rb', line 915 def self.inner_class_types @inner_class_types = { checks: Checks, extended_authorization: ExtendedAuthorization, incremental_authorization: IncrementalAuthorization, installments: Installments, multicapture: Multicapture, network_token: NetworkToken, overcapture: Overcapture, three_d_secure: ThreeDSecure, wallet: Wallet, } end |