Class: Stripe::Charge::PaymentMethodDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AccountFunding, Benefits, Checks, DecrementalAuthorization, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, PartialAuthorization, Reauthorization, ThreeDSecure, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_fundingObject (readonly)

Attribute for field account_funding



911
912
913
# File 'lib/stripe/resources/charge.rb', line 911

def 
  @account_funding
end

#amount_authorizedObject (readonly)

The authorized amount.



913
914
915
# File 'lib/stripe/resources/charge.rb', line 913

def amount_authorized
  @amount_authorized
end

#amount_requestedObject (readonly)

The latest amount intended to be authorized by this charge.



915
916
917
# File 'lib/stripe/resources/charge.rb', line 915

def amount_requested
  @amount_requested
end

#authorization_codeObject (readonly)

Authorization code on the charge.



917
918
919
# File 'lib/stripe/resources/charge.rb', line 917

def authorization_code
  @authorization_code
end

#benefitsObject (readonly)

Attribute for field benefits



919
920
921
# File 'lib/stripe/resources/charge.rb', line 919

def benefits
  @benefits
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



921
922
923
# File 'lib/stripe/resources/charge.rb', line 921

def brand
  @brand
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.



923
924
925
# File 'lib/stripe/resources/charge.rb', line 923

def capture_before
  @capture_before
end

#checksObject (readonly)

Check results by Card networks on Card address and CVC at time of payment.



925
926
927
# File 'lib/stripe/resources/charge.rb', line 925

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



927
928
929
# File 'lib/stripe/resources/charge.rb', line 927

def country
  @country
end

#decremental_authorizationObject (readonly)

Attribute for field decremental_authorization



929
930
931
# File 'lib/stripe/resources/charge.rb', line 929

def decremental_authorization
  @decremental_authorization
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



931
932
933
# File 'lib/stripe/resources/charge.rb', line 931

def description
  @description
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



933
934
935
# File 'lib/stripe/resources/charge.rb', line 933

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



935
936
937
# File 'lib/stripe/resources/charge.rb', line 935

def exp_year
  @exp_year
end

#extended_authorizationObject (readonly)

Attribute for field extended_authorization



937
938
939
# File 'lib/stripe/resources/charge.rb', line 937

def extended_authorization
  @extended_authorization
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



941
942
943
# File 'lib/stripe/resources/charge.rb', line 941

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



943
944
945
# File 'lib/stripe/resources/charge.rb', line 943

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



945
946
947
# File 'lib/stripe/resources/charge.rb', line 945

def iin
  @iin
end

#incremental_authorizationObject (readonly)

Attribute for field incremental_authorization



947
948
949
# File 'lib/stripe/resources/charge.rb', line 947

def incremental_authorization
  @incremental_authorization
end

#installmentsObject (readonly)

Installment details for this payment.

For more information, see the [installments integration guide](docs.stripe.com/payments/installments).



951
952
953
# File 'lib/stripe/resources/charge.rb', line 951

def installments
  @installments
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



953
954
955
# File 'lib/stripe/resources/charge.rb', line 953

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



955
956
957
# File 'lib/stripe/resources/charge.rb', line 955

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment or created by it.



957
958
959
# File 'lib/stripe/resources/charge.rb', line 957

def mandate
  @mandate
end

#motoObject (readonly)

True if this payment was marked as MOTO and out of scope for SCA.



959
960
961
# File 'lib/stripe/resources/charge.rb', line 959

def moto
  @moto
end

#multicaptureObject (readonly)

Attribute for field multicapture



961
962
963
# File 'lib/stripe/resources/charge.rb', line 961

def multicapture
  @multicapture
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



963
964
965
# File 'lib/stripe/resources/charge.rb', line 963

def network
  @network
end

#network_tokenObject (readonly)

If this card has network token credentials, this contains the details of the network token credentials.



965
966
967
# File 'lib/stripe/resources/charge.rb', line 965

def network_token
  @network_token
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



967
968
969
# File 'lib/stripe/resources/charge.rb', line 967

def network_transaction_id
  @network_transaction_id
end

#overcaptureObject (readonly)

Attribute for field overcapture



969
970
971
# File 'lib/stripe/resources/charge.rb', line 969

def overcapture
  @overcapture
end

#partial_authorizationObject (readonly)

Attribute for field partial_authorization



971
972
973
# File 'lib/stripe/resources/charge.rb', line 971

def partial_authorization
  @partial_authorization
end

#reauthorizationObject (readonly)

Whether the PaymentIntent can be reauthorized or not.



973
974
975
# File 'lib/stripe/resources/charge.rb', line 973

def reauthorization
  @reauthorization
end

#reauthorize_beforeObject (readonly)

The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.



975
976
977
# File 'lib/stripe/resources/charge.rb', line 975

def reauthorize_before
  @reauthorize_before
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



977
978
979
# File 'lib/stripe/resources/charge.rb', line 977

def regulated_status
  @regulated_status
end

#three_d_secureObject (readonly)

Populated if this transaction used 3D Secure authentication.



979
980
981
# File 'lib/stripe/resources/charge.rb', line 979

def three_d_secure
  @three_d_secure
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



981
982
983
# File 'lib/stripe/resources/charge.rb', line 981

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



1002
1003
1004
# File 'lib/stripe/resources/charge.rb', line 1002

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
# File 'lib/stripe/resources/charge.rb', line 983

def self.inner_class_types
  @inner_class_types = {
    account_funding: AccountFunding,
    benefits: Benefits,
    checks: Checks,
    decremental_authorization: DecrementalAuthorization,
    extended_authorization: ExtendedAuthorization,
    incremental_authorization: IncrementalAuthorization,
    installments: Installments,
    multicapture: Multicapture,
    network_token: NetworkToken,
    overcapture: Overcapture,
    partial_authorization: PartialAuthorization,
    reauthorization: Reauthorization,
    three_d_secure: ThreeDSecure,
    wallet: Wallet,
  }
end