Class: Stripe::Charge::PaymentMethodDetails::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Checks, DecrementalAuthorization, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, PartialAuthorization, ThreeDSecure, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#amount_requested ⇒ Object
readonly
The latest amount intended to be authorized by this charge.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#brand ⇒ Object
readonly
Card brand.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
-
#checks ⇒ Object
readonly
Check results by Card networks on Card address and CVC at time of payment.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#decremental_authorization ⇒ Object
readonly
Attribute for field decremental_authorization.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#extended_authorization ⇒ Object
readonly
Attribute for field extended_authorization.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization ⇒ Object
readonly
Attribute for field incremental_authorization.
-
#installments ⇒ Object
readonly
Installment details for this payment.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment or created by it.
-
#moto ⇒ Object
readonly
True if this payment was marked as MOTO and out of scope for SCA.
-
#multicapture ⇒ Object
readonly
Attribute for field multicapture.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_token ⇒ Object
readonly
If this card has network token credentials, this contains the details of the network token credentials.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#overcapture ⇒ Object
readonly
Attribute for field overcapture.
-
#partial_authorization ⇒ Object
readonly
Attribute for field partial_authorization.
-
#regulated_status ⇒ Object
readonly
Status of a card based on the card issuer.
-
#three_d_secure ⇒ Object
readonly
Populated if this transaction used 3D Secure authentication.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount.
872 873 874 |
# File 'lib/stripe/resources/charge.rb', line 872 def @amount_authorized end |
#amount_requested ⇒ Object (readonly)
The latest amount intended to be authorized by this charge.
874 875 876 |
# File 'lib/stripe/resources/charge.rb', line 874 def amount_requested @amount_requested end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
876 877 878 |
# File 'lib/stripe/resources/charge.rb', line 876 def @authorization_code end |
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.
878 879 880 |
# File 'lib/stripe/resources/charge.rb', line 878 def brand @brand end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
880 881 882 |
# File 'lib/stripe/resources/charge.rb', line 880 def capture_before @capture_before end |
#checks ⇒ Object (readonly)
Check results by Card networks on Card address and CVC at time of payment.
882 883 884 |
# File 'lib/stripe/resources/charge.rb', line 882 def checks @checks end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
884 885 886 |
# File 'lib/stripe/resources/charge.rb', line 884 def country @country end |
#decremental_authorization ⇒ Object (readonly)
Attribute for field decremental_authorization
886 887 888 |
# File 'lib/stripe/resources/charge.rb', line 886 def @decremental_authorization end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
888 889 890 |
# File 'lib/stripe/resources/charge.rb', line 888 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
890 891 892 |
# File 'lib/stripe/resources/charge.rb', line 890 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
892 893 894 |
# File 'lib/stripe/resources/charge.rb', line 892 def exp_year @exp_year end |
#extended_authorization ⇒ Object (readonly)
Attribute for field extended_authorization
894 895 896 |
# File 'lib/stripe/resources/charge.rb', line 894 def @extended_authorization end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
898 899 900 |
# File 'lib/stripe/resources/charge.rb', line 898 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
900 901 902 |
# File 'lib/stripe/resources/charge.rb', line 900 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
902 903 904 |
# File 'lib/stripe/resources/charge.rb', line 902 def iin @iin end |
#incremental_authorization ⇒ Object (readonly)
Attribute for field incremental_authorization
904 905 906 |
# File 'lib/stripe/resources/charge.rb', line 904 def @incremental_authorization end |
#installments ⇒ Object (readonly)
Installment details for this payment.
For more information, see the [installments integration guide](docs.stripe.com/payments/installments).
908 909 910 |
# File 'lib/stripe/resources/charge.rb', line 908 def installments @installments end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
910 911 912 |
# File 'lib/stripe/resources/charge.rb', line 910 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
912 913 914 |
# File 'lib/stripe/resources/charge.rb', line 912 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment or created by it.
914 915 916 |
# File 'lib/stripe/resources/charge.rb', line 914 def mandate @mandate end |
#moto ⇒ Object (readonly)
True if this payment was marked as MOTO and out of scope for SCA.
916 917 918 |
# File 'lib/stripe/resources/charge.rb', line 916 def moto @moto end |
#multicapture ⇒ Object (readonly)
Attribute for field multicapture
918 919 920 |
# File 'lib/stripe/resources/charge.rb', line 918 def multicapture @multicapture end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
920 921 922 |
# File 'lib/stripe/resources/charge.rb', line 920 def network @network end |
#network_token ⇒ Object (readonly)
If this card has network token credentials, this contains the details of the network token credentials.
922 923 924 |
# File 'lib/stripe/resources/charge.rb', line 922 def network_token @network_token end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
924 925 926 |
# File 'lib/stripe/resources/charge.rb', line 924 def network_transaction_id @network_transaction_id end |
#overcapture ⇒ Object (readonly)
Attribute for field overcapture
926 927 928 |
# File 'lib/stripe/resources/charge.rb', line 926 def overcapture @overcapture end |
#partial_authorization ⇒ Object (readonly)
Attribute for field partial_authorization
928 929 930 |
# File 'lib/stripe/resources/charge.rb', line 928 def @partial_authorization end |
#regulated_status ⇒ Object (readonly)
Status of a card based on the card issuer.
930 931 932 |
# File 'lib/stripe/resources/charge.rb', line 930 def regulated_status @regulated_status end |
#three_d_secure ⇒ Object (readonly)
Populated if this transaction used 3D Secure authentication.
932 933 934 |
# File 'lib/stripe/resources/charge.rb', line 932 def three_d_secure @three_d_secure end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
934 935 936 |
# File 'lib/stripe/resources/charge.rb', line 934 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
952 953 954 |
# File 'lib/stripe/resources/charge.rb', line 952 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 |
# File 'lib/stripe/resources/charge.rb', line 936 def self.inner_class_types @inner_class_types = { checks: Checks, decremental_authorization: DecrementalAuthorization, extended_authorization: ExtendedAuthorization, incremental_authorization: IncrementalAuthorization, installments: Installments, multicapture: Multicapture, network_token: NetworkToken, overcapture: Overcapture, partial_authorization: PartialAuthorization, three_d_secure: ThreeDSecure, wallet: Wallet, } end |