Class: Stripe::Charge::PaymentMethodDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Checks, DecrementalAuthorization, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, PartialAuthorization, ThreeDSecure, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount.



866
867
868
# File 'lib/stripe/resources/charge.rb', line 866

def amount_authorized
  @amount_authorized
end

#amount_requestedObject (readonly)

The latest amount intended to be authorized by this charge.



868
869
870
# File 'lib/stripe/resources/charge.rb', line 868

def amount_requested
  @amount_requested
end

#authorization_codeObject (readonly)

Authorization code on the charge.



870
871
872
# File 'lib/stripe/resources/charge.rb', line 870

def authorization_code
  @authorization_code
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



872
873
874
# File 'lib/stripe/resources/charge.rb', line 872

def brand
  @brand
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.



874
875
876
# File 'lib/stripe/resources/charge.rb', line 874

def capture_before
  @capture_before
end

#checksObject (readonly)

Check results by Card networks on Card address and CVC at time of payment.



876
877
878
# File 'lib/stripe/resources/charge.rb', line 876

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



878
879
880
# File 'lib/stripe/resources/charge.rb', line 878

def country
  @country
end

#decremental_authorizationObject (readonly)

Attribute for field decremental_authorization



880
881
882
# File 'lib/stripe/resources/charge.rb', line 880

def decremental_authorization
  @decremental_authorization
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



882
883
884
# File 'lib/stripe/resources/charge.rb', line 882

def description
  @description
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



884
885
886
# File 'lib/stripe/resources/charge.rb', line 884

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



886
887
888
# File 'lib/stripe/resources/charge.rb', line 886

def exp_year
  @exp_year
end

#extended_authorizationObject (readonly)

Attribute for field extended_authorization



888
889
890
# File 'lib/stripe/resources/charge.rb', line 888

def extended_authorization
  @extended_authorization
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



892
893
894
# File 'lib/stripe/resources/charge.rb', line 892

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



894
895
896
# File 'lib/stripe/resources/charge.rb', line 894

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



896
897
898
# File 'lib/stripe/resources/charge.rb', line 896

def iin
  @iin
end

#incremental_authorizationObject (readonly)

Attribute for field incremental_authorization



898
899
900
# File 'lib/stripe/resources/charge.rb', line 898

def incremental_authorization
  @incremental_authorization
end

#installmentsObject (readonly)

Installment details for this payment.

For more information, see the [installments integration guide](stripe.com/docs/payments/installments).



902
903
904
# File 'lib/stripe/resources/charge.rb', line 902

def installments
  @installments
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



904
905
906
# File 'lib/stripe/resources/charge.rb', line 904

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



906
907
908
# File 'lib/stripe/resources/charge.rb', line 906

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment or created by it.



908
909
910
# File 'lib/stripe/resources/charge.rb', line 908

def mandate
  @mandate
end

#motoObject (readonly)

True if this payment was marked as MOTO and out of scope for SCA.



910
911
912
# File 'lib/stripe/resources/charge.rb', line 910

def moto
  @moto
end

#multicaptureObject (readonly)

Attribute for field multicapture



912
913
914
# File 'lib/stripe/resources/charge.rb', line 912

def multicapture
  @multicapture
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



914
915
916
# File 'lib/stripe/resources/charge.rb', line 914

def network
  @network
end

#network_tokenObject (readonly)

If this card has network token credentials, this contains the details of the network token credentials.



916
917
918
# File 'lib/stripe/resources/charge.rb', line 916

def network_token
  @network_token
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



918
919
920
# File 'lib/stripe/resources/charge.rb', line 918

def network_transaction_id
  @network_transaction_id
end

#overcaptureObject (readonly)

Attribute for field overcapture



920
921
922
# File 'lib/stripe/resources/charge.rb', line 920

def overcapture
  @overcapture
end

#partial_authorizationObject (readonly)

Attribute for field partial_authorization



922
923
924
# File 'lib/stripe/resources/charge.rb', line 922

def partial_authorization
  @partial_authorization
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



924
925
926
# File 'lib/stripe/resources/charge.rb', line 924

def regulated_status
  @regulated_status
end

#three_d_secureObject (readonly)

Populated if this transaction used 3D Secure authentication.



926
927
928
# File 'lib/stripe/resources/charge.rb', line 926

def three_d_secure
  @three_d_secure
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



928
929
930
# File 'lib/stripe/resources/charge.rb', line 928

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



946
947
948
# File 'lib/stripe/resources/charge.rb', line 946

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
# File 'lib/stripe/resources/charge.rb', line 930

def self.inner_class_types
  @inner_class_types = {
    checks: Checks,
    decremental_authorization: DecrementalAuthorization,
    extended_authorization: ExtendedAuthorization,
    incremental_authorization: IncrementalAuthorization,
    installments: Installments,
    multicapture: Multicapture,
    network_token: NetworkToken,
    overcapture: Overcapture,
    partial_authorization: PartialAuthorization,
    three_d_secure: ThreeDSecure,
    wallet: Wallet,
  }
end