Class: Stripe::Charge::PaymentMethodDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Checks, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, ThreeDSecure, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount.



462
463
464
# File 'lib/stripe/resources/charge.rb', line 462

def amount_authorized
  @amount_authorized
end

#authorization_codeObject (readonly)

Authorization code on the charge.



464
465
466
# File 'lib/stripe/resources/charge.rb', line 464

def authorization_code
  @authorization_code
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



466
467
468
# File 'lib/stripe/resources/charge.rb', line 466

def brand
  @brand
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.



468
469
470
# File 'lib/stripe/resources/charge.rb', line 468

def capture_before
  @capture_before
end

#checksObject (readonly)

Check results by Card networks on Card address and CVC at time of payment.



470
471
472
# File 'lib/stripe/resources/charge.rb', line 470

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



472
473
474
# File 'lib/stripe/resources/charge.rb', line 472

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



474
475
476
# File 'lib/stripe/resources/charge.rb', line 474

def description
  @description
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



476
477
478
# File 'lib/stripe/resources/charge.rb', line 476

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



478
479
480
# File 'lib/stripe/resources/charge.rb', line 478

def exp_year
  @exp_year
end

#extended_authorizationObject (readonly)

Attribute for field extended_authorization



480
481
482
# File 'lib/stripe/resources/charge.rb', line 480

def extended_authorization
  @extended_authorization
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



484
485
486
# File 'lib/stripe/resources/charge.rb', line 484

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



486
487
488
# File 'lib/stripe/resources/charge.rb', line 486

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



488
489
490
# File 'lib/stripe/resources/charge.rb', line 488

def iin
  @iin
end

#incremental_authorizationObject (readonly)

Attribute for field incremental_authorization



490
491
492
# File 'lib/stripe/resources/charge.rb', line 490

def incremental_authorization
  @incremental_authorization
end

#installmentsObject (readonly)

Installment details for this payment.

For more information, see the [installments integration guide](stripe.com/docs/payments/installments).



494
495
496
# File 'lib/stripe/resources/charge.rb', line 494

def installments
  @installments
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



496
497
498
# File 'lib/stripe/resources/charge.rb', line 496

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



498
499
500
# File 'lib/stripe/resources/charge.rb', line 498

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment or created by it.



500
501
502
# File 'lib/stripe/resources/charge.rb', line 500

def mandate
  @mandate
end

#motoObject (readonly)

True if this payment was marked as MOTO and out of scope for SCA.



502
503
504
# File 'lib/stripe/resources/charge.rb', line 502

def moto
  @moto
end

#multicaptureObject (readonly)

Attribute for field multicapture



504
505
506
# File 'lib/stripe/resources/charge.rb', line 504

def multicapture
  @multicapture
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



506
507
508
# File 'lib/stripe/resources/charge.rb', line 506

def network
  @network
end

#network_tokenObject (readonly)

If this card has network token credentials, this contains the details of the network token credentials.



508
509
510
# File 'lib/stripe/resources/charge.rb', line 508

def network_token
  @network_token
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



510
511
512
# File 'lib/stripe/resources/charge.rb', line 510

def network_transaction_id
  @network_transaction_id
end

#overcaptureObject (readonly)

Attribute for field overcapture



512
513
514
# File 'lib/stripe/resources/charge.rb', line 512

def overcapture
  @overcapture
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



514
515
516
# File 'lib/stripe/resources/charge.rb', line 514

def regulated_status
  @regulated_status
end

#three_d_secureObject (readonly)

Populated if this transaction used 3D Secure authentication.



516
517
518
# File 'lib/stripe/resources/charge.rb', line 516

def three_d_secure
  @three_d_secure
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



518
519
520
# File 'lib/stripe/resources/charge.rb', line 518

def wallet
  @wallet
end