Class: Stripe::Charge::PaymentMethodDetails::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Checks, DecrementalAuthorization, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, PartialAuthorization, ThreeDSecure, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#amount_requested ⇒ Object
readonly
The latest amount intended to be authorized by this charge.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#brand ⇒ Object
readonly
Card brand.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
-
#checks ⇒ Object
readonly
Check results by Card networks on Card address and CVC at time of payment.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#decremental_authorization ⇒ Object
readonly
Attribute for field decremental_authorization.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#extended_authorization ⇒ Object
readonly
Attribute for field extended_authorization.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization ⇒ Object
readonly
Attribute for field incremental_authorization.
-
#installments ⇒ Object
readonly
Installment details for this payment (Mexico only).
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment or created by it.
-
#moto ⇒ Object
readonly
True if this payment was marked as MOTO and out of scope for SCA.
-
#multicapture ⇒ Object
readonly
Attribute for field multicapture.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_token ⇒ Object
readonly
If this card has network token credentials, this contains the details of the network token credentials.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#overcapture ⇒ Object
readonly
Attribute for field overcapture.
-
#partial_authorization ⇒ Object
readonly
Attribute for field partial_authorization.
-
#regulated_status ⇒ Object
readonly
Status of a card based on the card issuer.
-
#three_d_secure ⇒ Object
readonly
Populated if this transaction used 3D Secure authentication.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount.
558 559 560 |
# File 'lib/stripe/resources/charge.rb', line 558 def @amount_authorized end |
#amount_requested ⇒ Object (readonly)
The latest amount intended to be authorized by this charge.
561 562 563 |
# File 'lib/stripe/resources/charge.rb', line 561 def amount_requested @amount_requested end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
564 565 566 |
# File 'lib/stripe/resources/charge.rb', line 564 def @authorization_code end |
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
567 568 569 |
# File 'lib/stripe/resources/charge.rb', line 567 def brand @brand end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
570 571 572 |
# File 'lib/stripe/resources/charge.rb', line 570 def capture_before @capture_before end |
#checks ⇒ Object (readonly)
Check results by Card networks on Card address and CVC at time of payment.
573 574 575 |
# File 'lib/stripe/resources/charge.rb', line 573 def checks @checks end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
576 577 578 |
# File 'lib/stripe/resources/charge.rb', line 576 def country @country end |
#decremental_authorization ⇒ Object (readonly)
Attribute for field decremental_authorization
579 580 581 |
# File 'lib/stripe/resources/charge.rb', line 579 def @decremental_authorization end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
582 583 584 |
# File 'lib/stripe/resources/charge.rb', line 582 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
585 586 587 |
# File 'lib/stripe/resources/charge.rb', line 585 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
588 589 590 |
# File 'lib/stripe/resources/charge.rb', line 588 def exp_year @exp_year end |
#extended_authorization ⇒ Object (readonly)
Attribute for field extended_authorization
591 592 593 |
# File 'lib/stripe/resources/charge.rb', line 591 def @extended_authorization end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
596 597 598 |
# File 'lib/stripe/resources/charge.rb', line 596 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
599 600 601 |
# File 'lib/stripe/resources/charge.rb', line 599 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
602 603 604 |
# File 'lib/stripe/resources/charge.rb', line 602 def iin @iin end |
#incremental_authorization ⇒ Object (readonly)
Attribute for field incremental_authorization
605 606 607 |
# File 'lib/stripe/resources/charge.rb', line 605 def @incremental_authorization end |
#installments ⇒ Object (readonly)
Installment details for this payment (Mexico only).
For more information, see the [installments integration guide](stripe.com/docs/payments/installments).
610 611 612 |
# File 'lib/stripe/resources/charge.rb', line 610 def installments @installments end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
613 614 615 |
# File 'lib/stripe/resources/charge.rb', line 613 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
616 617 618 |
# File 'lib/stripe/resources/charge.rb', line 616 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment or created by it.
619 620 621 |
# File 'lib/stripe/resources/charge.rb', line 619 def mandate @mandate end |
#moto ⇒ Object (readonly)
True if this payment was marked as MOTO and out of scope for SCA.
622 623 624 |
# File 'lib/stripe/resources/charge.rb', line 622 def moto @moto end |
#multicapture ⇒ Object (readonly)
Attribute for field multicapture
625 626 627 |
# File 'lib/stripe/resources/charge.rb', line 625 def multicapture @multicapture end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
628 629 630 |
# File 'lib/stripe/resources/charge.rb', line 628 def network @network end |
#network_token ⇒ Object (readonly)
If this card has network token credentials, this contains the details of the network token credentials.
631 632 633 |
# File 'lib/stripe/resources/charge.rb', line 631 def network_token @network_token end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. The first three digits of the Trace ID is the Financial Network Code, the next 6 digits is the Banknet Reference Number, and the last 4 digits represent the date (MM/DD). This field will be available for successful Visa, Mastercard, or American Express transactions and always null for other card brands.
634 635 636 |
# File 'lib/stripe/resources/charge.rb', line 634 def network_transaction_id @network_transaction_id end |
#overcapture ⇒ Object (readonly)
Attribute for field overcapture
637 638 639 |
# File 'lib/stripe/resources/charge.rb', line 637 def overcapture @overcapture end |
#partial_authorization ⇒ Object (readonly)
Attribute for field partial_authorization
640 641 642 |
# File 'lib/stripe/resources/charge.rb', line 640 def @partial_authorization end |
#regulated_status ⇒ Object (readonly)
Status of a card based on the card issuer.
643 644 645 |
# File 'lib/stripe/resources/charge.rb', line 643 def regulated_status @regulated_status end |
#three_d_secure ⇒ Object (readonly)
Populated if this transaction used 3D Secure authentication.
646 647 648 |
# File 'lib/stripe/resources/charge.rb', line 646 def three_d_secure @three_d_secure end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
649 650 651 |
# File 'lib/stripe/resources/charge.rb', line 649 def wallet @wallet end |