Class: Stripe::Charge::PaymentMethodDetails::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Checks, ExtendedAuthorization, IncrementalAuthorization, Installments, Multicapture, NetworkToken, Overcapture, ThreeDSecure, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#authorization_code ⇒ Object
readonly
Authorization code on the charge.
-
#brand ⇒ Object
readonly
Card brand.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
-
#checks ⇒ Object
readonly
Check results by Card networks on Card address and CVC at time of payment.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card's expiration year.
-
#extended_authorization ⇒ Object
readonly
Attribute for field extended_authorization.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization ⇒ Object
readonly
Attribute for field incremental_authorization.
-
#installments ⇒ Object
readonly
Installment details for this payment.
-
#issuer ⇒ Object
readonly
The name of the card's issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment or created by it.
-
#moto ⇒ Object
readonly
True if this payment was marked as MOTO and out of scope for SCA.
-
#multicapture ⇒ Object
readonly
Attribute for field multicapture.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_token ⇒ Object
readonly
If this card has network token credentials, this contains the details of the network token credentials.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#overcapture ⇒ Object
readonly
Attribute for field overcapture.
-
#regulated_status ⇒ Object
readonly
Status of a card based on the card issuer.
-
#three_d_secure ⇒ Object
readonly
Populated if this transaction used 3D Secure authentication.
-
#transaction_link_id ⇒ Object
readonly
Transaction Link ID (TLID) is a unique identifier for a transaction.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount.
862 863 864 |
# File 'lib/stripe/resources/charge.rb', line 862 def @amount_authorized end |
#authorization_code ⇒ Object (readonly)
Authorization code on the charge.
864 865 866 |
# File 'lib/stripe/resources/charge.rb', line 864 def @authorization_code end |
#brand ⇒ Object (readonly)
Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.
866 867 868 |
# File 'lib/stripe/resources/charge.rb', line 866 def brand @brand end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
868 869 870 |
# File 'lib/stripe/resources/charge.rb', line 868 def capture_before @capture_before end |
#checks ⇒ Object (readonly)
Check results by Card networks on Card address and CVC at time of payment.
870 871 872 |
# File 'lib/stripe/resources/charge.rb', line 870 def checks @checks end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
872 873 874 |
# File 'lib/stripe/resources/charge.rb', line 872 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
874 875 876 |
# File 'lib/stripe/resources/charge.rb', line 874 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card's expiration month.
876 877 878 |
# File 'lib/stripe/resources/charge.rb', line 876 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card's expiration year.
878 879 880 |
# File 'lib/stripe/resources/charge.rb', line 878 def exp_year @exp_year end |
#extended_authorization ⇒ Object (readonly)
Attribute for field extended_authorization
880 881 882 |
# File 'lib/stripe/resources/charge.rb', line 880 def @extended_authorization end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
884 885 886 |
# File 'lib/stripe/resources/charge.rb', line 884 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be credit, debit, prepaid, or unknown.
886 887 888 |
# File 'lib/stripe/resources/charge.rb', line 886 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
888 889 890 |
# File 'lib/stripe/resources/charge.rb', line 888 def iin @iin end |
#incremental_authorization ⇒ Object (readonly)
Attribute for field incremental_authorization
890 891 892 |
# File 'lib/stripe/resources/charge.rb', line 890 def @incremental_authorization end |
#installments ⇒ Object (readonly)
Installment details for this payment.
For more information, see the installments integration guide.
894 895 896 |
# File 'lib/stripe/resources/charge.rb', line 894 def installments @installments end |
#issuer ⇒ Object (readonly)
The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)
896 897 898 |
# File 'lib/stripe/resources/charge.rb', line 896 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
898 899 900 |
# File 'lib/stripe/resources/charge.rb', line 898 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment or created by it.
900 901 902 |
# File 'lib/stripe/resources/charge.rb', line 900 def mandate @mandate end |
#moto ⇒ Object (readonly)
True if this payment was marked as MOTO and out of scope for SCA.
902 903 904 |
# File 'lib/stripe/resources/charge.rb', line 902 def moto @moto end |
#multicapture ⇒ Object (readonly)
Attribute for field multicapture
904 905 906 |
# File 'lib/stripe/resources/charge.rb', line 904 def multicapture @multicapture end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.
906 907 908 |
# File 'lib/stripe/resources/charge.rb', line 906 def network @network end |
#network_token ⇒ Object (readonly)
If this card has network token credentials, this contains the details of the network token credentials.
908 909 910 |
# File 'lib/stripe/resources/charge.rb', line 908 def network_token @network_token end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
910 911 912 |
# File 'lib/stripe/resources/charge.rb', line 910 def network_transaction_id @network_transaction_id end |
#overcapture ⇒ Object (readonly)
Attribute for field overcapture
912 913 914 |
# File 'lib/stripe/resources/charge.rb', line 912 def overcapture @overcapture end |
#regulated_status ⇒ Object (readonly)
Status of a card based on the card issuer.
914 915 916 |
# File 'lib/stripe/resources/charge.rb', line 914 def regulated_status @regulated_status end |
#three_d_secure ⇒ Object (readonly)
Populated if this transaction used 3D Secure authentication.
916 917 918 |
# File 'lib/stripe/resources/charge.rb', line 916 def three_d_secure @three_d_secure end |
#transaction_link_id ⇒ Object (readonly)
Transaction Link ID (TLID) is a unique identifier for a transaction. This is used by some card networks, such as Mastercard, for transaction linking, in addition to Network Transaction IDs. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
918 919 920 |
# File 'lib/stripe/resources/charge.rb', line 918 def transaction_link_id @transaction_link_id end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
920 921 922 |
# File 'lib/stripe/resources/charge.rb', line 920 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
936 937 938 |
# File 'lib/stripe/resources/charge.rb', line 936 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'lib/stripe/resources/charge.rb', line 922 def self.inner_class_types @inner_class_types = { checks: Checks, extended_authorization: ExtendedAuthorization, incremental_authorization: IncrementalAuthorization, installments: Installments, multicapture: Multicapture, network_token: NetworkToken, overcapture: Overcapture, three_d_secure: ThreeDSecure, wallet: Wallet, } end |