Class: Stripe::Charge::PaymentMethodDetails::Card::ThreeDSecure

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authentication_flowObject (readonly)

For authenticated transactions: how the customer was authenticated by the issuing bank.



623
624
625
# File 'lib/stripe/resources/charge.rb', line 623

def authentication_flow
  @authentication_flow
end

#electronic_commerce_indicatorObject (readonly)

The Electronic Commerce Indicator (ECI). A protocol-level field indicating what degree of authentication was performed.



626
627
628
# File 'lib/stripe/resources/charge.rb', line 626

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#exemption_indicatorObject (readonly)

The exemption requested via 3DS and accepted by the issuer at authentication time.



628
629
630
# File 'lib/stripe/resources/charge.rb', line 628

def exemption_indicator
  @exemption_indicator
end

#exemption_indicator_appliedObject (readonly)

Whether Stripe requested the value of ‘exemption_indicator` in the transaction. This will depend on the outcome of Stripe’s internal risk assessment.



631
632
633
# File 'lib/stripe/resources/charge.rb', line 631

def exemption_indicator_applied
  @exemption_indicator_applied
end

#resultObject (readonly)

Indicates the outcome of 3D Secure authentication.



633
634
635
# File 'lib/stripe/resources/charge.rb', line 633

def result
  @result
end

#result_reasonObject (readonly)

Additional information about why 3D Secure succeeded or failed based on the ‘result`.



636
637
638
# File 'lib/stripe/resources/charge.rb', line 636

def result_reason
  @result_reason
end

#transaction_idObject (readonly)

The 3D Secure 1 XID or 3D Secure 2 Directory Server Transaction ID (dsTransId) for this payment.



639
640
641
# File 'lib/stripe/resources/charge.rb', line 639

def transaction_id
  @transaction_id
end

#versionObject (readonly)

The version of 3D Secure that was used.



641
642
643
# File 'lib/stripe/resources/charge.rb', line 641

def version
  @version
end

Class Method Details

.field_remappingsObject



647
648
649
# File 'lib/stripe/resources/charge.rb', line 647

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



643
644
645
# File 'lib/stripe/resources/charge.rb', line 643

def self.inner_class_types
  @inner_class_types = {}
end