Class: Stripe::Charge::PaymentMethodDetails::Card::ThreeDSecure

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authentication_flowObject (readonly)

For authenticated transactions: how the customer was authenticated by the issuing bank.



346
347
348
# File 'lib/stripe/resources/charge.rb', line 346

def authentication_flow
  @authentication_flow
end

#electronic_commerce_indicatorObject (readonly)

The Electronic Commerce Indicator (ECI). A protocol-level field indicating what degree of authentication was performed.



349
350
351
# File 'lib/stripe/resources/charge.rb', line 349

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#exemption_indicatorObject (readonly)

The exemption requested via 3DS and accepted by the issuer at authentication time.



351
352
353
# File 'lib/stripe/resources/charge.rb', line 351

def exemption_indicator
  @exemption_indicator
end

#exemption_indicator_appliedObject (readonly)

Whether Stripe requested the value of ‘exemption_indicator` in the transaction. This will depend on the outcome of Stripe’s internal risk assessment.



354
355
356
# File 'lib/stripe/resources/charge.rb', line 354

def exemption_indicator_applied
  @exemption_indicator_applied
end

#resultObject (readonly)

Indicates the outcome of 3D Secure authentication.



356
357
358
# File 'lib/stripe/resources/charge.rb', line 356

def result
  @result
end

#result_reasonObject (readonly)

Additional information about why 3D Secure succeeded or failed based on the ‘result`.



359
360
361
# File 'lib/stripe/resources/charge.rb', line 359

def result_reason
  @result_reason
end

#transaction_idObject (readonly)

The 3D Secure 1 XID or 3D Secure 2 Directory Server Transaction ID (dsTransId) for this payment.



362
363
364
# File 'lib/stripe/resources/charge.rb', line 362

def transaction_id
  @transaction_id
end

#versionObject (readonly)

The version of 3D Secure that was used.



364
365
366
# File 'lib/stripe/resources/charge.rb', line 364

def version
  @version
end