Class: Stripe::Charge::PaymentMethodDetails::Card::ThreeDSecure
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card::ThreeDSecure
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authentication_flow ⇒ Object
readonly
For authenticated transactions: how the customer was authenticated by the issuing bank.
-
#electronic_commerce_indicator ⇒ Object
readonly
The Electronic Commerce Indicator (ECI).
-
#exemption_indicator ⇒ Object
readonly
The exemption requested via 3DS and accepted by the issuer at authentication time.
-
#exemption_indicator_applied ⇒ Object
readonly
Whether Stripe requested the value of ‘exemption_indicator` in the transaction.
-
#result ⇒ Object
readonly
Indicates the outcome of 3D Secure authentication.
-
#result_reason ⇒ Object
readonly
Additional information about why 3D Secure succeeded or failed based on the ‘result`.
-
#transaction_id ⇒ Object
readonly
The 3D Secure 1 XID or 3D Secure 2 Directory Server Transaction ID (dsTransId) for this payment.
-
#version ⇒ Object
readonly
The version of 3D Secure that was used.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authentication_flow ⇒ Object (readonly)
For authenticated transactions: how the customer was authenticated by the issuing bank.
328 329 330 |
# File 'lib/stripe/resources/charge.rb', line 328 def authentication_flow @authentication_flow end |
#electronic_commerce_indicator ⇒ Object (readonly)
The Electronic Commerce Indicator (ECI). A protocol-level field indicating what degree of authentication was performed.
331 332 333 |
# File 'lib/stripe/resources/charge.rb', line 331 def electronic_commerce_indicator @electronic_commerce_indicator end |
#exemption_indicator ⇒ Object (readonly)
The exemption requested via 3DS and accepted by the issuer at authentication time.
333 334 335 |
# File 'lib/stripe/resources/charge.rb', line 333 def exemption_indicator @exemption_indicator end |
#exemption_indicator_applied ⇒ Object (readonly)
Whether Stripe requested the value of ‘exemption_indicator` in the transaction. This will depend on the outcome of Stripe’s internal risk assessment.
336 337 338 |
# File 'lib/stripe/resources/charge.rb', line 336 def exemption_indicator_applied @exemption_indicator_applied end |
#result ⇒ Object (readonly)
Indicates the outcome of 3D Secure authentication.
338 339 340 |
# File 'lib/stripe/resources/charge.rb', line 338 def result @result end |
#result_reason ⇒ Object (readonly)
Additional information about why 3D Secure succeeded or failed based on the ‘result`.
341 342 343 |
# File 'lib/stripe/resources/charge.rb', line 341 def result_reason @result_reason end |
#transaction_id ⇒ Object (readonly)
The 3D Secure 1 XID or 3D Secure 2 Directory Server Transaction ID (dsTransId) for this payment.
344 345 346 |
# File 'lib/stripe/resources/charge.rb', line 344 def transaction_id @transaction_id end |
#version ⇒ Object (readonly)
The version of 3D Secure that was used.
346 347 348 |
# File 'lib/stripe/resources/charge.rb', line 346 def version @version end |