Class: Stripe::Charge::PaymentMethodDetails::Card::Wallet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amex_express_checkoutObject (readonly)

Attribute for field amex_express_checkout



822
823
824
# File 'lib/stripe/resources/charge.rb', line 822

def amex_express_checkout
  @amex_express_checkout
end

#apple_payObject (readonly)

Attribute for field apple_pay



824
825
826
# File 'lib/stripe/resources/charge.rb', line 824

def apple_pay
  @apple_pay
end

#dynamic_last4Object (readonly)

(For tokenized numbers only.) The last four digits of the device account number.



826
827
828
# File 'lib/stripe/resources/charge.rb', line 826

def dynamic_last4
  @dynamic_last4
end

#google_payObject (readonly)

Attribute for field google_pay



828
829
830
# File 'lib/stripe/resources/charge.rb', line 828

def google_pay
  @google_pay
end

Attribute for field link



830
831
832
# File 'lib/stripe/resources/charge.rb', line 830

def link
  @link
end

#masterpassObject (readonly)

Attribute for field masterpass



832
833
834
# File 'lib/stripe/resources/charge.rb', line 832

def masterpass
  @masterpass
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



834
835
836
# File 'lib/stripe/resources/charge.rb', line 834

def samsung_pay
  @samsung_pay
end

#typeObject (readonly)

The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.



836
837
838
# File 'lib/stripe/resources/charge.rb', line 836

def type
  @type
end

#visa_checkoutObject (readonly)

Attribute for field visa_checkout



838
839
840
# File 'lib/stripe/resources/charge.rb', line 838

def visa_checkout
  @visa_checkout
end

Class Method Details

.field_remappingsObject



852
853
854
# File 'lib/stripe/resources/charge.rb', line 852

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



840
841
842
843
844
845
846
847
848
849
850
# File 'lib/stripe/resources/charge.rb', line 840

def self.inner_class_types
  @inner_class_types = {
    amex_express_checkout: AmexExpressCheckout,
    apple_pay: ApplePay,
    google_pay: GooglePay,
    link: Link,
    masterpass: Masterpass,
    samsung_pay: SamsungPay,
    visa_checkout: VisaCheckout,
  }
end