Class: Stripe::Charge::PaymentMethodDetails::Card::Wallet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card::Wallet
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amex_express_checkout ⇒ Object
readonly
Attribute for field amex_express_checkout.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#dynamic_last4 ⇒ Object
readonly
(For tokenized numbers only.) The last four digits of the device account number.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#masterpass ⇒ Object
readonly
Attribute for field masterpass.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#type ⇒ Object
readonly
The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`.
-
#visa_checkout ⇒ Object
readonly
Attribute for field visa_checkout.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amex_express_checkout ⇒ Object (readonly)
Attribute for field amex_express_checkout
876 877 878 |
# File 'lib/stripe/resources/charge.rb', line 876 def amex_express_checkout @amex_express_checkout end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
878 879 880 |
# File 'lib/stripe/resources/charge.rb', line 878 def apple_pay @apple_pay end |
#dynamic_last4 ⇒ Object (readonly)
(For tokenized numbers only.) The last four digits of the device account number.
880 881 882 |
# File 'lib/stripe/resources/charge.rb', line 880 def dynamic_last4 @dynamic_last4 end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
882 883 884 |
# File 'lib/stripe/resources/charge.rb', line 882 def google_pay @google_pay end |
#link ⇒ Object (readonly)
Attribute for field link
884 885 886 |
# File 'lib/stripe/resources/charge.rb', line 884 def link @link end |
#masterpass ⇒ Object (readonly)
Attribute for field masterpass
886 887 888 |
# File 'lib/stripe/resources/charge.rb', line 886 def masterpass @masterpass end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
888 889 890 |
# File 'lib/stripe/resources/charge.rb', line 888 def samsung_pay @samsung_pay end |
#type ⇒ Object (readonly)
The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.
890 891 892 |
# File 'lib/stripe/resources/charge.rb', line 890 def type @type end |
#visa_checkout ⇒ Object (readonly)
Attribute for field visa_checkout
892 893 894 |
# File 'lib/stripe/resources/charge.rb', line 892 def visa_checkout @visa_checkout end |
Class Method Details
.field_remappings ⇒ Object
906 907 908 |
# File 'lib/stripe/resources/charge.rb', line 906 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/stripe/resources/charge.rb', line 894 def self.inner_class_types @inner_class_types = { amex_express_checkout: AmexExpressCheckout, apple_pay: ApplePay, google_pay: GooglePay, link: Link, masterpass: Masterpass, samsung_pay: SamsungPay, visa_checkout: VisaCheckout, } end |