Class: Stripe::Charge::PaymentMethodDetails::Card::Wallet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amex_express_checkoutObject (readonly)

Attribute for field amex_express_checkout



837
838
839
# File 'lib/stripe/resources/charge.rb', line 837

def amex_express_checkout
  @amex_express_checkout
end

#apple_payObject (readonly)

Attribute for field apple_pay



839
840
841
# File 'lib/stripe/resources/charge.rb', line 839

def apple_pay
  @apple_pay
end

#dynamic_last4Object (readonly)

(For tokenized numbers only.) The last four digits of the device account number.



841
842
843
# File 'lib/stripe/resources/charge.rb', line 841

def dynamic_last4
  @dynamic_last4
end

#google_payObject (readonly)

Attribute for field google_pay



843
844
845
# File 'lib/stripe/resources/charge.rb', line 843

def google_pay
  @google_pay
end

Attribute for field link



845
846
847
# File 'lib/stripe/resources/charge.rb', line 845

def link
  @link
end

#masterpassObject (readonly)

Attribute for field masterpass



847
848
849
# File 'lib/stripe/resources/charge.rb', line 847

def masterpass
  @masterpass
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



849
850
851
# File 'lib/stripe/resources/charge.rb', line 849

def samsung_pay
  @samsung_pay
end

#typeObject (readonly)

The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.



851
852
853
# File 'lib/stripe/resources/charge.rb', line 851

def type
  @type
end

#visa_checkoutObject (readonly)

Attribute for field visa_checkout



853
854
855
# File 'lib/stripe/resources/charge.rb', line 853

def visa_checkout
  @visa_checkout
end

Class Method Details

.field_remappingsObject



867
868
869
# File 'lib/stripe/resources/charge.rb', line 867

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



855
856
857
858
859
860
861
862
863
864
865
# File 'lib/stripe/resources/charge.rb', line 855

def self.inner_class_types
  @inner_class_types = {
    amex_express_checkout: AmexExpressCheckout,
    apple_pay: ApplePay,
    google_pay: GooglePay,
    link: Link,
    masterpass: Masterpass,
    samsung_pay: SamsungPay,
    visa_checkout: VisaCheckout,
  }
end