Class: Stripe::Charge::PaymentMethodDetails::Card::Wallet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card::Wallet
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amex_express_checkout ⇒ Object
readonly
Attribute for field amex_express_checkout.
-
#apple_pay ⇒ Object
readonly
Attribute for field apple_pay.
-
#dynamic_last4 ⇒ Object
readonly
(For tokenized numbers only.) The last four digits of the device account number.
-
#google_pay ⇒ Object
readonly
Attribute for field google_pay.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#masterpass ⇒ Object
readonly
Attribute for field masterpass.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#type ⇒ Object
readonly
The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`.
-
#visa_checkout ⇒ Object
readonly
Attribute for field visa_checkout.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amex_express_checkout ⇒ Object (readonly)
Attribute for field amex_express_checkout
455 456 457 |
# File 'lib/stripe/resources/charge.rb', line 455 def amex_express_checkout @amex_express_checkout end |
#apple_pay ⇒ Object (readonly)
Attribute for field apple_pay
457 458 459 |
# File 'lib/stripe/resources/charge.rb', line 457 def apple_pay @apple_pay end |
#dynamic_last4 ⇒ Object (readonly)
(For tokenized numbers only.) The last four digits of the device account number.
459 460 461 |
# File 'lib/stripe/resources/charge.rb', line 459 def dynamic_last4 @dynamic_last4 end |
#google_pay ⇒ Object (readonly)
Attribute for field google_pay
461 462 463 |
# File 'lib/stripe/resources/charge.rb', line 461 def google_pay @google_pay end |
#link ⇒ Object (readonly)
Attribute for field link
463 464 465 |
# File 'lib/stripe/resources/charge.rb', line 463 def link @link end |
#masterpass ⇒ Object (readonly)
Attribute for field masterpass
465 466 467 |
# File 'lib/stripe/resources/charge.rb', line 465 def masterpass @masterpass end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
467 468 469 |
# File 'lib/stripe/resources/charge.rb', line 467 def samsung_pay @samsung_pay end |
#type ⇒ Object (readonly)
The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.
469 470 471 |
# File 'lib/stripe/resources/charge.rb', line 469 def type @type end |
#visa_checkout ⇒ Object (readonly)
Attribute for field visa_checkout
471 472 473 |
# File 'lib/stripe/resources/charge.rb', line 471 def visa_checkout @visa_checkout end |