Class: Stripe::Charge::PaymentMethodDetails::Card::Wallet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amex_express_checkoutObject (readonly)

Attribute for field amex_express_checkout



531
532
533
# File 'lib/stripe/resources/charge.rb', line 531

def amex_express_checkout
  @amex_express_checkout
end

#apple_payObject (readonly)

Attribute for field apple_pay



534
535
536
# File 'lib/stripe/resources/charge.rb', line 534

def apple_pay
  @apple_pay
end

#dynamic_last4Object (readonly)

(For tokenized numbers only.) The last four digits of the device account number.



537
538
539
# File 'lib/stripe/resources/charge.rb', line 537

def dynamic_last4
  @dynamic_last4
end

#google_payObject (readonly)

Attribute for field google_pay



540
541
542
# File 'lib/stripe/resources/charge.rb', line 540

def google_pay
  @google_pay
end

Attribute for field link



543
544
545
# File 'lib/stripe/resources/charge.rb', line 543

def link
  @link
end

#masterpassObject (readonly)

Attribute for field masterpass



546
547
548
# File 'lib/stripe/resources/charge.rb', line 546

def masterpass
  @masterpass
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



549
550
551
# File 'lib/stripe/resources/charge.rb', line 549

def samsung_pay
  @samsung_pay
end

#typeObject (readonly)

The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.



552
553
554
# File 'lib/stripe/resources/charge.rb', line 552

def type
  @type
end

#visa_checkoutObject (readonly)

Attribute for field visa_checkout



555
556
557
# File 'lib/stripe/resources/charge.rb', line 555

def visa_checkout
  @visa_checkout
end