Class: Stripe::Charge::PaymentMethodDetails::Card::Wallet::VisaCheckout
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Card::Wallet::VisaCheckout
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: BillingAddress, ShippingAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_address ⇒ Object
readonly
Owner's verified billing address.
-
#email ⇒ Object
readonly
Owner's verified email.
-
#name ⇒ Object
readonly
Owner's verified full name.
-
#shipping_address ⇒ Object
readonly
Owner's verified shipping address.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_address ⇒ Object (readonly)
Owner's verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
804 805 806 |
# File 'lib/stripe/resources/charge.rb', line 804 def billing_address @billing_address end |
#email ⇒ Object (readonly)
Owner's verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
806 807 808 |
# File 'lib/stripe/resources/charge.rb', line 806 def email @email end |
#name ⇒ Object (readonly)
Owner's verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
808 809 810 |
# File 'lib/stripe/resources/charge.rb', line 808 def name @name end |
#shipping_address ⇒ Object (readonly)
Owner's verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
810 811 812 |
# File 'lib/stripe/resources/charge.rb', line 810 def shipping_address @shipping_address end |
Class Method Details
.field_remappings ⇒ Object
819 820 821 |
# File 'lib/stripe/resources/charge.rb', line 819 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
812 813 814 815 816 817 |
# File 'lib/stripe/resources/charge.rb', line 812 def self.inner_class_types @inner_class_types = { billing_address: BillingAddress, shipping_address: ShippingAddress, } end |