Class: Stripe::Charge::PaymentMethodDetails::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Offline, Receipt, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount



1035
1036
1037
# File 'lib/stripe/resources/charge.rb', line 1035

def amount_authorized
  @amount_authorized
end

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



1037
1038
1039
# File 'lib/stripe/resources/charge.rb', line 1037

def brand
  @brand
end

#brand_productObject (readonly)

The product code that identifies the specific program or product associated with a card.



1039
1040
1041
# File 'lib/stripe/resources/charge.rb', line 1039

def brand_product
  @brand_product
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.



1041
1042
1043
# File 'lib/stripe/resources/charge.rb', line 1041

def capture_before
  @capture_before
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



1043
1044
1045
# File 'lib/stripe/resources/charge.rb', line 1043

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



1045
1046
1047
# File 'lib/stripe/resources/charge.rb', line 1045

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



1047
1048
1049
# File 'lib/stripe/resources/charge.rb', line 1047

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



1049
1050
1051
# File 'lib/stripe/resources/charge.rb', line 1049

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



1051
1052
1053
# File 'lib/stripe/resources/charge.rb', line 1051

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



1053
1054
1055
# File 'lib/stripe/resources/charge.rb', line 1053

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.



1057
1058
1059
# File 'lib/stripe/resources/charge.rb', line 1057

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



1059
1060
1061
# File 'lib/stripe/resources/charge.rb', line 1059

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



1061
1062
1063
# File 'lib/stripe/resources/charge.rb', line 1061

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



1063
1064
1065
# File 'lib/stripe/resources/charge.rb', line 1063

def iin
  @iin
end

#incremental_authorization_supportedObject (readonly)

Whether this PaymentIntent is eligible for incremental authorizations. Request support using request_incremental_authorization_support.



1065
1066
1067
# File 'lib/stripe/resources/charge.rb', line 1065

def incremental_authorization_supported
  @incremental_authorization_supported
end

#issuerObject (readonly)

The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)



1067
1068
1069
# File 'lib/stripe/resources/charge.rb', line 1067

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



1069
1070
1071
# File 'lib/stripe/resources/charge.rb', line 1069

def last4
  @last4
end

#locationObject (readonly)

ID of the location that this transaction's reader is assigned to.



1071
1072
1073
# File 'lib/stripe/resources/charge.rb', line 1071

def location
  @location
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.



1073
1074
1075
# File 'lib/stripe/resources/charge.rb', line 1073

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



1075
1076
1077
# File 'lib/stripe/resources/charge.rb', line 1075

def network_transaction_id
  @network_transaction_id
end

#offlineObject (readonly)

Details about payments collected offline.



1077
1078
1079
# File 'lib/stripe/resources/charge.rb', line 1077

def offline
  @offline
end

#overcapture_supportedObject (readonly)

Defines whether the authorized amount can be over-captured or not



1079
1080
1081
# File 'lib/stripe/resources/charge.rb', line 1079

def overcapture_supported
  @overcapture_supported
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.



1081
1082
1083
# File 'lib/stripe/resources/charge.rb', line 1081

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



1083
1084
1085
# File 'lib/stripe/resources/charge.rb', line 1083

def read_method
  @read_method
end

#readerObject (readonly)

ID of the reader this transaction was made on.



1085
1086
1087
# File 'lib/stripe/resources/charge.rb', line 1085

def reader
  @reader
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



1087
1088
1089
# File 'lib/stripe/resources/charge.rb', line 1087

def receipt
  @receipt
end

#walletObject (readonly)

Attribute for field wallet



1089
1090
1091
# File 'lib/stripe/resources/charge.rb', line 1089

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



1095
1096
1097
# File 'lib/stripe/resources/charge.rb', line 1095

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1091
1092
1093
# File 'lib/stripe/resources/charge.rb', line 1091

def self.inner_class_types
  @inner_class_types = { offline: Offline, receipt: Receipt, wallet: Wallet }
end