Class: Stripe::Charge::PaymentMethodDetails::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::CardPresent
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Multicapture, Offline, Reauthorization, Receipt, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The product code that identifies the specific program or product associated with a card.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in ISO 7813 format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#emv_auth_data ⇒ Object
readonly
Authorization response cryptogram.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card's expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#generated_card ⇒ Object
readonly
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization_supported ⇒ Object
readonly
Whether this PaymentIntent is eligible for incremental authorizations.
-
#issuer ⇒ Object
readonly
The name of the card's issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#location ⇒ Object
readonly
ID of the location that this transaction's reader is assigned to.
-
#multicapture ⇒ Object
readonly
Attribute for field multicapture.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#offline ⇒ Object
readonly
Details about payments collected offline.
-
#overcapture_supported ⇒ Object
readonly
Defines whether the authorized amount can be over-captured or not.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#reader ⇒ Object
readonly
ID of the reader this transaction was made on.
-
#reauthorization ⇒ Object
readonly
Whether the PaymentIntent can be reauthorized or not.
-
#reauthorize_before ⇒ Object
readonly
The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.
-
#receipt ⇒ Object
readonly
A collection of fields required to be displayed on receipts.
-
#retrieval_reference_number ⇒ Object
readonly
The retrieval reference number assigned to this transaction.
-
#wallet ⇒ Object
readonly
Attribute for field wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount
1124 1125 1126 |
# File 'lib/stripe/resources/charge.rb', line 1124 def @amount_authorized end |
#brand ⇒ Object (readonly)
Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.
1126 1127 1128 |
# File 'lib/stripe/resources/charge.rb', line 1126 def brand @brand end |
#brand_product ⇒ Object (readonly)
The product code that identifies the specific program or product associated with a card.
1128 1129 1130 |
# File 'lib/stripe/resources/charge.rb', line 1128 def brand_product @brand_product end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
1130 1131 1132 |
# File 'lib/stripe/resources/charge.rb', line 1130 def capture_before @capture_before end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
1132 1133 1134 |
# File 'lib/stripe/resources/charge.rb', line 1132 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
1134 1135 1136 |
# File 'lib/stripe/resources/charge.rb', line 1134 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
1136 1137 1138 |
# File 'lib/stripe/resources/charge.rb', line 1136 def description @description end |
#emv_auth_data ⇒ Object (readonly)
Authorization response cryptogram.
1138 1139 1140 |
# File 'lib/stripe/resources/charge.rb', line 1138 def emv_auth_data @emv_auth_data end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card's expiration month.
1140 1141 1142 |
# File 'lib/stripe/resources/charge.rb', line 1140 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card's expiration year.
1142 1143 1144 |
# File 'lib/stripe/resources/charge.rb', line 1142 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
1146 1147 1148 |
# File 'lib/stripe/resources/charge.rb', line 1146 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be credit, debit, prepaid, or unknown.
1148 1149 1150 |
# File 'lib/stripe/resources/charge.rb', line 1148 def funding @funding end |
#generated_card ⇒ Object (readonly)
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.
1150 1151 1152 |
# File 'lib/stripe/resources/charge.rb', line 1150 def generated_card @generated_card end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
1152 1153 1154 |
# File 'lib/stripe/resources/charge.rb', line 1152 def iin @iin end |
#incremental_authorization_supported ⇒ Object (readonly)
Whether this PaymentIntent is eligible for incremental authorizations. Request support using request_incremental_authorization_support.
1154 1155 1156 |
# File 'lib/stripe/resources/charge.rb', line 1154 def @incremental_authorization_supported end |
#issuer ⇒ Object (readonly)
The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)
1156 1157 1158 |
# File 'lib/stripe/resources/charge.rb', line 1156 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
1158 1159 1160 |
# File 'lib/stripe/resources/charge.rb', line 1158 def last4 @last4 end |
#location ⇒ Object (readonly)
ID of the location that this transaction's reader is assigned to.
1160 1161 1162 |
# File 'lib/stripe/resources/charge.rb', line 1160 def location @location end |
#multicapture ⇒ Object (readonly)
Attribute for field multicapture
1162 1163 1164 |
# File 'lib/stripe/resources/charge.rb', line 1162 def multicapture @multicapture end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.
1164 1165 1166 |
# File 'lib/stripe/resources/charge.rb', line 1164 def network @network end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
1166 1167 1168 |
# File 'lib/stripe/resources/charge.rb', line 1166 def network_transaction_id @network_transaction_id end |
#offline ⇒ Object (readonly)
Details about payments collected offline.
1168 1169 1170 |
# File 'lib/stripe/resources/charge.rb', line 1168 def offline @offline end |
#overcapture_supported ⇒ Object (readonly)
Defines whether the authorized amount can be over-captured or not
1170 1171 1172 |
# File 'lib/stripe/resources/charge.rb', line 1170 def overcapture_supported @overcapture_supported end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.
1172 1173 1174 |
# File 'lib/stripe/resources/charge.rb', line 1172 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
1174 1175 1176 |
# File 'lib/stripe/resources/charge.rb', line 1174 def read_method @read_method end |
#reader ⇒ Object (readonly)
ID of the reader this transaction was made on.
1176 1177 1178 |
# File 'lib/stripe/resources/charge.rb', line 1176 def reader @reader end |
#reauthorization ⇒ Object (readonly)
Whether the PaymentIntent can be reauthorized or not.
1178 1179 1180 |
# File 'lib/stripe/resources/charge.rb', line 1178 def @reauthorization end |
#reauthorize_before ⇒ Object (readonly)
The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.
1180 1181 1182 |
# File 'lib/stripe/resources/charge.rb', line 1180 def @reauthorize_before end |
#receipt ⇒ Object (readonly)
A collection of fields required to be displayed on receipts. Only required for EMV transactions.
1182 1183 1184 |
# File 'lib/stripe/resources/charge.rb', line 1182 def receipt @receipt end |
#retrieval_reference_number ⇒ Object (readonly)
The retrieval reference number assigned to this transaction.
1184 1185 1186 |
# File 'lib/stripe/resources/charge.rb', line 1184 def retrieval_reference_number @retrieval_reference_number end |
#wallet ⇒ Object (readonly)
Attribute for field wallet
1186 1187 1188 |
# File 'lib/stripe/resources/charge.rb', line 1186 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
1198 1199 1200 |
# File 'lib/stripe/resources/charge.rb', line 1198 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1188 1189 1190 1191 1192 1193 1194 1195 1196 |
# File 'lib/stripe/resources/charge.rb', line 1188 def self.inner_class_types @inner_class_types = { multicapture: Multicapture, offline: Offline, reauthorization: Reauthorization, receipt: Receipt, wallet: Wallet, } end |