Class: Stripe::Charge::PaymentMethodDetails::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::CardPresent
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Offline, Reauthorization, Receipt, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#emv_auth_data ⇒ Object
readonly
Authorization response cryptogram.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#generated_card ⇒ Object
readonly
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization_supported ⇒ Object
readonly
Whether this [PaymentIntent](docs.stripe.com/api/payment_intents) is eligible for incremental authorizations.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#location ⇒ Object
readonly
ID of the [location](docs.stripe.com/api/terminal/locations) that this transaction’s reader is assigned to.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#offline ⇒ Object
readonly
Details about payments collected offline.
-
#overcapture_supported ⇒ Object
readonly
Defines whether the authorized amount can be over-captured or not.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#reader ⇒ Object
readonly
ID of the [reader](docs.stripe.com/api/terminal/readers) this transaction was made on.
-
#reauthorization ⇒ Object
readonly
Whether the PaymentIntent can be reauthorized or not.
-
#reauthorize_before ⇒ Object
readonly
The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.
-
#receipt ⇒ Object
readonly
A collection of fields required to be displayed on receipts.
-
#wallet ⇒ Object
readonly
Attribute for field wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount
1062 1063 1064 |
# File 'lib/stripe/resources/charge.rb', line 1062 def @amount_authorized end |
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.
1064 1065 1066 |
# File 'lib/stripe/resources/charge.rb', line 1064 def brand @brand end |
#brand_product ⇒ Object (readonly)
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
1066 1067 1068 |
# File 'lib/stripe/resources/charge.rb', line 1066 def brand_product @brand_product end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
1068 1069 1070 |
# File 'lib/stripe/resources/charge.rb', line 1068 def capture_before @capture_before end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
1070 1071 1072 |
# File 'lib/stripe/resources/charge.rb', line 1070 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
1072 1073 1074 |
# File 'lib/stripe/resources/charge.rb', line 1072 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
1074 1075 1076 |
# File 'lib/stripe/resources/charge.rb', line 1074 def description @description end |
#emv_auth_data ⇒ Object (readonly)
Authorization response cryptogram.
1076 1077 1078 |
# File 'lib/stripe/resources/charge.rb', line 1076 def emv_auth_data @emv_auth_data end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
1078 1079 1080 |
# File 'lib/stripe/resources/charge.rb', line 1078 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
1080 1081 1082 |
# File 'lib/stripe/resources/charge.rb', line 1080 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
1084 1085 1086 |
# File 'lib/stripe/resources/charge.rb', line 1084 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
1086 1087 1088 |
# File 'lib/stripe/resources/charge.rb', line 1086 def funding @funding end |
#generated_card ⇒ Object (readonly)
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.
1088 1089 1090 |
# File 'lib/stripe/resources/charge.rb', line 1088 def generated_card @generated_card end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
1090 1091 1092 |
# File 'lib/stripe/resources/charge.rb', line 1090 def iin @iin end |
#incremental_authorization_supported ⇒ Object (readonly)
Whether this [PaymentIntent](docs.stripe.com/api/payment_intents) is eligible for incremental authorizations. Request support using [request_incremental_authorization_support](docs.stripe.com/api/payment_intents/create#create_payment_intent-payment_method_options-card_present-request_incremental_authorization_support).
1092 1093 1094 |
# File 'lib/stripe/resources/charge.rb', line 1092 def @incremental_authorization_supported end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
1094 1095 1096 |
# File 'lib/stripe/resources/charge.rb', line 1094 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
1096 1097 1098 |
# File 'lib/stripe/resources/charge.rb', line 1096 def last4 @last4 end |
#location ⇒ Object (readonly)
ID of the [location](docs.stripe.com/api/terminal/locations) that this transaction’s reader is assigned to.
1098 1099 1100 |
# File 'lib/stripe/resources/charge.rb', line 1098 def location @location end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
1100 1101 1102 |
# File 'lib/stripe/resources/charge.rb', line 1100 def network @network end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
1102 1103 1104 |
# File 'lib/stripe/resources/charge.rb', line 1102 def network_transaction_id @network_transaction_id end |
#offline ⇒ Object (readonly)
Details about payments collected offline.
1104 1105 1106 |
# File 'lib/stripe/resources/charge.rb', line 1104 def offline @offline end |
#overcapture_supported ⇒ Object (readonly)
Defines whether the authorized amount can be over-captured or not
1106 1107 1108 |
# File 'lib/stripe/resources/charge.rb', line 1106 def overcapture_supported @overcapture_supported end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.
1108 1109 1110 |
# File 'lib/stripe/resources/charge.rb', line 1108 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
1110 1111 1112 |
# File 'lib/stripe/resources/charge.rb', line 1110 def read_method @read_method end |
#reader ⇒ Object (readonly)
ID of the [reader](docs.stripe.com/api/terminal/readers) this transaction was made on.
1112 1113 1114 |
# File 'lib/stripe/resources/charge.rb', line 1112 def reader @reader end |
#reauthorization ⇒ Object (readonly)
Whether the PaymentIntent can be reauthorized or not.
1118 1119 1120 |
# File 'lib/stripe/resources/charge.rb', line 1118 def @reauthorization end |
#reauthorize_before ⇒ Object (readonly)
The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.
1120 1121 1122 |
# File 'lib/stripe/resources/charge.rb', line 1120 def @reauthorize_before end |
#receipt ⇒ Object (readonly)
A collection of fields required to be displayed on receipts. Only required for EMV transactions.
1114 1115 1116 |
# File 'lib/stripe/resources/charge.rb', line 1114 def receipt @receipt end |
#wallet ⇒ Object (readonly)
Attribute for field wallet
1116 1117 1118 |
# File 'lib/stripe/resources/charge.rb', line 1116 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
1131 1132 1133 |
# File 'lib/stripe/resources/charge.rb', line 1131 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1122 1123 1124 1125 1126 1127 1128 1129 |
# File 'lib/stripe/resources/charge.rb', line 1122 def self.inner_class_types @inner_class_types = { offline: Offline, receipt: Receipt, wallet: Wallet, reauthorization: Reauthorization, } end |