Class: Stripe::Charge::PaymentMethodDetails::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::CardPresent
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Offline, Receipt, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#emv_auth_data ⇒ Object
readonly
Authorization response cryptogram.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#generated_card ⇒ Object
readonly
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization_supported ⇒ Object
readonly
Whether this [PaymentIntent](stripe.com/docs/api/payment_intents) is eligible for incremental authorizations.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#offline ⇒ Object
readonly
Details about payments collected offline.
-
#overcapture_supported ⇒ Object
readonly
Defines whether the authorized amount can be over-captured or not.
-
#preferred_locales ⇒ Object
readonly
EMV tag 5F2D.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#receipt ⇒ Object
readonly
A collection of fields required to be displayed on receipts.
-
#wallet ⇒ Object
readonly
Attribute for field wallet.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount
541 542 543 |
# File 'lib/stripe/resources/charge.rb', line 541 def @amount_authorized end |
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
543 544 545 |
# File 'lib/stripe/resources/charge.rb', line 543 def brand @brand end |
#brand_product ⇒ Object (readonly)
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
545 546 547 |
# File 'lib/stripe/resources/charge.rb', line 545 def brand_product @brand_product end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
547 548 549 |
# File 'lib/stripe/resources/charge.rb', line 547 def capture_before @capture_before end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
549 550 551 |
# File 'lib/stripe/resources/charge.rb', line 549 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
551 552 553 |
# File 'lib/stripe/resources/charge.rb', line 551 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
553 554 555 |
# File 'lib/stripe/resources/charge.rb', line 553 def description @description end |
#emv_auth_data ⇒ Object (readonly)
Authorization response cryptogram.
555 556 557 |
# File 'lib/stripe/resources/charge.rb', line 555 def emv_auth_data @emv_auth_data end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
557 558 559 |
# File 'lib/stripe/resources/charge.rb', line 557 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
559 560 561 |
# File 'lib/stripe/resources/charge.rb', line 559 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
563 564 565 |
# File 'lib/stripe/resources/charge.rb', line 563 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
565 566 567 |
# File 'lib/stripe/resources/charge.rb', line 565 def funding @funding end |
#generated_card ⇒ Object (readonly)
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.
567 568 569 |
# File 'lib/stripe/resources/charge.rb', line 567 def generated_card @generated_card end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
569 570 571 |
# File 'lib/stripe/resources/charge.rb', line 569 def iin @iin end |
#incremental_authorization_supported ⇒ Object (readonly)
Whether this [PaymentIntent](stripe.com/docs/api/payment_intents) is eligible for incremental authorizations. Request support using [request_incremental_authorization_support](stripe.com/docs/api/payment_intents/create#create_payment_intent-payment_method_options-card_present-request_incremental_authorization_support).
571 572 573 |
# File 'lib/stripe/resources/charge.rb', line 571 def @incremental_authorization_supported end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
573 574 575 |
# File 'lib/stripe/resources/charge.rb', line 573 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
575 576 577 |
# File 'lib/stripe/resources/charge.rb', line 575 def last4 @last4 end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
577 578 579 |
# File 'lib/stripe/resources/charge.rb', line 577 def network @network end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
579 580 581 |
# File 'lib/stripe/resources/charge.rb', line 579 def network_transaction_id @network_transaction_id end |
#offline ⇒ Object (readonly)
Details about payments collected offline.
581 582 583 |
# File 'lib/stripe/resources/charge.rb', line 581 def offline @offline end |
#overcapture_supported ⇒ Object (readonly)
Defines whether the authorized amount can be over-captured or not
583 584 585 |
# File 'lib/stripe/resources/charge.rb', line 583 def overcapture_supported @overcapture_supported end |
#preferred_locales ⇒ Object (readonly)
EMV tag 5F2D. Preferred languages specified by the integrated circuit chip.
585 586 587 |
# File 'lib/stripe/resources/charge.rb', line 585 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
587 588 589 |
# File 'lib/stripe/resources/charge.rb', line 587 def read_method @read_method end |
#receipt ⇒ Object (readonly)
A collection of fields required to be displayed on receipts. Only required for EMV transactions.
589 590 591 |
# File 'lib/stripe/resources/charge.rb', line 589 def receipt @receipt end |
#wallet ⇒ Object (readonly)
Attribute for field wallet
591 592 593 |
# File 'lib/stripe/resources/charge.rb', line 591 def wallet @wallet end |