Class: Stripe::Charge::PaymentMethodDetails::CardPresent::Receipt

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_typeObject (readonly)

The type of account being debited or credited



1051
1052
1053
# File 'lib/stripe/resources/charge.rb', line 1051

def 
  @account_type
end

#application_cryptogramObject (readonly)

The Application Cryptogram, a unique value generated by the card to authenticate the transaction with issuers.



1053
1054
1055
# File 'lib/stripe/resources/charge.rb', line 1053

def application_cryptogram
  @application_cryptogram
end

#application_preferred_nameObject (readonly)

The Application Identifier (AID) on the card used to determine which networks are eligible to process the transaction. Referenced from EMV tag 9F12, data encoded on the card’s chip.



1055
1056
1057
# File 'lib/stripe/resources/charge.rb', line 1055

def application_preferred_name
  @application_preferred_name
end

#authorization_codeObject (readonly)

Identifier for this transaction.



1057
1058
1059
# File 'lib/stripe/resources/charge.rb', line 1057

def authorization_code
  @authorization_code
end

#authorization_response_codeObject (readonly)

EMV tag 8A. A code returned by the card issuer.



1059
1060
1061
# File 'lib/stripe/resources/charge.rb', line 1059

def authorization_response_code
  @authorization_response_code
end

#cardholder_verification_methodObject (readonly)

Describes the method used by the cardholder to verify ownership of the card. One of the following: ‘approval`, `failure`, `none`, `offline_pin`, `offline_pin_and_signature`, `online_pin`, or `signature`.



1061
1062
1063
# File 'lib/stripe/resources/charge.rb', line 1061

def cardholder_verification_method
  @cardholder_verification_method
end

#dedicated_file_nameObject (readonly)

Similar to the application_preferred_name, identifying the applications (AIDs) available on the card. Referenced from EMV tag 84.



1063
1064
1065
# File 'lib/stripe/resources/charge.rb', line 1063

def dedicated_file_name
  @dedicated_file_name
end

#terminal_verification_resultsObject (readonly)

A 5-byte string that records the checks and validations that occur between the card and the terminal. These checks determine how the terminal processes the transaction and what risk tolerance is acceptable. Referenced from EMV Tag 95.



1065
1066
1067
# File 'lib/stripe/resources/charge.rb', line 1065

def terminal_verification_results
  @terminal_verification_results
end

#transaction_status_informationObject (readonly)

An indication of which steps were completed during the card read process. Referenced from EMV Tag 9B.



1067
1068
1069
# File 'lib/stripe/resources/charge.rb', line 1067

def transaction_status_information
  @transaction_status_information
end

Class Method Details

.field_remappingsObject



1073
1074
1075
# File 'lib/stripe/resources/charge.rb', line 1073

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1069
1070
1071
# File 'lib/stripe/resources/charge.rb', line 1069

def self.inner_class_types
  @inner_class_types = {}
end