Class: Stripe::Charge::PaymentMethodDetails::CardPresent::Receipt

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_typeObject (readonly)

The type of account being debited or credited



663
664
665
# File 'lib/stripe/resources/charge.rb', line 663

def 
  @account_type
end

#application_cryptogramObject (readonly)

EMV tag 9F26, cryptogram generated by the integrated circuit chip.



666
667
668
# File 'lib/stripe/resources/charge.rb', line 666

def application_cryptogram
  @application_cryptogram
end

#application_preferred_nameObject (readonly)

Mnenomic of the Application Identifier.



669
670
671
# File 'lib/stripe/resources/charge.rb', line 669

def application_preferred_name
  @application_preferred_name
end

#authorization_codeObject (readonly)

Identifier for this transaction.



672
673
674
# File 'lib/stripe/resources/charge.rb', line 672

def authorization_code
  @authorization_code
end

#authorization_response_codeObject (readonly)

EMV tag 8A. A code returned by the card issuer.



675
676
677
# File 'lib/stripe/resources/charge.rb', line 675

def authorization_response_code
  @authorization_response_code
end

#cardholder_verification_methodObject (readonly)

Describes the method used by the cardholder to verify ownership of the card. One of the following: ‘approval`, `failure`, `none`, `offline_pin`, `offline_pin_and_signature`, `online_pin`, or `signature`.



678
679
680
# File 'lib/stripe/resources/charge.rb', line 678

def cardholder_verification_method
  @cardholder_verification_method
end

#dedicated_file_nameObject (readonly)

EMV tag 84. Similar to the application identifier stored on the integrated circuit chip.



681
682
683
# File 'lib/stripe/resources/charge.rb', line 681

def dedicated_file_name
  @dedicated_file_name
end

#terminal_verification_resultsObject (readonly)

The outcome of a series of EMV functions performed by the card reader.



684
685
686
# File 'lib/stripe/resources/charge.rb', line 684

def terminal_verification_results
  @terminal_verification_results
end

#transaction_status_informationObject (readonly)

An indication of various EMV functions performed during the transaction.



687
688
689
# File 'lib/stripe/resources/charge.rb', line 687

def transaction_status_information
  @transaction_status_information
end