Class: Stripe::Charge::PaymentMethodDetails::Crypto

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#buyer_addressObject (readonly)

The wallet address of the customer.



1171
1172
1173
# File 'lib/stripe/resources/charge.rb', line 1171

def buyer_address
  @buyer_address
end

#networkObject (readonly)

The blockchain network that the transaction was sent on.



1173
1174
1175
# File 'lib/stripe/resources/charge.rb', line 1173

def network
  @network
end

#token_currencyObject (readonly)

The token currency that the transaction was sent with.



1175
1176
1177
# File 'lib/stripe/resources/charge.rb', line 1175

def token_currency
  @token_currency
end

#transaction_hashObject (readonly)

The blockchain transaction hash of the crypto payment.



1177
1178
1179
# File 'lib/stripe/resources/charge.rb', line 1177

def transaction_hash
  @transaction_hash
end

Class Method Details

.field_remappingsObject



1183
1184
1185
# File 'lib/stripe/resources/charge.rb', line 1183

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1179
1180
1181
# File 'lib/stripe/resources/charge.rb', line 1179

def self.inner_class_types
  @inner_class_types = {}
end