Class: Stripe::Charge::PaymentMethodDetails::Crypto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Crypto
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#buyer_address ⇒ Object
readonly
The wallet address of the customer.
-
#network ⇒ Object
readonly
The blockchain network that the transaction was sent on.
-
#token_currency ⇒ Object
readonly
The token currency that the transaction was sent with.
-
#transaction_hash ⇒ Object
readonly
The blockchain transaction hash of the crypto payment.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#buyer_address ⇒ Object (readonly)
The wallet address of the customer.
605 606 607 |
# File 'lib/stripe/resources/charge.rb', line 605 def buyer_address @buyer_address end |
#network ⇒ Object (readonly)
The blockchain network that the transaction was sent on.
607 608 609 |
# File 'lib/stripe/resources/charge.rb', line 607 def network @network end |
#token_currency ⇒ Object (readonly)
The token currency that the transaction was sent with.
609 610 611 |
# File 'lib/stripe/resources/charge.rb', line 609 def token_currency @token_currency end |
#transaction_hash ⇒ Object (readonly)
The blockchain transaction hash of the crypto payment.
611 612 613 |
# File 'lib/stripe/resources/charge.rb', line 611 def transaction_hash @transaction_hash end |