Class: Stripe::Charge::PaymentMethodDetails::GiftCard

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Balance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

Attribute for field balance



1248
1249
1250
# File 'lib/stripe/resources/charge.rb', line 1248

def balance
  @balance
end

#brandObject (readonly)

The brand of the gift card.



1250
1251
1252
# File 'lib/stripe/resources/charge.rb', line 1250

def brand
  @brand
end

#exp_monthObject (readonly)

The expiration month of the gift card.



1252
1253
1254
# File 'lib/stripe/resources/charge.rb', line 1252

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the gift card.



1254
1255
1256
# File 'lib/stripe/resources/charge.rb', line 1254

def exp_year
  @exp_year
end

#first6Object (readonly)

The first six digits of the gift card number.



1256
1257
1258
# File 'lib/stripe/resources/charge.rb', line 1256

def first6
  @first6
end

#last4Object (readonly)

The last four digits of the gift card number.



1258
1259
1260
# File 'lib/stripe/resources/charge.rb', line 1258

def last4
  @last4
end

#transaction_idObject (readonly)

The transaction ID from the gift card processor.



1260
1261
1262
# File 'lib/stripe/resources/charge.rb', line 1260

def transaction_id
  @transaction_id
end

Class Method Details

.field_remappingsObject



1266
1267
1268
# File 'lib/stripe/resources/charge.rb', line 1266

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1262
1263
1264
# File 'lib/stripe/resources/charge.rb', line 1262

def self.inner_class_types
  @inner_class_types = { balance: Balance }
end