Class: Stripe::Charge::PaymentMethodDetails::GiftCard
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::GiftCard
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Balance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#balance ⇒ Object
readonly
Attribute for field balance.
-
#brand ⇒ Object
readonly
The brand of the gift card.
-
#exp_month ⇒ Object
readonly
The expiration month of the gift card.
-
#exp_year ⇒ Object
readonly
The expiration year of the gift card.
-
#first6 ⇒ Object
readonly
The first six digits of the gift card number.
-
#transaction_id ⇒ Object
readonly
The transaction ID from the gift card processor.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#balance ⇒ Object (readonly)
Attribute for field balance
1248 1249 1250 |
# File 'lib/stripe/resources/charge.rb', line 1248 def balance @balance end |
#brand ⇒ Object (readonly)
The brand of the gift card.
1250 1251 1252 |
# File 'lib/stripe/resources/charge.rb', line 1250 def brand @brand end |
#exp_month ⇒ Object (readonly)
The expiration month of the gift card.
1252 1253 1254 |
# File 'lib/stripe/resources/charge.rb', line 1252 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
The expiration year of the gift card.
1254 1255 1256 |
# File 'lib/stripe/resources/charge.rb', line 1254 def exp_year @exp_year end |
#first6 ⇒ Object (readonly)
The first six digits of the gift card number.
1256 1257 1258 |
# File 'lib/stripe/resources/charge.rb', line 1256 def first6 @first6 end |
#transaction_id ⇒ Object (readonly)
The transaction ID from the gift card processor.
1258 1259 1260 |
# File 'lib/stripe/resources/charge.rb', line 1258 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
1264 1265 1266 |
# File 'lib/stripe/resources/charge.rb', line 1264 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1260 1261 1262 |
# File 'lib/stripe/resources/charge.rb', line 1260 def self.inner_class_types @inner_class_types = { balance: Balance } end |