Class: Stripe::Charge::PaymentMethodDetails::Giropay

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1143
1144
1145
# File 'lib/stripe/resources/charge.rb', line 1143

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1145
1146
1147
# File 'lib/stripe/resources/charge.rb', line 1145

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1147
1148
1149
# File 'lib/stripe/resources/charge.rb', line 1147

def bic
  @bic
end

#verified_nameObject (readonly)

Owner's verified full name. Values are verified or provided by Giropay directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Giropay rarely provides this information so the attribute is usually empty.



1151
1152
1153
# File 'lib/stripe/resources/charge.rb', line 1151

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1157
1158
1159
# File 'lib/stripe/resources/charge.rb', line 1157

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1153
1154
1155
# File 'lib/stripe/resources/charge.rb', line 1153

def self.inner_class_types
  @inner_class_types = {}
end