Class: Stripe::Charge::PaymentMethodDetails::IdBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::IdBankTransfer
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number of the bank account to transfer funds to.
-
#bank ⇒ Object
readonly
Bank where the account is located.
-
#bank_code ⇒ Object
readonly
Local bank code of the bank.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#display_name ⇒ Object
readonly
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number of the bank account to transfer funds to.
1378 1379 1380 |
# File 'lib/stripe/resources/charge.rb', line 1378 def account_number @account_number end |
#bank ⇒ Object (readonly)
Bank where the account is located.
1380 1381 1382 |
# File 'lib/stripe/resources/charge.rb', line 1380 def bank @bank end |
#bank_code ⇒ Object (readonly)
Local bank code of the bank.
1382 1383 1384 |
# File 'lib/stripe/resources/charge.rb', line 1382 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1384 1385 1386 |
# File 'lib/stripe/resources/charge.rb', line 1384 def bank_name @bank_name end |
#display_name ⇒ Object (readonly)
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
1386 1387 1388 |
# File 'lib/stripe/resources/charge.rb', line 1386 def display_name @display_name end |
Class Method Details
.field_remappings ⇒ Object
1392 1393 1394 |
# File 'lib/stripe/resources/charge.rb', line 1392 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1388 1389 1390 |
# File 'lib/stripe/resources/charge.rb', line 1388 def self.inner_class_types @inner_class_types = {} end |