Class: Stripe::Charge::PaymentMethodDetails::IdBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::IdBankTransfer
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number of the bank account to transfer funds to.
-
#bank ⇒ Object
readonly
Bank where the account is located.
-
#bank_code ⇒ Object
readonly
Local bank code of the bank.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#display_name ⇒ Object
readonly
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number of the bank account to transfer funds to.
1330 1331 1332 |
# File 'lib/stripe/resources/charge.rb', line 1330 def account_number @account_number end |
#bank ⇒ Object (readonly)
Bank where the account is located.
1332 1333 1334 |
# File 'lib/stripe/resources/charge.rb', line 1332 def bank @bank end |
#bank_code ⇒ Object (readonly)
Local bank code of the bank.
1334 1335 1336 |
# File 'lib/stripe/resources/charge.rb', line 1334 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1336 1337 1338 |
# File 'lib/stripe/resources/charge.rb', line 1336 def bank_name @bank_name end |
#display_name ⇒ Object (readonly)
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
1338 1339 1340 |
# File 'lib/stripe/resources/charge.rb', line 1338 def display_name @display_name end |
Class Method Details
.field_remappings ⇒ Object
1344 1345 1346 |
# File 'lib/stripe/resources/charge.rb', line 1344 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1340 1341 1342 |
# File 'lib/stripe/resources/charge.rb', line 1340 def self.inner_class_types @inner_class_types = {} end |