Class: Stripe::Charge::PaymentMethodDetails::IdBankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_numberObject (readonly)

Account number of the bank account to transfer funds to.



1206
1207
1208
# File 'lib/stripe/resources/charge.rb', line 1206

def 
  @account_number
end

#bankObject (readonly)

Bank where the account is located.



1208
1209
1210
# File 'lib/stripe/resources/charge.rb', line 1208

def bank
  @bank
end

#bank_codeObject (readonly)

Local bank code of the bank.



1210
1211
1212
# File 'lib/stripe/resources/charge.rb', line 1210

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1212
1213
1214
# File 'lib/stripe/resources/charge.rb', line 1212

def bank_name
  @bank_name
end

#display_nameObject (readonly)

Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.



1214
1215
1216
# File 'lib/stripe/resources/charge.rb', line 1214

def display_name
  @display_name
end

Class Method Details

.field_remappingsObject



1220
1221
1222
# File 'lib/stripe/resources/charge.rb', line 1220

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1216
1217
1218
# File 'lib/stripe/resources/charge.rb', line 1216

def self.inner_class_types
  @inner_class_types = {}
end