Class: Stripe::Charge::PaymentMethodDetails::IdBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::IdBankTransfer
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number of the bank account to transfer funds to.
-
#bank ⇒ Object
readonly
Bank where the account is located.
-
#bank_code ⇒ Object
readonly
Local bank code of the bank.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#display_name ⇒ Object
readonly
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number of the bank account to transfer funds to.
657 658 659 |
# File 'lib/stripe/resources/charge.rb', line 657 def account_number @account_number end |
#bank ⇒ Object (readonly)
Bank where the account is located.
659 660 661 |
# File 'lib/stripe/resources/charge.rb', line 659 def bank @bank end |
#bank_code ⇒ Object (readonly)
Local bank code of the bank.
661 662 663 |
# File 'lib/stripe/resources/charge.rb', line 661 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
663 664 665 |
# File 'lib/stripe/resources/charge.rb', line 663 def bank_name @bank_name end |
#display_name ⇒ Object (readonly)
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
665 666 667 |
# File 'lib/stripe/resources/charge.rb', line 665 def display_name @display_name end |