Class: Stripe::Charge::PaymentMethodDetails::InteracPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::InteracPresent
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Receipt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in ISO 7813 format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#emv_auth_data ⇒ Object
readonly
Authorization response cryptogram.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card's expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#generated_card ⇒ Object
readonly
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card's issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#location ⇒ Object
readonly
ID of the location that this transaction's reader is assigned to.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#reader ⇒ Object
readonly
ID of the reader this transaction was made on.
-
#receipt ⇒ Object
readonly
A collection of fields required to be displayed on receipts.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be interac, mastercard or visa.
1231 1232 1233 |
# File 'lib/stripe/resources/charge.rb', line 1231 def brand @brand end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
1233 1234 1235 |
# File 'lib/stripe/resources/charge.rb', line 1233 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
1235 1236 1237 |
# File 'lib/stripe/resources/charge.rb', line 1235 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
1237 1238 1239 |
# File 'lib/stripe/resources/charge.rb', line 1237 def description @description end |
#emv_auth_data ⇒ Object (readonly)
Authorization response cryptogram.
1239 1240 1241 |
# File 'lib/stripe/resources/charge.rb', line 1239 def emv_auth_data @emv_auth_data end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card's expiration month.
1241 1242 1243 |
# File 'lib/stripe/resources/charge.rb', line 1241 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card's expiration year.
1243 1244 1245 |
# File 'lib/stripe/resources/charge.rb', line 1243 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
1247 1248 1249 |
# File 'lib/stripe/resources/charge.rb', line 1247 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be credit, debit, prepaid, or unknown.
1249 1250 1251 |
# File 'lib/stripe/resources/charge.rb', line 1249 def funding @funding end |
#generated_card ⇒ Object (readonly)
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.
1251 1252 1253 |
# File 'lib/stripe/resources/charge.rb', line 1251 def generated_card @generated_card end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
1253 1254 1255 |
# File 'lib/stripe/resources/charge.rb', line 1253 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)
1255 1256 1257 |
# File 'lib/stripe/resources/charge.rb', line 1255 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
1257 1258 1259 |
# File 'lib/stripe/resources/charge.rb', line 1257 def last4 @last4 end |
#location ⇒ Object (readonly)
ID of the location that this transaction's reader is assigned to.
1259 1260 1261 |
# File 'lib/stripe/resources/charge.rb', line 1259 def location @location end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.
1261 1262 1263 |
# File 'lib/stripe/resources/charge.rb', line 1261 def network @network end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
1263 1264 1265 |
# File 'lib/stripe/resources/charge.rb', line 1263 def network_transaction_id @network_transaction_id end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.
1265 1266 1267 |
# File 'lib/stripe/resources/charge.rb', line 1265 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
1267 1268 1269 |
# File 'lib/stripe/resources/charge.rb', line 1267 def read_method @read_method end |
#reader ⇒ Object (readonly)
ID of the reader this transaction was made on.
1269 1270 1271 |
# File 'lib/stripe/resources/charge.rb', line 1269 def reader @reader end |
#receipt ⇒ Object (readonly)
A collection of fields required to be displayed on receipts. Only required for EMV transactions.
1271 1272 1273 |
# File 'lib/stripe/resources/charge.rb', line 1271 def receipt @receipt end |
Class Method Details
.field_remappings ⇒ Object
1277 1278 1279 |
# File 'lib/stripe/resources/charge.rb', line 1277 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1273 1274 1275 |
# File 'lib/stripe/resources/charge.rb', line 1273 def self.inner_class_types @inner_class_types = { receipt: Receipt } end |