Class: Stripe::Charge::PaymentMethodDetails::InteracPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Receipt

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘interac`, `mastercard` or `visa`.



1227
1228
1229
# File 'lib/stripe/resources/charge.rb', line 1227

def brand
  @brand
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



1229
1230
1231
# File 'lib/stripe/resources/charge.rb', line 1229

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



1231
1232
1233
# File 'lib/stripe/resources/charge.rb', line 1231

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



1233
1234
1235
# File 'lib/stripe/resources/charge.rb', line 1233

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



1235
1236
1237
# File 'lib/stripe/resources/charge.rb', line 1235

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



1237
1238
1239
# File 'lib/stripe/resources/charge.rb', line 1237

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



1239
1240
1241
# File 'lib/stripe/resources/charge.rb', line 1239

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



1243
1244
1245
# File 'lib/stripe/resources/charge.rb', line 1243

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



1245
1246
1247
# File 'lib/stripe/resources/charge.rb', line 1245

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



1247
1248
1249
# File 'lib/stripe/resources/charge.rb', line 1247

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



1249
1250
1251
# File 'lib/stripe/resources/charge.rb', line 1249

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



1251
1252
1253
# File 'lib/stripe/resources/charge.rb', line 1251

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



1253
1254
1255
# File 'lib/stripe/resources/charge.rb', line 1253

def last4
  @last4
end

#locationObject (readonly)

ID of the [location](docs.stripe.com/api/terminal/locations) that this transaction’s reader is assigned to.



1255
1256
1257
# File 'lib/stripe/resources/charge.rb', line 1255

def location
  @location
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



1257
1258
1259
# File 'lib/stripe/resources/charge.rb', line 1257

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



1259
1260
1261
# File 'lib/stripe/resources/charge.rb', line 1259

def network_transaction_id
  @network_transaction_id
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.



1261
1262
1263
# File 'lib/stripe/resources/charge.rb', line 1261

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



1263
1264
1265
# File 'lib/stripe/resources/charge.rb', line 1263

def read_method
  @read_method
end

#readerObject (readonly)

ID of the [reader](docs.stripe.com/api/terminal/readers) this transaction was made on.



1265
1266
1267
# File 'lib/stripe/resources/charge.rb', line 1265

def reader
  @reader
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



1267
1268
1269
# File 'lib/stripe/resources/charge.rb', line 1267

def receipt
  @receipt
end

Class Method Details

.field_remappingsObject



1273
1274
1275
# File 'lib/stripe/resources/charge.rb', line 1273

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1269
1270
1271
# File 'lib/stripe/resources/charge.rb', line 1269

def self.inner_class_types
  @inner_class_types = { receipt: Receipt }
end