Class: Stripe::Charge::PaymentMethodDetails::InteracPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Receipt

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘interac`, `mastercard` or `visa`.



1281
1282
1283
# File 'lib/stripe/resources/charge.rb', line 1281

def brand
  @brand
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



1283
1284
1285
# File 'lib/stripe/resources/charge.rb', line 1283

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



1285
1286
1287
# File 'lib/stripe/resources/charge.rb', line 1285

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



1287
1288
1289
# File 'lib/stripe/resources/charge.rb', line 1287

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



1289
1290
1291
# File 'lib/stripe/resources/charge.rb', line 1289

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



1291
1292
1293
# File 'lib/stripe/resources/charge.rb', line 1291

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



1293
1294
1295
# File 'lib/stripe/resources/charge.rb', line 1293

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



1297
1298
1299
# File 'lib/stripe/resources/charge.rb', line 1297

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



1299
1300
1301
# File 'lib/stripe/resources/charge.rb', line 1299

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



1301
1302
1303
# File 'lib/stripe/resources/charge.rb', line 1301

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



1303
1304
1305
# File 'lib/stripe/resources/charge.rb', line 1303

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



1305
1306
1307
# File 'lib/stripe/resources/charge.rb', line 1305

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



1307
1308
1309
# File 'lib/stripe/resources/charge.rb', line 1307

def last4
  @last4
end

#locationObject (readonly)

ID of the [location](docs.stripe.com/api/terminal/locations) that this transaction’s reader is assigned to.



1309
1310
1311
# File 'lib/stripe/resources/charge.rb', line 1309

def location
  @location
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



1311
1312
1313
# File 'lib/stripe/resources/charge.rb', line 1311

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



1313
1314
1315
# File 'lib/stripe/resources/charge.rb', line 1313

def network_transaction_id
  @network_transaction_id
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.



1315
1316
1317
# File 'lib/stripe/resources/charge.rb', line 1315

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



1317
1318
1319
# File 'lib/stripe/resources/charge.rb', line 1317

def read_method
  @read_method
end

#readerObject (readonly)

ID of the [reader](docs.stripe.com/api/terminal/readers) this transaction was made on.



1319
1320
1321
# File 'lib/stripe/resources/charge.rb', line 1319

def reader
  @reader
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



1321
1322
1323
# File 'lib/stripe/resources/charge.rb', line 1321

def receipt
  @receipt
end

Class Method Details

.field_remappingsObject



1327
1328
1329
# File 'lib/stripe/resources/charge.rb', line 1327

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1323
1324
1325
# File 'lib/stripe/resources/charge.rb', line 1323

def self.inner_class_types
  @inner_class_types = { receipt: Receipt }
end