Class: Stripe::Charge::PaymentMethodDetails::InteracPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Receipt

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘interac`, `mastercard` or `visa`.



702
703
704
# File 'lib/stripe/resources/charge.rb', line 702

def brand
  @brand
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



704
705
706
# File 'lib/stripe/resources/charge.rb', line 704

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



706
707
708
# File 'lib/stripe/resources/charge.rb', line 706

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



708
709
710
# File 'lib/stripe/resources/charge.rb', line 708

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



710
711
712
# File 'lib/stripe/resources/charge.rb', line 710

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



712
713
714
# File 'lib/stripe/resources/charge.rb', line 712

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



714
715
716
# File 'lib/stripe/resources/charge.rb', line 714

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



718
719
720
# File 'lib/stripe/resources/charge.rb', line 718

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



720
721
722
# File 'lib/stripe/resources/charge.rb', line 720

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



722
723
724
# File 'lib/stripe/resources/charge.rb', line 722

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



724
725
726
# File 'lib/stripe/resources/charge.rb', line 724

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



726
727
728
# File 'lib/stripe/resources/charge.rb', line 726

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



728
729
730
# File 'lib/stripe/resources/charge.rb', line 728

def last4
  @last4
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



730
731
732
# File 'lib/stripe/resources/charge.rb', line 730

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



732
733
734
# File 'lib/stripe/resources/charge.rb', line 732

def network_transaction_id
  @network_transaction_id
end

#preferred_localesObject (readonly)

EMV tag 5F2D. Preferred languages specified by the integrated circuit chip.



734
735
736
# File 'lib/stripe/resources/charge.rb', line 734

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



736
737
738
# File 'lib/stripe/resources/charge.rb', line 736

def read_method
  @read_method
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



738
739
740
# File 'lib/stripe/resources/charge.rb', line 738

def receipt
  @receipt
end