Class: Stripe::Charge::PaymentMethodDetails::InteracPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::InteracPresent
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Receipt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#emv_auth_data ⇒ Object
readonly
Authorization response cryptogram.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#generated_card ⇒ Object
readonly
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#preferred_locales ⇒ Object
readonly
EMV tag 5F2D.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#receipt ⇒ Object
readonly
A collection of fields required to be displayed on receipts.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be ‘interac`, `mastercard` or `visa`.
894 895 896 |
# File 'lib/stripe/resources/charge.rb', line 894 def brand @brand end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
897 898 899 |
# File 'lib/stripe/resources/charge.rb', line 897 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
900 901 902 |
# File 'lib/stripe/resources/charge.rb', line 900 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
903 904 905 |
# File 'lib/stripe/resources/charge.rb', line 903 def description @description end |
#emv_auth_data ⇒ Object (readonly)
Authorization response cryptogram.
906 907 908 |
# File 'lib/stripe/resources/charge.rb', line 906 def emv_auth_data @emv_auth_data end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
909 910 911 |
# File 'lib/stripe/resources/charge.rb', line 909 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
912 913 914 |
# File 'lib/stripe/resources/charge.rb', line 912 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
917 918 919 |
# File 'lib/stripe/resources/charge.rb', line 917 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
920 921 922 |
# File 'lib/stripe/resources/charge.rb', line 920 def funding @funding end |
#generated_card ⇒ Object (readonly)
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.
923 924 925 |
# File 'lib/stripe/resources/charge.rb', line 923 def generated_card @generated_card end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
926 927 928 |
# File 'lib/stripe/resources/charge.rb', line 926 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
929 930 931 |
# File 'lib/stripe/resources/charge.rb', line 929 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
932 933 934 |
# File 'lib/stripe/resources/charge.rb', line 932 def last4 @last4 end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
935 936 937 |
# File 'lib/stripe/resources/charge.rb', line 935 def network @network end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. The first three digits of the Trace ID is the Financial Network Code, the next 6 digits is the Banknet Reference Number, and the last 4 digits represent the date (MM/DD). This field will be available for successful Visa, Mastercard, or American Express transactions and always null for other card brands.
938 939 940 |
# File 'lib/stripe/resources/charge.rb', line 938 def network_transaction_id @network_transaction_id end |
#preferred_locales ⇒ Object (readonly)
EMV tag 5F2D. Preferred languages specified by the integrated circuit chip.
941 942 943 |
# File 'lib/stripe/resources/charge.rb', line 941 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
944 945 946 |
# File 'lib/stripe/resources/charge.rb', line 944 def read_method @read_method end |
#receipt ⇒ Object (readonly)
A collection of fields required to be displayed on receipts. Only required for EMV transactions.
947 948 949 |
# File 'lib/stripe/resources/charge.rb', line 947 def receipt @receipt end |