Class: Stripe::Charge::PaymentMethodDetails::Konbini
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Konbini
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Store
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#store ⇒ Object
readonly
If the payment succeeded, this contains the details of the convenience store where the payment was completed.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#store ⇒ Object (readonly)
If the payment succeeded, this contains the details of the convenience store where the payment was completed.
1476 1477 1478 |
# File 'lib/stripe/resources/charge.rb', line 1476 def store @store end |
Class Method Details
.field_remappings ⇒ Object
1482 1483 1484 |
# File 'lib/stripe/resources/charge.rb', line 1482 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1478 1479 1480 |
# File 'lib/stripe/resources/charge.rb', line 1478 def self.inner_class_types @inner_class_types = { store: Store } end |