Class: Stripe::Charge::PaymentMethodDetails::KrCard

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

The local credit or debit card brand.



1421
1422
1423
# File 'lib/stripe/resources/charge.rb', line 1421

def brand
  @brand
end

#buyer_idObject (readonly)

A unique identifier for the buyer as determined by the local payment processor.



1423
1424
1425
# File 'lib/stripe/resources/charge.rb', line 1423

def buyer_id
  @buyer_id
end

#last4Object (readonly)

The last four digits of the card. This may not be present for American Express cards.



1425
1426
1427
# File 'lib/stripe/resources/charge.rb', line 1425

def last4
  @last4
end

#transaction_idObject (readonly)

The Korean Card transaction ID associated with this payment.



1427
1428
1429
# File 'lib/stripe/resources/charge.rb', line 1427

def transaction_id
  @transaction_id
end

Class Method Details

.field_remappingsObject



1433
1434
1435
# File 'lib/stripe/resources/charge.rb', line 1433

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1429
1430
1431
# File 'lib/stripe/resources/charge.rb', line 1429

def self.inner_class_types
  @inner_class_types = {}
end