Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::NzBankAccount
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account's bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account's bank branch.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer's bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1549 1550 1551 |
# File 'lib/stripe/resources/charge.rb', line 1549 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account's bank.
1551 1552 1553 |
# File 'lib/stripe/resources/charge.rb', line 1551 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1553 1554 1555 |
# File 'lib/stripe/resources/charge.rb', line 1553 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account's bank branch.
1555 1556 1557 |
# File 'lib/stripe/resources/charge.rb', line 1555 def branch_code @branch_code end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format.
1557 1558 1559 |
# File 'lib/stripe/resources/charge.rb', line 1557 def expected_debit_date @expected_debit_date end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1559 1560 1561 |
# File 'lib/stripe/resources/charge.rb', line 1559 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1561 1562 1563 |
# File 'lib/stripe/resources/charge.rb', line 1561 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1567 1568 1569 |
# File 'lib/stripe/resources/charge.rb', line 1567 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1563 1564 1565 |
# File 'lib/stripe/resources/charge.rb', line 1563 def self.inner_class_types @inner_class_types = {} end |