Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::NzBankAccount
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account's bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account's bank branch.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer's bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1701 1702 1703 |
# File 'lib/stripe/resources/charge.rb', line 1701 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account's bank.
1703 1704 1705 |
# File 'lib/stripe/resources/charge.rb', line 1703 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1705 1706 1707 |
# File 'lib/stripe/resources/charge.rb', line 1705 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account's bank branch.
1707 1708 1709 |
# File 'lib/stripe/resources/charge.rb', line 1707 def branch_code @branch_code end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format.
1709 1710 1711 |
# File 'lib/stripe/resources/charge.rb', line 1709 def expected_debit_date @expected_debit_date end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1711 1712 1713 |
# File 'lib/stripe/resources/charge.rb', line 1711 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1713 1714 1715 |
# File 'lib/stripe/resources/charge.rb', line 1713 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1719 1720 1721 |
# File 'lib/stripe/resources/charge.rb', line 1719 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1715 1716 1717 |
# File 'lib/stripe/resources/charge.rb', line 1715 def self.inner_class_types @inner_class_types = {} end |