Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1477
1478
1479
# File 'lib/stripe/resources/charge.rb', line 1477

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account's bank.



1479
1480
1481
# File 'lib/stripe/resources/charge.rb', line 1479

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1481
1482
1483
# File 'lib/stripe/resources/charge.rb', line 1481

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account's bank branch.



1483
1484
1485
# File 'lib/stripe/resources/charge.rb', line 1483

def branch_code
  @branch_code
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format.



1485
1486
1487
# File 'lib/stripe/resources/charge.rb', line 1485

def expected_debit_date
  @expected_debit_date
end

#last4Object (readonly)

Last four digits of the bank account number.



1487
1488
1489
# File 'lib/stripe/resources/charge.rb', line 1487

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1489
1490
1491
# File 'lib/stripe/resources/charge.rb', line 1489

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1495
1496
1497
# File 'lib/stripe/resources/charge.rb', line 1495

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1491
1492
1493
# File 'lib/stripe/resources/charge.rb', line 1491

def self.inner_class_types
  @inner_class_types = {}
end