Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1651
1652
1653
# File 'lib/stripe/resources/charge.rb', line 1651

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1653
1654
1655
# File 'lib/stripe/resources/charge.rb', line 1653

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1655
1656
1657
# File 'lib/stripe/resources/charge.rb', line 1655

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1657
1658
1659
# File 'lib/stripe/resources/charge.rb', line 1657

def branch_code
  @branch_code
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1659
1660
1661
# File 'lib/stripe/resources/charge.rb', line 1659

def expected_debit_date
  @expected_debit_date
end

#last4Object (readonly)

Last four digits of the bank account number.



1661
1662
1663
# File 'lib/stripe/resources/charge.rb', line 1661

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1663
1664
1665
# File 'lib/stripe/resources/charge.rb', line 1663

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1669
1670
1671
# File 'lib/stripe/resources/charge.rb', line 1669

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1665
1666
1667
# File 'lib/stripe/resources/charge.rb', line 1665

def self.inner_class_types
  @inner_class_types = {}
end