Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1632
1633
1634
# File 'lib/stripe/resources/charge.rb', line 1632

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1634
1635
1636
# File 'lib/stripe/resources/charge.rb', line 1634

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1636
1637
1638
# File 'lib/stripe/resources/charge.rb', line 1636

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1638
1639
1640
# File 'lib/stripe/resources/charge.rb', line 1638

def branch_code
  @branch_code
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1640
1641
1642
# File 'lib/stripe/resources/charge.rb', line 1640

def expected_debit_date
  @expected_debit_date
end

#last4Object (readonly)

Last four digits of the bank account number.



1642
1643
1644
# File 'lib/stripe/resources/charge.rb', line 1642

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1644
1645
1646
# File 'lib/stripe/resources/charge.rb', line 1644

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1650
1651
1652
# File 'lib/stripe/resources/charge.rb', line 1650

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1646
1647
1648
# File 'lib/stripe/resources/charge.rb', line 1646

def self.inner_class_types
  @inner_class_types = {}
end