Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1527
1528
1529
# File 'lib/stripe/resources/charge.rb', line 1527

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1529
1530
1531
# File 'lib/stripe/resources/charge.rb', line 1529

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1531
1532
1533
# File 'lib/stripe/resources/charge.rb', line 1531

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1533
1534
1535
# File 'lib/stripe/resources/charge.rb', line 1533

def branch_code
  @branch_code
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1535
1536
1537
# File 'lib/stripe/resources/charge.rb', line 1535

def expected_debit_date
  @expected_debit_date
end

#last4Object (readonly)

Last four digits of the bank account number.



1537
1538
1539
# File 'lib/stripe/resources/charge.rb', line 1537

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1539
1540
1541
# File 'lib/stripe/resources/charge.rb', line 1539

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1545
1546
1547
# File 'lib/stripe/resources/charge.rb', line 1545

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1541
1542
1543
# File 'lib/stripe/resources/charge.rb', line 1541

def self.inner_class_types
  @inner_class_types = {}
end