Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1448
1449
1450
# File 'lib/stripe/resources/charge.rb', line 1448

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1450
1451
1452
# File 'lib/stripe/resources/charge.rb', line 1450

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1452
1453
1454
# File 'lib/stripe/resources/charge.rb', line 1452

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1454
1455
1456
# File 'lib/stripe/resources/charge.rb', line 1454

def branch_code
  @branch_code
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1456
1457
1458
# File 'lib/stripe/resources/charge.rb', line 1456

def expected_debit_date
  @expected_debit_date
end

#last4Object (readonly)

Last four digits of the bank account number.



1458
1459
1460
# File 'lib/stripe/resources/charge.rb', line 1458

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1460
1461
1462
# File 'lib/stripe/resources/charge.rb', line 1460

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1466
1467
1468
# File 'lib/stripe/resources/charge.rb', line 1466

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1462
1463
1464
# File 'lib/stripe/resources/charge.rb', line 1462

def self.inner_class_types
  @inner_class_types = {}
end