Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::NzBankAccount
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
863 864 865 |
# File 'lib/stripe/resources/charge.rb', line 863 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
865 866 867 |
# File 'lib/stripe/resources/charge.rb', line 865 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
867 868 869 |
# File 'lib/stripe/resources/charge.rb', line 867 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
869 870 871 |
# File 'lib/stripe/resources/charge.rb', line 869 def branch_code @branch_code end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
871 872 873 |
# File 'lib/stripe/resources/charge.rb', line 871 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
873 874 875 |
# File 'lib/stripe/resources/charge.rb', line 873 def suffix @suffix end |