Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1508
1509
1510
# File 'lib/stripe/resources/charge.rb', line 1508

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1510
1511
1512
# File 'lib/stripe/resources/charge.rb', line 1510

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1512
1513
1514
# File 'lib/stripe/resources/charge.rb', line 1512

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1514
1515
1516
# File 'lib/stripe/resources/charge.rb', line 1514

def branch_code
  @branch_code
end

#last4Object (readonly)

Last four digits of the bank account number.



1516
1517
1518
# File 'lib/stripe/resources/charge.rb', line 1516

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1518
1519
1520
# File 'lib/stripe/resources/charge.rb', line 1518

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1524
1525
1526
# File 'lib/stripe/resources/charge.rb', line 1524

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1520
1521
1522
# File 'lib/stripe/resources/charge.rb', line 1520

def self.inner_class_types
  @inner_class_types = {}
end