Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



841
842
843
# File 'lib/stripe/resources/charge.rb', line 841

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



843
844
845
# File 'lib/stripe/resources/charge.rb', line 843

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



845
846
847
# File 'lib/stripe/resources/charge.rb', line 845

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



847
848
849
# File 'lib/stripe/resources/charge.rb', line 847

def branch_code
  @branch_code
end

#last4Object (readonly)

Last four digits of the bank account number.



849
850
851
# File 'lib/stripe/resources/charge.rb', line 849

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



851
852
853
# File 'lib/stripe/resources/charge.rb', line 851

def suffix
  @suffix
end