Class: Stripe::Charge::PaymentMethodDetails::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::NzBankAccount
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account's bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account's bank branch.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer's bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1482 1483 1484 |
# File 'lib/stripe/resources/charge.rb', line 1482 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account's bank.
1484 1485 1486 |
# File 'lib/stripe/resources/charge.rb', line 1484 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1486 1487 1488 |
# File 'lib/stripe/resources/charge.rb', line 1486 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account's bank branch.
1488 1489 1490 |
# File 'lib/stripe/resources/charge.rb', line 1488 def branch_code @branch_code end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format.
1490 1491 1492 |
# File 'lib/stripe/resources/charge.rb', line 1490 def expected_debit_date @expected_debit_date end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1492 1493 1494 |
# File 'lib/stripe/resources/charge.rb', line 1492 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1494 1495 1496 |
# File 'lib/stripe/resources/charge.rb', line 1494 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1500 1501 1502 |
# File 'lib/stripe/resources/charge.rb', line 1500 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1496 1497 1498 |
# File 'lib/stripe/resources/charge.rb', line 1496 def self.inner_class_types @inner_class_types = {} end |