Class: Stripe::Charge::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer's country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1708
1709
1710
# File 'lib/stripe/resources/charge.rb', line 1708

def country
  @country
end

#payer_emailObject (readonly)

Owner's email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1711
1712
1713
# File 'lib/stripe/resources/charge.rb', line 1711

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



1713
1714
1715
# File 'lib/stripe/resources/charge.rb', line 1713

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner's full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1716
1717
1718
# File 'lib/stripe/resources/charge.rb', line 1716

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



1718
1719
1720
# File 'lib/stripe/resources/charge.rb', line 1718

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1722
1723
1724
# File 'lib/stripe/resources/charge.rb', line 1722

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



1724
1725
1726
# File 'lib/stripe/resources/charge.rb', line 1724

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1728
1729
1730
# File 'lib/stripe/resources/charge.rb', line 1728

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner's verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1731
1732
1733
# File 'lib/stripe/resources/charge.rb', line 1731

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner's verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1734
1735
1736
# File 'lib/stripe/resources/charge.rb', line 1734

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1744
1745
1746
# File 'lib/stripe/resources/charge.rb', line 1744

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1736
1737
1738
1739
1740
1741
1742
# File 'lib/stripe/resources/charge.rb', line 1736

def self.inner_class_types
  @inner_class_types = {
    seller_protection: SellerProtection,
    shipping: Shipping,
    verified_address: VerifiedAddress,
  }
end