Class: Stripe::Charge::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer's country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1860
1861
1862
# File 'lib/stripe/resources/charge.rb', line 1860

def country
  @country
end

#payer_emailObject (readonly)

Owner's email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1863
1864
1865
# File 'lib/stripe/resources/charge.rb', line 1863

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



1865
1866
1867
# File 'lib/stripe/resources/charge.rb', line 1865

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner's full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1868
1869
1870
# File 'lib/stripe/resources/charge.rb', line 1868

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



1870
1871
1872
# File 'lib/stripe/resources/charge.rb', line 1870

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1874
1875
1876
# File 'lib/stripe/resources/charge.rb', line 1874

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



1876
1877
1878
# File 'lib/stripe/resources/charge.rb', line 1876

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1880
1881
1882
# File 'lib/stripe/resources/charge.rb', line 1880

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner's verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1883
1884
1885
# File 'lib/stripe/resources/charge.rb', line 1883

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner's verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1886
1887
1888
# File 'lib/stripe/resources/charge.rb', line 1886

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1896
1897
1898
# File 'lib/stripe/resources/charge.rb', line 1896

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1888
1889
1890
1891
1892
1893
1894
# File 'lib/stripe/resources/charge.rb', line 1888

def self.inner_class_types
  @inner_class_types = {
    seller_protection: SellerProtection,
    shipping: Shipping,
    verified_address: VerifiedAddress,
  }
end