Class: Stripe::Charge::PaymentMethodDetails::Paypal
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Paypal
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: SellerProtection, Shipping, VerifiedAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter ISO code representing the buyer’s country.
-
#payer_email ⇒ Object
readonly
Owner’s email.
-
#payer_id ⇒ Object
readonly
PayPal account PayerID.
-
#payer_name ⇒ Object
readonly
Owner’s full name.
-
#seller_protection ⇒ Object
readonly
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
-
#shipping ⇒ Object
readonly
The shipping address for the customer, as supplied by the merchant at the point of payment execution.
-
#transaction_id ⇒ Object
readonly
A unique ID generated by PayPal for this transaction.
-
#verified_address ⇒ Object
readonly
The shipping address for the customer, as supplied by the merchant at the point of payment execution.
-
#verified_email ⇒ Object
readonly
Owner’s verified email.
-
#verified_name ⇒ Object
readonly
Owner’s verified full name.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter ISO code representing the buyer’s country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1703 1704 1705 |
# File 'lib/stripe/resources/charge.rb', line 1703 def country @country end |
#payer_email ⇒ Object (readonly)
Owner’s email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1706 1707 1708 |
# File 'lib/stripe/resources/charge.rb', line 1706 def payer_email @payer_email end |
#payer_id ⇒ Object (readonly)
PayPal account PayerID. This identifier uniquely identifies the PayPal customer.
1708 1709 1710 |
# File 'lib/stripe/resources/charge.rb', line 1708 def payer_id @payer_id end |
#payer_name ⇒ Object (readonly)
Owner’s full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1711 1712 1713 |
# File 'lib/stripe/resources/charge.rb', line 1711 def payer_name @payer_name end |
#seller_protection ⇒ Object (readonly)
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
1713 1714 1715 |
# File 'lib/stripe/resources/charge.rb', line 1713 def seller_protection @seller_protection end |
#shipping ⇒ Object (readonly)
The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.
1717 1718 1719 |
# File 'lib/stripe/resources/charge.rb', line 1717 def shipping @shipping end |
#transaction_id ⇒ Object (readonly)
A unique ID generated by PayPal for this transaction.
1719 1720 1721 |
# File 'lib/stripe/resources/charge.rb', line 1719 def transaction_id @transaction_id end |
#verified_address ⇒ Object (readonly)
The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.
1723 1724 1725 |
# File 'lib/stripe/resources/charge.rb', line 1723 def verified_address @verified_address end |
#verified_email ⇒ Object (readonly)
Owner’s verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1726 1727 1728 |
# File 'lib/stripe/resources/charge.rb', line 1726 def verified_email @verified_email end |
#verified_name ⇒ Object (readonly)
Owner’s verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1729 1730 1731 |
# File 'lib/stripe/resources/charge.rb', line 1729 def verified_name @verified_name end |
Class Method Details
.field_remappings ⇒ Object
1739 1740 1741 |
# File 'lib/stripe/resources/charge.rb', line 1739 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/stripe/resources/charge.rb', line 1731 def self.inner_class_types @inner_class_types = { seller_protection: SellerProtection, shipping: Shipping, verified_address: VerifiedAddress, } end |