Class: Stripe::Charge::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer’s country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1686
1687
1688
# File 'lib/stripe/resources/charge.rb', line 1686

def country
  @country
end

#payer_emailObject (readonly)

Owner’s email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1689
1690
1691
# File 'lib/stripe/resources/charge.rb', line 1689

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



1691
1692
1693
# File 'lib/stripe/resources/charge.rb', line 1691

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner’s full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1694
1695
1696
# File 'lib/stripe/resources/charge.rb', line 1694

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



1696
1697
1698
# File 'lib/stripe/resources/charge.rb', line 1696

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1700
1701
1702
# File 'lib/stripe/resources/charge.rb', line 1700

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



1702
1703
1704
# File 'lib/stripe/resources/charge.rb', line 1702

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1706
1707
1708
# File 'lib/stripe/resources/charge.rb', line 1706

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner’s verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1709
1710
1711
# File 'lib/stripe/resources/charge.rb', line 1709

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1712
1713
1714
# File 'lib/stripe/resources/charge.rb', line 1712

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1722
1723
1724
# File 'lib/stripe/resources/charge.rb', line 1722

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1714
1715
1716
1717
1718
1719
1720
# File 'lib/stripe/resources/charge.rb', line 1714

def self.inner_class_types
  @inner_class_types = {
    seller_protection: SellerProtection,
    shipping: Shipping,
    verified_address: VerifiedAddress,
  }
end