Class: Stripe::Charge::PaymentMethodDetails::Payto
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Payto
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bsb_number ⇒ Object
readonly
Bank-State-Branch number of the bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#pay_id ⇒ Object
readonly
The PayID alias for the bank account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bsb_number ⇒ Object (readonly)
Bank-State-Branch number of the bank account.
1717 1718 1719 |
# File 'lib/stripe/resources/charge.rb', line 1717 def bsb_number @bsb_number end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1719 1720 1721 |
# File 'lib/stripe/resources/charge.rb', line 1719 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
1721 1722 1723 |
# File 'lib/stripe/resources/charge.rb', line 1721 def mandate @mandate end |
#pay_id ⇒ Object (readonly)
The PayID alias for the bank account.
1723 1724 1725 |
# File 'lib/stripe/resources/charge.rb', line 1723 def pay_id @pay_id end |
Class Method Details
.field_remappings ⇒ Object
1729 1730 1731 |
# File 'lib/stripe/resources/charge.rb', line 1729 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1725 1726 1727 |
# File 'lib/stripe/resources/charge.rb', line 1725 def self.inner_class_types @inner_class_types = {} end |