Class: Stripe::Charge::PaymentMethodDetails::RevolutPay::Funding::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be American Express, Cartes Bancaires, Diners Club, Discover, Eftpos Australia, Girocard, JCB, MasterCard, UnionPay, Visa, or Unknown.



1835
1836
1837
# File 'lib/stripe/resources/charge.rb', line 1835

def brand
  @brand
end

#brand_productObject (readonly)

The product code that identifies the specific program or product associated with a card. (For internal use only and not typically available in standard API requests.)



1837
1838
1839
# File 'lib/stripe/resources/charge.rb', line 1837

def brand_product
  @brand_product
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



1839
1840
1841
# File 'lib/stripe/resources/charge.rb', line 1839

def country
  @country
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



1841
1842
1843
# File 'lib/stripe/resources/charge.rb', line 1841

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



1843
1844
1845
# File 'lib/stripe/resources/charge.rb', line 1843

def exp_year
  @exp_year
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



1845
1846
1847
# File 'lib/stripe/resources/charge.rb', line 1845

def funding
  @funding
end

#last4Object (readonly)

The last four digits of the card.



1847
1848
1849
# File 'lib/stripe/resources/charge.rb', line 1847

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1853
1854
1855
# File 'lib/stripe/resources/charge.rb', line 1853

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1849
1850
1851
# File 'lib/stripe/resources/charge.rb', line 1849

def self.inner_class_types
  @inner_class_types = {}
end