Class: Stripe::Charge::PaymentMethodDetails::RevolutPay::Funding::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



1935
1936
1937
# File 'lib/stripe/resources/charge.rb', line 1935

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card. (For internal use only and not typically available in standard API requests.)



1937
1938
1939
# File 'lib/stripe/resources/charge.rb', line 1937

def brand_product
  @brand_product
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



1939
1940
1941
# File 'lib/stripe/resources/charge.rb', line 1939

def country
  @country
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



1941
1942
1943
# File 'lib/stripe/resources/charge.rb', line 1941

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



1943
1944
1945
# File 'lib/stripe/resources/charge.rb', line 1943

def exp_year
  @exp_year
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



1945
1946
1947
# File 'lib/stripe/resources/charge.rb', line 1945

def funding
  @funding
end

#last4Object (readonly)

The last four digits of the card.



1947
1948
1949
# File 'lib/stripe/resources/charge.rb', line 1947

def last4
  @last4
end

Class Method Details

.field_remappingsObject



1953
1954
1955
# File 'lib/stripe/resources/charge.rb', line 1953

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1949
1950
1951
# File 'lib/stripe/resources/charge.rb', line 1949

def self.inner_class_types
  @inner_class_types = {}
end