Class: Stripe::Charge::PaymentMethodDetails::RevolutPay::Funding::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



962
963
964
# File 'lib/stripe/resources/charge.rb', line 962

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card. (For internal use only and not typically available in standard API requests.)



964
965
966
# File 'lib/stripe/resources/charge.rb', line 964

def brand_product
  @brand_product
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



966
967
968
# File 'lib/stripe/resources/charge.rb', line 966

def country
  @country
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



968
969
970
# File 'lib/stripe/resources/charge.rb', line 968

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



970
971
972
# File 'lib/stripe/resources/charge.rb', line 970

def exp_year
  @exp_year
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



972
973
974
# File 'lib/stripe/resources/charge.rb', line 972

def funding
  @funding
end

#last4Object (readonly)

The last four digits of the card.



974
975
976
# File 'lib/stripe/resources/charge.rb', line 974

def last4
  @last4
end