Class: Stripe::Charge::PaymentMethodDetails::SepaCreditTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::SepaCreditTransfer
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#iban ⇒ Object
readonly
IBAN of the bank account to transfer funds to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1927 1928 1929 |
# File 'lib/stripe/resources/charge.rb', line 1927 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
1929 1930 1931 |
# File 'lib/stripe/resources/charge.rb', line 1929 def bic @bic end |
#iban ⇒ Object (readonly)
IBAN of the bank account to transfer funds to.
1931 1932 1933 |
# File 'lib/stripe/resources/charge.rb', line 1931 def iban @iban end |
Class Method Details
.field_remappings ⇒ Object
1937 1938 1939 |
# File 'lib/stripe/resources/charge.rb', line 1937 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1933 1934 1935 |
# File 'lib/stripe/resources/charge.rb', line 1933 def self.inner_class_types @inner_class_types = {} end |