Class: Stripe::Charge::PaymentMethodDetails::SepaCreditTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::SepaCreditTransfer
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#iban ⇒ Object
readonly
IBAN of the bank account to transfer funds to.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
2001 2002 2003 |
# File 'lib/stripe/resources/charge.rb', line 2001 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
2003 2004 2005 |
# File 'lib/stripe/resources/charge.rb', line 2003 def bic @bic end |
#iban ⇒ Object (readonly)
IBAN of the bank account to transfer funds to.
2005 2006 2007 |
# File 'lib/stripe/resources/charge.rb', line 2005 def iban @iban end |
Class Method Details
.field_remappings ⇒ Object
2011 2012 2013 |
# File 'lib/stripe/resources/charge.rb', line 2011 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2007 2008 2009 |
# File 'lib/stripe/resources/charge.rb', line 2007 def self.inner_class_types @inner_class_types = {} end |