Class: Stripe::Charge::PaymentMethodDetails::SepaCreditTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1890
1891
1892
# File 'lib/stripe/resources/charge.rb', line 1890

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1892
1893
1894
# File 'lib/stripe/resources/charge.rb', line 1892

def bic
  @bic
end

#ibanObject (readonly)

IBAN of the bank account to transfer funds to.



1894
1895
1896
# File 'lib/stripe/resources/charge.rb', line 1894

def iban
  @iban
end

Class Method Details

.field_remappingsObject



1900
1901
1902
# File 'lib/stripe/resources/charge.rb', line 1900

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1896
1897
1898
# File 'lib/stripe/resources/charge.rb', line 1896

def self.inner_class_types
  @inner_class_types = {}
end