Class: Stripe::Charge::PaymentMethodDetails::SepaCreditTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1718
1719
1720
# File 'lib/stripe/resources/charge.rb', line 1718

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1720
1721
1722
# File 'lib/stripe/resources/charge.rb', line 1720

def bic
  @bic
end

#ibanObject (readonly)

IBAN of the bank account to transfer funds to.



1722
1723
1724
# File 'lib/stripe/resources/charge.rb', line 1722

def iban
  @iban
end

Class Method Details

.field_remappingsObject



1728
1729
1730
# File 'lib/stripe/resources/charge.rb', line 1728

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1724
1725
1726
# File 'lib/stripe/resources/charge.rb', line 1724

def self.inner_class_types
  @inner_class_types = {}
end