Class: Stripe::Charge::PaymentMethodDetails::SepaCreditTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



914
915
916
# File 'lib/stripe/resources/charge.rb', line 914

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



916
917
918
# File 'lib/stripe/resources/charge.rb', line 916

def bic
  @bic
end

#ibanObject (readonly)

IBAN of the bank account to transfer funds to.



918
919
920
# File 'lib/stripe/resources/charge.rb', line 918

def iban
  @iban
end