Class: Stripe::Charge::PaymentMethodDetails::SepaCreditTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



967
968
969
# File 'lib/stripe/resources/charge.rb', line 967

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



969
970
971
# File 'lib/stripe/resources/charge.rb', line 969

def bic
  @bic
end

#ibanObject (readonly)

IBAN of the bank account to transfer funds to.



971
972
973
# File 'lib/stripe/resources/charge.rb', line 971

def iban
  @iban
end