Class: Stripe::Charge::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1944
1945
1946
# File 'lib/stripe/resources/charge.rb', line 1944

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1946
1947
1948
# File 'lib/stripe/resources/charge.rb', line 1946

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1948
1949
1950
# File 'lib/stripe/resources/charge.rb', line 1948

def country
  @country
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format.



1950
1951
1952
# File 'lib/stripe/resources/charge.rb', line 1950

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1952
1953
1954
# File 'lib/stripe/resources/charge.rb', line 1952

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1954
1955
1956
# File 'lib/stripe/resources/charge.rb', line 1954

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the payment_method_details.sepa_debit.mandate property on the Charge. Use this mandate ID to retrieve the Mandate.



1956
1957
1958
# File 'lib/stripe/resources/charge.rb', line 1956

def mandate
  @mandate
end

Class Method Details

.field_remappingsObject



1962
1963
1964
# File 'lib/stripe/resources/charge.rb', line 1962

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1958
1959
1960
# File 'lib/stripe/resources/charge.rb', line 1958

def self.inner_class_types
  @inner_class_types = {}
end