Class: Stripe::Charge::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1933
1934
1935
# File 'lib/stripe/resources/charge.rb', line 1933

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1935
1936
1937
# File 'lib/stripe/resources/charge.rb', line 1935

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1937
1938
1939
# File 'lib/stripe/resources/charge.rb', line 1937

def country
  @country
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1939
1940
1941
# File 'lib/stripe/resources/charge.rb', line 1939

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1941
1942
1943
# File 'lib/stripe/resources/charge.rb', line 1941

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1943
1944
1945
# File 'lib/stripe/resources/charge.rb', line 1943

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](docs.stripe.com/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](docs.stripe.com/api/mandates/retrieve).



1945
1946
1947
# File 'lib/stripe/resources/charge.rb', line 1945

def mandate
  @mandate
end

Class Method Details

.field_remappingsObject



1951
1952
1953
# File 'lib/stripe/resources/charge.rb', line 1951

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1947
1948
1949
# File 'lib/stripe/resources/charge.rb', line 1947

def self.inner_class_types
  @inner_class_types = {}
end