Class: Stripe::Charge::PaymentMethodDetails::SepaDebit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::SepaDebit
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#branch_code ⇒ Object
readonly
Branch code of bank associated with the bank account.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country the bank account is located in.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer’s bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four characters of the IBAN.
-
#mandate ⇒ Object
readonly
Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](docs.stripe.com/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
1959 1960 1961 |
# File 'lib/stripe/resources/charge.rb', line 1959 def bank_code @bank_code end |
#branch_code ⇒ Object (readonly)
Branch code of bank associated with the bank account.
1961 1962 1963 |
# File 'lib/stripe/resources/charge.rb', line 1961 def branch_code @branch_code end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country the bank account is located in.
1963 1964 1965 |
# File 'lib/stripe/resources/charge.rb', line 1963 def country @country end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.
1965 1966 1967 |
# File 'lib/stripe/resources/charge.rb', line 1965 def expected_debit_date @expected_debit_date end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
1967 1968 1969 |
# File 'lib/stripe/resources/charge.rb', line 1967 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four characters of the IBAN.
1969 1970 1971 |
# File 'lib/stripe/resources/charge.rb', line 1969 def last4 @last4 end |
#mandate ⇒ Object (readonly)
Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](docs.stripe.com/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](docs.stripe.com/api/mandates/retrieve).
1971 1972 1973 |
# File 'lib/stripe/resources/charge.rb', line 1971 def mandate @mandate end |
Class Method Details
.field_remappings ⇒ Object
1977 1978 1979 |
# File 'lib/stripe/resources/charge.rb', line 1977 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1973 1974 1975 |
# File 'lib/stripe/resources/charge.rb', line 1973 def self.inner_class_types @inner_class_types = {} end |