Class: Stripe::Charge::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1882
1883
1884
# File 'lib/stripe/resources/charge.rb', line 1882

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1884
1885
1886
# File 'lib/stripe/resources/charge.rb', line 1884

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1886
1887
1888
# File 'lib/stripe/resources/charge.rb', line 1886

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1888
1889
1890
# File 'lib/stripe/resources/charge.rb', line 1888

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1890
1891
1892
# File 'lib/stripe/resources/charge.rb', line 1890

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](stripe.com/docs/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](stripe.com/docs/api/mandates/retrieve).



1892
1893
1894
# File 'lib/stripe/resources/charge.rb', line 1892

def mandate
  @mandate
end

Class Method Details

.field_remappingsObject



1898
1899
1900
# File 'lib/stripe/resources/charge.rb', line 1898

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1894
1895
1896
# File 'lib/stripe/resources/charge.rb', line 1894

def self.inner_class_types
  @inner_class_types = {}
end