Class: Stripe::Charge::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1869
1870
1871
# File 'lib/stripe/resources/charge.rb', line 1869

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1871
1872
1873
# File 'lib/stripe/resources/charge.rb', line 1871

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1873
1874
1875
# File 'lib/stripe/resources/charge.rb', line 1873

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1875
1876
1877
# File 'lib/stripe/resources/charge.rb', line 1875

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1877
1878
1879
# File 'lib/stripe/resources/charge.rb', line 1877

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](stripe.com/docs/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](stripe.com/docs/api/mandates/retrieve).



1879
1880
1881
# File 'lib/stripe/resources/charge.rb', line 1879

def mandate
  @mandate
end

Class Method Details

.field_remappingsObject



1885
1886
1887
# File 'lib/stripe/resources/charge.rb', line 1885

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1881
1882
1883
# File 'lib/stripe/resources/charge.rb', line 1881

def self.inner_class_types
  @inner_class_types = {}
end