Class: Stripe::Charge::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1018
1019
1020
# File 'lib/stripe/resources/charge.rb', line 1018

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1020
1021
1022
# File 'lib/stripe/resources/charge.rb', line 1020

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1022
1023
1024
# File 'lib/stripe/resources/charge.rb', line 1022

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1024
1025
1026
# File 'lib/stripe/resources/charge.rb', line 1024

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1026
1027
1028
# File 'lib/stripe/resources/charge.rb', line 1026

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](stripe.com/docs/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](stripe.com/docs/api/mandates/retrieve).



1028
1029
1030
# File 'lib/stripe/resources/charge.rb', line 1028

def mandate
  @mandate
end