Class: Stripe::Charge::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1226
1227
1228
# File 'lib/stripe/resources/charge.rb', line 1226

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1229
1230
1231
# File 'lib/stripe/resources/charge.rb', line 1229

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1232
1233
1234
# File 'lib/stripe/resources/charge.rb', line 1232

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1235
1236
1237
# File 'lib/stripe/resources/charge.rb', line 1235

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1238
1239
1240
# File 'lib/stripe/resources/charge.rb', line 1238

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](stripe.com/docs/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](stripe.com/docs/api/mandates/retrieve).



1241
1242
1243
# File 'lib/stripe/resources/charge.rb', line 1241

def mandate
  @mandate
end