Class: Stripe::Charge::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1979
1980
1981
# File 'lib/stripe/resources/charge.rb', line 1979

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1981
1982
1983
# File 'lib/stripe/resources/charge.rb', line 1981

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1983
1984
1985
# File 'lib/stripe/resources/charge.rb', line 1983

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1985
1986
1987
# File 'lib/stripe/resources/charge.rb', line 1985

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1987
1988
1989
# File 'lib/stripe/resources/charge.rb', line 1987

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1989
1990
1991
# File 'lib/stripe/resources/charge.rb', line 1989

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1991
1992
1993
# File 'lib/stripe/resources/charge.rb', line 1991

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of de, en, es, fr, it, nl, or pl



1994
1995
1996
# File 'lib/stripe/resources/charge.rb', line 1994

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner's verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1997
1998
1999
# File 'lib/stripe/resources/charge.rb', line 1997

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



2003
2004
2005
# File 'lib/stripe/resources/charge.rb', line 2003

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1999
2000
2001
# File 'lib/stripe/resources/charge.rb', line 1999

def self.inner_class_types
  @inner_class_types = {}
end