Class: Stripe::Charge::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



2144
2145
2146
# File 'lib/stripe/resources/charge.rb', line 2144

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



2146
2147
2148
# File 'lib/stripe/resources/charge.rb', line 2146

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



2148
2149
2150
# File 'lib/stripe/resources/charge.rb', line 2148

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



2150
2151
2152
# File 'lib/stripe/resources/charge.rb', line 2150

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



2152
2153
2154
# File 'lib/stripe/resources/charge.rb', line 2152

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



2154
2155
2156
# File 'lib/stripe/resources/charge.rb', line 2154

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



2156
2157
2158
# File 'lib/stripe/resources/charge.rb', line 2156

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of de, en, es, fr, it, nl, or pl



2159
2160
2161
# File 'lib/stripe/resources/charge.rb', line 2159

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner's verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



2162
2163
2164
# File 'lib/stripe/resources/charge.rb', line 2162

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



2168
2169
2170
# File 'lib/stripe/resources/charge.rb', line 2168

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2164
2165
2166
# File 'lib/stripe/resources/charge.rb', line 2164

def self.inner_class_types
  @inner_class_types = {}
end