Class: Stripe::Charge::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1798
1799
1800
# File 'lib/stripe/resources/charge.rb', line 1798

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1800
1801
1802
# File 'lib/stripe/resources/charge.rb', line 1800

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1802
1803
1804
# File 'lib/stripe/resources/charge.rb', line 1802

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1804
1805
1806
# File 'lib/stripe/resources/charge.rb', line 1804

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1806
1807
1808
# File 'lib/stripe/resources/charge.rb', line 1806

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1808
1809
1810
# File 'lib/stripe/resources/charge.rb', line 1808

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1810
1811
1812
# File 'lib/stripe/resources/charge.rb', line 1810

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of de, en, es, fr, it, nl, or pl



1813
1814
1815
# File 'lib/stripe/resources/charge.rb', line 1813

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner's verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1816
1817
1818
# File 'lib/stripe/resources/charge.rb', line 1816

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1822
1823
1824
# File 'lib/stripe/resources/charge.rb', line 1822

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1818
1819
1820
# File 'lib/stripe/resources/charge.rb', line 1818

def self.inner_class_types
  @inner_class_types = {}
end