Class: Stripe::Charge::PaymentMethodDetails::Sofort
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Sofort
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country the bank account is located in.
-
#generated_sepa_debit ⇒ Object
readonly
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#generated_sepa_debit_mandate ⇒ Object
readonly
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#iban_last4 ⇒ Object
readonly
Last four characters of the IBAN.
-
#preferred_language ⇒ Object
readonly
Preferred language of the SOFORT authorization page that the customer is redirected to.
-
#verified_name ⇒ Object
readonly
Owner’s verified full name.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
2047 2048 2049 |
# File 'lib/stripe/resources/charge.rb', line 2047 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
2049 2050 2051 |
# File 'lib/stripe/resources/charge.rb', line 2049 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
2051 2052 2053 |
# File 'lib/stripe/resources/charge.rb', line 2051 def bic @bic end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country the bank account is located in.
2053 2054 2055 |
# File 'lib/stripe/resources/charge.rb', line 2053 def country @country end |
#generated_sepa_debit ⇒ Object (readonly)
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
2055 2056 2057 |
# File 'lib/stripe/resources/charge.rb', line 2055 def generated_sepa_debit @generated_sepa_debit end |
#generated_sepa_debit_mandate ⇒ Object (readonly)
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
2057 2058 2059 |
# File 'lib/stripe/resources/charge.rb', line 2057 def generated_sepa_debit_mandate @generated_sepa_debit_mandate end |
#iban_last4 ⇒ Object (readonly)
Last four characters of the IBAN.
2059 2060 2061 |
# File 'lib/stripe/resources/charge.rb', line 2059 def iban_last4 @iban_last4 end |
#preferred_language ⇒ Object (readonly)
Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`
2062 2063 2064 |
# File 'lib/stripe/resources/charge.rb', line 2062 def preferred_language @preferred_language end |
#verified_name ⇒ Object (readonly)
Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
2065 2066 2067 |
# File 'lib/stripe/resources/charge.rb', line 2065 def verified_name @verified_name end |
Class Method Details
.field_remappings ⇒ Object
2071 2072 2073 |
# File 'lib/stripe/resources/charge.rb', line 2071 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2067 2068 2069 |
# File 'lib/stripe/resources/charge.rb', line 2067 def self.inner_class_types @inner_class_types = {} end |