Class: Stripe::Charge::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



2053
2054
2055
# File 'lib/stripe/resources/charge.rb', line 2053

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



2055
2056
2057
# File 'lib/stripe/resources/charge.rb', line 2055

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



2057
2058
2059
# File 'lib/stripe/resources/charge.rb', line 2057

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



2059
2060
2061
# File 'lib/stripe/resources/charge.rb', line 2059

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



2061
2062
2063
# File 'lib/stripe/resources/charge.rb', line 2061

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



2063
2064
2065
# File 'lib/stripe/resources/charge.rb', line 2063

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



2065
2066
2067
# File 'lib/stripe/resources/charge.rb', line 2065

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



2068
2069
2070
# File 'lib/stripe/resources/charge.rb', line 2068

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



2071
2072
2073
# File 'lib/stripe/resources/charge.rb', line 2071

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



2077
2078
2079
# File 'lib/stripe/resources/charge.rb', line 2077

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2073
2074
2075
# File 'lib/stripe/resources/charge.rb', line 2073

def self.inner_class_types
  @inner_class_types = {}
end