Class: Stripe::Charge::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1931
1932
1933
# File 'lib/stripe/resources/charge.rb', line 1931

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1933
1934
1935
# File 'lib/stripe/resources/charge.rb', line 1933

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1935
1936
1937
# File 'lib/stripe/resources/charge.rb', line 1935

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1937
1938
1939
# File 'lib/stripe/resources/charge.rb', line 1937

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1939
1940
1941
# File 'lib/stripe/resources/charge.rb', line 1939

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1941
1942
1943
# File 'lib/stripe/resources/charge.rb', line 1941

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1943
1944
1945
# File 'lib/stripe/resources/charge.rb', line 1943

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1946
1947
1948
# File 'lib/stripe/resources/charge.rb', line 1946

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1949
1950
1951
# File 'lib/stripe/resources/charge.rb', line 1949

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1955
1956
1957
# File 'lib/stripe/resources/charge.rb', line 1955

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1951
1952
1953
# File 'lib/stripe/resources/charge.rb', line 1951

def self.inner_class_types
  @inner_class_types = {}
end