Class: Stripe::Charge::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1915
1916
1917
# File 'lib/stripe/resources/charge.rb', line 1915

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1917
1918
1919
# File 'lib/stripe/resources/charge.rb', line 1917

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1919
1920
1921
# File 'lib/stripe/resources/charge.rb', line 1919

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1921
1922
1923
# File 'lib/stripe/resources/charge.rb', line 1921

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1923
1924
1925
# File 'lib/stripe/resources/charge.rb', line 1923

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1925
1926
1927
# File 'lib/stripe/resources/charge.rb', line 1925

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1927
1928
1929
# File 'lib/stripe/resources/charge.rb', line 1927

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1930
1931
1932
# File 'lib/stripe/resources/charge.rb', line 1930

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1933
1934
1935
# File 'lib/stripe/resources/charge.rb', line 1933

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1939
1940
1941
# File 'lib/stripe/resources/charge.rb', line 1939

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1935
1936
1937
# File 'lib/stripe/resources/charge.rb', line 1935

def self.inner_class_types
  @inner_class_types = {}
end