Class: Stripe::Charge::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1902
1903
1904
# File 'lib/stripe/resources/charge.rb', line 1902

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1904
1905
1906
# File 'lib/stripe/resources/charge.rb', line 1904

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1906
1907
1908
# File 'lib/stripe/resources/charge.rb', line 1906

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1908
1909
1910
# File 'lib/stripe/resources/charge.rb', line 1908

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1910
1911
1912
# File 'lib/stripe/resources/charge.rb', line 1910

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1912
1913
1914
# File 'lib/stripe/resources/charge.rb', line 1912

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1914
1915
1916
# File 'lib/stripe/resources/charge.rb', line 1914

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1917
1918
1919
# File 'lib/stripe/resources/charge.rb', line 1917

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1920
1921
1922
# File 'lib/stripe/resources/charge.rb', line 1920

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1926
1927
1928
# File 'lib/stripe/resources/charge.rb', line 1926

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1922
1923
1924
# File 'lib/stripe/resources/charge.rb', line 1922

def self.inner_class_types
  @inner_class_types = {}
end