Class: Stripe::Charge::PaymentMethodDetails::Sofort
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Sofort
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country the bank account is located in.
-
#generated_sepa_debit ⇒ Object
readonly
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#generated_sepa_debit_mandate ⇒ Object
readonly
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#iban_last4 ⇒ Object
readonly
Last four characters of the IBAN.
-
#preferred_language ⇒ Object
readonly
Preferred language of the SOFORT authorization page that the customer is redirected to.
-
#verified_name ⇒ Object
readonly
Owner’s verified full name.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
1035 1036 1037 |
# File 'lib/stripe/resources/charge.rb', line 1035 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1037 1038 1039 |
# File 'lib/stripe/resources/charge.rb', line 1037 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
1039 1040 1041 |
# File 'lib/stripe/resources/charge.rb', line 1039 def bic @bic end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country the bank account is located in.
1041 1042 1043 |
# File 'lib/stripe/resources/charge.rb', line 1041 def country @country end |
#generated_sepa_debit ⇒ Object (readonly)
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
1043 1044 1045 |
# File 'lib/stripe/resources/charge.rb', line 1043 def generated_sepa_debit @generated_sepa_debit end |
#generated_sepa_debit_mandate ⇒ Object (readonly)
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
1045 1046 1047 |
# File 'lib/stripe/resources/charge.rb', line 1045 def generated_sepa_debit_mandate @generated_sepa_debit_mandate end |
#iban_last4 ⇒ Object (readonly)
Last four characters of the IBAN.
1047 1048 1049 |
# File 'lib/stripe/resources/charge.rb', line 1047 def iban_last4 @iban_last4 end |
#preferred_language ⇒ Object (readonly)
Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`
1050 1051 1052 |
# File 'lib/stripe/resources/charge.rb', line 1050 def preferred_language @preferred_language end |
#verified_name ⇒ Object (readonly)
Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1053 1054 1055 |
# File 'lib/stripe/resources/charge.rb', line 1053 def verified_name @verified_name end |