Class: Stripe::Charge::PaymentMethodDetails::Swish

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#fingerprintObject (readonly)

Uniquely identifies the payer’s Swish account. You can use this attribute to check whether two Swish transactions were paid for by the same payer



1987
1988
1989
# File 'lib/stripe/resources/charge.rb', line 1987

def fingerprint
  @fingerprint
end

#payment_referenceObject (readonly)

Payer bank reference number for the payment



1989
1990
1991
# File 'lib/stripe/resources/charge.rb', line 1989

def payment_reference
  @payment_reference
end

#verified_phone_last4Object (readonly)

The last four digits of the Swish account phone number



1991
1992
1993
# File 'lib/stripe/resources/charge.rb', line 1991

def verified_phone_last4
  @verified_phone_last4
end

Class Method Details

.field_remappingsObject



1997
1998
1999
# File 'lib/stripe/resources/charge.rb', line 1997

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1993
1994
1995
# File 'lib/stripe/resources/charge.rb', line 1993

def self.inner_class_types
  @inner_class_types = {}
end