Class: Stripe::Charge::PaymentMethodDetails::Swish

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#fingerprintObject (readonly)

Uniquely identifies the payer’s Swish account. You can use this attribute to check whether two Swish transactions were paid for by the same payer



952
953
954
# File 'lib/stripe/resources/charge.rb', line 952

def fingerprint
  @fingerprint
end

#payment_referenceObject (readonly)

Payer bank reference number for the payment



954
955
956
# File 'lib/stripe/resources/charge.rb', line 954

def payment_reference
  @payment_reference
end

#verified_phone_last4Object (readonly)

The last four digits of the Swish account phone number



956
957
958
# File 'lib/stripe/resources/charge.rb', line 956

def verified_phone_last4
  @verified_phone_last4
end