Class: Stripe::Charge::PaymentMethodDetails::Swish
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::Swish
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fingerprint ⇒ Object
readonly
Uniquely identifies the payer’s Swish account.
-
#payment_reference ⇒ Object
readonly
Payer bank reference number for the payment.
-
#verified_phone_last4 ⇒ Object
readonly
The last four digits of the Swish account phone number.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fingerprint ⇒ Object (readonly)
Uniquely identifies the payer’s Swish account. You can use this attribute to check whether two Swish transactions were paid for by the same payer
1018 1019 1020 |
# File 'lib/stripe/resources/charge.rb', line 1018 def fingerprint @fingerprint end |
#payment_reference ⇒ Object (readonly)
Payer bank reference number for the payment
1020 1021 1022 |
# File 'lib/stripe/resources/charge.rb', line 1020 def payment_reference @payment_reference end |
#verified_phone_last4 ⇒ Object (readonly)
The last four digits of the Swish account phone number
1022 1023 1024 |
# File 'lib/stripe/resources/charge.rb', line 1022 def verified_phone_last4 @verified_phone_last4 end |