Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



2267
2268
2269
# File 'lib/stripe/resources/charge.rb', line 2267

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



2269
2270
2271
# File 'lib/stripe/resources/charge.rb', line 2269

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



2271
2272
2273
# File 'lib/stripe/resources/charge.rb', line 2271

def bank_name
  @bank_name
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer's bank account. A date string in YYYY-MM-DD format.



2273
2274
2275
# File 'lib/stripe/resources/charge.rb', line 2273

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



2275
2276
2277
# File 'lib/stripe/resources/charge.rb', line 2275

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



2277
2278
2279
# File 'lib/stripe/resources/charge.rb', line 2277

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



2279
2280
2281
# File 'lib/stripe/resources/charge.rb', line 2279

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer's bank.



2281
2282
2283
# File 'lib/stripe/resources/charge.rb', line 2281

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



2283
2284
2285
# File 'lib/stripe/resources/charge.rb', line 2283

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



2289
2290
2291
# File 'lib/stripe/resources/charge.rb', line 2289

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2285
2286
2287
# File 'lib/stripe/resources/charge.rb', line 2285

def self.inner_class_types
  @inner_class_types = {}
end