Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
Account holder type: individual or company.
-
#account_type ⇒ Object
readonly
Account type: checkings or savings.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer’s bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#payment_reference ⇒ Object
readonly
Reference number to locate ACH payments with customer’s bank.
-
#routing_number ⇒ Object
readonly
Routing number of the bank account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
Account holder type: individual or company.
2078 2079 2080 |
# File 'lib/stripe/resources/charge.rb', line 2078 def account_holder_type @account_holder_type end |
#account_type ⇒ Object (readonly)
Account type: checkings or savings. Defaults to checking if omitted.
2080 2081 2082 |
# File 'lib/stripe/resources/charge.rb', line 2080 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
2082 2083 2084 |
# File 'lib/stripe/resources/charge.rb', line 2082 def bank_name @bank_name end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.
2084 2085 2086 |
# File 'lib/stripe/resources/charge.rb', line 2084 def expected_debit_date @expected_debit_date end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
2086 2087 2088 |
# File 'lib/stripe/resources/charge.rb', line 2086 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
2088 2089 2090 |
# File 'lib/stripe/resources/charge.rb', line 2088 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
2090 2091 2092 |
# File 'lib/stripe/resources/charge.rb', line 2090 def mandate @mandate end |
#payment_reference ⇒ Object (readonly)
Reference number to locate ACH payments with customer’s bank.
2092 2093 2094 |
# File 'lib/stripe/resources/charge.rb', line 2092 def payment_reference @payment_reference end |
#routing_number ⇒ Object (readonly)
Routing number of the bank account.
2094 2095 2096 |
# File 'lib/stripe/resources/charge.rb', line 2094 def routing_number @routing_number end |
Class Method Details
.field_remappings ⇒ Object
2100 2101 2102 |
# File 'lib/stripe/resources/charge.rb', line 2100 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2096 2097 2098 |
# File 'lib/stripe/resources/charge.rb', line 2096 def self.inner_class_types @inner_class_types = {} end |