Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1889
1890
1891
# File 'lib/stripe/resources/charge.rb', line 1889

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1891
1892
1893
# File 'lib/stripe/resources/charge.rb', line 1891

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1893
1894
1895
# File 'lib/stripe/resources/charge.rb', line 1893

def bank_name
  @bank_name
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1895
1896
1897
# File 'lib/stripe/resources/charge.rb', line 1895

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1897
1898
1899
# File 'lib/stripe/resources/charge.rb', line 1897

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1899
1900
1901
# File 'lib/stripe/resources/charge.rb', line 1899

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



1901
1902
1903
# File 'lib/stripe/resources/charge.rb', line 1901

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



1903
1904
1905
# File 'lib/stripe/resources/charge.rb', line 1903

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



1905
1906
1907
# File 'lib/stripe/resources/charge.rb', line 1905

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



1911
1912
1913
# File 'lib/stripe/resources/charge.rb', line 1911

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1907
1908
1909
# File 'lib/stripe/resources/charge.rb', line 1907

def self.inner_class_types
  @inner_class_types = {}
end