Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
Account holder type: individual or company.
-
#account_type ⇒ Object
readonly
Account type: checkings or savings.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer’s bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#payment_reference ⇒ Object
readonly
Reference number to locate ACH payments with customer’s bank.
-
#routing_number ⇒ Object
readonly
Routing number of the bank account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
Account holder type: individual or company.
2141 2142 2143 |
# File 'lib/stripe/resources/charge.rb', line 2141 def account_holder_type @account_holder_type end |
#account_type ⇒ Object (readonly)
Account type: checkings or savings. Defaults to checking if omitted.
2143 2144 2145 |
# File 'lib/stripe/resources/charge.rb', line 2143 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
2145 2146 2147 |
# File 'lib/stripe/resources/charge.rb', line 2145 def bank_name @bank_name end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.
2147 2148 2149 |
# File 'lib/stripe/resources/charge.rb', line 2147 def expected_debit_date @expected_debit_date end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
2149 2150 2151 |
# File 'lib/stripe/resources/charge.rb', line 2149 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
2151 2152 2153 |
# File 'lib/stripe/resources/charge.rb', line 2151 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
2153 2154 2155 |
# File 'lib/stripe/resources/charge.rb', line 2153 def mandate @mandate end |
#payment_reference ⇒ Object (readonly)
Reference number to locate ACH payments with customer’s bank.
2155 2156 2157 |
# File 'lib/stripe/resources/charge.rb', line 2155 def payment_reference @payment_reference end |
#routing_number ⇒ Object (readonly)
Routing number of the bank account.
2157 2158 2159 |
# File 'lib/stripe/resources/charge.rb', line 2157 def routing_number @routing_number end |
Class Method Details
.field_remappings ⇒ Object
2163 2164 2165 |
# File 'lib/stripe/resources/charge.rb', line 2163 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2159 2160 2161 |
# File 'lib/stripe/resources/charge.rb', line 2159 def self.inner_class_types @inner_class_types = {} end |