Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



2077
2078
2079
# File 'lib/stripe/resources/charge.rb', line 2077

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



2079
2080
2081
# File 'lib/stripe/resources/charge.rb', line 2079

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



2081
2082
2083
# File 'lib/stripe/resources/charge.rb', line 2081

def bank_name
  @bank_name
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



2083
2084
2085
# File 'lib/stripe/resources/charge.rb', line 2083

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



2085
2086
2087
# File 'lib/stripe/resources/charge.rb', line 2085

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



2087
2088
2089
# File 'lib/stripe/resources/charge.rb', line 2087

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



2089
2090
2091
# File 'lib/stripe/resources/charge.rb', line 2089

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



2091
2092
2093
# File 'lib/stripe/resources/charge.rb', line 2091

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



2093
2094
2095
# File 'lib/stripe/resources/charge.rb', line 2093

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



2099
2100
2101
# File 'lib/stripe/resources/charge.rb', line 2099

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2095
2096
2097
# File 'lib/stripe/resources/charge.rb', line 2095

def self.inner_class_types
  @inner_class_types = {}
end