Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



2013
2014
2015
# File 'lib/stripe/resources/charge.rb', line 2013

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



2015
2016
2017
# File 'lib/stripe/resources/charge.rb', line 2015

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



2017
2018
2019
# File 'lib/stripe/resources/charge.rb', line 2017

def bank_name
  @bank_name
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



2019
2020
2021
# File 'lib/stripe/resources/charge.rb', line 2019

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



2021
2022
2023
# File 'lib/stripe/resources/charge.rb', line 2021

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



2023
2024
2025
# File 'lib/stripe/resources/charge.rb', line 2023

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



2025
2026
2027
# File 'lib/stripe/resources/charge.rb', line 2025

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



2027
2028
2029
# File 'lib/stripe/resources/charge.rb', line 2027

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



2029
2030
2031
# File 'lib/stripe/resources/charge.rb', line 2029

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



2035
2036
2037
# File 'lib/stripe/resources/charge.rb', line 2035

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2031
2032
2033
# File 'lib/stripe/resources/charge.rb', line 2031

def self.inner_class_types
  @inner_class_types = {}
end