Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1998
1999
2000
# File 'lib/stripe/resources/charge.rb', line 1998

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



2000
2001
2002
# File 'lib/stripe/resources/charge.rb', line 2000

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



2002
2003
2004
# File 'lib/stripe/resources/charge.rb', line 2002

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



2004
2005
2006
# File 'lib/stripe/resources/charge.rb', line 2004

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



2006
2007
2008
# File 'lib/stripe/resources/charge.rb', line 2006

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



2008
2009
2010
# File 'lib/stripe/resources/charge.rb', line 2008

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



2010
2011
2012
# File 'lib/stripe/resources/charge.rb', line 2010

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



2012
2013
2014
# File 'lib/stripe/resources/charge.rb', line 2012

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



2018
2019
2020
# File 'lib/stripe/resources/charge.rb', line 2018

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2014
2015
2016
# File 'lib/stripe/resources/charge.rb', line 2014

def self.inner_class_types
  @inner_class_types = {}
end