Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1111
1112
1113
# File 'lib/stripe/resources/charge.rb', line 1111

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1113
1114
1115
# File 'lib/stripe/resources/charge.rb', line 1113

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1115
1116
1117
# File 'lib/stripe/resources/charge.rb', line 1115

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1117
1118
1119
# File 'lib/stripe/resources/charge.rb', line 1117

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1119
1120
1121
# File 'lib/stripe/resources/charge.rb', line 1119

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



1121
1122
1123
# File 'lib/stripe/resources/charge.rb', line 1121

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



1123
1124
1125
# File 'lib/stripe/resources/charge.rb', line 1123

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



1125
1126
1127
# File 'lib/stripe/resources/charge.rb', line 1125

def routing_number
  @routing_number
end