Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1078
1079
1080
# File 'lib/stripe/resources/charge.rb', line 1078

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1080
1081
1082
# File 'lib/stripe/resources/charge.rb', line 1080

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1082
1083
1084
# File 'lib/stripe/resources/charge.rb', line 1082

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1084
1085
1086
# File 'lib/stripe/resources/charge.rb', line 1084

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1086
1087
1088
# File 'lib/stripe/resources/charge.rb', line 1086

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



1088
1089
1090
# File 'lib/stripe/resources/charge.rb', line 1088

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



1090
1091
1092
# File 'lib/stripe/resources/charge.rb', line 1090

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



1092
1093
1094
# File 'lib/stripe/resources/charge.rb', line 1092

def routing_number
  @routing_number
end