Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::PaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
Account holder type: individual or company.
-
#account_type ⇒ Object
readonly
Account type: checkings or savings.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#payment_reference ⇒ Object
readonly
Reference number to locate ACH payments with customer’s bank.
-
#routing_number ⇒ Object
readonly
Routing number of the bank account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
Account holder type: individual or company.
1063 1064 1065 |
# File 'lib/stripe/resources/charge.rb', line 1063 def account_holder_type @account_holder_type end |
#account_type ⇒ Object (readonly)
Account type: checkings or savings. Defaults to checking if omitted.
1065 1066 1067 |
# File 'lib/stripe/resources/charge.rb', line 1065 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1067 1068 1069 |
# File 'lib/stripe/resources/charge.rb', line 1067 def bank_name @bank_name end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
1069 1070 1071 |
# File 'lib/stripe/resources/charge.rb', line 1069 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1071 1072 1073 |
# File 'lib/stripe/resources/charge.rb', line 1071 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
1073 1074 1075 |
# File 'lib/stripe/resources/charge.rb', line 1073 def mandate @mandate end |
#payment_reference ⇒ Object (readonly)
Reference number to locate ACH payments with customer’s bank.
1075 1076 1077 |
# File 'lib/stripe/resources/charge.rb', line 1075 def payment_reference @payment_reference end |
#routing_number ⇒ Object (readonly)
Routing number of the bank account.
1077 1078 1079 |
# File 'lib/stripe/resources/charge.rb', line 1077 def routing_number @routing_number end |