Class: Stripe::Charge::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1294
1295
1296
# File 'lib/stripe/resources/charge.rb', line 1294

def 
  @account_holder_type
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1297
1298
1299
# File 'lib/stripe/resources/charge.rb', line 1297

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1300
1301
1302
# File 'lib/stripe/resources/charge.rb', line 1300

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1303
1304
1305
# File 'lib/stripe/resources/charge.rb', line 1303

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1306
1307
1308
# File 'lib/stripe/resources/charge.rb', line 1306

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



1309
1310
1311
# File 'lib/stripe/resources/charge.rb', line 1309

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



1312
1313
1314
# File 'lib/stripe/resources/charge.rb', line 1312

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



1315
1316
1317
# File 'lib/stripe/resources/charge.rb', line 1315

def routing_number
  @routing_number
end