Class: Stripe::Charge::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



1486
1487
1488
1489
1490
1491
# File 'lib/stripe/resources/charge.rb', line 1486

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1478
1479
1480
# File 'lib/stripe/resources/charge.rb', line 1478

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1480
1481
1482
# File 'lib/stripe/resources/charge.rb', line 1480

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



1482
1483
1484
# File 'lib/stripe/resources/charge.rb', line 1482

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for charges](stripe.com/docs/search#query-fields-for-charges).



1484
1485
1486
# File 'lib/stripe/resources/charge.rb', line 1484

def query
  @query
end