Class: Stripe::Charge::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::SearchParams
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
2725 2726 2727 2728 2729 2730 |
# File 'lib/stripe/resources/charge.rb', line 2725 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2714 2715 2716 |
# File 'lib/stripe/resources/charge.rb', line 2714 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2717 2718 2719 |
# File 'lib/stripe/resources/charge.rb', line 2717 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
2720 2721 2722 |
# File 'lib/stripe/resources/charge.rb', line 2720 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for charges](stripe.com/docs/search#query-fields-for-charges).
2723 2724 2725 |
# File 'lib/stripe/resources/charge.rb', line 2723 def query @query end |