Class: Stripe::Charge::Shipping
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::Shipping
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#carrier ⇒ Object
readonly
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
readonly
Recipient name.
-
#phone ⇒ Object
readonly
Recipient phone (including extension).
-
#tracking_number ⇒ Object
readonly
The tracking number for a physical product, obtained from the delivery service.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
2353 2354 2355 |
# File 'lib/stripe/resources/charge.rb', line 2353 def address @address end |
#carrier ⇒ Object (readonly)
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
2355 2356 2357 |
# File 'lib/stripe/resources/charge.rb', line 2355 def carrier @carrier end |
#name ⇒ Object (readonly)
Recipient name.
2357 2358 2359 |
# File 'lib/stripe/resources/charge.rb', line 2357 def name @name end |
#phone ⇒ Object (readonly)
Recipient phone (including extension).
2359 2360 2361 |
# File 'lib/stripe/resources/charge.rb', line 2359 def phone @phone end |
#tracking_number ⇒ Object (readonly)
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
2361 2362 2363 |
# File 'lib/stripe/resources/charge.rb', line 2361 def tracking_number @tracking_number end |
Class Method Details
.field_remappings ⇒ Object
2367 2368 2369 |
# File 'lib/stripe/resources/charge.rb', line 2367 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2363 2364 2365 |
# File 'lib/stripe/resources/charge.rb', line 2363 def self.inner_class_types @inner_class_types = { address: Address } end |