Class: Stripe::Charge::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



1302
1303
1304
# File 'lib/stripe/resources/charge.rb', line 1302

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



1304
1305
1306
# File 'lib/stripe/resources/charge.rb', line 1304

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



1306
1307
1308
# File 'lib/stripe/resources/charge.rb', line 1306

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



1308
1309
1310
# File 'lib/stripe/resources/charge.rb', line 1308

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



1310
1311
1312
# File 'lib/stripe/resources/charge.rb', line 1310

def tracking_number
  @tracking_number
end