Class: Stripe::Charge::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



1201
1202
1203
# File 'lib/stripe/resources/charge.rb', line 1201

def address
  @address
end

#carrierObject (readonly)

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



1203
1204
1205
# File 'lib/stripe/resources/charge.rb', line 1203

def carrier
  @carrier
end

#nameObject (readonly)

Recipient name.



1205
1206
1207
# File 'lib/stripe/resources/charge.rb', line 1205

def name
  @name
end

#phoneObject (readonly)

Recipient phone (including extension).



1207
1208
1209
# File 'lib/stripe/resources/charge.rb', line 1207

def phone
  @phone
end

#tracking_numberObject (readonly)

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



1209
1210
1211
# File 'lib/stripe/resources/charge.rb', line 1209

def tracking_number
  @tracking_number
end