Class: Stripe::Charge::TransferData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Charge::TransferData
- Defined in:
- lib/stripe/resources/charge.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount transferred to the destination account, if specified.
-
#destination ⇒ Object
readonly
ID of an existing, connected Stripe account to transfer funds to if ‘transfer_data` was specified in the charge request.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.
2549 2550 2551 |
# File 'lib/stripe/resources/charge.rb', line 2549 def amount @amount end |
#destination ⇒ Object (readonly)
ID of an existing, connected Stripe account to transfer funds to if ‘transfer_data` was specified in the charge request.
2551 2552 2553 |
# File 'lib/stripe/resources/charge.rb', line 2551 def destination @destination end |
Class Method Details
.field_remappings ⇒ Object
2557 2558 2559 |
# File 'lib/stripe/resources/charge.rb', line 2557 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2553 2554 2555 |
# File 'lib/stripe/resources/charge.rb', line 2553 def self.inner_class_types @inner_class_types = {} end |