Class: Stripe::Charge::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: FraudDetails, PaymentDetails, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
# File 'lib/stripe/resources/charge.rb', line 3346

def initialize(
  customer: nil,
  description: nil,
  expand: nil,
  fraud_details: nil,
  metadata: nil,
  payment_details: nil,
  receipt_email: nil,
  shipping: nil,
  transfer_group: nil
)
  @customer = customer
  @description = description
  @expand = expand
  @fraud_details = fraud_details
  @metadata = 
  @payment_details = payment_details
  @receipt_email = receipt_email
  @shipping = shipping
  @transfer_group = transfer_group
end

Instance Attribute Details

#customerObject

The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.



3328
3329
3330
# File 'lib/stripe/resources/charge.rb', line 3328

def customer
  @customer
end

#descriptionObject

An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.



3330
3331
3332
# File 'lib/stripe/resources/charge.rb', line 3330

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



3332
3333
3334
# File 'lib/stripe/resources/charge.rb', line 3332

def expand
  @expand
end

#fraud_detailsObject

A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.



3334
3335
3336
# File 'lib/stripe/resources/charge.rb', line 3334

def fraud_details
  @fraud_details
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3336
3337
3338
# File 'lib/stripe/resources/charge.rb', line 3336

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



3338
3339
3340
# File 'lib/stripe/resources/charge.rb', line 3338

def payment_details
  @payment_details
end

#receipt_emailObject

This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.



3340
3341
3342
# File 'lib/stripe/resources/charge.rb', line 3340

def receipt_email
  @receipt_email
end

#shippingObject

Shipping information for the charge. Helps prevent fraud on charges for physical goods.



3342
3343
3344
# File 'lib/stripe/resources/charge.rb', line 3342

def shipping
  @shipping
end

#transfer_groupObject

A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.



3344
3345
3346
# File 'lib/stripe/resources/charge.rb', line 3344

def transfer_group
  @transfer_group
end