Class: Stripe::Charge::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: FraudDetails, Shipping
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of an existing customer that will be associated with this request.
-
#description ⇒ Object
An arbitrary string which you can attach to a charge object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fraud_details ⇒ Object
A set of key-value pairs you can attach to a charge giving information about its riskiness.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#receipt_email ⇒ Object
This is the email address that the receipt for this charge will be sent to.
-
#shipping ⇒ Object
Shipping information for the charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 |
# File 'lib/stripe/resources/charge.rb', line 1503 def initialize( customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, receipt_email: nil, shipping: nil, transfer_group: nil ) @customer = customer @description = description @expand = @fraud_details = fraud_details @metadata = @receipt_email = receipt_email @shipping = shipping @transfer_group = transfer_group end |
Instance Attribute Details
#customer ⇒ Object
The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.
1487 1488 1489 |
# File 'lib/stripe/resources/charge.rb', line 1487 def customer @customer end |
#description ⇒ Object
An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.
1489 1490 1491 |
# File 'lib/stripe/resources/charge.rb', line 1489 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1491 1492 1493 |
# File 'lib/stripe/resources/charge.rb', line 1491 def @expand end |
#fraud_details ⇒ Object
A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.
1493 1494 1495 |
# File 'lib/stripe/resources/charge.rb', line 1493 def fraud_details @fraud_details end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1495 1496 1497 |
# File 'lib/stripe/resources/charge.rb', line 1495 def @metadata end |
#receipt_email ⇒ Object
This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.
1497 1498 1499 |
# File 'lib/stripe/resources/charge.rb', line 1497 def receipt_email @receipt_email end |
#shipping ⇒ Object
Shipping information for the charge. Helps prevent fraud on charges for physical goods.
1499 1500 1501 |
# File 'lib/stripe/resources/charge.rb', line 1499 def shipping @shipping end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
1501 1502 1503 |
# File 'lib/stripe/resources/charge.rb', line 1501 def transfer_group @transfer_group end |