Class: Stripe::Charge::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: FraudDetails, PaymentDetails, Shipping
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of an existing customer that will be associated with this request.
-
#description ⇒ Object
An arbitrary string which you can attach to a charge object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fraud_details ⇒ Object
A set of key-value pairs you can attach to a charge giving information about its riskiness.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#receipt_email ⇒ Object
This is the email address that the receipt for this charge will be sent to.
-
#shipping ⇒ Object
Shipping information for the charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2282 2283 2284 2285 2286 2287 2288 2289 2290 2291 2292 2293 2294 2295 2296 2297 2298 2299 2300 2301 2302 |
# File 'lib/stripe/resources/charge.rb', line 2282 def initialize( customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil ) @customer = customer @description = description @expand = @fraud_details = fraud_details @metadata = @payment_details = payment_details @receipt_email = receipt_email @shipping = shipping @transfer_group = transfer_group end |
Instance Attribute Details
#customer ⇒ Object
The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.
2264 2265 2266 |
# File 'lib/stripe/resources/charge.rb', line 2264 def customer @customer end |
#description ⇒ Object
An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.
2266 2267 2268 |
# File 'lib/stripe/resources/charge.rb', line 2266 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2268 2269 2270 |
# File 'lib/stripe/resources/charge.rb', line 2268 def @expand end |
#fraud_details ⇒ Object
A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.
2270 2271 2272 |
# File 'lib/stripe/resources/charge.rb', line 2270 def fraud_details @fraud_details end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2272 2273 2274 |
# File 'lib/stripe/resources/charge.rb', line 2272 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
2274 2275 2276 |
# File 'lib/stripe/resources/charge.rb', line 2274 def payment_details @payment_details end |
#receipt_email ⇒ Object
This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.
2276 2277 2278 |
# File 'lib/stripe/resources/charge.rb', line 2276 def receipt_email @receipt_email end |
#shipping ⇒ Object
Shipping information for the charge. Helps prevent fraud on charges for physical goods.
2278 2279 2280 |
# File 'lib/stripe/resources/charge.rb', line 2278 def shipping @shipping end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
2280 2281 2282 |
# File 'lib/stripe/resources/charge.rb', line 2280 def transfer_group @transfer_group end |