Class: Stripe::Charge::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: FraudDetails, PaymentDetails, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
# File 'lib/stripe/resources/charge.rb', line 2240

def initialize(
  customer: nil,
  description: nil,
  expand: nil,
  fraud_details: nil,
  metadata: nil,
  payment_details: nil,
  receipt_email: nil,
  shipping: nil,
  transfer_group: nil
)
  @customer = customer
  @description = description
  @expand = expand
  @fraud_details = fraud_details
  @metadata = 
  @payment_details = payment_details
  @receipt_email = receipt_email
  @shipping = shipping
  @transfer_group = transfer_group
end

Instance Attribute Details

#customerObject

The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.



2222
2223
2224
# File 'lib/stripe/resources/charge.rb', line 2222

def customer
  @customer
end

#descriptionObject

An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.



2224
2225
2226
# File 'lib/stripe/resources/charge.rb', line 2224

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



2226
2227
2228
# File 'lib/stripe/resources/charge.rb', line 2226

def expand
  @expand
end

#fraud_detailsObject

A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.



2228
2229
2230
# File 'lib/stripe/resources/charge.rb', line 2228

def fraud_details
  @fraud_details
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2230
2231
2232
# File 'lib/stripe/resources/charge.rb', line 2230

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



2232
2233
2234
# File 'lib/stripe/resources/charge.rb', line 2232

def payment_details
  @payment_details
end

#receipt_emailObject

This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.



2234
2235
2236
# File 'lib/stripe/resources/charge.rb', line 2234

def receipt_email
  @receipt_email
end

#shippingObject

Shipping information for the charge. Helps prevent fraud on charges for physical goods.



2236
2237
2238
# File 'lib/stripe/resources/charge.rb', line 2236

def shipping
  @shipping
end

#transfer_groupObject

A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.



2238
2239
2240
# File 'lib/stripe/resources/charge.rb', line 2238

def transfer_group
  @transfer_group
end