Class: Stripe::Charge::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: FraudDetails, PaymentDetails, Shipping
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of an existing customer that will be associated with this request.
-
#description ⇒ Object
An arbitrary string which you can attach to a charge object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fraud_details ⇒ Object
A set of key-value pairs you can attach to a charge giving information about its riskiness.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#receipt_email ⇒ Object
This is the email address that the receipt for this charge will be sent to.
-
#shipping ⇒ Object
Shipping information for the charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 |
# File 'lib/stripe/resources/charge.rb', line 2194 def initialize( customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil ) @customer = customer @description = description @expand = @fraud_details = fraud_details @metadata = @payment_details = payment_details @receipt_email = receipt_email @shipping = shipping @transfer_group = transfer_group end |
Instance Attribute Details
#customer ⇒ Object
The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.
2176 2177 2178 |
# File 'lib/stripe/resources/charge.rb', line 2176 def customer @customer end |
#description ⇒ Object
An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.
2178 2179 2180 |
# File 'lib/stripe/resources/charge.rb', line 2178 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2180 2181 2182 |
# File 'lib/stripe/resources/charge.rb', line 2180 def @expand end |
#fraud_details ⇒ Object
A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.
2182 2183 2184 |
# File 'lib/stripe/resources/charge.rb', line 2182 def fraud_details @fraud_details end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2184 2185 2186 |
# File 'lib/stripe/resources/charge.rb', line 2184 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
2186 2187 2188 |
# File 'lib/stripe/resources/charge.rb', line 2186 def payment_details @payment_details end |
#receipt_email ⇒ Object
This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.
2188 2189 2190 |
# File 'lib/stripe/resources/charge.rb', line 2188 def receipt_email @receipt_email end |
#shipping ⇒ Object
Shipping information for the charge. Helps prevent fraud on charges for physical goods.
2190 2191 2192 |
# File 'lib/stripe/resources/charge.rb', line 2190 def shipping @shipping end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
2192 2193 2194 |
# File 'lib/stripe/resources/charge.rb', line 2192 def transfer_group @transfer_group end |