Class: Stripe::Charge::UpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 |
# File 'lib/stripe/resources/charge.rb', line 3258 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
3244 3245 3246 |
# File 'lib/stripe/resources/charge.rb', line 3244 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
3246 3247 3248 |
# File 'lib/stripe/resources/charge.rb', line 3246 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
3248 3249 3250 |
# File 'lib/stripe/resources/charge.rb', line 3248 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
3250 3251 3252 |
# File 'lib/stripe/resources/charge.rb', line 3250 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
3252 3253 3254 |
# File 'lib/stripe/resources/charge.rb', line 3252 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
3254 3255 3256 |
# File 'lib/stripe/resources/charge.rb', line 3254 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
3256 3257 3258 |
# File 'lib/stripe/resources/charge.rb', line 3256 def subscription @subscription end |