Class: Stripe::Charge::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



2207
2208
2209
2210
2211
2212
2213
2214
2215
2216
2217
2218
2219
2220
2221
2222
2223
# File 'lib/stripe/resources/charge.rb', line 2207

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



2193
2194
2195
# File 'lib/stripe/resources/charge.rb', line 2193

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



2195
2196
2197
# File 'lib/stripe/resources/charge.rb', line 2195

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



2197
2198
2199
# File 'lib/stripe/resources/charge.rb', line 2197

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



2199
2200
2201
# File 'lib/stripe/resources/charge.rb', line 2199

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



2201
2202
2203
# File 'lib/stripe/resources/charge.rb', line 2201

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



2203
2204
2205
# File 'lib/stripe/resources/charge.rb', line 2203

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



2205
2206
2207
# File 'lib/stripe/resources/charge.rb', line 2205

def subscription
  @subscription
end