Class: Stripe::Charge::UpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 |
# File 'lib/stripe/resources/charge.rb', line 2194 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
2180 2181 2182 |
# File 'lib/stripe/resources/charge.rb', line 2180 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
2182 2183 2184 |
# File 'lib/stripe/resources/charge.rb', line 2182 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
2184 2185 2186 |
# File 'lib/stripe/resources/charge.rb', line 2184 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
2186 2187 2188 |
# File 'lib/stripe/resources/charge.rb', line 2186 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
2188 2189 2190 |
# File 'lib/stripe/resources/charge.rb', line 2188 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
2190 2191 2192 |
# File 'lib/stripe/resources/charge.rb', line 2190 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
2192 2193 2194 |
# File 'lib/stripe/resources/charge.rb', line 2192 def subscription @subscription end |