Class: Stripe::Charge::UpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
# File 'lib/stripe/resources/charge.rb', line 2152

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



2138
2139
2140
# File 'lib/stripe/resources/charge.rb', line 2138

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



2140
2141
2142
# File 'lib/stripe/resources/charge.rb', line 2140

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



2142
2143
2144
# File 'lib/stripe/resources/charge.rb', line 2142

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



2144
2145
2146
# File 'lib/stripe/resources/charge.rb', line 2144

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



2146
2147
2148
# File 'lib/stripe/resources/charge.rb', line 2146

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



2148
2149
2150
# File 'lib/stripe/resources/charge.rb', line 2148

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



2150
2151
2152
# File 'lib/stripe/resources/charge.rb', line 2150

def subscription
  @subscription
end