Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 |
# File 'lib/stripe/resources/charge.rb', line 1728 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1680 1681 1682 |
# File 'lib/stripe/resources/charge.rb', line 1680 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
1682 1683 1684 |
# File 'lib/stripe/resources/charge.rb', line 1682 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
1684 1685 1686 |
# File 'lib/stripe/resources/charge.rb', line 1684 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
1686 1687 1688 |
# File 'lib/stripe/resources/charge.rb', line 1686 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
1688 1689 1690 |
# File 'lib/stripe/resources/charge.rb', line 1688 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
1690 1691 1692 |
# File 'lib/stripe/resources/charge.rb', line 1690 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
1692 1693 1694 |
# File 'lib/stripe/resources/charge.rb', line 1692 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
1694 1695 1696 |
# File 'lib/stripe/resources/charge.rb', line 1694 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
1696 1697 1698 |
# File 'lib/stripe/resources/charge.rb', line 1696 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
1698 1699 1700 |
# File 'lib/stripe/resources/charge.rb', line 1698 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
1700 1701 1702 |
# File 'lib/stripe/resources/charge.rb', line 1700 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
1702 1703 1704 |
# File 'lib/stripe/resources/charge.rb', line 1702 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
1704 1705 1706 |
# File 'lib/stripe/resources/charge.rb', line 1704 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
1706 1707 1708 |
# File 'lib/stripe/resources/charge.rb', line 1706 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
1708 1709 1710 |
# File 'lib/stripe/resources/charge.rb', line 1708 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
1710 1711 1712 |
# File 'lib/stripe/resources/charge.rb', line 1710 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
1712 1713 1714 |
# File 'lib/stripe/resources/charge.rb', line 1712 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1714 1715 1716 |
# File 'lib/stripe/resources/charge.rb', line 1714 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
1716 1717 1718 |
# File 'lib/stripe/resources/charge.rb', line 1716 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
1718 1719 1720 |
# File 'lib/stripe/resources/charge.rb', line 1718 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
1720 1721 1722 |
# File 'lib/stripe/resources/charge.rb', line 1720 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
1722 1723 1724 |
# File 'lib/stripe/resources/charge.rb', line 1722 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
1724 1725 1726 |
# File 'lib/stripe/resources/charge.rb', line 1724 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
1726 1727 1728 |
# File 'lib/stripe/resources/charge.rb', line 1726 def vehicle_identification_number @vehicle_identification_number end |