Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 |
# File 'lib/stripe/resources/charge.rb', line 2746 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
2698 2699 2700 |
# File 'lib/stripe/resources/charge.rb', line 2698 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
2700 2701 2702 |
# File 'lib/stripe/resources/charge.rb', line 2700 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
2702 2703 2704 |
# File 'lib/stripe/resources/charge.rb', line 2702 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
2704 2705 2706 |
# File 'lib/stripe/resources/charge.rb', line 2704 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
2706 2707 2708 |
# File 'lib/stripe/resources/charge.rb', line 2706 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
2708 2709 2710 |
# File 'lib/stripe/resources/charge.rb', line 2708 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
2710 2711 2712 |
# File 'lib/stripe/resources/charge.rb', line 2710 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
2712 2713 2714 |
# File 'lib/stripe/resources/charge.rb', line 2712 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
2714 2715 2716 |
# File 'lib/stripe/resources/charge.rb', line 2714 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
2716 2717 2718 |
# File 'lib/stripe/resources/charge.rb', line 2716 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
2718 2719 2720 |
# File 'lib/stripe/resources/charge.rb', line 2718 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
2720 2721 2722 |
# File 'lib/stripe/resources/charge.rb', line 2720 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
2722 2723 2724 |
# File 'lib/stripe/resources/charge.rb', line 2722 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
2724 2725 2726 |
# File 'lib/stripe/resources/charge.rb', line 2724 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
2726 2727 2728 |
# File 'lib/stripe/resources/charge.rb', line 2726 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
2728 2729 2730 |
# File 'lib/stripe/resources/charge.rb', line 2728 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
2730 2731 2732 |
# File 'lib/stripe/resources/charge.rb', line 2730 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
2732 2733 2734 |
# File 'lib/stripe/resources/charge.rb', line 2732 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
2734 2735 2736 |
# File 'lib/stripe/resources/charge.rb', line 2734 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
2736 2737 2738 |
# File 'lib/stripe/resources/charge.rb', line 2736 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
2738 2739 2740 |
# File 'lib/stripe/resources/charge.rb', line 2738 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
2740 2741 2742 |
# File 'lib/stripe/resources/charge.rb', line 2740 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
2742 2743 2744 |
# File 'lib/stripe/resources/charge.rb', line 2742 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
2744 2745 2746 |
# File 'lib/stripe/resources/charge.rb', line 2744 def vehicle_identification_number @vehicle_identification_number end |