Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 |
# File 'lib/stripe/resources/charge.rb', line 1682 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1634 1635 1636 |
# File 'lib/stripe/resources/charge.rb', line 1634 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
1636 1637 1638 |
# File 'lib/stripe/resources/charge.rb', line 1636 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
1638 1639 1640 |
# File 'lib/stripe/resources/charge.rb', line 1638 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
1640 1641 1642 |
# File 'lib/stripe/resources/charge.rb', line 1640 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
1642 1643 1644 |
# File 'lib/stripe/resources/charge.rb', line 1642 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
1644 1645 1646 |
# File 'lib/stripe/resources/charge.rb', line 1644 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
1646 1647 1648 |
# File 'lib/stripe/resources/charge.rb', line 1646 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
1648 1649 1650 |
# File 'lib/stripe/resources/charge.rb', line 1648 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
1650 1651 1652 |
# File 'lib/stripe/resources/charge.rb', line 1650 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
1652 1653 1654 |
# File 'lib/stripe/resources/charge.rb', line 1652 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
1654 1655 1656 |
# File 'lib/stripe/resources/charge.rb', line 1654 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
1656 1657 1658 |
# File 'lib/stripe/resources/charge.rb', line 1656 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
1658 1659 1660 |
# File 'lib/stripe/resources/charge.rb', line 1658 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
1660 1661 1662 |
# File 'lib/stripe/resources/charge.rb', line 1660 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
1662 1663 1664 |
# File 'lib/stripe/resources/charge.rb', line 1662 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
1664 1665 1666 |
# File 'lib/stripe/resources/charge.rb', line 1664 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
1666 1667 1668 |
# File 'lib/stripe/resources/charge.rb', line 1666 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1668 1669 1670 |
# File 'lib/stripe/resources/charge.rb', line 1668 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
1670 1671 1672 |
# File 'lib/stripe/resources/charge.rb', line 1670 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
1672 1673 1674 |
# File 'lib/stripe/resources/charge.rb', line 1672 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
1674 1675 1676 |
# File 'lib/stripe/resources/charge.rb', line 1674 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
1676 1677 1678 |
# File 'lib/stripe/resources/charge.rb', line 1676 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
1678 1679 1680 |
# File 'lib/stripe/resources/charge.rb', line 1678 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
1680 1681 1682 |
# File 'lib/stripe/resources/charge.rb', line 1680 def vehicle_identification_number @vehicle_identification_number end |