Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
# File 'lib/stripe/resources/charge.rb', line 1648

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



1608
1609
1610
# File 'lib/stripe/resources/charge.rb', line 1608

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



1610
1611
1612
# File 'lib/stripe/resources/charge.rb', line 1610

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



1612
1613
1614
# File 'lib/stripe/resources/charge.rb', line 1612

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



1614
1615
1616
# File 'lib/stripe/resources/charge.rb', line 1614

def car_make
  @car_make
end

#car_modelObject

Model of the car.



1616
1617
1618
# File 'lib/stripe/resources/charge.rb', line 1616

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



1618
1619
1620
# File 'lib/stripe/resources/charge.rb', line 1618

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



1620
1621
1622
# File 'lib/stripe/resources/charge.rb', line 1620

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



1622
1623
1624
# File 'lib/stripe/resources/charge.rb', line 1622

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



1624
1625
1626
# File 'lib/stripe/resources/charge.rb', line 1624

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



1626
1627
1628
# File 'lib/stripe/resources/charge.rb', line 1626

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



1628
1629
1630
# File 'lib/stripe/resources/charge.rb', line 1628

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



1630
1631
1632
# File 'lib/stripe/resources/charge.rb', line 1630

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



1632
1633
1634
# File 'lib/stripe/resources/charge.rb', line 1632

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



1634
1635
1636
# File 'lib/stripe/resources/charge.rb', line 1634

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



1636
1637
1638
# File 'lib/stripe/resources/charge.rb', line 1636

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



1638
1639
1640
# File 'lib/stripe/resources/charge.rb', line 1638

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



1640
1641
1642
# File 'lib/stripe/resources/charge.rb', line 1640

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



1642
1643
1644
# File 'lib/stripe/resources/charge.rb', line 1642

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



1644
1645
1646
# File 'lib/stripe/resources/charge.rb', line 1644

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



1646
1647
1648
# File 'lib/stripe/resources/charge.rb', line 1646

def tax_exempt
  @tax_exempt
end