Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 |
# File 'lib/stripe/resources/charge.rb', line 1646 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1606 1607 1608 |
# File 'lib/stripe/resources/charge.rb', line 1606 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
1608 1609 1610 |
# File 'lib/stripe/resources/charge.rb', line 1608 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
1610 1611 1612 |
# File 'lib/stripe/resources/charge.rb', line 1610 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
1612 1613 1614 |
# File 'lib/stripe/resources/charge.rb', line 1612 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
1614 1615 1616 |
# File 'lib/stripe/resources/charge.rb', line 1614 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
1616 1617 1618 |
# File 'lib/stripe/resources/charge.rb', line 1616 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
1618 1619 1620 |
# File 'lib/stripe/resources/charge.rb', line 1618 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
1620 1621 1622 |
# File 'lib/stripe/resources/charge.rb', line 1620 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
1622 1623 1624 |
# File 'lib/stripe/resources/charge.rb', line 1622 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
1624 1625 1626 |
# File 'lib/stripe/resources/charge.rb', line 1624 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
1626 1627 1628 |
# File 'lib/stripe/resources/charge.rb', line 1626 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
1628 1629 1630 |
# File 'lib/stripe/resources/charge.rb', line 1628 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
1630 1631 1632 |
# File 'lib/stripe/resources/charge.rb', line 1630 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
1632 1633 1634 |
# File 'lib/stripe/resources/charge.rb', line 1632 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
1634 1635 1636 |
# File 'lib/stripe/resources/charge.rb', line 1634 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1636 1637 1638 |
# File 'lib/stripe/resources/charge.rb', line 1636 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
1638 1639 1640 |
# File 'lib/stripe/resources/charge.rb', line 1638 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
1640 1641 1642 |
# File 'lib/stripe/resources/charge.rb', line 1640 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
1642 1643 1644 |
# File 'lib/stripe/resources/charge.rb', line 1642 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
1644 1645 1646 |
# File 'lib/stripe/resources/charge.rb', line 1644 def tax_exempt @tax_exempt end |