Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 |
# File 'lib/stripe/resources/charge.rb', line 2017 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1958 1959 1960 |
# File 'lib/stripe/resources/charge.rb', line 1958 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
1961 1962 1963 |
# File 'lib/stripe/resources/charge.rb', line 1961 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
1964 1965 1966 |
# File 'lib/stripe/resources/charge.rb', line 1964 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
1967 1968 1969 |
# File 'lib/stripe/resources/charge.rb', line 1967 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
1970 1971 1972 |
# File 'lib/stripe/resources/charge.rb', line 1970 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
1973 1974 1975 |
# File 'lib/stripe/resources/charge.rb', line 1973 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
1976 1977 1978 |
# File 'lib/stripe/resources/charge.rb', line 1976 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
1979 1980 1981 |
# File 'lib/stripe/resources/charge.rb', line 1979 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
1982 1983 1984 |
# File 'lib/stripe/resources/charge.rb', line 1982 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
1985 1986 1987 |
# File 'lib/stripe/resources/charge.rb', line 1985 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
1988 1989 1990 |
# File 'lib/stripe/resources/charge.rb', line 1988 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
1991 1992 1993 |
# File 'lib/stripe/resources/charge.rb', line 1991 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
1994 1995 1996 |
# File 'lib/stripe/resources/charge.rb', line 1994 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
1997 1998 1999 |
# File 'lib/stripe/resources/charge.rb', line 1997 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
2000 2001 2002 |
# File 'lib/stripe/resources/charge.rb', line 2000 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
2003 2004 2005 |
# File 'lib/stripe/resources/charge.rb', line 2003 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
2006 2007 2008 |
# File 'lib/stripe/resources/charge.rb', line 2006 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
2009 2010 2011 |
# File 'lib/stripe/resources/charge.rb', line 2009 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
2012 2013 2014 |
# File 'lib/stripe/resources/charge.rb', line 2012 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
2015 2016 2017 |
# File 'lib/stripe/resources/charge.rb', line 2015 def tax_exempt @tax_exempt end |