Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1528 1529 1530 1531 1532 |
# File 'lib/stripe/resources/charge.rb', line 1528 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1522 1523 1524 |
# File 'lib/stripe/resources/charge.rb', line 1522 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1524 1525 1526 |
# File 'lib/stripe/resources/charge.rb', line 1524 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1526 1527 1528 |
# File 'lib/stripe/resources/charge.rb', line 1526 def phone @phone end |