Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1520
1521
1522
1523
1524
# File 'lib/stripe/resources/charge.rb', line 1520

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1514
1515
1516
# File 'lib/stripe/resources/charge.rb', line 1514

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1516
1517
1518
# File 'lib/stripe/resources/charge.rb', line 1516

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1518
1519
1520
# File 'lib/stripe/resources/charge.rb', line 1518

def phone
  @phone
end