Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1486 1487 1488 1489 1490 |
# File 'lib/stripe/resources/charge.rb', line 1486 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1480 1481 1482 |
# File 'lib/stripe/resources/charge.rb', line 1480 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1482 1483 1484 |
# File 'lib/stripe/resources/charge.rb', line 1482 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1484 1485 1486 |
# File 'lib/stripe/resources/charge.rb', line 1484 def phone @phone end |