Class: Stripe::Charge::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1859
1860
1861
1862
1863
# File 'lib/stripe/resources/charge.rb', line 1859

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1851
1852
1853
# File 'lib/stripe/resources/charge.rb', line 1851

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1854
1855
1856
# File 'lib/stripe/resources/charge.rb', line 1854

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1857
1858
1859
# File 'lib/stripe/resources/charge.rb', line 1857

def phone
  @phone
end