Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 |
# File 'lib/stripe/resources/charge.rb', line 1833 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1815 1816 1817 |
# File 'lib/stripe/resources/charge.rb', line 1815 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
1817 1818 1819 |
# File 'lib/stripe/resources/charge.rb', line 1817 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1819 1820 1821 |
# File 'lib/stripe/resources/charge.rb', line 1819 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1821 1822 1823 |
# File 'lib/stripe/resources/charge.rb', line 1821 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1823 1824 1825 |
# File 'lib/stripe/resources/charge.rb', line 1823 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1825 1826 1827 |
# File 'lib/stripe/resources/charge.rb', line 1825 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1827 1828 1829 |
# File 'lib/stripe/resources/charge.rb', line 1827 def genre @genre end |
#name ⇒ Object
The name of the event.
1829 1830 1831 |
# File 'lib/stripe/resources/charge.rb', line 1829 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1831 1832 1833 |
# File 'lib/stripe/resources/charge.rb', line 1831 def starts_at @starts_at end |