Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 |
# File 'lib/stripe/resources/charge.rb', line 1744 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1726 1727 1728 |
# File 'lib/stripe/resources/charge.rb', line 1726 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
1728 1729 1730 |
# File 'lib/stripe/resources/charge.rb', line 1728 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1730 1731 1732 |
# File 'lib/stripe/resources/charge.rb', line 1730 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1732 1733 1734 |
# File 'lib/stripe/resources/charge.rb', line 1732 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1734 1735 1736 |
# File 'lib/stripe/resources/charge.rb', line 1734 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1736 1737 1738 |
# File 'lib/stripe/resources/charge.rb', line 1736 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1738 1739 1740 |
# File 'lib/stripe/resources/charge.rb', line 1738 def genre @genre end |
#name ⇒ Object
The name of the event.
1740 1741 1742 |
# File 'lib/stripe/resources/charge.rb', line 1740 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1742 1743 1744 |
# File 'lib/stripe/resources/charge.rb', line 1742 def starts_at @starts_at end |