Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 |
# File 'lib/stripe/resources/charge.rb', line 2163 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
2137 2138 2139 |
# File 'lib/stripe/resources/charge.rb', line 2137 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
2140 2141 2142 |
# File 'lib/stripe/resources/charge.rb', line 2140 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2143 2144 2145 |
# File 'lib/stripe/resources/charge.rb', line 2143 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
2146 2147 2148 |
# File 'lib/stripe/resources/charge.rb', line 2146 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
2149 2150 2151 |
# File 'lib/stripe/resources/charge.rb', line 2149 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
2152 2153 2154 |
# File 'lib/stripe/resources/charge.rb', line 2152 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
2155 2156 2157 |
# File 'lib/stripe/resources/charge.rb', line 2155 def genre @genre end |
#name ⇒ Object
The name of the event.
2158 2159 2160 |
# File 'lib/stripe/resources/charge.rb', line 2158 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
2161 2162 2163 |
# File 'lib/stripe/resources/charge.rb', line 2161 def starts_at @starts_at end |