Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2849
2850
2851
2852
2853
# File 'lib/stripe/resources/charge.rb', line 2849

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2843
2844
2845
# File 'lib/stripe/resources/charge.rb', line 2843

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2845
2846
2847
# File 'lib/stripe/resources/charge.rb', line 2845

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2847
2848
2849
# File 'lib/stripe/resources/charge.rb', line 2847

def phone
  @phone
end