Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1785
1786
1787
1788
1789
# File 'lib/stripe/resources/charge.rb', line 1785

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1779
1780
1781
# File 'lib/stripe/resources/charge.rb', line 1779

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1781
1782
1783
# File 'lib/stripe/resources/charge.rb', line 1781

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1783
1784
1785
# File 'lib/stripe/resources/charge.rb', line 1783

def phone
  @phone
end