Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1743
1744
1745
1746
1747
# File 'lib/stripe/resources/charge.rb', line 1743

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1737
1738
1739
# File 'lib/stripe/resources/charge.rb', line 1737

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1739
1740
1741
# File 'lib/stripe/resources/charge.rb', line 1739

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1741
1742
1743
# File 'lib/stripe/resources/charge.rb', line 1741

def phone
  @phone
end