Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1709
1710
1711
1712
1713
# File 'lib/stripe/resources/charge.rb', line 1709

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1703
1704
1705
# File 'lib/stripe/resources/charge.rb', line 1703

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1705
1706
1707
# File 'lib/stripe/resources/charge.rb', line 1705

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1707
1708
1709
# File 'lib/stripe/resources/charge.rb', line 1707

def phone
  @phone
end