Class: Stripe::Charge::UpdateParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2119
2120
2121
2122
2123
# File 'lib/stripe/resources/charge.rb', line 2119

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2111
2112
2113
# File 'lib/stripe/resources/charge.rb', line 2111

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2114
2115
2116
# File 'lib/stripe/resources/charge.rb', line 2114

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2117
2118
2119
# File 'lib/stripe/resources/charge.rb', line 2117

def phone
  @phone
end