Class: Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2926
2927
2928
2929
2930
# File 'lib/stripe/resources/charge.rb', line 2926

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2920
2921
2922
# File 'lib/stripe/resources/charge.rb', line 2920

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2922
2923
2924
# File 'lib/stripe/resources/charge.rb', line 2922

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2924
2925
2926
# File 'lib/stripe/resources/charge.rb', line 2924

def phone
  @phone
end