Class: Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1862
1863
1864
1865
1866
# File 'lib/stripe/resources/charge.rb', line 1862

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1856
1857
1858
# File 'lib/stripe/resources/charge.rb', line 1856

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1858
1859
1860
# File 'lib/stripe/resources/charge.rb', line 1858

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1860
1861
1862
# File 'lib/stripe/resources/charge.rb', line 1860

def phone
  @phone
end