Class: Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1820
1821
1822
1823
1824
# File 'lib/stripe/resources/charge.rb', line 1820

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1814
1815
1816
# File 'lib/stripe/resources/charge.rb', line 1814

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1816
1817
1818
# File 'lib/stripe/resources/charge.rb', line 1816

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1818
1819
1820
# File 'lib/stripe/resources/charge.rb', line 1818

def phone
  @phone
end