Class: Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1818 1819 1820 1821 1822 |
# File 'lib/stripe/resources/charge.rb', line 1818 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1812 1813 1814 |
# File 'lib/stripe/resources/charge.rb', line 1812 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1814 1815 1816 |
# File 'lib/stripe/resources/charge.rb', line 1814 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1816 1817 1818 |
# File 'lib/stripe/resources/charge.rb', line 1816 def phone @phone end |