Class: Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1786
1787
1788
1789
1790
# File 'lib/stripe/resources/charge.rb', line 1786

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1780
1781
1782
# File 'lib/stripe/resources/charge.rb', line 1780

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1782
1783
1784
# File 'lib/stripe/resources/charge.rb', line 1782

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1784
1785
1786
# File 'lib/stripe/resources/charge.rb', line 1784

def phone
  @phone
end