Class: Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2207
2208
2209
2210
2211
# File 'lib/stripe/resources/charge.rb', line 2207

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2199
2200
2201
# File 'lib/stripe/resources/charge.rb', line 2199

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2202
2203
2204
# File 'lib/stripe/resources/charge.rb', line 2202

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2205
2206
2207
# File 'lib/stripe/resources/charge.rb', line 2205

def phone
  @phone
end