Class: Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1782 1783 1784 1785 1786 |
# File 'lib/stripe/resources/charge.rb', line 1782 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1776 1777 1778 |
# File 'lib/stripe/resources/charge.rb', line 1776 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1778 1779 1780 |
# File 'lib/stripe/resources/charge.rb', line 1778 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1780 1781 1782 |
# File 'lib/stripe/resources/charge.rb', line 1780 def phone @phone end |