Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 |
# File 'lib/stripe/resources/charge.rb', line 2128 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2086 2087 2088 |
# File 'lib/stripe/resources/charge.rb', line 2086 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2088 2089 2090 |
# File 'lib/stripe/resources/charge.rb', line 2088 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2090 2091 2092 |
# File 'lib/stripe/resources/charge.rb', line 2090 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2092 2093 2094 |
# File 'lib/stripe/resources/charge.rb', line 2092 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2094 2095 2096 |
# File 'lib/stripe/resources/charge.rb', line 2094 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
2096 2097 2098 |
# File 'lib/stripe/resources/charge.rb', line 2096 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2098 2099 2100 |
# File 'lib/stripe/resources/charge.rb', line 2098 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2100 2101 2102 |
# File 'lib/stripe/resources/charge.rb', line 2100 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2102 2103 2104 |
# File 'lib/stripe/resources/charge.rb', line 2102 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2104 2105 2106 |
# File 'lib/stripe/resources/charge.rb', line 2104 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2106 2107 2108 |
# File 'lib/stripe/resources/charge.rb', line 2106 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2108 2109 2110 |
# File 'lib/stripe/resources/charge.rb', line 2108 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2110 2111 2112 |
# File 'lib/stripe/resources/charge.rb', line 2110 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2112 2113 2114 |
# File 'lib/stripe/resources/charge.rb', line 2112 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2114 2115 2116 |
# File 'lib/stripe/resources/charge.rb', line 2114 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2116 2117 2118 |
# File 'lib/stripe/resources/charge.rb', line 2116 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2118 2119 2120 |
# File 'lib/stripe/resources/charge.rb', line 2118 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2120 2121 2122 |
# File 'lib/stripe/resources/charge.rb', line 2120 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2122 2123 2124 |
# File 'lib/stripe/resources/charge.rb', line 2122 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2124 2125 2126 |
# File 'lib/stripe/resources/charge.rb', line 2124 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2126 2127 2128 |
# File 'lib/stripe/resources/charge.rb', line 2126 def total_tax_amount @total_tax_amount end |