Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 3168 3169 3170 3171 3172 3173 3174 3175 3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 |
# File 'lib/stripe/resources/charge.rb', line 3146 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
3104 3105 3106 |
# File 'lib/stripe/resources/charge.rb', line 3104 def address @address end |
#adults ⇒ Object
The number of adults on the booking
3106 3107 3108 |
# File 'lib/stripe/resources/charge.rb', line 3106 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
3108 3109 3110 |
# File 'lib/stripe/resources/charge.rb', line 3108 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
3110 3111 3112 |
# File 'lib/stripe/resources/charge.rb', line 3110 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
3112 3113 3114 |
# File 'lib/stripe/resources/charge.rb', line 3112 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
3114 3115 3116 |
# File 'lib/stripe/resources/charge.rb', line 3114 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
3116 3117 3118 |
# File 'lib/stripe/resources/charge.rb', line 3116 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
3118 3119 3120 |
# File 'lib/stripe/resources/charge.rb', line 3118 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
3120 3121 3122 |
# File 'lib/stripe/resources/charge.rb', line 3120 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
3122 3123 3124 |
# File 'lib/stripe/resources/charge.rb', line 3122 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
3124 3125 3126 |
# File 'lib/stripe/resources/charge.rb', line 3124 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
3126 3127 3128 |
# File 'lib/stripe/resources/charge.rb', line 3126 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
3128 3129 3130 |
# File 'lib/stripe/resources/charge.rb', line 3128 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
3130 3131 3132 |
# File 'lib/stripe/resources/charge.rb', line 3130 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
3132 3133 3134 |
# File 'lib/stripe/resources/charge.rb', line 3132 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
3134 3135 3136 |
# File 'lib/stripe/resources/charge.rb', line 3134 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
3136 3137 3138 |
# File 'lib/stripe/resources/charge.rb', line 3136 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
3138 3139 3140 |
# File 'lib/stripe/resources/charge.rb', line 3138 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
3140 3141 3142 |
# File 'lib/stripe/resources/charge.rb', line 3140 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
3142 3143 3144 |
# File 'lib/stripe/resources/charge.rb', line 3142 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
3144 3145 3146 |
# File 'lib/stripe/resources/charge.rb', line 3144 def total_tax_amount @total_tax_amount end |