Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
# File 'lib/stripe/resources/charge.rb', line 2082

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



2040
2041
2042
# File 'lib/stripe/resources/charge.rb', line 2040

def address
  @address
end

#adultsObject

The number of adults on the booking



2042
2043
2044
# File 'lib/stripe/resources/charge.rb', line 2042

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



2044
2045
2046
# File 'lib/stripe/resources/charge.rb', line 2044

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



2046
2047
2048
# File 'lib/stripe/resources/charge.rb', line 2046

def booking_number
  @booking_number
end

#categoryObject

The lodging category



2048
2049
2050
# File 'lib/stripe/resources/charge.rb', line 2048

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



2050
2051
2052
# File 'lib/stripe/resources/charge.rb', line 2050

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



2052
2053
2054
# File 'lib/stripe/resources/charge.rb', line 2052

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



2054
2055
2056
# File 'lib/stripe/resources/charge.rb', line 2054

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



2056
2057
2058
# File 'lib/stripe/resources/charge.rb', line 2056

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



2058
2059
2060
# File 'lib/stripe/resources/charge.rb', line 2058

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



2060
2061
2062
# File 'lib/stripe/resources/charge.rb', line 2060

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



2062
2063
2064
# File 'lib/stripe/resources/charge.rb', line 2062

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



2064
2065
2066
# File 'lib/stripe/resources/charge.rb', line 2064

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



2066
2067
2068
# File 'lib/stripe/resources/charge.rb', line 2066

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



2068
2069
2070
# File 'lib/stripe/resources/charge.rb', line 2068

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



2070
2071
2072
# File 'lib/stripe/resources/charge.rb', line 2070

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



2072
2073
2074
# File 'lib/stripe/resources/charge.rb', line 2072

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



2074
2075
2076
# File 'lib/stripe/resources/charge.rb', line 2074

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



2076
2077
2078
# File 'lib/stripe/resources/charge.rb', line 2076

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



2078
2079
2080
# File 'lib/stripe/resources/charge.rb', line 2078

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



2080
2081
2082
# File 'lib/stripe/resources/charge.rb', line 2080

def total_tax_amount
  @total_tax_amount
end