Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
# File 'lib/stripe/resources/charge.rb', line 2040

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



1998
1999
2000
# File 'lib/stripe/resources/charge.rb', line 1998

def address
  @address
end

#adultsObject

The number of adults on the booking



2000
2001
2002
# File 'lib/stripe/resources/charge.rb', line 2000

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



2002
2003
2004
# File 'lib/stripe/resources/charge.rb', line 2002

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



2004
2005
2006
# File 'lib/stripe/resources/charge.rb', line 2004

def booking_number
  @booking_number
end

#categoryObject

The lodging category



2006
2007
2008
# File 'lib/stripe/resources/charge.rb', line 2006

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



2008
2009
2010
# File 'lib/stripe/resources/charge.rb', line 2008

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



2010
2011
2012
# File 'lib/stripe/resources/charge.rb', line 2010

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



2012
2013
2014
# File 'lib/stripe/resources/charge.rb', line 2012

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



2014
2015
2016
# File 'lib/stripe/resources/charge.rb', line 2014

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



2016
2017
2018
# File 'lib/stripe/resources/charge.rb', line 2016

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



2018
2019
2020
# File 'lib/stripe/resources/charge.rb', line 2018

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



2020
2021
2022
# File 'lib/stripe/resources/charge.rb', line 2020

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



2022
2023
2024
# File 'lib/stripe/resources/charge.rb', line 2022

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



2024
2025
2026
# File 'lib/stripe/resources/charge.rb', line 2024

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



2026
2027
2028
# File 'lib/stripe/resources/charge.rb', line 2026

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



2028
2029
2030
# File 'lib/stripe/resources/charge.rb', line 2028

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



2030
2031
2032
# File 'lib/stripe/resources/charge.rb', line 2030

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



2032
2033
2034
# File 'lib/stripe/resources/charge.rb', line 2032

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



2034
2035
2036
# File 'lib/stripe/resources/charge.rb', line 2034

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



2036
2037
2038
# File 'lib/stripe/resources/charge.rb', line 2036

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



2038
2039
2040
# File 'lib/stripe/resources/charge.rb', line 2038

def total_tax_amount
  @total_tax_amount
end