Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 |
# File 'lib/stripe/resources/charge.rb', line 2038 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1996 1997 1998 |
# File 'lib/stripe/resources/charge.rb', line 1996 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1998 1999 2000 |
# File 'lib/stripe/resources/charge.rb', line 1998 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2000 2001 2002 |
# File 'lib/stripe/resources/charge.rb', line 2000 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2002 2003 2004 |
# File 'lib/stripe/resources/charge.rb', line 2002 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2004 2005 2006 |
# File 'lib/stripe/resources/charge.rb', line 2004 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
2006 2007 2008 |
# File 'lib/stripe/resources/charge.rb', line 2006 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2008 2009 2010 |
# File 'lib/stripe/resources/charge.rb', line 2008 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2010 2011 2012 |
# File 'lib/stripe/resources/charge.rb', line 2010 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2012 2013 2014 |
# File 'lib/stripe/resources/charge.rb', line 2012 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2014 2015 2016 |
# File 'lib/stripe/resources/charge.rb', line 2014 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2016 2017 2018 |
# File 'lib/stripe/resources/charge.rb', line 2016 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2018 2019 2020 |
# File 'lib/stripe/resources/charge.rb', line 2018 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2020 2021 2022 |
# File 'lib/stripe/resources/charge.rb', line 2020 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2022 2023 2024 |
# File 'lib/stripe/resources/charge.rb', line 2022 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2024 2025 2026 |
# File 'lib/stripe/resources/charge.rb', line 2024 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2026 2027 2028 |
# File 'lib/stripe/resources/charge.rb', line 2026 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2028 2029 2030 |
# File 'lib/stripe/resources/charge.rb', line 2028 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2030 2031 2032 |
# File 'lib/stripe/resources/charge.rb', line 2030 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2032 2033 2034 |
# File 'lib/stripe/resources/charge.rb', line 2032 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2034 2035 2036 |
# File 'lib/stripe/resources/charge.rb', line 2034 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2036 2037 2038 |
# File 'lib/stripe/resources/charge.rb', line 2036 def total_tax_amount @total_tax_amount end |