Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2470 2471 2472 2473 2474 2475 2476 2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 2487 2488 2489 2490 2491 2492 2493 2494 2495 2496 2497 2498 2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 |
# File 'lib/stripe/resources/charge.rb', line 2470 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
2408 2409 2410 |
# File 'lib/stripe/resources/charge.rb', line 2408 def address @address end |
#adults ⇒ Object
The number of adults on the booking
2411 2412 2413 |
# File 'lib/stripe/resources/charge.rb', line 2411 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
2414 2415 2416 |
# File 'lib/stripe/resources/charge.rb', line 2414 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
2417 2418 2419 |
# File 'lib/stripe/resources/charge.rb', line 2417 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
2420 2421 2422 |
# File 'lib/stripe/resources/charge.rb', line 2420 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
2423 2424 2425 |
# File 'lib/stripe/resources/charge.rb', line 2423 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
2426 2427 2428 |
# File 'lib/stripe/resources/charge.rb', line 2426 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
2429 2430 2431 |
# File 'lib/stripe/resources/charge.rb', line 2429 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
2432 2433 2434 |
# File 'lib/stripe/resources/charge.rb', line 2432 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
2435 2436 2437 |
# File 'lib/stripe/resources/charge.rb', line 2435 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
2438 2439 2440 |
# File 'lib/stripe/resources/charge.rb', line 2438 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
2441 2442 2443 |
# File 'lib/stripe/resources/charge.rb', line 2441 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
2444 2445 2446 |
# File 'lib/stripe/resources/charge.rb', line 2444 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
2447 2448 2449 |
# File 'lib/stripe/resources/charge.rb', line 2447 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
2450 2451 2452 |
# File 'lib/stripe/resources/charge.rb', line 2450 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
2453 2454 2455 |
# File 'lib/stripe/resources/charge.rb', line 2453 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
2456 2457 2458 |
# File 'lib/stripe/resources/charge.rb', line 2456 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
2459 2460 2461 |
# File 'lib/stripe/resources/charge.rb', line 2459 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
2462 2463 2464 |
# File 'lib/stripe/resources/charge.rb', line 2462 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
2465 2466 2467 |
# File 'lib/stripe/resources/charge.rb', line 2465 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2468 2469 2470 |
# File 'lib/stripe/resources/charge.rb', line 2468 def total_tax_amount @total_tax_amount end |