Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/charge.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 |
# File 'lib/stripe/resources/charge.rb', line 2002 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1960 1961 1962 |
# File 'lib/stripe/resources/charge.rb', line 1960 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1962 1963 1964 |
# File 'lib/stripe/resources/charge.rb', line 1962 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1964 1965 1966 |
# File 'lib/stripe/resources/charge.rb', line 1964 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1966 1967 1968 |
# File 'lib/stripe/resources/charge.rb', line 1966 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1968 1969 1970 |
# File 'lib/stripe/resources/charge.rb', line 1968 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
1970 1971 1972 |
# File 'lib/stripe/resources/charge.rb', line 1970 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1972 1973 1974 |
# File 'lib/stripe/resources/charge.rb', line 1972 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1974 1975 1976 |
# File 'lib/stripe/resources/charge.rb', line 1974 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1976 1977 1978 |
# File 'lib/stripe/resources/charge.rb', line 1976 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1978 1979 1980 |
# File 'lib/stripe/resources/charge.rb', line 1978 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1980 1981 1982 |
# File 'lib/stripe/resources/charge.rb', line 1980 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1982 1983 1984 |
# File 'lib/stripe/resources/charge.rb', line 1982 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1984 1985 1986 |
# File 'lib/stripe/resources/charge.rb', line 1984 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1986 1987 1988 |
# File 'lib/stripe/resources/charge.rb', line 1986 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1988 1989 1990 |
# File 'lib/stripe/resources/charge.rb', line 1988 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1990 1991 1992 |
# File 'lib/stripe/resources/charge.rb', line 1990 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1992 1993 1994 |
# File 'lib/stripe/resources/charge.rb', line 1992 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1994 1995 1996 |
# File 'lib/stripe/resources/charge.rb', line 1994 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1996 1997 1998 |
# File 'lib/stripe/resources/charge.rb', line 1996 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1998 1999 2000 |
# File 'lib/stripe/resources/charge.rb', line 1998 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
2000 2001 2002 |
# File 'lib/stripe/resources/charge.rb', line 2000 def total_tax_amount @total_tax_amount end |