Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2060 2061 2062 2063 2064 |
# File 'lib/stripe/resources/charge.rb', line 2060 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2054 2055 2056 |
# File 'lib/stripe/resources/charge.rb', line 2054 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2056 2057 2058 |
# File 'lib/stripe/resources/charge.rb', line 2056 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2058 2059 2060 |
# File 'lib/stripe/resources/charge.rb', line 2058 def phone @phone end |