Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



2027
2028
2029
2030
2031
# File 'lib/stripe/resources/charge.rb', line 2027

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



2021
2022
2023
# File 'lib/stripe/resources/charge.rb', line 2021

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



2023
2024
2025
# File 'lib/stripe/resources/charge.rb', line 2023

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



2025
2026
2027
# File 'lib/stripe/resources/charge.rb', line 2025

def phone
  @phone
end