Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1970
1971
1972
1973
1974
# File 'lib/stripe/resources/charge.rb', line 1970

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1964
1965
1966
# File 'lib/stripe/resources/charge.rb', line 1964

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1966
1967
1968
# File 'lib/stripe/resources/charge.rb', line 1966

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1968
1969
1970
# File 'lib/stripe/resources/charge.rb', line 1968

def phone
  @phone
end