Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/charge.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1930
1931
1932
1933
1934
# File 'lib/stripe/resources/charge.rb', line 1930

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1924
1925
1926
# File 'lib/stripe/resources/charge.rb', line 1924

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1926
1927
1928
# File 'lib/stripe/resources/charge.rb', line 1926

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1928
1929
1930
# File 'lib/stripe/resources/charge.rb', line 1928

def phone
  @phone
end