Class: Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Charge::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/charge.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
2381 2382 2383 2384 2385 |
# File 'lib/stripe/resources/charge.rb', line 2381 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
2373 2374 2375 |
# File 'lib/stripe/resources/charge.rb', line 2373 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
2376 2377 2378 |
# File 'lib/stripe/resources/charge.rb', line 2376 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
2379 2380 2381 |
# File 'lib/stripe/resources/charge.rb', line 2379 def phone @phone end |