Class: Stripe::ChargeCaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: PaymentDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
-
#application_fee ⇒ Object
An application fee to add on to this charge.
-
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#receipt_email ⇒ Object
The email address to send this charge's receipt to.
-
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer's statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ ChargeCaptureParams
constructor
A new instance of ChargeCaptureParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ ChargeCaptureParams
Returns a new instance of ChargeCaptureParams.
1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1679 def initialize( amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @amount = amount @application_fee = application_fee @application_fee_amount = application_fee_amount @expand = @payment_details = payment_details @receipt_email = receipt_email @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
1657 1658 1659 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1657 def amount @amount end |
#application_fee ⇒ Object
An application fee to add on to this charge.
1659 1660 1661 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1659 def application_fee @application_fee end |
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
1661 1662 1663 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1661 def application_fee_amount @application_fee_amount end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1663 1664 1665 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1663 def @expand end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
1665 1666 1667 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1665 def payment_details @payment_details end |
#receipt_email ⇒ Object
The email address to send this charge's receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.
1667 1668 1669 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1667 def receipt_email @receipt_email end |
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer's statement as the statement descriptor. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.
For a card charge, this value is ignored unless you don't specify a statement_descriptor_suffix, in which case this value is used as the suffix.
1671 1672 1673 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1671 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement. If the account has no prefix value, the suffix is concatenated to the account's statement descriptor.
1673 1674 1675 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1673 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge. See the Connect documentation for details.
1675 1676 1677 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1675 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. transfer_group may only be provided if it has not been set. See the Connect documentation for details.
1677 1678 1679 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1677 def transfer_group @transfer_group end |