Class: Stripe::ChargeCaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, FleetDatum, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, fleet_data: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, money_services: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/stripe/params/charge_capture_params.rb', line 1885

def initialize(
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  fleet_data: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  money_services: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @fleet_data = fleet_data
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @money_services = money_services
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



1857
1858
1859
# File 'lib/stripe/params/charge_capture_params.rb', line 1857

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



1859
1860
1861
# File 'lib/stripe/params/charge_capture_params.rb', line 1859

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1863
1864
1865
# File 'lib/stripe/params/charge_capture_params.rb', line 1863

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1865
1866
1867
# File 'lib/stripe/params/charge_capture_params.rb', line 1865

def event_details
  @event_details
end

#fleet_dataObject

Fleet data for this PaymentIntent.



1867
1868
1869
# File 'lib/stripe/params/charge_capture_params.rb', line 1867

def fleet_data
  @fleet_data
end

#flightObject

Flight reservation details for this PaymentIntent



1869
1870
1871
# File 'lib/stripe/params/charge_capture_params.rb', line 1869

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



1871
1872
1873
# File 'lib/stripe/params/charge_capture_params.rb', line 1871

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1873
1874
1875
# File 'lib/stripe/params/charge_capture_params.rb', line 1873

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



1875
1876
1877
# File 'lib/stripe/params/charge_capture_params.rb', line 1875

def lodging_data
  @lodging_data
end

#money_servicesObject

Money services details for this PaymentIntent.



1877
1878
1879
# File 'lib/stripe/params/charge_capture_params.rb', line 1877

def money_services
  @money_services
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1881
1882
1883
# File 'lib/stripe/params/charge_capture_params.rb', line 1881

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1883
1884
1885
# File 'lib/stripe/params/charge_capture_params.rb', line 1883

def subscription
  @subscription
end