Class: Stripe::ChargeCaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
-
#customer_reference ⇒ Object
A unique value to identify the customer.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#flight_data ⇒ Object
Flight data for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1623 def initialize( car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @car_rental_data = car_rental_data @customer_reference = customer_reference @event_details = event_details @flight = flight @flight_data = flight_data @lodging = lodging @lodging_data = lodging_data @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1599 1600 1601 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1599 def car_rental @car_rental end |
#car_rental_data ⇒ Object
Car rental data for this PaymentIntent.
1601 1602 1603 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1601 def car_rental_data @car_rental_data end |
#customer_reference ⇒ Object
A unique value to identify the customer. This field is available only for card payments.
This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.
1605 1606 1607 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1605 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1607 1608 1609 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1607 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
1609 1610 1611 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1609 def flight @flight end |
#flight_data ⇒ Object
Flight data for this PaymentIntent.
1611 1612 1613 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1611 def flight_data @flight_data end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
1613 1614 1615 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1613 def lodging @lodging end |
#lodging_data ⇒ Object
Lodging data for this PaymentIntent.
1615 1616 1617 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1615 def lodging_data @lodging_data end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.
For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.
1619 1620 1621 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1619 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
1621 1622 1623 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1621 def subscription @subscription end |