Class: Stripe::ChargeCaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil, money_services: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
# File 'lib/stripe/params/charge_capture_params.rb', line 1638

def initialize(
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  order_reference: nil,
  subscription: nil,
  money_services: nil
)
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @order_reference = order_reference
  @subscription = subscription
  @money_services = money_services
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



1612
1613
1614
# File 'lib/stripe/params/charge_capture_params.rb', line 1612

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



1614
1615
1616
# File 'lib/stripe/params/charge_capture_params.rb', line 1614

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1618
1619
1620
# File 'lib/stripe/params/charge_capture_params.rb', line 1618

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1620
1621
1622
# File 'lib/stripe/params/charge_capture_params.rb', line 1620

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



1622
1623
1624
# File 'lib/stripe/params/charge_capture_params.rb', line 1622

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



1624
1625
1626
# File 'lib/stripe/params/charge_capture_params.rb', line 1624

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1626
1627
1628
# File 'lib/stripe/params/charge_capture_params.rb', line 1626

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



1628
1629
1630
# File 'lib/stripe/params/charge_capture_params.rb', line 1628

def lodging_data
  @lodging_data
end

#money_servicesObject

Money services details for this PaymentIntent.



1636
1637
1638
# File 'lib/stripe/params/charge_capture_params.rb', line 1636

def money_services
  @money_services
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1632
1633
1634
# File 'lib/stripe/params/charge_capture_params.rb', line 1632

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1634
1635
1636
# File 'lib/stripe/params/charge_capture_params.rb', line 1634

def subscription
  @subscription
end