Class: Stripe::ChargeCaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
# File 'lib/stripe/params/charge_capture_params.rb', line 692

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



678
679
680
# File 'lib/stripe/params/charge_capture_params.rb', line 678

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



680
681
682
# File 'lib/stripe/params/charge_capture_params.rb', line 680

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



682
683
684
# File 'lib/stripe/params/charge_capture_params.rb', line 682

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



684
685
686
# File 'lib/stripe/params/charge_capture_params.rb', line 684

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



686
687
688
# File 'lib/stripe/params/charge_capture_params.rb', line 686

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



688
689
690
# File 'lib/stripe/params/charge_capture_params.rb', line 688

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



690
691
692
# File 'lib/stripe/params/charge_capture_params.rb', line 690

def subscription
  @subscription
end