Class: Stripe::ChargeCaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/stripe/params/charge_capture_params.rb', line 318 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
300 301 302 |
# File 'lib/stripe/params/charge_capture_params.rb', line 300 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
302 303 304 |
# File 'lib/stripe/params/charge_capture_params.rb', line 302 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
304 305 306 |
# File 'lib/stripe/params/charge_capture_params.rb', line 304 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
306 307 308 |
# File 'lib/stripe/params/charge_capture_params.rb', line 306 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
308 309 310 |
# File 'lib/stripe/params/charge_capture_params.rb', line 308 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
310 311 312 |
# File 'lib/stripe/params/charge_capture_params.rb', line 310 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
312 313 314 |
# File 'lib/stripe/params/charge_capture_params.rb', line 312 def genre @genre end |
#name ⇒ Object
The name of the event.
314 315 316 |
# File 'lib/stripe/params/charge_capture_params.rb', line 314 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
316 317 318 |
# File 'lib/stripe/params/charge_capture_params.rb', line 316 def starts_at @starts_at end |