Class: Stripe::ChargeCaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
1240
1241
1242
1243
1244
1245
1246
1247
1248
1249
1250
1251
# File 'lib/stripe/params/charge_capture_params.rb', line 1207

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



1165
1166
1167
# File 'lib/stripe/params/charge_capture_params.rb', line 1165

def address
  @address
end

#adultsObject

The number of adults on the booking



1167
1168
1169
# File 'lib/stripe/params/charge_capture_params.rb', line 1167

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



1169
1170
1171
# File 'lib/stripe/params/charge_capture_params.rb', line 1169

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



1171
1172
1173
# File 'lib/stripe/params/charge_capture_params.rb', line 1171

def booking_number
  @booking_number
end

#categoryObject

The lodging category



1173
1174
1175
# File 'lib/stripe/params/charge_capture_params.rb', line 1173

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



1175
1176
1177
# File 'lib/stripe/params/charge_capture_params.rb', line 1175

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



1177
1178
1179
# File 'lib/stripe/params/charge_capture_params.rb', line 1177

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



1179
1180
1181
# File 'lib/stripe/params/charge_capture_params.rb', line 1179

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



1181
1182
1183
# File 'lib/stripe/params/charge_capture_params.rb', line 1181

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



1183
1184
1185
# File 'lib/stripe/params/charge_capture_params.rb', line 1183

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



1185
1186
1187
# File 'lib/stripe/params/charge_capture_params.rb', line 1185

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



1187
1188
1189
# File 'lib/stripe/params/charge_capture_params.rb', line 1187

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



1189
1190
1191
# File 'lib/stripe/params/charge_capture_params.rb', line 1189

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



1191
1192
1193
# File 'lib/stripe/params/charge_capture_params.rb', line 1191

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



1193
1194
1195
# File 'lib/stripe/params/charge_capture_params.rb', line 1193

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



1195
1196
1197
# File 'lib/stripe/params/charge_capture_params.rb', line 1195

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



1197
1198
1199
# File 'lib/stripe/params/charge_capture_params.rb', line 1197

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



1199
1200
1201
# File 'lib/stripe/params/charge_capture_params.rb', line 1199

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



1201
1202
1203
# File 'lib/stripe/params/charge_capture_params.rb', line 1201

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



1203
1204
1205
# File 'lib/stripe/params/charge_capture_params.rb', line 1203

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



1205
1206
1207
# File 'lib/stripe/params/charge_capture_params.rb', line 1205

def total_tax_amount
  @total_tax_amount
end