Class: Stripe::ChargeCaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
# File 'lib/stripe/params/charge_capture_params.rb', line 580

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



538
539
540
# File 'lib/stripe/params/charge_capture_params.rb', line 538

def address
  @address
end

#adultsObject

The number of adults on the booking



540
541
542
# File 'lib/stripe/params/charge_capture_params.rb', line 540

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



542
543
544
# File 'lib/stripe/params/charge_capture_params.rb', line 542

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



544
545
546
# File 'lib/stripe/params/charge_capture_params.rb', line 544

def booking_number
  @booking_number
end

#categoryObject

The lodging category



546
547
548
# File 'lib/stripe/params/charge_capture_params.rb', line 546

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



548
549
550
# File 'lib/stripe/params/charge_capture_params.rb', line 548

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



550
551
552
# File 'lib/stripe/params/charge_capture_params.rb', line 550

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



552
553
554
# File 'lib/stripe/params/charge_capture_params.rb', line 552

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



554
555
556
# File 'lib/stripe/params/charge_capture_params.rb', line 554

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



556
557
558
# File 'lib/stripe/params/charge_capture_params.rb', line 556

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



558
559
560
# File 'lib/stripe/params/charge_capture_params.rb', line 558

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



560
561
562
# File 'lib/stripe/params/charge_capture_params.rb', line 560

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



562
563
564
# File 'lib/stripe/params/charge_capture_params.rb', line 562

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



564
565
566
# File 'lib/stripe/params/charge_capture_params.rb', line 564

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



566
567
568
# File 'lib/stripe/params/charge_capture_params.rb', line 566

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



568
569
570
# File 'lib/stripe/params/charge_capture_params.rb', line 568

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



570
571
572
# File 'lib/stripe/params/charge_capture_params.rb', line 570

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



572
573
574
# File 'lib/stripe/params/charge_capture_params.rb', line 572

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



574
575
576
# File 'lib/stripe/params/charge_capture_params.rb', line 574

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



576
577
578
# File 'lib/stripe/params/charge_capture_params.rb', line 576

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



578
579
580
# File 'lib/stripe/params/charge_capture_params.rb', line 578

def total_tax_amount
  @total_tax_amount
end