Class: Stripe::ChargeCaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 |
# File 'lib/stripe/params/charge_capture_params.rb', line 580 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
538 539 540 |
# File 'lib/stripe/params/charge_capture_params.rb', line 538 def address @address end |
#adults ⇒ Object
The number of adults on the booking
540 541 542 |
# File 'lib/stripe/params/charge_capture_params.rb', line 540 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
542 543 544 |
# File 'lib/stripe/params/charge_capture_params.rb', line 542 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
544 545 546 |
# File 'lib/stripe/params/charge_capture_params.rb', line 544 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
546 547 548 |
# File 'lib/stripe/params/charge_capture_params.rb', line 546 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
548 549 550 |
# File 'lib/stripe/params/charge_capture_params.rb', line 548 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
550 551 552 |
# File 'lib/stripe/params/charge_capture_params.rb', line 550 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
552 553 554 |
# File 'lib/stripe/params/charge_capture_params.rb', line 552 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
554 555 556 |
# File 'lib/stripe/params/charge_capture_params.rb', line 554 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
556 557 558 |
# File 'lib/stripe/params/charge_capture_params.rb', line 556 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
558 559 560 |
# File 'lib/stripe/params/charge_capture_params.rb', line 558 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
560 561 562 |
# File 'lib/stripe/params/charge_capture_params.rb', line 560 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
562 563 564 |
# File 'lib/stripe/params/charge_capture_params.rb', line 562 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
564 565 566 |
# File 'lib/stripe/params/charge_capture_params.rb', line 564 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
566 567 568 |
# File 'lib/stripe/params/charge_capture_params.rb', line 566 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
568 569 570 |
# File 'lib/stripe/params/charge_capture_params.rb', line 568 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
570 571 572 |
# File 'lib/stripe/params/charge_capture_params.rb', line 570 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
572 573 574 |
# File 'lib/stripe/params/charge_capture_params.rb', line 572 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
574 575 576 |
# File 'lib/stripe/params/charge_capture_params.rb', line 574 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
576 577 578 |
# File 'lib/stripe/params/charge_capture_params.rb', line 576 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
578 579 580 |
# File 'lib/stripe/params/charge_capture_params.rb', line 578 def total_tax_amount @total_tax_amount end |