Class: Stripe::ChargeCaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1139 1140 1141 1142 1143 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1139 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1133 1134 1135 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1133 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1135 1136 1137 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1135 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1137 1138 1139 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1137 def phone @phone end |