Class: Stripe::ChargeCaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



512
513
514
515
516
# File 'lib/stripe/params/charge_capture_params.rb', line 512

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



506
507
508
# File 'lib/stripe/params/charge_capture_params.rb', line 506

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



508
509
510
# File 'lib/stripe/params/charge_capture_params.rb', line 508

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



510
511
512
# File 'lib/stripe/params/charge_capture_params.rb', line 510

def phone
  @phone
end