Class: Stripe::ChargeCaptureParams::PaymentDetails::MoneyServices::AccountFunding
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeCaptureParams::PaymentDetails::MoneyServices::AccountFunding
- Defined in:
- lib/stripe/params/charge_capture_params.rb
Defined Under Namespace
Classes: BeneficiaryDetails, SenderDetails
Instance Attribute Summary collapse
-
#beneficiary_account ⇒ Object
ID of the Account representing the beneficiary in this account funding transaction.
-
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this account funding transaction.
-
#sender_account ⇒ Object
ID of the Account representing the sender in this account funding transaction.
-
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
Instance Method Summary collapse
-
#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding
constructor
A new instance of AccountFunding.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil) ⇒ AccountFunding
Returns a new instance of AccountFunding.
1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1783 def initialize( beneficiary_account: nil, beneficiary_details: nil, sender_account: nil, sender_details: nil ) @beneficiary_account = beneficiary_account @beneficiary_details = beneficiary_details @sender_account = sender_account @sender_details = sender_details end |
Instance Attribute Details
#beneficiary_account ⇒ Object
ID of the Account representing the beneficiary in this account funding transaction.
1775 1776 1777 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1775 def beneficiary_account @beneficiary_account end |
#beneficiary_details ⇒ Object
Inline identity details for the beneficiary of this account funding transaction.
1777 1778 1779 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1777 def beneficiary_details @beneficiary_details end |
#sender_account ⇒ Object
ID of the Account representing the sender in this account funding transaction.
1779 1780 1781 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1779 def sender_account @sender_account end |
#sender_details ⇒ Object
Inline identity details for the sender of this account funding transaction.
1781 1782 1783 |
# File 'lib/stripe/params/charge_capture_params.rb', line 1781 def sender_details @sender_details end |