Class: Stripe::ChargeCaptureParams::TransferData

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/charge_capture_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil) ⇒ TransferData

Returns a new instance of TransferData.



1652
1653
1654
# File 'lib/stripe/params/charge_capture_params.rb', line 1652

def initialize(amount: nil)
  @amount = amount
end

Instance Attribute Details

#amountObject

The amount transferred to the destination account, if specified. By default, the entire charge amount is transferred to the destination account.



1650
1651
1652
# File 'lib/stripe/params/charge_capture_params.rb', line 1650

def amount
  @amount
end