Class: Stripe::ChargeService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: CaptureParams, CreateParams, ListParams, RetrieveParams, SearchParams, UpdateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#capture(charge, params = {}, opts = {}) ⇒ Object

Capture the payment of an existing, uncaptured charge that was created with the capture option set to false.

Uncaptured payments expire a set number of days after they are created ([7 by default](stripe.com/docs/charges/placing-a-hold)), after which they are marked as refunded and capture attempts will fail.

Don’t use this method to capture a PaymentIntent-initiated charge. Use [Capture a PaymentIntent](stripe.com/docs/api/payment_intents/capture).



2021
2022
2023
2024
2025
2026
2027
2028
2029
# File 'lib/stripe/services/charge_service.rb', line 2021

def capture(charge, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/charges/%<charge>s/capture", { charge: CGI.escape(charge) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#create(params = {}, opts = {}) ⇒ Object

This method is no longer recommended—use the [Payment Intents API](stripe.com/docs/api/payment_intents) to initiate a new payment instead. Confirmation of the PaymentIntent creates the Charge object used to request payment.



2034
2035
2036
# File 'lib/stripe/services/charge_service.rb', line 2034

def create(params = {}, opts = {})
  request(method: :post, path: "/v1/charges", params: params, opts: opts, base_address: :api)
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of charges you’ve previously created. The charges are returned in sorted order, with the most recent charges appearing first.



2039
2040
2041
# File 'lib/stripe/services/charge_service.rb', line 2039

def list(params = {}, opts = {})
  request(method: :get, path: "/v1/charges", params: params, opts: opts, base_address: :api)
end

#retrieve(charge, params = {}, opts = {}) ⇒ Object

Retrieves the details of a charge that has previously been created. Supply the unique charge ID that was returned from your previous request, and Stripe will return the corresponding charge information. The same information is returned when creating or refunding the charge.



2044
2045
2046
2047
2048
2049
2050
2051
2052
# File 'lib/stripe/services/charge_service.rb', line 2044

def retrieve(charge, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/charges/%<charge>s", { charge: CGI.escape(charge) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#search(params = {}, opts = {}) ⇒ Object

Search for charges you’ve previously created using Stripe’s [Search Query Language](stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.



2058
2059
2060
2061
2062
2063
2064
2065
2066
# File 'lib/stripe/services/charge_service.rb', line 2058

def search(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/charges/search",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(charge, params = {}, opts = {}) ⇒ Object

Updates the specified charge by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



2069
2070
2071
2072
2073
2074
2075
2076
2077
# File 'lib/stripe/services/charge_service.rb', line 2069

def update(charge, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/charges/%<charge>s", { charge: CGI.escape(charge) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end