Class: Stripe::ChargeService::CaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: PaymentDetails, TransferData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
-
#application_fee ⇒ Object
An application fee to add on to this charge.
-
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#receipt_email ⇒ Object
The email address to send this charge’s receipt to.
-
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams
constructor
A new instance of CaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ CaptureParams
Returns a new instance of CaptureParams.
1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 |
# File 'lib/stripe/services/charge_service.rb', line 1801 def initialize( amount: nil, application_fee: nil, application_fee_amount: nil, expand: nil, payment_details: nil, receipt_email: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @amount = amount @application_fee = application_fee @application_fee_amount = application_fee_amount @expand = @payment_details = payment_details @receipt_email = receipt_email @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#amount ⇒ Object
The amount to capture, which must be less than or equal to the original amount.
1779 1780 1781 |
# File 'lib/stripe/services/charge_service.rb', line 1779 def amount @amount end |
#application_fee ⇒ Object
An application fee to add on to this charge.
1781 1782 1783 |
# File 'lib/stripe/services/charge_service.rb', line 1781 def application_fee @application_fee end |
#application_fee_amount ⇒ Object
An application fee amount to add on to this charge, which must be less than or equal to the original amount.
1783 1784 1785 |
# File 'lib/stripe/services/charge_service.rb', line 1783 def application_fee_amount @application_fee_amount end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1785 1786 1787 |
# File 'lib/stripe/services/charge_service.rb', line 1785 def @expand end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
1787 1788 1789 |
# File 'lib/stripe/services/charge_service.rb', line 1787 def payment_details @payment_details end |
#receipt_email ⇒ Object
The email address to send this charge’s receipt to. This will override the previously-specified email address for this charge, if one was set. Receipts will not be sent in test mode.
1789 1790 1791 |
# File 'lib/stripe/services/charge_service.rb', line 1789 def receipt_email @receipt_email end |
#statement_descriptor ⇒ Object
For a non-card charge, text that appears on the customer’s statement as the statement descriptor. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
For a card charge, this value is ignored unless you don’t specify a ‘statement_descriptor_suffix`, in which case this value is used as the suffix.
1793 1794 1795 |
# File 'lib/stripe/services/charge_service.rb', line 1793 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement. If the account has no prefix value, the suffix is concatenated to the account’s statement descriptor.
1795 1796 1797 |
# File 'lib/stripe/services/charge_service.rb', line 1795 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
An optional dictionary including the account to automatically transfer to as part of a destination charge. [See the Connect documentation](stripe.com/docs/connect/destination-charges) for details.
1797 1798 1799 |
# File 'lib/stripe/services/charge_service.rb', line 1797 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.
1799 1800 1801 |
# File 'lib/stripe/services/charge_service.rb', line 1799 def transfer_group @transfer_group end |