Class: Stripe::ChargeService::CaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 |
# File 'lib/stripe/services/charge_service.rb', line 1683 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
1669 1670 1671 |
# File 'lib/stripe/services/charge_service.rb', line 1669 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
1671 1672 1673 |
# File 'lib/stripe/services/charge_service.rb', line 1671 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
1673 1674 1675 |
# File 'lib/stripe/services/charge_service.rb', line 1673 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
1675 1676 1677 |
# File 'lib/stripe/services/charge_service.rb', line 1675 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
1677 1678 1679 |
# File 'lib/stripe/services/charge_service.rb', line 1677 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
1679 1680 1681 |
# File 'lib/stripe/services/charge_service.rb', line 1679 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
1681 1682 1683 |
# File 'lib/stripe/services/charge_service.rb', line 1681 def subscription @subscription end |