Class: Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
# File 'lib/stripe/services/charge_service.rb', line 1171

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



1131
1132
1133
# File 'lib/stripe/services/charge_service.rb', line 1131

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



1133
1134
1135
# File 'lib/stripe/services/charge_service.rb', line 1133

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



1135
1136
1137
# File 'lib/stripe/services/charge_service.rb', line 1135

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



1137
1138
1139
# File 'lib/stripe/services/charge_service.rb', line 1137

def car_make
  @car_make
end

#car_modelObject

Model of the car.



1139
1140
1141
# File 'lib/stripe/services/charge_service.rb', line 1139

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



1141
1142
1143
# File 'lib/stripe/services/charge_service.rb', line 1141

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



1143
1144
1145
# File 'lib/stripe/services/charge_service.rb', line 1143

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



1145
1146
1147
# File 'lib/stripe/services/charge_service.rb', line 1145

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



1147
1148
1149
# File 'lib/stripe/services/charge_service.rb', line 1147

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



1149
1150
1151
# File 'lib/stripe/services/charge_service.rb', line 1149

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



1151
1152
1153
# File 'lib/stripe/services/charge_service.rb', line 1151

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



1153
1154
1155
# File 'lib/stripe/services/charge_service.rb', line 1153

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



1155
1156
1157
# File 'lib/stripe/services/charge_service.rb', line 1155

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



1157
1158
1159
# File 'lib/stripe/services/charge_service.rb', line 1157

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



1159
1160
1161
# File 'lib/stripe/services/charge_service.rb', line 1159

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



1161
1162
1163
# File 'lib/stripe/services/charge_service.rb', line 1161

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



1163
1164
1165
# File 'lib/stripe/services/charge_service.rb', line 1163

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



1165
1166
1167
# File 'lib/stripe/services/charge_service.rb', line 1165

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



1167
1168
1169
# File 'lib/stripe/services/charge_service.rb', line 1167

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



1169
1170
1171
# File 'lib/stripe/services/charge_service.rb', line 1169

def tax_exempt
  @tax_exempt
end