Class: Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 |
# File 'lib/stripe/services/charge_service.rb', line 1179 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1139 1140 1141 |
# File 'lib/stripe/services/charge_service.rb', line 1139 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
1141 1142 1143 |
# File 'lib/stripe/services/charge_service.rb', line 1141 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
1143 1144 1145 |
# File 'lib/stripe/services/charge_service.rb', line 1143 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
1145 1146 1147 |
# File 'lib/stripe/services/charge_service.rb', line 1145 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
1147 1148 1149 |
# File 'lib/stripe/services/charge_service.rb', line 1147 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
1149 1150 1151 |
# File 'lib/stripe/services/charge_service.rb', line 1149 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
1151 1152 1153 |
# File 'lib/stripe/services/charge_service.rb', line 1151 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
1153 1154 1155 |
# File 'lib/stripe/services/charge_service.rb', line 1153 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
1155 1156 1157 |
# File 'lib/stripe/services/charge_service.rb', line 1155 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
1157 1158 1159 |
# File 'lib/stripe/services/charge_service.rb', line 1157 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
1159 1160 1161 |
# File 'lib/stripe/services/charge_service.rb', line 1159 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
1161 1162 1163 |
# File 'lib/stripe/services/charge_service.rb', line 1161 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
1163 1164 1165 |
# File 'lib/stripe/services/charge_service.rb', line 1163 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
1165 1166 1167 |
# File 'lib/stripe/services/charge_service.rb', line 1165 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
1167 1168 1169 |
# File 'lib/stripe/services/charge_service.rb', line 1167 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1169 1170 1171 |
# File 'lib/stripe/services/charge_service.rb', line 1169 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
1171 1172 1173 |
# File 'lib/stripe/services/charge_service.rb', line 1171 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
1173 1174 1175 |
# File 'lib/stripe/services/charge_service.rb', line 1173 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
1175 1176 1177 |
# File 'lib/stripe/services/charge_service.rb', line 1175 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
1177 1178 1179 |
# File 'lib/stripe/services/charge_service.rb', line 1177 def tax_exempt @tax_exempt end |