Class: Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/stripe/services/charge_service.rb', line 1365 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
1306 1307 1308 |
# File 'lib/stripe/services/charge_service.rb', line 1306 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
1309 1310 1311 |
# File 'lib/stripe/services/charge_service.rb', line 1309 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
1312 1313 1314 |
# File 'lib/stripe/services/charge_service.rb', line 1312 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
1315 1316 1317 |
# File 'lib/stripe/services/charge_service.rb', line 1315 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
1318 1319 1320 |
# File 'lib/stripe/services/charge_service.rb', line 1318 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
1321 1322 1323 |
# File 'lib/stripe/services/charge_service.rb', line 1321 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
1324 1325 1326 |
# File 'lib/stripe/services/charge_service.rb', line 1324 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
1327 1328 1329 |
# File 'lib/stripe/services/charge_service.rb', line 1327 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
1330 1331 1332 |
# File 'lib/stripe/services/charge_service.rb', line 1330 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
1333 1334 1335 |
# File 'lib/stripe/services/charge_service.rb', line 1333 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
1336 1337 1338 |
# File 'lib/stripe/services/charge_service.rb', line 1336 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
1339 1340 1341 |
# File 'lib/stripe/services/charge_service.rb', line 1339 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
1342 1343 1344 |
# File 'lib/stripe/services/charge_service.rb', line 1342 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
1345 1346 1347 |
# File 'lib/stripe/services/charge_service.rb', line 1345 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
1348 1349 1350 |
# File 'lib/stripe/services/charge_service.rb', line 1348 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
1351 1352 1353 |
# File 'lib/stripe/services/charge_service.rb', line 1351 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
1354 1355 1356 |
# File 'lib/stripe/services/charge_service.rb', line 1354 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
1357 1358 1359 |
# File 'lib/stripe/services/charge_service.rb', line 1357 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
1360 1361 1362 |
# File 'lib/stripe/services/charge_service.rb', line 1360 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
1363 1364 1365 |
# File 'lib/stripe/services/charge_service.rb', line 1363 def tax_exempt @tax_exempt end |