Class: Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1051
1052
1053
1054
1055
# File 'lib/stripe/services/charge_service.rb', line 1051

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1045
1046
1047
# File 'lib/stripe/services/charge_service.rb', line 1045

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1047
1048
1049
# File 'lib/stripe/services/charge_service.rb', line 1047

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1049
1050
1051
# File 'lib/stripe/services/charge_service.rb', line 1049

def phone
  @phone
end