Class: Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1043 1044 1045 1046 1047 |
# File 'lib/stripe/services/charge_service.rb', line 1043 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1037 1038 1039 |
# File 'lib/stripe/services/charge_service.rb', line 1037 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1039 1040 1041 |
# File 'lib/stripe/services/charge_service.rb', line 1039 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1041 1042 1043 |
# File 'lib/stripe/services/charge_service.rb', line 1041 def phone @phone end |