Class: Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1207 1208 1209 1210 1211 |
# File 'lib/stripe/services/charge_service.rb', line 1207 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1199 1200 1201 |
# File 'lib/stripe/services/charge_service.rb', line 1199 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1202 1203 1204 |
# File 'lib/stripe/services/charge_service.rb', line 1202 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1205 1206 1207 |
# File 'lib/stripe/services/charge_service.rb', line 1205 def phone @phone end |