Class: Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 |
# File 'lib/stripe/services/charge_service.rb', line 1309 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1291 1292 1293 |
# File 'lib/stripe/services/charge_service.rb', line 1291 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
1293 1294 1295 |
# File 'lib/stripe/services/charge_service.rb', line 1293 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1295 1296 1297 |
# File 'lib/stripe/services/charge_service.rb', line 1295 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1297 1298 1299 |
# File 'lib/stripe/services/charge_service.rb', line 1297 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1299 1300 1301 |
# File 'lib/stripe/services/charge_service.rb', line 1299 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1301 1302 1303 |
# File 'lib/stripe/services/charge_service.rb', line 1301 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1303 1304 1305 |
# File 'lib/stripe/services/charge_service.rb', line 1303 def genre @genre end |
#name ⇒ Object
The name of the event.
1305 1306 1307 |
# File 'lib/stripe/services/charge_service.rb', line 1305 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1307 1308 1309 |
# File 'lib/stripe/services/charge_service.rb', line 1307 def starts_at @starts_at end |