Class: Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/stripe/services/charge_service.rb', line 1511 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1485 1486 1487 |
# File 'lib/stripe/services/charge_service.rb', line 1485 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
1488 1489 1490 |
# File 'lib/stripe/services/charge_service.rb', line 1488 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1491 1492 1493 |
# File 'lib/stripe/services/charge_service.rb', line 1491 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1494 1495 1496 |
# File 'lib/stripe/services/charge_service.rb', line 1494 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1497 1498 1499 |
# File 'lib/stripe/services/charge_service.rb', line 1497 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1500 1501 1502 |
# File 'lib/stripe/services/charge_service.rb', line 1500 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1503 1504 1505 |
# File 'lib/stripe/services/charge_service.rb', line 1503 def genre @genre end |
#name ⇒ Object
The name of the event.
1506 1507 1508 |
# File 'lib/stripe/services/charge_service.rb', line 1506 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1509 1510 1511 |
# File 'lib/stripe/services/charge_service.rb', line 1509 def starts_at @starts_at end |