Class: Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 |
# File 'lib/stripe/services/charge_service.rb', line 1301 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
1283 1284 1285 |
# File 'lib/stripe/services/charge_service.rb', line 1283 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
1285 1286 1287 |
# File 'lib/stripe/services/charge_service.rb', line 1285 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1287 1288 1289 |
# File 'lib/stripe/services/charge_service.rb', line 1287 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
1289 1290 1291 |
# File 'lib/stripe/services/charge_service.rb', line 1289 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
1291 1292 1293 |
# File 'lib/stripe/services/charge_service.rb', line 1291 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
1293 1294 1295 |
# File 'lib/stripe/services/charge_service.rb', line 1293 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
1295 1296 1297 |
# File 'lib/stripe/services/charge_service.rb', line 1295 def genre @genre end |
#name ⇒ Object
The name of the event.
1297 1298 1299 |
# File 'lib/stripe/services/charge_service.rb', line 1297 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
1299 1300 1301 |
# File 'lib/stripe/services/charge_service.rb', line 1299 def starts_at @starts_at end |