Class: Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
1274 1275 1276 1277 1278 |
# File 'lib/stripe/services/charge_service.rb', line 1274 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
1268 1269 1270 |
# File 'lib/stripe/services/charge_service.rb', line 1268 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
1270 1271 1272 |
# File 'lib/stripe/services/charge_service.rb', line 1270 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
1272 1273 1274 |
# File 'lib/stripe/services/charge_service.rb', line 1272 def phone @phone end |