Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1343
1344
1345
1346
1347
# File 'lib/stripe/services/charge_service.rb', line 1343

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1337
1338
1339
# File 'lib/stripe/services/charge_service.rb', line 1337

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1339
1340
1341
# File 'lib/stripe/services/charge_service.rb', line 1339

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1341
1342
1343
# File 'lib/stripe/services/charge_service.rb', line 1341

def phone
  @phone
end