Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Flight::Segment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::Flight::Segment
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The flight segment amount.
-
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
-
#arrives_at ⇒ Object
The arrival time for the flight segment.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
-
#departs_at ⇒ Object
The departure time for the flight segment.
-
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
-
#flight_number ⇒ Object
The flight number associated with the segment.
-
#service_class ⇒ Object
The fare class for the segment.
Instance Method Summary collapse
-
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
constructor
A new instance of Segment.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
Returns a new instance of Segment.
1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 |
# File 'lib/stripe/services/charge_service.rb', line 1395 def initialize( amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil ) @amount = amount @arrival_airport = arrival_airport @arrives_at = arrives_at @carrier = carrier @departs_at = departs_at @departure_airport = departure_airport @flight_number = flight_number @service_class = service_class end |
Instance Attribute Details
#amount ⇒ Object
The flight segment amount.
1379 1380 1381 |
# File 'lib/stripe/services/charge_service.rb', line 1379 def amount @amount end |
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
1381 1382 1383 |
# File 'lib/stripe/services/charge_service.rb', line 1381 def arrival_airport @arrival_airport end |
#arrives_at ⇒ Object
The arrival time for the flight segment. Measured in seconds since the Unix epoch.
1383 1384 1385 |
# File 'lib/stripe/services/charge_service.rb', line 1383 def arrives_at @arrives_at end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
1385 1386 1387 |
# File 'lib/stripe/services/charge_service.rb', line 1385 def carrier @carrier end |
#departs_at ⇒ Object
The departure time for the flight segment. Measured in seconds since the Unix epoch.
1387 1388 1389 |
# File 'lib/stripe/services/charge_service.rb', line 1387 def departs_at @departs_at end |
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
1389 1390 1391 |
# File 'lib/stripe/services/charge_service.rb', line 1389 def departure_airport @departure_airport end |
#flight_number ⇒ Object
The flight number associated with the segment
1391 1392 1393 |
# File 'lib/stripe/services/charge_service.rb', line 1391 def flight_number @flight_number end |
#service_class ⇒ Object
The fare class for the segment.
1393 1394 1395 |
# File 'lib/stripe/services/charge_service.rb', line 1393 def service_class @service_class end |