Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 |
# File 'lib/stripe/services/charge_service.rb', line 1563 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1521 1522 1523 |
# File 'lib/stripe/services/charge_service.rb', line 1521 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1523 1524 1525 |
# File 'lib/stripe/services/charge_service.rb', line 1523 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1525 1526 1527 |
# File 'lib/stripe/services/charge_service.rb', line 1525 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1527 1528 1529 |
# File 'lib/stripe/services/charge_service.rb', line 1527 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1529 1530 1531 |
# File 'lib/stripe/services/charge_service.rb', line 1529 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
1531 1532 1533 |
# File 'lib/stripe/services/charge_service.rb', line 1531 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1533 1534 1535 |
# File 'lib/stripe/services/charge_service.rb', line 1533 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1535 1536 1537 |
# File 'lib/stripe/services/charge_service.rb', line 1535 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1537 1538 1539 |
# File 'lib/stripe/services/charge_service.rb', line 1537 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1539 1540 1541 |
# File 'lib/stripe/services/charge_service.rb', line 1539 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1541 1542 1543 |
# File 'lib/stripe/services/charge_service.rb', line 1541 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1543 1544 1545 |
# File 'lib/stripe/services/charge_service.rb', line 1543 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1545 1546 1547 |
# File 'lib/stripe/services/charge_service.rb', line 1545 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1547 1548 1549 |
# File 'lib/stripe/services/charge_service.rb', line 1547 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1549 1550 1551 |
# File 'lib/stripe/services/charge_service.rb', line 1549 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1551 1552 1553 |
# File 'lib/stripe/services/charge_service.rb', line 1551 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1553 1554 1555 |
# File 'lib/stripe/services/charge_service.rb', line 1553 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1555 1556 1557 |
# File 'lib/stripe/services/charge_service.rb', line 1555 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1557 1558 1559 |
# File 'lib/stripe/services/charge_service.rb', line 1557 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1559 1560 1561 |
# File 'lib/stripe/services/charge_service.rb', line 1559 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
1561 1562 1563 |
# File 'lib/stripe/services/charge_service.rb', line 1561 def total_tax_amount @total_tax_amount end |