Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 |
# File 'lib/stripe/services/charge_service.rb', line 1818 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1756 1757 1758 |
# File 'lib/stripe/services/charge_service.rb', line 1756 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1759 1760 1761 |
# File 'lib/stripe/services/charge_service.rb', line 1759 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1762 1763 1764 |
# File 'lib/stripe/services/charge_service.rb', line 1762 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1765 1766 1767 |
# File 'lib/stripe/services/charge_service.rb', line 1765 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1768 1769 1770 |
# File 'lib/stripe/services/charge_service.rb', line 1768 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
1771 1772 1773 |
# File 'lib/stripe/services/charge_service.rb', line 1771 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1774 1775 1776 |
# File 'lib/stripe/services/charge_service.rb', line 1774 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1777 1778 1779 |
# File 'lib/stripe/services/charge_service.rb', line 1777 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1780 1781 1782 |
# File 'lib/stripe/services/charge_service.rb', line 1780 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1783 1784 1785 |
# File 'lib/stripe/services/charge_service.rb', line 1783 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1786 1787 1788 |
# File 'lib/stripe/services/charge_service.rb', line 1786 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1789 1790 1791 |
# File 'lib/stripe/services/charge_service.rb', line 1789 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1792 1793 1794 |
# File 'lib/stripe/services/charge_service.rb', line 1792 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1795 1796 1797 |
# File 'lib/stripe/services/charge_service.rb', line 1795 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1798 1799 1800 |
# File 'lib/stripe/services/charge_service.rb', line 1798 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1801 1802 1803 |
# File 'lib/stripe/services/charge_service.rb', line 1801 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1804 1805 1806 |
# File 'lib/stripe/services/charge_service.rb', line 1804 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1807 1808 1809 |
# File 'lib/stripe/services/charge_service.rb', line 1807 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1810 1811 1812 |
# File 'lib/stripe/services/charge_service.rb', line 1810 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1813 1814 1815 |
# File 'lib/stripe/services/charge_service.rb', line 1813 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
1816 1817 1818 |
# File 'lib/stripe/services/charge_service.rb', line 1816 def total_tax_amount @total_tax_amount end |