Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1503
1504
1505
1506
1507
# File 'lib/stripe/services/charge_service.rb', line 1503

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1497
1498
1499
# File 'lib/stripe/services/charge_service.rb', line 1497

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1499
1500
1501
# File 'lib/stripe/services/charge_service.rb', line 1499

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1501
1502
1503
# File 'lib/stripe/services/charge_service.rb', line 1501

def phone
  @phone
end