Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



1495
1496
1497
1498
1499
# File 'lib/stripe/services/charge_service.rb', line 1495

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



1489
1490
1491
# File 'lib/stripe/services/charge_service.rb', line 1489

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



1491
1492
1493
# File 'lib/stripe/services/charge_service.rb', line 1491

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



1493
1494
1495
# File 'lib/stripe/services/charge_service.rb', line 1493

def phone
  @phone
end