Class: Stripe::ChargeService::CaptureParams::PaymentDetails::Subscription::BillingInterval
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::CaptureParams::PaymentDetails::Subscription::BillingInterval
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
The number of intervals, as an whole number greater than 0.
-
#interval ⇒ Object
Specifies a type of interval unit.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil) ⇒ BillingInterval
constructor
A new instance of BillingInterval.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil) ⇒ BillingInterval
Returns a new instance of BillingInterval.
1626 1627 1628 1629 |
# File 'lib/stripe/services/charge_service.rb', line 1626 def initialize(count: nil, interval: nil) @count = count @interval = interval end |
Instance Attribute Details
#count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
1622 1623 1624 |
# File 'lib/stripe/services/charge_service.rb', line 1622 def count @count end |
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
1624 1625 1626 |
# File 'lib/stripe/services/charge_service.rb', line 1624 def interval @interval end |