Class: Stripe::ChargeService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: FraudDetails, PaymentDetails, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
# File 'lib/stripe/services/charge_service.rb', line 981

def initialize(
  customer: nil,
  description: nil,
  expand: nil,
  fraud_details: nil,
  metadata: nil,
  payment_details: nil,
  receipt_email: nil,
  shipping: nil,
  transfer_group: nil
)
  @customer = customer
  @description = description
  @expand = expand
  @fraud_details = fraud_details
  @metadata = 
  @payment_details = payment_details
  @receipt_email = receipt_email
  @shipping = shipping
  @transfer_group = transfer_group
end

Instance Attribute Details

#customerObject

The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.



963
964
965
# File 'lib/stripe/services/charge_service.rb', line 963

def customer
  @customer
end

#descriptionObject

An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.



965
966
967
# File 'lib/stripe/services/charge_service.rb', line 965

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



967
968
969
# File 'lib/stripe/services/charge_service.rb', line 967

def expand
  @expand
end

#fraud_detailsObject

A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.



969
970
971
# File 'lib/stripe/services/charge_service.rb', line 969

def fraud_details
  @fraud_details
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



971
972
973
# File 'lib/stripe/services/charge_service.rb', line 971

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



973
974
975
# File 'lib/stripe/services/charge_service.rb', line 973

def payment_details
  @payment_details
end

#receipt_emailObject

This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.



975
976
977
# File 'lib/stripe/services/charge_service.rb', line 975

def receipt_email
  @receipt_email
end

#shippingObject

Shipping information for the charge. Helps prevent fraud on charges for physical goods.



977
978
979
# File 'lib/stripe/services/charge_service.rb', line 977

def shipping
  @shipping
end

#transfer_groupObject

A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.



979
980
981
# File 'lib/stripe/services/charge_service.rb', line 979

def transfer_group
  @transfer_group
end