Class: Stripe::ChargeService::UpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::UpdateParams::PaymentDetails
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 |
# File 'lib/stripe/services/charge_service.rb', line 901 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
887 888 889 |
# File 'lib/stripe/services/charge_service.rb', line 887 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
889 890 891 |
# File 'lib/stripe/services/charge_service.rb', line 889 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
891 892 893 |
# File 'lib/stripe/services/charge_service.rb', line 891 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
893 894 895 |
# File 'lib/stripe/services/charge_service.rb', line 893 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
895 896 897 |
# File 'lib/stripe/services/charge_service.rb', line 895 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
897 898 899 |
# File 'lib/stripe/services/charge_service.rb', line 897 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
899 900 901 |
# File 'lib/stripe/services/charge_service.rb', line 899 def subscription @subscription end |