Class: Stripe::ChargeService::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/stripe/services/charge_service.rb', line 468

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



409
410
411
# File 'lib/stripe/services/charge_service.rb', line 409

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



412
413
414
# File 'lib/stripe/services/charge_service.rb', line 412

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



415
416
417
# File 'lib/stripe/services/charge_service.rb', line 415

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



418
419
420
# File 'lib/stripe/services/charge_service.rb', line 418

def car_make
  @car_make
end

#car_modelObject

Model of the car.



421
422
423
# File 'lib/stripe/services/charge_service.rb', line 421

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



424
425
426
# File 'lib/stripe/services/charge_service.rb', line 424

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



427
428
429
# File 'lib/stripe/services/charge_service.rb', line 427

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



430
431
432
# File 'lib/stripe/services/charge_service.rb', line 430

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



433
434
435
# File 'lib/stripe/services/charge_service.rb', line 433

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



436
437
438
# File 'lib/stripe/services/charge_service.rb', line 436

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



439
440
441
# File 'lib/stripe/services/charge_service.rb', line 439

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



442
443
444
# File 'lib/stripe/services/charge_service.rb', line 442

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



445
446
447
# File 'lib/stripe/services/charge_service.rb', line 445

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



448
449
450
# File 'lib/stripe/services/charge_service.rb', line 448

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



451
452
453
# File 'lib/stripe/services/charge_service.rb', line 451

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



454
455
456
# File 'lib/stripe/services/charge_service.rb', line 454

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



457
458
459
# File 'lib/stripe/services/charge_service.rb', line 457

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



460
461
462
# File 'lib/stripe/services/charge_service.rb', line 460

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



463
464
465
# File 'lib/stripe/services/charge_service.rb', line 463

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



466
467
468
# File 'lib/stripe/services/charge_service.rb', line 466

def tax_exempt
  @tax_exempt
end