Class: Stripe::ChargeService::UpdateParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/stripe/services/charge_service.rb', line 397

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



357
358
359
# File 'lib/stripe/services/charge_service.rb', line 357

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



359
360
361
# File 'lib/stripe/services/charge_service.rb', line 359

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



361
362
363
# File 'lib/stripe/services/charge_service.rb', line 361

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



363
364
365
# File 'lib/stripe/services/charge_service.rb', line 363

def car_make
  @car_make
end

#car_modelObject

Model of the car.



365
366
367
# File 'lib/stripe/services/charge_service.rb', line 365

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



367
368
369
# File 'lib/stripe/services/charge_service.rb', line 367

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



369
370
371
# File 'lib/stripe/services/charge_service.rb', line 369

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



371
372
373
# File 'lib/stripe/services/charge_service.rb', line 371

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



373
374
375
# File 'lib/stripe/services/charge_service.rb', line 373

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



375
376
377
# File 'lib/stripe/services/charge_service.rb', line 375

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



377
378
379
# File 'lib/stripe/services/charge_service.rb', line 377

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



379
380
381
# File 'lib/stripe/services/charge_service.rb', line 379

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



381
382
383
# File 'lib/stripe/services/charge_service.rb', line 381

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



383
384
385
# File 'lib/stripe/services/charge_service.rb', line 383

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



385
386
387
# File 'lib/stripe/services/charge_service.rb', line 385

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



387
388
389
# File 'lib/stripe/services/charge_service.rb', line 387

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



389
390
391
# File 'lib/stripe/services/charge_service.rb', line 389

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



391
392
393
# File 'lib/stripe/services/charge_service.rb', line 391

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



393
394
395
# File 'lib/stripe/services/charge_service.rb', line 393

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



395
396
397
# File 'lib/stripe/services/charge_service.rb', line 395

def tax_exempt
  @tax_exempt
end