Class: Stripe::ChargeService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::UpdateParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
310 311 312 313 314 |
# File 'lib/stripe/services/charge_service.rb', line 310 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
302 303 304 |
# File 'lib/stripe/services/charge_service.rb', line 302 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
305 306 307 |
# File 'lib/stripe/services/charge_service.rb', line 305 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
308 309 310 |
# File 'lib/stripe/services/charge_service.rb', line 308 def phone @phone end |