Class: Stripe::ChargeService::UpdateParams::PaymentDetails::EventDetails::Affiliate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::UpdateParams::PaymentDetails::EventDetails::Affiliate
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the affiliate that originated the purchase.
Instance Method Summary collapse
-
#initialize(name: nil) ⇒ Affiliate
constructor
A new instance of Affiliate.
Methods inherited from RequestParams
Constructor Details
#initialize(name: nil) ⇒ Affiliate
Returns a new instance of Affiliate.
554 555 556 |
# File 'lib/stripe/services/charge_service.rb', line 554 def initialize(name: nil) @name = name end |
Instance Attribute Details
#name ⇒ Object
The name of the affiliate that originated the purchase.
552 553 554 |
# File 'lib/stripe/services/charge_service.rb', line 552 def name @name end |