Class: Stripe::ChargeService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::UpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
569 570 571 572 573 |
# File 'lib/stripe/services/charge_service.rb', line 569 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
563 564 565 |
# File 'lib/stripe/services/charge_service.rb', line 563 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
565 566 567 |
# File 'lib/stripe/services/charge_service.rb', line 565 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
567 568 569 |
# File 'lib/stripe/services/charge_service.rb', line 567 def phone @phone end |