Class: Stripe::ChargeService::UpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::UpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/services/charge_service.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 |
# File 'lib/stripe/services/charge_service.rb', line 921 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
859 860 861 |
# File 'lib/stripe/services/charge_service.rb', line 859 def address @address end |
#adults ⇒ Object
The number of adults on the booking
862 863 864 |
# File 'lib/stripe/services/charge_service.rb', line 862 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
865 866 867 |
# File 'lib/stripe/services/charge_service.rb', line 865 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
868 869 870 |
# File 'lib/stripe/services/charge_service.rb', line 868 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
871 872 873 |
# File 'lib/stripe/services/charge_service.rb', line 871 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
874 875 876 |
# File 'lib/stripe/services/charge_service.rb', line 874 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
877 878 879 |
# File 'lib/stripe/services/charge_service.rb', line 877 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
880 881 882 |
# File 'lib/stripe/services/charge_service.rb', line 880 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
883 884 885 |
# File 'lib/stripe/services/charge_service.rb', line 883 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
886 887 888 |
# File 'lib/stripe/services/charge_service.rb', line 886 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
889 890 891 |
# File 'lib/stripe/services/charge_service.rb', line 889 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
892 893 894 |
# File 'lib/stripe/services/charge_service.rb', line 892 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
895 896 897 |
# File 'lib/stripe/services/charge_service.rb', line 895 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
898 899 900 |
# File 'lib/stripe/services/charge_service.rb', line 898 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
901 902 903 |
# File 'lib/stripe/services/charge_service.rb', line 901 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
904 905 906 |
# File 'lib/stripe/services/charge_service.rb', line 904 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
907 908 909 |
# File 'lib/stripe/services/charge_service.rb', line 907 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
910 911 912 |
# File 'lib/stripe/services/charge_service.rb', line 910 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
913 914 915 |
# File 'lib/stripe/services/charge_service.rb', line 913 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
916 917 918 |
# File 'lib/stripe/services/charge_service.rb', line 916 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
919 920 921 |
# File 'lib/stripe/services/charge_service.rb', line 919 def total_tax_amount @total_tax_amount end |