Class: Stripe::ChargeService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/charge_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



721
722
723
724
725
# File 'lib/stripe/services/charge_service.rb', line 721

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



715
716
717
# File 'lib/stripe/services/charge_service.rb', line 715

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



717
718
719
# File 'lib/stripe/services/charge_service.rb', line 717

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



719
720
721
# File 'lib/stripe/services/charge_service.rb', line 719

def phone
  @phone
end