Class: Stripe::ChargeService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeService::UpdateParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/services/charge_service.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
832 833 834 835 836 |
# File 'lib/stripe/services/charge_service.rb', line 832 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
824 825 826 |
# File 'lib/stripe/services/charge_service.rb', line 824 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
827 828 829 |
# File 'lib/stripe/services/charge_service.rb', line 827 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
830 831 832 |
# File 'lib/stripe/services/charge_service.rb', line 830 def phone @phone end |