Class: Stripe::ChargeUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: FraudDetails, PaymentDetails, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ ChargeUpdateParams

Returns a new instance of ChargeUpdateParams.



1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
# File 'lib/stripe/params/charge_update_params.rb', line 1726

def initialize(
  customer: nil,
  description: nil,
  expand: nil,
  fraud_details: nil,
  metadata: nil,
  payment_details: nil,
  receipt_email: nil,
  shipping: nil,
  transfer_group: nil
)
  @customer = customer
  @description = description
  @expand = expand
  @fraud_details = fraud_details
  @metadata = 
  @payment_details = payment_details
  @receipt_email = receipt_email
  @shipping = shipping
  @transfer_group = transfer_group
end

Instance Attribute Details

#customerObject

The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.



1708
1709
1710
# File 'lib/stripe/params/charge_update_params.rb', line 1708

def customer
  @customer
end

#descriptionObject

An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.



1710
1711
1712
# File 'lib/stripe/params/charge_update_params.rb', line 1710

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



1712
1713
1714
# File 'lib/stripe/params/charge_update_params.rb', line 1712

def expand
  @expand
end

#fraud_detailsObject

A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.



1714
1715
1716
# File 'lib/stripe/params/charge_update_params.rb', line 1714

def fraud_details
  @fraud_details
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1716
1717
1718
# File 'lib/stripe/params/charge_update_params.rb', line 1716

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



1718
1719
1720
# File 'lib/stripe/params/charge_update_params.rb', line 1718

def payment_details
  @payment_details
end

#receipt_emailObject

This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.



1720
1721
1722
# File 'lib/stripe/params/charge_update_params.rb', line 1720

def receipt_email
  @receipt_email
end

#shippingObject

Shipping information for the charge. Helps prevent fraud on charges for physical goods.



1722
1723
1724
# File 'lib/stripe/params/charge_update_params.rb', line 1722

def shipping
  @shipping
end

#transfer_groupObject

A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](docs.stripe.com/connect/separate-charges-and-transfers#transfer-options) for details.



1724
1725
1726
# File 'lib/stripe/params/charge_update_params.rb', line 1724

def transfer_group
  @transfer_group
end