Class: Stripe::ChargeUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: FraudDetails, PaymentDetails, Shipping
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of an existing customer that will be associated with this request.
-
#description ⇒ Object
An arbitrary string which you can attach to a charge object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fraud_details ⇒ Object
A set of key-value pairs you can attach to a charge giving information about its riskiness.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#receipt_email ⇒ Object
This is the email address that the receipt for this charge will be sent to.
-
#shipping ⇒ Object
Shipping information for the charge.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ ChargeUpdateParams
constructor
A new instance of ChargeUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ ChargeUpdateParams
Returns a new instance of ChargeUpdateParams.
1743 1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 |
# File 'lib/stripe/params/charge_update_params.rb', line 1743 def initialize( customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil ) @customer = customer @description = description @expand = @fraud_details = fraud_details @metadata = @payment_details = payment_details @receipt_email = receipt_email @shipping = shipping @transfer_group = transfer_group end |
Instance Attribute Details
#customer ⇒ Object
The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.
1725 1726 1727 |
# File 'lib/stripe/params/charge_update_params.rb', line 1725 def customer @customer end |
#description ⇒ Object
An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.
1727 1728 1729 |
# File 'lib/stripe/params/charge_update_params.rb', line 1727 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1729 1730 1731 |
# File 'lib/stripe/params/charge_update_params.rb', line 1729 def @expand end |
#fraud_details ⇒ Object
A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.
1731 1732 1733 |
# File 'lib/stripe/params/charge_update_params.rb', line 1731 def fraud_details @fraud_details end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1733 1734 1735 |
# File 'lib/stripe/params/charge_update_params.rb', line 1733 def @metadata end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
1735 1736 1737 |
# File 'lib/stripe/params/charge_update_params.rb', line 1735 def payment_details @payment_details end |
#receipt_email ⇒ Object
This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.
1737 1738 1739 |
# File 'lib/stripe/params/charge_update_params.rb', line 1737 def receipt_email @receipt_email end |
#shipping ⇒ Object
Shipping information for the charge. Helps prevent fraud on charges for physical goods.
1739 1740 1741 |
# File 'lib/stripe/params/charge_update_params.rb', line 1739 def shipping @shipping end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](docs.stripe.com/connect/separate-charges-and-transfers#transfer-options) for details.
1741 1742 1743 |
# File 'lib/stripe/params/charge_update_params.rb', line 1741 def transfer_group @transfer_group end |