Class: Stripe::ChargeUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: FraudDetails, PaymentDetails, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(customer: nil, description: nil, expand: nil, fraud_details: nil, metadata: nil, payment_details: nil, receipt_email: nil, shipping: nil, transfer_group: nil) ⇒ ChargeUpdateParams

Returns a new instance of ChargeUpdateParams.



789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
# File 'lib/stripe/params/charge_update_params.rb', line 789

def initialize(
  customer: nil,
  description: nil,
  expand: nil,
  fraud_details: nil,
  metadata: nil,
  payment_details: nil,
  receipt_email: nil,
  shipping: nil,
  transfer_group: nil
)
  @customer = customer
  @description = description
  @expand = expand
  @fraud_details = fraud_details
  @metadata = 
  @payment_details = payment_details
  @receipt_email = receipt_email
  @shipping = shipping
  @transfer_group = transfer_group
end

Instance Attribute Details

#customerObject

The ID of an existing customer that will be associated with this request. This field may only be updated if there is no existing associated customer with this charge.



771
772
773
# File 'lib/stripe/params/charge_update_params.rb', line 771

def customer
  @customer
end

#descriptionObject

An arbitrary string which you can attach to a charge object. It is displayed when in the web interface alongside the charge. Note that if you use Stripe to send automatic email receipts to your customers, your receipt emails will include the ‘description` of the charge(s) that they are describing.



773
774
775
# File 'lib/stripe/params/charge_update_params.rb', line 773

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



775
776
777
# File 'lib/stripe/params/charge_update_params.rb', line 775

def expand
  @expand
end

#fraud_detailsObject

A set of key-value pairs you can attach to a charge giving information about its riskiness. If you believe a charge is fraudulent, include a ‘user_report` key with a value of `fraudulent`. If you believe a charge is safe, include a `user_report` key with a value of `safe`. Stripe will use the information you send to improve our fraud detection algorithms.



777
778
779
# File 'lib/stripe/params/charge_update_params.rb', line 777

def fraud_details
  @fraud_details
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



779
780
781
# File 'lib/stripe/params/charge_update_params.rb', line 779

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



781
782
783
# File 'lib/stripe/params/charge_update_params.rb', line 781

def payment_details
  @payment_details
end

#receipt_emailObject

This is the email address that the receipt for this charge will be sent to. If this field is updated, then a new email receipt will be sent to the updated address.



783
784
785
# File 'lib/stripe/params/charge_update_params.rb', line 783

def receipt_email
  @receipt_email
end

#shippingObject

Shipping information for the charge. Helps prevent fraud on charges for physical goods.



785
786
787
# File 'lib/stripe/params/charge_update_params.rb', line 785

def shipping
  @shipping
end

#transfer_groupObject

A string that identifies this transaction as part of a group. ‘transfer_group` may only be provided if it has not been set. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers#transfer-options) for details.



787
788
789
# File 'lib/stripe/params/charge_update_params.rb', line 787

def transfer_group
  @transfer_group
end