Class: Stripe::ChargeUpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
# File 'lib/stripe/params/charge_update_params.rb', line 1632

def initialize(
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



1608
1609
1610
# File 'lib/stripe/params/charge_update_params.rb', line 1608

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



1610
1611
1612
# File 'lib/stripe/params/charge_update_params.rb', line 1610

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1614
1615
1616
# File 'lib/stripe/params/charge_update_params.rb', line 1614

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1616
1617
1618
# File 'lib/stripe/params/charge_update_params.rb', line 1616

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



1618
1619
1620
# File 'lib/stripe/params/charge_update_params.rb', line 1618

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



1620
1621
1622
# File 'lib/stripe/params/charge_update_params.rb', line 1620

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1622
1623
1624
# File 'lib/stripe/params/charge_update_params.rb', line 1622

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



1624
1625
1626
# File 'lib/stripe/params/charge_update_params.rb', line 1624

def lodging_data
  @lodging_data
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1628
1629
1630
# File 'lib/stripe/params/charge_update_params.rb', line 1628

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1630
1631
1632
# File 'lib/stripe/params/charge_update_params.rb', line 1630

def subscription
  @subscription
end