Class: Stripe::ChargeUpdateParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: CarRental, CarRentalDatum, EventDetails, Flight, FlightDatum, Lodging, LodgingDatum, MoneyServices, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(car_rental: nil, car_rental_data: nil, customer_reference: nil, event_details: nil, flight: nil, flight_data: nil, lodging: nil, lodging_data: nil, order_reference: nil, subscription: nil, money_services: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
# File 'lib/stripe/params/charge_update_params.rb', line 1647

def initialize(
  car_rental: nil,
  car_rental_data: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  flight_data: nil,
  lodging: nil,
  lodging_data: nil,
  order_reference: nil,
  subscription: nil,
  money_services: nil
)
  @car_rental = car_rental
  @car_rental_data = car_rental_data
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @flight_data = flight_data
  @lodging = lodging
  @lodging_data = lodging_data
  @order_reference = order_reference
  @subscription = subscription
  @money_services = money_services
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



1621
1622
1623
# File 'lib/stripe/params/charge_update_params.rb', line 1621

def car_rental
  @car_rental
end

#car_rental_dataObject

Car rental data for this PaymentIntent.



1623
1624
1625
# File 'lib/stripe/params/charge_update_params.rb', line 1623

def car_rental_data
  @car_rental_data
end

#customer_referenceObject

A unique value to identify the customer. This field is available only for card payments.

This field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks.



1627
1628
1629
# File 'lib/stripe/params/charge_update_params.rb', line 1627

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



1629
1630
1631
# File 'lib/stripe/params/charge_update_params.rb', line 1629

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



1631
1632
1633
# File 'lib/stripe/params/charge_update_params.rb', line 1631

def flight
  @flight
end

#flight_dataObject

Flight data for this PaymentIntent.



1633
1634
1635
# File 'lib/stripe/params/charge_update_params.rb', line 1633

def flight_data
  @flight_data
end

#lodgingObject

Lodging reservation details for this PaymentIntent



1635
1636
1637
# File 'lib/stripe/params/charge_update_params.rb', line 1635

def lodging
  @lodging
end

#lodging_dataObject

Lodging data for this PaymentIntent.



1637
1638
1639
# File 'lib/stripe/params/charge_update_params.rb', line 1637

def lodging_data
  @lodging_data
end

#money_servicesObject

Money services details for this PaymentIntent.



1645
1646
1647
# File 'lib/stripe/params/charge_update_params.rb', line 1645

def money_services
  @money_services
end

#order_referenceObject

A unique value assigned by the business to identify the transaction. Required for L2 and L3 rates.

For Cards, this field is truncated to 25 alphanumeric characters, excluding spaces, before being sent to card networks. For Klarna, this field is truncated to 255 characters and is visible to customers when they view the order in the Klarna app.



1641
1642
1643
# File 'lib/stripe/params/charge_update_params.rb', line 1641

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



1643
1644
1645
# File 'lib/stripe/params/charge_update_params.rb', line 1643

def subscription
  @subscription
end