Class: Stripe::ChargeUpdateParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/stripe/params/charge_update_params.rb', line 701 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
687 688 689 |
# File 'lib/stripe/params/charge_update_params.rb', line 687 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
689 690 691 |
# File 'lib/stripe/params/charge_update_params.rb', line 689 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
691 692 693 |
# File 'lib/stripe/params/charge_update_params.rb', line 691 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
693 694 695 |
# File 'lib/stripe/params/charge_update_params.rb', line 693 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
695 696 697 |
# File 'lib/stripe/params/charge_update_params.rb', line 695 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
697 698 699 |
# File 'lib/stripe/params/charge_update_params.rb', line 697 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
699 700 701 |
# File 'lib/stripe/params/charge_update_params.rb', line 699 def subscription @subscription end |