Class: Stripe::ChargeUpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/params/charge_update_params.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
369 370 371 372 373 |
# File 'lib/stripe/params/charge_update_params.rb', line 369 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
363 364 365 |
# File 'lib/stripe/params/charge_update_params.rb', line 363 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
365 366 367 |
# File 'lib/stripe/params/charge_update_params.rb', line 365 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
367 368 369 |
# File 'lib/stripe/params/charge_update_params.rb', line 367 def phone @phone end |