Class: Stripe::ChargeUpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/stripe/params/charge_update_params.rb', line 1309 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1267 1268 1269 |
# File 'lib/stripe/params/charge_update_params.rb', line 1267 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1269 1270 1271 |
# File 'lib/stripe/params/charge_update_params.rb', line 1269 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1271 1272 1273 |
# File 'lib/stripe/params/charge_update_params.rb', line 1271 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1273 1274 1275 |
# File 'lib/stripe/params/charge_update_params.rb', line 1273 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1275 1276 1277 |
# File 'lib/stripe/params/charge_update_params.rb', line 1275 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
1277 1278 1279 |
# File 'lib/stripe/params/charge_update_params.rb', line 1277 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1279 1280 1281 |
# File 'lib/stripe/params/charge_update_params.rb', line 1279 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1281 1282 1283 |
# File 'lib/stripe/params/charge_update_params.rb', line 1281 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1283 1284 1285 |
# File 'lib/stripe/params/charge_update_params.rb', line 1283 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1285 1286 1287 |
# File 'lib/stripe/params/charge_update_params.rb', line 1285 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1287 1288 1289 |
# File 'lib/stripe/params/charge_update_params.rb', line 1287 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1289 1290 1291 |
# File 'lib/stripe/params/charge_update_params.rb', line 1289 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1291 1292 1293 |
# File 'lib/stripe/params/charge_update_params.rb', line 1291 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1293 1294 1295 |
# File 'lib/stripe/params/charge_update_params.rb', line 1293 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1295 1296 1297 |
# File 'lib/stripe/params/charge_update_params.rb', line 1295 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1297 1298 1299 |
# File 'lib/stripe/params/charge_update_params.rb', line 1297 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1299 1300 1301 |
# File 'lib/stripe/params/charge_update_params.rb', line 1299 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1301 1302 1303 |
# File 'lib/stripe/params/charge_update_params.rb', line 1301 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1303 1304 1305 |
# File 'lib/stripe/params/charge_update_params.rb', line 1303 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1305 1306 1307 |
# File 'lib/stripe/params/charge_update_params.rb', line 1305 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
1307 1308 1309 |
# File 'lib/stripe/params/charge_update_params.rb', line 1307 def total_tax_amount @total_tax_amount end |