Class: Stripe::ChargeUpdateParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 |
# File 'lib/stripe/params/charge_update_params.rb', line 1216 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
1174 1175 1176 |
# File 'lib/stripe/params/charge_update_params.rb', line 1174 def address @address end |
#adults ⇒ Object
The number of adults on the booking
1176 1177 1178 |
# File 'lib/stripe/params/charge_update_params.rb', line 1176 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
1178 1179 1180 |
# File 'lib/stripe/params/charge_update_params.rb', line 1178 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
1180 1181 1182 |
# File 'lib/stripe/params/charge_update_params.rb', line 1180 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
1182 1183 1184 |
# File 'lib/stripe/params/charge_update_params.rb', line 1182 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
1184 1185 1186 |
# File 'lib/stripe/params/charge_update_params.rb', line 1184 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
1186 1187 1188 |
# File 'lib/stripe/params/charge_update_params.rb', line 1186 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
1188 1189 1190 |
# File 'lib/stripe/params/charge_update_params.rb', line 1188 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
1190 1191 1192 |
# File 'lib/stripe/params/charge_update_params.rb', line 1190 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
1192 1193 1194 |
# File 'lib/stripe/params/charge_update_params.rb', line 1192 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
1194 1195 1196 |
# File 'lib/stripe/params/charge_update_params.rb', line 1194 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
1196 1197 1198 |
# File 'lib/stripe/params/charge_update_params.rb', line 1196 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
1198 1199 1200 |
# File 'lib/stripe/params/charge_update_params.rb', line 1198 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
1200 1201 1202 |
# File 'lib/stripe/params/charge_update_params.rb', line 1200 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
1202 1203 1204 |
# File 'lib/stripe/params/charge_update_params.rb', line 1202 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
1204 1205 1206 |
# File 'lib/stripe/params/charge_update_params.rb', line 1204 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
1206 1207 1208 |
# File 'lib/stripe/params/charge_update_params.rb', line 1206 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
1208 1209 1210 |
# File 'lib/stripe/params/charge_update_params.rb', line 1208 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
1210 1211 1212 |
# File 'lib/stripe/params/charge_update_params.rb', line 1210 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
1212 1213 1214 |
# File 'lib/stripe/params/charge_update_params.rb', line 1212 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
1214 1215 1216 |
# File 'lib/stripe/params/charge_update_params.rb', line 1214 def total_tax_amount @total_tax_amount end |