Class: Stripe::ChargeUpdateParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
# File 'lib/stripe/params/charge_update_params.rb', line 589

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



547
548
549
# File 'lib/stripe/params/charge_update_params.rb', line 547

def address
  @address
end

#adultsObject

The number of adults on the booking



549
550
551
# File 'lib/stripe/params/charge_update_params.rb', line 549

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



551
552
553
# File 'lib/stripe/params/charge_update_params.rb', line 551

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



553
554
555
# File 'lib/stripe/params/charge_update_params.rb', line 553

def booking_number
  @booking_number
end

#categoryObject

The lodging category



555
556
557
# File 'lib/stripe/params/charge_update_params.rb', line 555

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



557
558
559
# File 'lib/stripe/params/charge_update_params.rb', line 557

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



559
560
561
# File 'lib/stripe/params/charge_update_params.rb', line 559

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



561
562
563
# File 'lib/stripe/params/charge_update_params.rb', line 561

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



563
564
565
# File 'lib/stripe/params/charge_update_params.rb', line 563

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



565
566
567
# File 'lib/stripe/params/charge_update_params.rb', line 565

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



567
568
569
# File 'lib/stripe/params/charge_update_params.rb', line 567

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



569
570
571
# File 'lib/stripe/params/charge_update_params.rb', line 569

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



571
572
573
# File 'lib/stripe/params/charge_update_params.rb', line 571

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



573
574
575
# File 'lib/stripe/params/charge_update_params.rb', line 573

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



575
576
577
# File 'lib/stripe/params/charge_update_params.rb', line 575

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



577
578
579
# File 'lib/stripe/params/charge_update_params.rb', line 577

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



579
580
581
# File 'lib/stripe/params/charge_update_params.rb', line 579

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



581
582
583
# File 'lib/stripe/params/charge_update_params.rb', line 581

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



583
584
585
# File 'lib/stripe/params/charge_update_params.rb', line 583

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



585
586
587
# File 'lib/stripe/params/charge_update_params.rb', line 585

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



587
588
589
# File 'lib/stripe/params/charge_update_params.rb', line 587

def total_tax_amount
  @total_tax_amount
end