Class: Stripe::ChargeUpdateParams::PaymentDetails::LodgingDatum
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::PaymentDetails::LodgingDatum
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Accommodation, Affiliate, Guest, Host, Insurance, Total
Instance Attribute Summary collapse
-
#accommodation ⇒ Object
Accommodation details for the lodging.
-
#affiliate ⇒ Object
Affiliate details if applicable.
-
#booking_number ⇒ Object
Booking confirmation number for the lodging.
-
#checkin_at ⇒ Object
Check-in date.
-
#checkout_at ⇒ Object
Check-out date.
-
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
-
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
-
#guests ⇒ Object
List of guests for the lodging.
-
#host ⇒ Object
Host details for the lodging.
-
#insurances ⇒ Object
List of insurances for the lodging.
-
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
-
#renter_id_number ⇒ Object
Renter ID number for the lodging.
-
#renter_name ⇒ Object
Renter name for the lodging.
-
#total ⇒ Object
Total details for the lodging.
Instance Method Summary collapse
-
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
constructor
A new instance of LodgingDatum.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil) ⇒ LodgingDatum
Returns a new instance of LodgingDatum.
1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 |
# File 'lib/stripe/params/charge_update_params.rb', line 1524 def initialize( accommodation: nil, affiliate: nil, booking_number: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, fire_safety_act_compliance_indicator: nil, guests: nil, host: nil, insurances: nil, no_show_indicator: nil, renter_id_number: nil, renter_name: nil, total: nil ) @accommodation = accommodation @affiliate = affiliate @booking_number = booking_number @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @fire_safety_act_compliance_indicator = fire_safety_act_compliance_indicator @guests = guests @host = host @insurances = insurances @no_show_indicator = no_show_indicator @renter_id_number = renter_id_number @renter_name = renter_name @total = total end |
Instance Attribute Details
#accommodation ⇒ Object
Accommodation details for the lodging.
1496 1497 1498 |
# File 'lib/stripe/params/charge_update_params.rb', line 1496 def accommodation @accommodation end |
#affiliate ⇒ Object
Affiliate details if applicable.
1498 1499 1500 |
# File 'lib/stripe/params/charge_update_params.rb', line 1498 def affiliate @affiliate end |
#booking_number ⇒ Object
Booking confirmation number for the lodging.
1500 1501 1502 |
# File 'lib/stripe/params/charge_update_params.rb', line 1500 def booking_number @booking_number end |
#checkin_at ⇒ Object
Check-in date.
1502 1503 1504 |
# File 'lib/stripe/params/charge_update_params.rb', line 1502 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Check-out date.
1504 1505 1506 |
# File 'lib/stripe/params/charge_update_params.rb', line 1504 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
Customer service phone number for the lodging company.
1506 1507 1508 |
# File 'lib/stripe/params/charge_update_params.rb', line 1506 def customer_service_phone_number @customer_service_phone_number end |
#fire_safety_act_compliance_indicator ⇒ Object
Whether the lodging is compliant with any hotel fire safety regulations.
1508 1509 1510 |
# File 'lib/stripe/params/charge_update_params.rb', line 1508 def fire_safety_act_compliance_indicator @fire_safety_act_compliance_indicator end |
#guests ⇒ Object
List of guests for the lodging.
1510 1511 1512 |
# File 'lib/stripe/params/charge_update_params.rb', line 1510 def guests @guests end |
#host ⇒ Object
Host details for the lodging.
1512 1513 1514 |
# File 'lib/stripe/params/charge_update_params.rb', line 1512 def host @host end |
#insurances ⇒ Object
List of insurances for the lodging.
1514 1515 1516 |
# File 'lib/stripe/params/charge_update_params.rb', line 1514 def insurances @insurances end |
#no_show_indicator ⇒ Object
Whether the renter is a no-show.
1516 1517 1518 |
# File 'lib/stripe/params/charge_update_params.rb', line 1516 def no_show_indicator @no_show_indicator end |
#renter_id_number ⇒ Object
Renter ID number for the lodging.
1518 1519 1520 |
# File 'lib/stripe/params/charge_update_params.rb', line 1518 def renter_id_number @renter_id_number end |
#renter_name ⇒ Object
Renter name for the lodging.
1520 1521 1522 |
# File 'lib/stripe/params/charge_update_params.rb', line 1520 def renter_name @renter_name end |
#total ⇒ Object
Total details for the lodging.
1522 1523 1524 |
# File 'lib/stripe/params/charge_update_params.rb', line 1522 def total @total end |