Class: Stripe::ChargeUpdateParams::PaymentDetails::Subscription::BillingInterval

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/charge_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil) ⇒ BillingInterval

Returns a new instance of BillingInterval.



1573
1574
1575
1576
# File 'lib/stripe/params/charge_update_params.rb', line 1573

def initialize(count: nil, interval: nil)
  @count = count
  @interval = interval
end

Instance Attribute Details

#countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1569
1570
1571
# File 'lib/stripe/params/charge_update_params.rb', line 1569

def count
  @count
end

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1571
1572
1573
# File 'lib/stripe/params/charge_update_params.rb', line 1571

def interval
  @interval
end