Class: Stripe::ChargeUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::Shipping
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
1965 1966 1967 1968 1969 1970 1971 |
# File 'lib/stripe/params/charge_update_params.rb', line 1965 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
1955 1956 1957 |
# File 'lib/stripe/params/charge_update_params.rb', line 1955 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
1957 1958 1959 |
# File 'lib/stripe/params/charge_update_params.rb', line 1957 def carrier @carrier end |
#name ⇒ Object
Recipient name.
1959 1960 1961 |
# File 'lib/stripe/params/charge_update_params.rb', line 1959 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
1961 1962 1963 |
# File 'lib/stripe/params/charge_update_params.rb', line 1961 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
1963 1964 1965 |
# File 'lib/stripe/params/charge_update_params.rb', line 1963 def tracking_number @tracking_number end |