Class: Stripe::ChargeUpdateParams::Shipping

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/charge_update_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



1699
1700
1701
1702
1703
1704
1705
# File 'lib/stripe/params/charge_update_params.rb', line 1699

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



1689
1690
1691
# File 'lib/stripe/params/charge_update_params.rb', line 1689

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



1691
1692
1693
# File 'lib/stripe/params/charge_update_params.rb', line 1691

def carrier
  @carrier
end

#nameObject

Recipient name.



1693
1694
1695
# File 'lib/stripe/params/charge_update_params.rb', line 1693

def name
  @name
end

#phoneObject

Recipient phone (including extension).



1695
1696
1697
# File 'lib/stripe/params/charge_update_params.rb', line 1695

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



1697
1698
1699
# File 'lib/stripe/params/charge_update_params.rb', line 1697

def tracking_number
  @tracking_number
end