Class: Stripe::ChargeUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::Shipping
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
1716 1717 1718 1719 1720 1721 1722 |
# File 'lib/stripe/params/charge_update_params.rb', line 1716 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
1706 1707 1708 |
# File 'lib/stripe/params/charge_update_params.rb', line 1706 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
1708 1709 1710 |
# File 'lib/stripe/params/charge_update_params.rb', line 1708 def carrier @carrier end |
#name ⇒ Object
Recipient name.
1710 1711 1712 |
# File 'lib/stripe/params/charge_update_params.rb', line 1710 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
1712 1713 1714 |
# File 'lib/stripe/params/charge_update_params.rb', line 1712 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
1714 1715 1716 |
# File 'lib/stripe/params/charge_update_params.rb', line 1714 def tracking_number @tracking_number end |