Class: Stripe::ChargeUpdateParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ChargeUpdateParams::Shipping
- Defined in:
- lib/stripe/params/charge_update_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
762 763 764 765 766 767 768 |
# File 'lib/stripe/params/charge_update_params.rb', line 762 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
752 753 754 |
# File 'lib/stripe/params/charge_update_params.rb', line 752 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
754 755 756 |
# File 'lib/stripe/params/charge_update_params.rb', line 754 def carrier @carrier end |
#name ⇒ Object
Recipient name.
756 757 758 |
# File 'lib/stripe/params/charge_update_params.rb', line 756 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
758 759 760 |
# File 'lib/stripe/params/charge_update_params.rb', line 758 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
760 761 762 |
# File 'lib/stripe/params/charge_update_params.rb', line 760 def tracking_number @tracking_number end |