Class: Stripe::Checkout::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/checkout/session.rb

Overview

A Checkout Session represents your customer’s session as they pay for one-time purchases or subscriptions through [Checkout](docs.stripe.com/payments/checkout) or [Payment Links](docs.stripe.com/payments/payment-links). We recommend creating a new Session each time your customer attempts to pay.

Once payment is successful, the Checkout Session will contain a reference to the [Customer](docs.stripe.com/api/customers), and either the successful [PaymentIntent](docs.stripe.com/api/payment_intents) or an active [Subscription](docs.stripe.com/api/subscriptions).

You can create a Checkout Session on your server and redirect to its URL to begin Checkout.

Related guide: [Checkout quickstart](docs.stripe.com/checkout/quickstart)

Defined Under Namespace

Classes: AdaptivePricing, AfterExpiration, AutomaticTax, BrandingSettings, CheckoutItem, CollectedInformation, Consent, ConsentCollection, CurrencyConversion, CurrentAttempt, CustomField, CustomText, CustomerDetails, Discount, InvoiceCreation, ManagedPayments, NameCollection, OptionalItem, PaymentMethodConfigurationDetails, PaymentMethodOptions, Permissions, PhoneNumberCollection, PresentmentDetails, SavedPaymentMethodOptions, ShippingAddressCollection, ShippingCost, ShippingOption, TaxIdCollection, TotalDetails, WalletOptions

Constant Summary collapse

OBJECT_NAME =
"checkout.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#adaptive_pricingObject (readonly)

Settings for price localization with [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing).



2474
2475
2476
# File 'lib/stripe/resources/checkout/session.rb', line 2474

def adaptive_pricing
  @adaptive_pricing
end

#after_expirationObject (readonly)

When set, provides configuration for actions to take if this Checkout Session expires.



2476
2477
2478
# File 'lib/stripe/resources/checkout/session.rb', line 2476

def after_expiration
  @after_expiration
end

#allow_promotion_codesObject (readonly)

Enables user redeemable promotion codes.



2478
2479
2480
# File 'lib/stripe/resources/checkout/session.rb', line 2478

def allow_promotion_codes
  @allow_promotion_codes
end

#amount_subtotalObject (readonly)

Total of all items before discounts or taxes are applied.



2480
2481
2482
# File 'lib/stripe/resources/checkout/session.rb', line 2480

def amount_subtotal
  @amount_subtotal
end

#amount_totalObject (readonly)

Total of all items after discounts and taxes are applied.



2482
2483
2484
# File 'lib/stripe/resources/checkout/session.rb', line 2482

def amount_total
  @amount_total
end

#approval_methodObject (readonly)

Determines whether the customer’s attempt to pay must be manually approved.

Default is ‘auto`, when the customer’s attempt to pay is approved automatically with no action required on your server.

When set to ‘manual`, you must approve the customer’s attempt to pay by calling [approve](api/checkout/sessions/approve) from your server.



2631
2632
2633
# File 'lib/stripe/resources/checkout/session.rb', line 2631

def approval_method
  @approval_method
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



2484
2485
2486
# File 'lib/stripe/resources/checkout/session.rb', line 2484

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject (readonly)

Describes whether Checkout should collect the customer’s billing address. Defaults to ‘auto`.



2486
2487
2488
# File 'lib/stripe/resources/checkout/session.rb', line 2486

def billing_address_collection
  @billing_address_collection
end

#branding_settingsObject (readonly)

Attribute for field branding_settings



2488
2489
2490
# File 'lib/stripe/resources/checkout/session.rb', line 2488

def branding_settings
  @branding_settings
end

#cancel_urlObject (readonly)

If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website.



2490
2491
2492
# File 'lib/stripe/resources/checkout/session.rb', line 2490

def cancel_url
  @cancel_url
end

#checkout_itemsObject (readonly)

Attribute for field checkout_items



2635
2636
2637
# File 'lib/stripe/resources/checkout/session.rb', line 2635

def checkout_items
  @checkout_items
end

#client_reference_idObject (readonly)

A unique string to reference the Checkout Session. This can be a customer ID, a cart ID, or similar, and can be used to reconcile the Session with your internal systems.



2494
2495
2496
# File 'lib/stripe/resources/checkout/session.rb', line 2494

def client_reference_id
  @client_reference_id
end

#client_secretObject (readonly)

The client secret of your Checkout Session. Applies to Checkout Sessions with ‘ui_mode: embedded` or `ui_mode: custom`. For `ui_mode: embedded`, the client secret is to be used when initializing Stripe.js embedded checkout.

For `ui_mode: custom`, use the client secret with [initCheckout](https://docs.stripe.com/js/custom_checkout/init) on your front end.


2497
2498
2499
# File 'lib/stripe/resources/checkout/session.rb', line 2497

def client_secret
  @client_secret
end

#collected_informationObject (readonly)

Information about the customer collected within the Checkout Session.



2499
2500
2501
# File 'lib/stripe/resources/checkout/session.rb', line 2499

def collected_information
  @collected_information
end

Results of ‘consent_collection` for this session.



2501
2502
2503
# File 'lib/stripe/resources/checkout/session.rb', line 2501

def consent
  @consent
end

When set, provides configuration for the Checkout Session to gather active consent from customers.



2503
2504
2505
# File 'lib/stripe/resources/checkout/session.rb', line 2503

def consent_collection
  @consent_collection
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2505
2506
2507
# File 'lib/stripe/resources/checkout/session.rb', line 2505

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2507
2508
2509
# File 'lib/stripe/resources/checkout/session.rb', line 2507

def currency
  @currency
end

#currency_conversionObject (readonly)

Currency conversion details for [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing) sessions created before 2025-03-31.



2509
2510
2511
# File 'lib/stripe/resources/checkout/session.rb', line 2509

def currency_conversion
  @currency_conversion
end

#current_attemptObject (readonly)

The customer’s pending attempt to pay that requires your approval. Contains information about the customer and their payment details.



2633
2634
2635
# File 'lib/stripe/resources/checkout/session.rb', line 2633

def current_attempt
  @current_attempt
end

#custom_fieldsObject (readonly)

Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can’t set this parameter if ‘ui_mode` is `custom`.



2511
2512
2513
# File 'lib/stripe/resources/checkout/session.rb', line 2511

def custom_fields
  @custom_fields
end

#custom_textObject (readonly)

Attribute for field custom_text



2513
2514
2515
# File 'lib/stripe/resources/checkout/session.rb', line 2513

def custom_text
  @custom_text
end

#customerObject (readonly)

The ID of the customer for this Session. For Checkout Sessions in ‘subscription` mode or Checkout Sessions with `customer_creation` set as `always` in `payment` mode, Checkout will create a new customer object based on information provided during the payment flow unless an existing customer was provided when the Session was created.



2519
2520
2521
# File 'lib/stripe/resources/checkout/session.rb', line 2519

def customer
  @customer
end

#customer_accountObject (readonly)

The ID of the account for this Session.



2521
2522
2523
# File 'lib/stripe/resources/checkout/session.rb', line 2521

def 
  @customer_account
end

#customer_creationObject (readonly)

Configure whether a Checkout Session creates a Customer when the Checkout Session completes.



2523
2524
2525
# File 'lib/stripe/resources/checkout/session.rb', line 2523

def customer_creation
  @customer_creation
end

#customer_detailsObject (readonly)

The customer details including the customer’s tax exempt status and the customer’s tax IDs. Customer’s address details are not present on Sessions in ‘setup` mode.



2525
2526
2527
# File 'lib/stripe/resources/checkout/session.rb', line 2525

def customer_details
  @customer_details
end

#customer_emailObject (readonly)

If provided, this value will be used when the Customer object is created. If not provided, customers will be asked to enter their email address. Use this parameter to prefill customer data if you already have an email on file. To access information about the customer once the payment flow is complete, use the ‘customer` attribute.



2531
2532
2533
# File 'lib/stripe/resources/checkout/session.rb', line 2531

def customer_email
  @customer_email
end

#discountsObject (readonly)

List of coupons and promotion codes attached to the Checkout Session.



2533
2534
2535
# File 'lib/stripe/resources/checkout/session.rb', line 2533

def discounts
  @discounts
end

#excluded_payment_method_typesObject (readonly)

A list of the types of payment methods (e.g., ‘card`) that should be excluded from this Checkout Session. This should only be used when payment methods for this Checkout Session are managed through the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



2535
2536
2537
# File 'lib/stripe/resources/checkout/session.rb', line 2535

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expires_atObject (readonly)

The timestamp at which the Checkout Session will expire.



2537
2538
2539
# File 'lib/stripe/resources/checkout/session.rb', line 2537

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



2539
2540
2541
# File 'lib/stripe/resources/checkout/session.rb', line 2539

def id
  @id
end

#invoiceObject (readonly)

ID of the invoice created by the Checkout Session, if it exists.



2541
2542
2543
# File 'lib/stripe/resources/checkout/session.rb', line 2541

def invoice
  @invoice
end

#invoice_creationObject (readonly)

Details on the state of invoice creation for the Checkout Session.



2543
2544
2545
# File 'lib/stripe/resources/checkout/session.rb', line 2543

def invoice_creation
  @invoice_creation
end

#line_itemsObject (readonly)

The line items purchased by the customer.



2545
2546
2547
# File 'lib/stripe/resources/checkout/session.rb', line 2545

def line_items
  @line_items
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2547
2548
2549
# File 'lib/stripe/resources/checkout/session.rb', line 2547

def livemode
  @livemode
end

#localeObject (readonly)

The IETF language tag of the locale Checkout is displayed in. If blank or ‘auto`, the browser’s locale is used.



2549
2550
2551
# File 'lib/stripe/resources/checkout/session.rb', line 2549

def locale
  @locale
end

#managed_paymentsObject (readonly)

Settings for Managed Payments for this Checkout Session and resulting [PaymentIntents](/api/payment_intents/object), [Invoices](/api/invoices/object), and [Subscriptions](/api/subscriptions/object).



2551
2552
2553
# File 'lib/stripe/resources/checkout/session.rb', line 2551

def managed_payments
  @managed_payments
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2553
2554
2555
# File 'lib/stripe/resources/checkout/session.rb', line 2553

def 
  @metadata
end

#modeObject (readonly)

The mode of the Checkout Session.



2555
2556
2557
# File 'lib/stripe/resources/checkout/session.rb', line 2555

def mode
  @mode
end

#name_collectionObject (readonly)

Attribute for field name_collection



2557
2558
2559
# File 'lib/stripe/resources/checkout/session.rb', line 2557

def name_collection
  @name_collection
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2559
2560
2561
# File 'lib/stripe/resources/checkout/session.rb', line 2559

def object
  @object
end

#optional_itemsObject (readonly)

The optional items presented to the customer at checkout.



2561
2562
2563
# File 'lib/stripe/resources/checkout/session.rb', line 2561

def optional_items
  @optional_items
end

#origin_contextObject (readonly)

Where the user is coming from. This informs the optimizations that are applied to the session.



2563
2564
2565
# File 'lib/stripe/resources/checkout/session.rb', line 2563

def origin_context
  @origin_context
end

#payment_intentObject (readonly)

The ID of the PaymentIntent for Checkout Sessions in ‘payment` mode. You can’t confirm or cancel the PaymentIntent for a Checkout Session. To cancel, [expire the Checkout Session](docs.stripe.com/api/checkout/sessions/expire) instead.



2565
2566
2567
# File 'lib/stripe/resources/checkout/session.rb', line 2565

def payment_intent
  @payment_intent
end

The ID of the Payment Link that created this Session.



2567
2568
2569
# File 'lib/stripe/resources/checkout/session.rb', line 2567

def payment_link
  @payment_link
end

#payment_method_collectionObject (readonly)

Configure whether a Checkout Session should collect a payment method. Defaults to ‘always`.



2569
2570
2571
# File 'lib/stripe/resources/checkout/session.rb', line 2569

def payment_method_collection
  @payment_method_collection
end

#payment_method_configuration_detailsObject (readonly)

Information about the payment method configuration used for this Checkout session if using dynamic payment methods.



2571
2572
2573
# File 'lib/stripe/resources/checkout/session.rb', line 2571

def payment_method_configuration_details
  @payment_method_configuration_details
end

#payment_method_optionsObject (readonly)

Payment-method-specific configuration for the PaymentIntent or SetupIntent of this CheckoutSession.



2573
2574
2575
# File 'lib/stripe/resources/checkout/session.rb', line 2573

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

A list of the types of payment methods (e.g. card) this Checkout Session is allowed to accept.



2576
2577
2578
# File 'lib/stripe/resources/checkout/session.rb', line 2576

def payment_method_types
  @payment_method_types
end

#payment_statusObject (readonly)

The payment status of the Checkout Session, one of ‘paid`, `unpaid`, or `no_payment_required`. You can use this value to decide when to fulfill your customer’s order.



2579
2580
2581
# File 'lib/stripe/resources/checkout/session.rb', line 2579

def payment_status
  @payment_status
end

#permissionsObject (readonly)

This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object.

For specific permissions, please refer to their dedicated subsections, such as ‘permissions.update_shipping_details`.



2583
2584
2585
# File 'lib/stripe/resources/checkout/session.rb', line 2583

def permissions
  @permissions
end

#phone_number_collectionObject (readonly)

Attribute for field phone_number_collection



2585
2586
2587
# File 'lib/stripe/resources/checkout/session.rb', line 2585

def phone_number_collection
  @phone_number_collection
end

#presentment_detailsObject (readonly)

Attribute for field presentment_details



2587
2588
2589
# File 'lib/stripe/resources/checkout/session.rb', line 2587

def presentment_details
  @presentment_details
end

#recovered_fromObject (readonly)

The ID of the original expired Checkout Session that triggered the recovery flow.



2589
2590
2591
# File 'lib/stripe/resources/checkout/session.rb', line 2589

def recovered_from
  @recovered_from
end

#redirect_on_completionObject (readonly)

This parameter applies to ‘ui_mode: embedded`. Learn more about the [redirect behavior](docs.stripe.com/payments/checkout/custom-success-page?payment-ui=embedded-form) of embedded sessions. Defaults to `always`.



2591
2592
2593
# File 'lib/stripe/resources/checkout/session.rb', line 2591

def redirect_on_completion
  @redirect_on_completion
end

#return_urlObject (readonly)

Applies to Checkout Sessions with ‘ui_mode: embedded` or `ui_mode: custom`. The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.



2593
2594
2595
# File 'lib/stripe/resources/checkout/session.rb', line 2593

def return_url
  @return_url
end

#saved_payment_method_optionsObject (readonly)

Controls saved payment method settings for the session. Only available in ‘payment` and `subscription` mode.



2595
2596
2597
# File 'lib/stripe/resources/checkout/session.rb', line 2595

def saved_payment_method_options
  @saved_payment_method_options
end

#setup_intentObject (readonly)

The ID of the SetupIntent for Checkout Sessions in ‘setup` mode. You can’t confirm or cancel the SetupIntent for a Checkout Session. To cancel, [expire the Checkout Session](docs.stripe.com/api/checkout/sessions/expire) instead.



2597
2598
2599
# File 'lib/stripe/resources/checkout/session.rb', line 2597

def setup_intent
  @setup_intent
end

#shipping_address_collectionObject (readonly)

When set, provides configuration for Checkout to collect a shipping address from a customer.



2599
2600
2601
# File 'lib/stripe/resources/checkout/session.rb', line 2599

def shipping_address_collection
  @shipping_address_collection
end

#shipping_costObject (readonly)

The details of the customer cost of shipping, including the customer chosen ShippingRate.



2601
2602
2603
# File 'lib/stripe/resources/checkout/session.rb', line 2601

def shipping_cost
  @shipping_cost
end

#shipping_optionsObject (readonly)

The shipping rate options applied to this Session.



2603
2604
2605
# File 'lib/stripe/resources/checkout/session.rb', line 2603

def shipping_options
  @shipping_options
end

#statusObject (readonly)

The status of the Checkout Session, one of ‘open`, `complete`, or `expired`.



2605
2606
2607
# File 'lib/stripe/resources/checkout/session.rb', line 2605

def status
  @status
end

#submit_typeObject (readonly)

Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button. ‘submit_type` can only be specified on Checkout Sessions in `payment` mode. If blank or `auto`, `pay` is used.



2609
2610
2611
# File 'lib/stripe/resources/checkout/session.rb', line 2609

def submit_type
  @submit_type
end

#subscriptionObject (readonly)

The ID of the [Subscription](docs.stripe.com/api/subscriptions) for Checkout Sessions in ‘subscription` mode.



2611
2612
2613
# File 'lib/stripe/resources/checkout/session.rb', line 2611

def subscription
  @subscription
end

#success_urlObject (readonly)

The URL the customer will be directed to after the payment or subscription creation is successful.



2614
2615
2616
# File 'lib/stripe/resources/checkout/session.rb', line 2614

def success_url
  @success_url
end

#tax_id_collectionObject (readonly)

Attribute for field tax_id_collection



2616
2617
2618
# File 'lib/stripe/resources/checkout/session.rb', line 2616

def tax_id_collection
  @tax_id_collection
end

#total_detailsObject (readonly)

Tax and discount details for the computed total amount.



2618
2619
2620
# File 'lib/stripe/resources/checkout/session.rb', line 2618

def total_details
  @total_details
end

#ui_modeObject (readonly)

The UI mode of the Session. Defaults to ‘hosted`.



2620
2621
2622
# File 'lib/stripe/resources/checkout/session.rb', line 2620

def ui_mode
  @ui_mode
end

#urlObject (readonly)

The URL to the Checkout Session. Applies to Checkout Sessions with ‘ui_mode: hosted`. Redirect customers to this URL to take them to Checkout. If you’re using [Custom Domains](docs.stripe.com/payments/checkout/custom-domains), the URL will use your subdomain. Otherwise, it’ll use `checkout.stripe.com.` This value is only present when the session is active.



2623
2624
2625
# File 'lib/stripe/resources/checkout/session.rb', line 2623

def url
  @url
end

#wallet_optionsObject (readonly)

Wallet-specific configuration for this Checkout Session.



2625
2626
2627
# File 'lib/stripe/resources/checkout/session.rb', line 2625

def wallet_options
  @wallet_options
end

Class Method Details

.approve(session, params = {}, opts = {}) ⇒ Object

Approves a customer’s attempt to pay for a Checkout Session with approval_method set to manual.



2648
2649
2650
2651
2652
2653
2654
2655
# File 'lib/stripe/resources/checkout/session.rb', line 2648

def self.approve(session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s/approve", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a Checkout Session object.



2658
2659
2660
2661
2662
2663
2664
2665
# File 'lib/stripe/resources/checkout/session.rb', line 2658

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/checkout/sessions",
    params: params,
    opts: opts
  )
end

.expire(session, params = {}, opts = {}) ⇒ Object

A Checkout Session can be expired when it is in one of these statuses: open

After it expires, a customer can’t complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.



2682
2683
2684
2685
2686
2687
2688
2689
# File 'lib/stripe/resources/checkout/session.rb', line 2682

def self.expire(session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s/expire", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2768
2769
2770
# File 'lib/stripe/resources/checkout/session.rb', line 2768

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
2758
2759
2760
2761
2762
2763
2764
2765
2766
# File 'lib/stripe/resources/checkout/session.rb', line 2733

def self.inner_class_types
  @inner_class_types = {
    adaptive_pricing: AdaptivePricing,
    after_expiration: AfterExpiration,
    automatic_tax: AutomaticTax,
    branding_settings: BrandingSettings,
    collected_information: CollectedInformation,
    consent: Consent,
    consent_collection: ConsentCollection,
    currency_conversion: CurrencyConversion,
    custom_fields: CustomField,
    custom_text: CustomText,
    customer_details: CustomerDetails,
    discounts: Discount,
    invoice_creation: InvoiceCreation,
    managed_payments: ManagedPayments,
    name_collection: NameCollection,
    optional_items: OptionalItem,
    payment_method_configuration_details: PaymentMethodConfigurationDetails,
    payment_method_options: PaymentMethodOptions,
    permissions: Permissions,
    phone_number_collection: PhoneNumberCollection,
    presentment_details: PresentmentDetails,
    saved_payment_method_options: SavedPaymentMethodOptions,
    shipping_address_collection: ShippingAddressCollection,
    shipping_cost: ShippingCost,
    shipping_options: ShippingOption,
    tax_id_collection: TaxIdCollection,
    total_details: TotalDetails,
    wallet_options: WalletOptions,
    current_attempt: CurrentAttempt,
    checkout_items: CheckoutItem,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Checkout Sessions.



2692
2693
2694
2695
2696
2697
2698
2699
# File 'lib/stripe/resources/checkout/session.rb', line 2692

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/checkout/sessions",
    params: params,
    opts: opts
  )
end

.list_line_items(session, params = {}, opts = {}) ⇒ Object

When retrieving a Checkout Session, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



2712
2713
2714
2715
2716
2717
2718
2719
# File 'lib/stripe/resources/checkout/session.rb', line 2712

def self.list_line_items(session, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/checkout/sessions/%<session>s/line_items", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



26
27
28
# File 'lib/stripe/resources/checkout/session.rb', line 26

def self.object_name
  "checkout.session"
end

.update(session, params = {}, opts = {}) ⇒ Object

Updates a Checkout Session object.

Related guide: [Dynamically update a Checkout Session](docs.stripe.com/payments/advanced/dynamic-updates)



2724
2725
2726
2727
2728
2729
2730
2731
# File 'lib/stripe/resources/checkout/session.rb', line 2724

def self.update(session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#approve(params = {}, opts = {}) ⇒ Object

Approves a customer’s attempt to pay for a Checkout Session with approval_method set to manual.



2638
2639
2640
2641
2642
2643
2644
2645
# File 'lib/stripe/resources/checkout/session.rb', line 2638

def approve(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s/approve", { session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#expire(params = {}, opts = {}) ⇒ Object

A Checkout Session can be expired when it is in one of these statuses: open

After it expires, a customer can’t complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.



2670
2671
2672
2673
2674
2675
2676
2677
# File 'lib/stripe/resources/checkout/session.rb', line 2670

def expire(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s/expire", { session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#list_line_items(params = {}, opts = {}) ⇒ Object

When retrieving a Checkout Session, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



2702
2703
2704
2705
2706
2707
2708
2709
# File 'lib/stripe/resources/checkout/session.rb', line 2702

def list_line_items(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/checkout/sessions/%<session>s/line_items", { session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end