Class: Stripe::Checkout::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/checkout/session.rb

Overview

A Checkout Session represents your customer’s session as they pay for one-time purchases or subscriptions through [Checkout](stripe.com/docs/payments/checkout) or [Payment Links](stripe.com/docs/payments/payment-links). We recommend creating a new Session each time your customer attempts to pay.

Once payment is successful, the Checkout Session will contain a reference to the [Customer](stripe.com/docs/api/customers), and either the successful [PaymentIntent](stripe.com/docs/api/payment_intents) or an active [Subscription](stripe.com/docs/api/subscriptions).

You can create a Checkout Session on your server and redirect to its URL to begin Checkout.

Related guide: [Checkout quickstart](stripe.com/docs/checkout/quickstart)

Defined Under Namespace

Classes: AdaptivePricing, AfterExpiration, AutomaticTax, BrandingSettings, CheckoutItem, CollectedInformation, Consent, ConsentCollection, CurrencyConversion, CustomField, CustomText, CustomerDetails, Discount, InvoiceCreation, NameCollection, OptionalItem, PaymentMethodConfigurationDetails, PaymentMethodOptions, Permissions, PhoneNumberCollection, PresentmentDetails, SavedPaymentMethodOptions, ShippingAddressCollection, ShippingCost, ShippingOption, TaxIdCollection, TotalDetails, WalletOptions

Constant Summary collapse

OBJECT_NAME =
"checkout.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#adaptive_pricingObject (readonly)

Settings for price localization with [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing).



2280
2281
2282
# File 'lib/stripe/resources/checkout/session.rb', line 2280

def adaptive_pricing
  @adaptive_pricing
end

#after_expirationObject (readonly)

When set, provides configuration for actions to take if this Checkout Session expires.



2282
2283
2284
# File 'lib/stripe/resources/checkout/session.rb', line 2282

def after_expiration
  @after_expiration
end

#allow_promotion_codesObject (readonly)

Enables user redeemable promotion codes.



2284
2285
2286
# File 'lib/stripe/resources/checkout/session.rb', line 2284

def allow_promotion_codes
  @allow_promotion_codes
end

#amount_subtotalObject (readonly)

Total of all items before discounts or taxes are applied.



2286
2287
2288
# File 'lib/stripe/resources/checkout/session.rb', line 2286

def amount_subtotal
  @amount_subtotal
end

#amount_totalObject (readonly)

Total of all items after discounts and taxes are applied.



2288
2289
2290
# File 'lib/stripe/resources/checkout/session.rb', line 2288

def amount_total
  @amount_total
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



2290
2291
2292
# File 'lib/stripe/resources/checkout/session.rb', line 2290

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject (readonly)

Describes whether Checkout should collect the customer’s billing address. Defaults to ‘auto`.



2292
2293
2294
# File 'lib/stripe/resources/checkout/session.rb', line 2292

def billing_address_collection
  @billing_address_collection
end

#branding_settingsObject (readonly)

Attribute for field branding_settings



2294
2295
2296
# File 'lib/stripe/resources/checkout/session.rb', line 2294

def branding_settings
  @branding_settings
end

#cancel_urlObject (readonly)

If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website.



2296
2297
2298
# File 'lib/stripe/resources/checkout/session.rb', line 2296

def cancel_url
  @cancel_url
end

#checkout_itemsObject (readonly)

Attribute for field checkout_items



2431
2432
2433
# File 'lib/stripe/resources/checkout/session.rb', line 2431

def checkout_items
  @checkout_items
end

#client_reference_idObject (readonly)

A unique string to reference the Checkout Session. This can be a customer ID, a cart ID, or similar, and can be used to reconcile the Session with your internal systems.



2300
2301
2302
# File 'lib/stripe/resources/checkout/session.rb', line 2300

def client_reference_id
  @client_reference_id
end

#client_secretObject (readonly)

The client secret of your Checkout Session. Applies to Checkout Sessions with ‘ui_mode: embedded` or `ui_mode: custom`. For `ui_mode: embedded`, the client secret is to be used when initializing Stripe.js embedded checkout.

For `ui_mode: custom`, use the client secret with [initCheckout](https://stripe.com/docs/js/custom_checkout/init) on your front end.


2303
2304
2305
# File 'lib/stripe/resources/checkout/session.rb', line 2303

def client_secret
  @client_secret
end

#collected_informationObject (readonly)

Information about the customer collected within the Checkout Session.



2305
2306
2307
# File 'lib/stripe/resources/checkout/session.rb', line 2305

def collected_information
  @collected_information
end

Results of ‘consent_collection` for this session.



2307
2308
2309
# File 'lib/stripe/resources/checkout/session.rb', line 2307

def consent
  @consent
end

When set, provides configuration for the Checkout Session to gather active consent from customers.



2309
2310
2311
# File 'lib/stripe/resources/checkout/session.rb', line 2309

def consent_collection
  @consent_collection
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2311
2312
2313
# File 'lib/stripe/resources/checkout/session.rb', line 2311

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2313
2314
2315
# File 'lib/stripe/resources/checkout/session.rb', line 2313

def currency
  @currency
end

#currency_conversionObject (readonly)

Currency conversion details for [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing) sessions created before 2025-03-31.



2315
2316
2317
# File 'lib/stripe/resources/checkout/session.rb', line 2315

def currency_conversion
  @currency_conversion
end

#custom_fieldsObject (readonly)

Collect additional information from your customer using custom fields. Up to 3 fields are supported.



2317
2318
2319
# File 'lib/stripe/resources/checkout/session.rb', line 2317

def custom_fields
  @custom_fields
end

#custom_textObject (readonly)

Attribute for field custom_text



2319
2320
2321
# File 'lib/stripe/resources/checkout/session.rb', line 2319

def custom_text
  @custom_text
end

#customerObject (readonly)

The ID of the customer for this Session. For Checkout Sessions in ‘subscription` mode or Checkout Sessions with `customer_creation` set as `always` in `payment` mode, Checkout will create a new customer object based on information provided during the payment flow unless an existing customer was provided when the Session was created.



2325
2326
2327
# File 'lib/stripe/resources/checkout/session.rb', line 2325

def customer
  @customer
end

#customer_accountObject (readonly)

The ID of the account for this Session.



2327
2328
2329
# File 'lib/stripe/resources/checkout/session.rb', line 2327

def 
  @customer_account
end

#customer_creationObject (readonly)

Configure whether a Checkout Session creates a Customer when the Checkout Session completes.



2329
2330
2331
# File 'lib/stripe/resources/checkout/session.rb', line 2329

def customer_creation
  @customer_creation
end

#customer_detailsObject (readonly)

The customer details including the customer’s tax exempt status and the customer’s tax IDs. Customer’s address details are not present on Sessions in ‘setup` mode.



2331
2332
2333
# File 'lib/stripe/resources/checkout/session.rb', line 2331

def customer_details
  @customer_details
end

#customer_emailObject (readonly)

If provided, this value will be used when the Customer object is created. If not provided, customers will be asked to enter their email address. Use this parameter to prefill customer data if you already have an email on file. To access information about the customer once the payment flow is complete, use the ‘customer` attribute.



2337
2338
2339
# File 'lib/stripe/resources/checkout/session.rb', line 2337

def customer_email
  @customer_email
end

#discountsObject (readonly)

List of coupons and promotion codes attached to the Checkout Session.



2339
2340
2341
# File 'lib/stripe/resources/checkout/session.rb', line 2339

def discounts
  @discounts
end

#excluded_payment_method_typesObject (readonly)

A list of the types of payment methods (e.g., ‘card`) that should be excluded from this Checkout Session. This should only be used when payment methods for this Checkout Session are managed through the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



2341
2342
2343
# File 'lib/stripe/resources/checkout/session.rb', line 2341

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expires_atObject (readonly)

The timestamp at which the Checkout Session will expire.



2343
2344
2345
# File 'lib/stripe/resources/checkout/session.rb', line 2343

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



2345
2346
2347
# File 'lib/stripe/resources/checkout/session.rb', line 2345

def id
  @id
end

#invoiceObject (readonly)

ID of the invoice created by the Checkout Session, if it exists.



2347
2348
2349
# File 'lib/stripe/resources/checkout/session.rb', line 2347

def invoice
  @invoice
end

#invoice_creationObject (readonly)

Details on the state of invoice creation for the Checkout Session.



2349
2350
2351
# File 'lib/stripe/resources/checkout/session.rb', line 2349

def invoice_creation
  @invoice_creation
end

#line_itemsObject (readonly)

The line items purchased by the customer.



2351
2352
2353
# File 'lib/stripe/resources/checkout/session.rb', line 2351

def line_items
  @line_items
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2353
2354
2355
# File 'lib/stripe/resources/checkout/session.rb', line 2353

def livemode
  @livemode
end

#localeObject (readonly)

The IETF language tag of the locale Checkout is displayed in. If blank or ‘auto`, the browser’s locale is used.



2355
2356
2357
# File 'lib/stripe/resources/checkout/session.rb', line 2355

def locale
  @locale
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2357
2358
2359
# File 'lib/stripe/resources/checkout/session.rb', line 2357

def 
  @metadata
end

#modeObject (readonly)

The mode of the Checkout Session.



2359
2360
2361
# File 'lib/stripe/resources/checkout/session.rb', line 2359

def mode
  @mode
end

#name_collectionObject (readonly)

Attribute for field name_collection



2361
2362
2363
# File 'lib/stripe/resources/checkout/session.rb', line 2361

def name_collection
  @name_collection
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2363
2364
2365
# File 'lib/stripe/resources/checkout/session.rb', line 2363

def object
  @object
end

#optional_itemsObject (readonly)

The optional items presented to the customer at checkout.



2365
2366
2367
# File 'lib/stripe/resources/checkout/session.rb', line 2365

def optional_items
  @optional_items
end

#origin_contextObject (readonly)

Where the user is coming from. This informs the optimizations that are applied to the session.



2367
2368
2369
# File 'lib/stripe/resources/checkout/session.rb', line 2367

def origin_context
  @origin_context
end

#payment_intentObject (readonly)

The ID of the PaymentIntent for Checkout Sessions in ‘payment` mode. You can’t confirm or cancel the PaymentIntent for a Checkout Session. To cancel, [expire the Checkout Session](stripe.com/docs/api/checkout/sessions/expire) instead.



2369
2370
2371
# File 'lib/stripe/resources/checkout/session.rb', line 2369

def payment_intent
  @payment_intent
end

The ID of the Payment Link that created this Session.



2371
2372
2373
# File 'lib/stripe/resources/checkout/session.rb', line 2371

def payment_link
  @payment_link
end

#payment_method_collectionObject (readonly)

Configure whether a Checkout Session should collect a payment method. Defaults to ‘always`.



2373
2374
2375
# File 'lib/stripe/resources/checkout/session.rb', line 2373

def payment_method_collection
  @payment_method_collection
end

#payment_method_configuration_detailsObject (readonly)

Information about the payment method configuration used for this Checkout session if using dynamic payment methods.



2375
2376
2377
# File 'lib/stripe/resources/checkout/session.rb', line 2375

def payment_method_configuration_details
  @payment_method_configuration_details
end

#payment_method_optionsObject (readonly)

Payment-method-specific configuration for the PaymentIntent or SetupIntent of this CheckoutSession.



2377
2378
2379
# File 'lib/stripe/resources/checkout/session.rb', line 2377

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

A list of the types of payment methods (e.g. card) this Checkout Session is allowed to accept.



2380
2381
2382
# File 'lib/stripe/resources/checkout/session.rb', line 2380

def payment_method_types
  @payment_method_types
end

#payment_statusObject (readonly)

The payment status of the Checkout Session, one of ‘paid`, `unpaid`, or `no_payment_required`. You can use this value to decide when to fulfill your customer’s order.



2383
2384
2385
# File 'lib/stripe/resources/checkout/session.rb', line 2383

def payment_status
  @payment_status
end

#permissionsObject (readonly)

This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object.

For specific permissions, please refer to their dedicated subsections, such as ‘permissions.update_shipping_details`.



2387
2388
2389
# File 'lib/stripe/resources/checkout/session.rb', line 2387

def permissions
  @permissions
end

#phone_number_collectionObject (readonly)

Attribute for field phone_number_collection



2389
2390
2391
# File 'lib/stripe/resources/checkout/session.rb', line 2389

def phone_number_collection
  @phone_number_collection
end

#presentment_detailsObject (readonly)

Attribute for field presentment_details



2391
2392
2393
# File 'lib/stripe/resources/checkout/session.rb', line 2391

def presentment_details
  @presentment_details
end

#recovered_fromObject (readonly)

The ID of the original expired Checkout Session that triggered the recovery flow.



2393
2394
2395
# File 'lib/stripe/resources/checkout/session.rb', line 2393

def recovered_from
  @recovered_from
end

#redirect_on_completionObject (readonly)

This parameter applies to ‘ui_mode: embedded`. Learn more about the [redirect behavior](stripe.com/docs/payments/checkout/custom-success-page?payment-ui=embedded-form) of embedded sessions. Defaults to `always`.



2395
2396
2397
# File 'lib/stripe/resources/checkout/session.rb', line 2395

def redirect_on_completion
  @redirect_on_completion
end

#return_urlObject (readonly)

Applies to Checkout Sessions with ‘ui_mode: embedded` or `ui_mode: custom`. The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.



2397
2398
2399
# File 'lib/stripe/resources/checkout/session.rb', line 2397

def return_url
  @return_url
end

#saved_payment_method_optionsObject (readonly)

Controls saved payment method settings for the session. Only available in ‘payment` and `subscription` mode.



2399
2400
2401
# File 'lib/stripe/resources/checkout/session.rb', line 2399

def saved_payment_method_options
  @saved_payment_method_options
end

#setup_intentObject (readonly)

The ID of the SetupIntent for Checkout Sessions in ‘setup` mode. You can’t confirm or cancel the SetupIntent for a Checkout Session. To cancel, [expire the Checkout Session](stripe.com/docs/api/checkout/sessions/expire) instead.



2401
2402
2403
# File 'lib/stripe/resources/checkout/session.rb', line 2401

def setup_intent
  @setup_intent
end

#shipping_address_collectionObject (readonly)

When set, provides configuration for Checkout to collect a shipping address from a customer.



2403
2404
2405
# File 'lib/stripe/resources/checkout/session.rb', line 2403

def shipping_address_collection
  @shipping_address_collection
end

#shipping_costObject (readonly)

The details of the customer cost of shipping, including the customer chosen ShippingRate.



2405
2406
2407
# File 'lib/stripe/resources/checkout/session.rb', line 2405

def shipping_cost
  @shipping_cost
end

#shipping_optionsObject (readonly)

The shipping rate options applied to this Session.



2407
2408
2409
# File 'lib/stripe/resources/checkout/session.rb', line 2407

def shipping_options
  @shipping_options
end

#statusObject (readonly)

The status of the Checkout Session, one of ‘open`, `complete`, or `expired`.



2409
2410
2411
# File 'lib/stripe/resources/checkout/session.rb', line 2409

def status
  @status
end

#submit_typeObject (readonly)

Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button. ‘submit_type` can only be specified on Checkout Sessions in `payment` mode. If blank or `auto`, `pay` is used.



2413
2414
2415
# File 'lib/stripe/resources/checkout/session.rb', line 2413

def submit_type
  @submit_type
end

#subscriptionObject (readonly)

The ID of the [Subscription](stripe.com/docs/api/subscriptions) for Checkout Sessions in ‘subscription` mode.



2415
2416
2417
# File 'lib/stripe/resources/checkout/session.rb', line 2415

def subscription
  @subscription
end

#success_urlObject (readonly)

The URL the customer will be directed to after the payment or subscription creation is successful.



2418
2419
2420
# File 'lib/stripe/resources/checkout/session.rb', line 2418

def success_url
  @success_url
end

#tax_id_collectionObject (readonly)

Attribute for field tax_id_collection



2420
2421
2422
# File 'lib/stripe/resources/checkout/session.rb', line 2420

def tax_id_collection
  @tax_id_collection
end

#total_detailsObject (readonly)

Tax and discount details for the computed total amount.



2422
2423
2424
# File 'lib/stripe/resources/checkout/session.rb', line 2422

def total_details
  @total_details
end

#ui_modeObject (readonly)

The UI mode of the Session. Defaults to ‘hosted`.



2424
2425
2426
# File 'lib/stripe/resources/checkout/session.rb', line 2424

def ui_mode
  @ui_mode
end

#urlObject (readonly)

The URL to the Checkout Session. Applies to Checkout Sessions with ‘ui_mode: hosted`. Redirect customers to this URL to take them to Checkout. If you’re using [Custom Domains](stripe.com/docs/payments/checkout/custom-domains), the URL will use your subdomain. Otherwise, it’ll use `checkout.stripe.com.` This value is only present when the session is active.



2427
2428
2429
# File 'lib/stripe/resources/checkout/session.rb', line 2427

def url
  @url
end

#wallet_optionsObject (readonly)

Wallet-specific configuration for this Checkout Session.



2429
2430
2431
# File 'lib/stripe/resources/checkout/session.rb', line 2429

def wallet_options
  @wallet_options
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a Checkout Session object.



2434
2435
2436
2437
2438
2439
2440
2441
# File 'lib/stripe/resources/checkout/session.rb', line 2434

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/checkout/sessions",
    params: params,
    opts: opts
  )
end

.expire(session, params = {}, opts = {}) ⇒ Object

A Checkout Session can be expired when it is in one of these statuses: open

After it expires, a customer can’t complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.



2458
2459
2460
2461
2462
2463
2464
2465
# File 'lib/stripe/resources/checkout/session.rb', line 2458

def self.expire(session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s/expire", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



2542
2543
2544
# File 'lib/stripe/resources/checkout/session.rb', line 2542

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
# File 'lib/stripe/resources/checkout/session.rb', line 2509

def self.inner_class_types
  @inner_class_types = {
    adaptive_pricing: AdaptivePricing,
    after_expiration: AfterExpiration,
    automatic_tax: AutomaticTax,
    branding_settings: BrandingSettings,
    collected_information: CollectedInformation,
    consent: Consent,
    consent_collection: ConsentCollection,
    currency_conversion: CurrencyConversion,
    custom_fields: CustomField,
    custom_text: CustomText,
    customer_details: CustomerDetails,
    discounts: Discount,
    invoice_creation: InvoiceCreation,
    name_collection: NameCollection,
    optional_items: OptionalItem,
    payment_method_configuration_details: PaymentMethodConfigurationDetails,
    payment_method_options: PaymentMethodOptions,
    permissions: Permissions,
    phone_number_collection: PhoneNumberCollection,
    presentment_details: PresentmentDetails,
    saved_payment_method_options: SavedPaymentMethodOptions,
    shipping_address_collection: ShippingAddressCollection,
    shipping_cost: ShippingCost,
    shipping_options: ShippingOption,
    tax_id_collection: TaxIdCollection,
    total_details: TotalDetails,
    wallet_options: WalletOptions,
    checkout_items: CheckoutItem,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Checkout Sessions.



2468
2469
2470
2471
2472
2473
2474
2475
# File 'lib/stripe/resources/checkout/session.rb', line 2468

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/checkout/sessions",
    params: params,
    opts: opts
  )
end

.list_line_items(session, params = {}, opts = {}) ⇒ Object

When retrieving a Checkout Session, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



2488
2489
2490
2491
2492
2493
2494
2495
# File 'lib/stripe/resources/checkout/session.rb', line 2488

def self.list_line_items(session, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/checkout/sessions/%<session>s/line_items", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



26
27
28
# File 'lib/stripe/resources/checkout/session.rb', line 26

def self.object_name
  "checkout.session"
end

.update(session, params = {}, opts = {}) ⇒ Object

Updates a Checkout Session object.

Related guide: [Dynamically update Checkout](docs.stripe.com/payments/checkout/dynamic-updates)



2500
2501
2502
2503
2504
2505
2506
2507
# File 'lib/stripe/resources/checkout/session.rb', line 2500

def self.update(session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#expire(params = {}, opts = {}) ⇒ Object

A Checkout Session can be expired when it is in one of these statuses: open

After it expires, a customer can’t complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.



2446
2447
2448
2449
2450
2451
2452
2453
# File 'lib/stripe/resources/checkout/session.rb', line 2446

def expire(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s/expire", { session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#list_line_items(params = {}, opts = {}) ⇒ Object

When retrieving a Checkout Session, there is an includable line_items property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



2478
2479
2480
2481
2482
2483
2484
2485
# File 'lib/stripe/resources/checkout/session.rb', line 2478

def list_line_items(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/checkout/sessions/%<session>s/line_items", { session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end