Class: Stripe::Checkout::Session::AutomaticSurcharge
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::AutomaticSurcharge
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#calculation_basis ⇒ Object
readonly
Determines which amount serves as the basis for calculating the surcharge.
-
#enabled ⇒ Object
readonly
Indicates whether automatic surcharge is enabled for the session.
-
#provider ⇒ Object
readonly
The surcharge provider used for this session.
-
#status ⇒ Object
readonly
The status of the most recent surcharge calculation for this session.
-
#tax_behavior ⇒ Object
readonly
Specifies whether the surcharge is considered inclusive or exclusive of taxes.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#calculation_basis ⇒ Object (readonly)
Determines which amount serves as the basis for calculating the surcharge.
78 79 80 |
# File 'lib/stripe/resources/checkout/session.rb', line 78 def calculation_basis @calculation_basis end |
#enabled ⇒ Object (readonly)
Indicates whether automatic surcharge is enabled for the session.
80 81 82 |
# File 'lib/stripe/resources/checkout/session.rb', line 80 def enabled @enabled end |
#provider ⇒ Object (readonly)
The surcharge provider used for this session.
82 83 84 |
# File 'lib/stripe/resources/checkout/session.rb', line 82 def provider @provider end |
#status ⇒ Object (readonly)
The status of the most recent surcharge calculation for this session.
84 85 86 |
# File 'lib/stripe/resources/checkout/session.rb', line 84 def status @status end |
#tax_behavior ⇒ Object (readonly)
Specifies whether the surcharge is considered inclusive or exclusive of taxes.
86 87 88 |
# File 'lib/stripe/resources/checkout/session.rb', line 86 def tax_behavior @tax_behavior end |
Class Method Details
.field_remappings ⇒ Object
92 93 94 |
# File 'lib/stripe/resources/checkout/session.rb', line 92 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
88 89 90 |
# File 'lib/stripe/resources/checkout/session.rb', line 88 def self.inner_class_types @inner_class_types = {} end |