Class: Stripe::Checkout::Session::AutomaticTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::AutomaticTax
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address_collection_precision ⇒ Object
readonly
Controls how much address information Checkout collects when automatic tax is enabled.
-
#enabled ⇒ Object
readonly
Indicates whether automatic tax is enabled for the session.
-
#liability ⇒ Object
readonly
The account that's liable for tax.
-
#provider ⇒ Object
readonly
The tax provider powering automatic tax.
-
#status ⇒ Object
readonly
The status of the most recent automated tax calculation for this session.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address_collection_precision ⇒ Object (readonly)
Controls how much address information Checkout collects when automatic tax is enabled.
113 114 115 |
# File 'lib/stripe/resources/checkout/session.rb', line 113 def address_collection_precision @address_collection_precision end |
#enabled ⇒ Object (readonly)
Indicates whether automatic tax is enabled for the session
115 116 117 |
# File 'lib/stripe/resources/checkout/session.rb', line 115 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that's liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
117 118 119 |
# File 'lib/stripe/resources/checkout/session.rb', line 117 def liability @liability end |
#provider ⇒ Object (readonly)
The tax provider powering automatic tax.
119 120 121 |
# File 'lib/stripe/resources/checkout/session.rb', line 119 def provider @provider end |
#status ⇒ Object (readonly)
The status of the most recent automated tax calculation for this session.
121 122 123 |
# File 'lib/stripe/resources/checkout/session.rb', line 121 def status @status end |
Class Method Details
.field_remappings ⇒ Object
127 128 129 |
# File 'lib/stripe/resources/checkout/session.rb', line 127 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
123 124 125 |
# File 'lib/stripe/resources/checkout/session.rb', line 123 def self.inner_class_types @inner_class_types = { liability: Liability } end |