Class: Stripe::Checkout::Session::ConsentCollection
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::ConsentCollection
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: PaymentMethodReuseAgreement
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payment_method_reuse_agreement ⇒ Object
readonly
If set to
hidden, it will hide legal text related to the reuse of a payment method. -
#promotions ⇒ Object
readonly
If set to
auto, enables the collection of customer consent for promotional communications. -
#terms_of_service ⇒ Object
readonly
If set to
required, it requires customers to accept the terms of service before being able to pay.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payment_method_reuse_agreement ⇒ Object (readonly)
If set to hidden, it will hide legal text related to the reuse of a payment method.
296 297 298 |
# File 'lib/stripe/resources/checkout/session.rb', line 296 def payment_method_reuse_agreement @payment_method_reuse_agreement end |
#promotions ⇒ Object (readonly)
If set to auto, enables the collection of customer consent for promotional communications. The Checkout
Session will determine whether to display an option to opt into promotional communication
from the merchant depending on the customer's locale. Only available to US merchants and US customers.
300 301 302 |
# File 'lib/stripe/resources/checkout/session.rb', line 300 def promotions @promotions end |
#terms_of_service ⇒ Object (readonly)
If set to required, it requires customers to accept the terms of service before being able to pay.
302 303 304 |
# File 'lib/stripe/resources/checkout/session.rb', line 302 def terms_of_service @terms_of_service end |
Class Method Details
.field_remappings ⇒ Object
308 309 310 |
# File 'lib/stripe/resources/checkout/session.rb', line 308 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
304 305 306 |
# File 'lib/stripe/resources/checkout/session.rb', line 304 def self.inner_class_types @inner_class_types = { payment_method_reuse_agreement: PaymentMethodReuseAgreement } end |