Class: Stripe::Checkout::Session::ConsentCollection
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::ConsentCollection
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: PaymentMethodReuseAgreement
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payment_method_reuse_agreement ⇒ Object
readonly
If set to ‘hidden`, it will hide legal text related to the reuse of a payment method.
-
#promotions ⇒ Object
readonly
If set to ‘auto`, enables the collection of customer consent for promotional communications.
-
#terms_of_service ⇒ Object
readonly
If set to ‘required`, it requires customers to accept the terms of service before being able to pay.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payment_method_reuse_agreement ⇒ Object (readonly)
If set to ‘hidden`, it will hide legal text related to the reuse of a payment method.
125 126 127 |
# File 'lib/stripe/resources/checkout/session.rb', line 125 def payment_method_reuse_agreement @payment_method_reuse_agreement end |
#promotions ⇒ Object (readonly)
If set to ‘auto`, enables the collection of customer consent for promotional communications. The Checkout Session will determine whether to display an option to opt into promotional communication from the merchant depending on the customer’s locale. Only available to US merchants.
129 130 131 |
# File 'lib/stripe/resources/checkout/session.rb', line 129 def promotions @promotions end |
#terms_of_service ⇒ Object (readonly)
If set to ‘required`, it requires customers to accept the terms of service before being able to pay.
131 132 133 |
# File 'lib/stripe/resources/checkout/session.rb', line 131 def terms_of_service @terms_of_service end |