Class: Stripe::Checkout::Session::ConsentCollection::PaymentMethodReuseAgreement

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#positionObject (readonly)

Determines the position and visibility of the payment method reuse agreement in the UI. When set to auto, Stripe's defaults will be used.

When set to hidden, the payment method reuse agreement text will always be hidden in the UI.



262
263
264
# File 'lib/stripe/resources/checkout/session.rb', line 262

def position
  @position
end

Class Method Details

.field_remappingsObject



268
269
270
# File 'lib/stripe/resources/checkout/session.rb', line 268

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



264
265
266
# File 'lib/stripe/resources/checkout/session.rb', line 264

def self.inner_class_types
  @inner_class_types = {}
end