Class: Stripe::Checkout::Session::ConsentCollection::PaymentMethodReuseAgreement
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::ConsentCollection::PaymentMethodReuseAgreement
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#position ⇒ Object
readonly
Determines the position and visibility of the payment method reuse agreement in the UI.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#position ⇒ Object (readonly)
Determines the position and visibility of the payment method reuse agreement in the UI. When set to auto, Stripe's defaults will be used.
When set to hidden, the payment method reuse agreement text will always be hidden in the UI.
262 263 264 |
# File 'lib/stripe/resources/checkout/session.rb', line 262 def position @position end |
Class Method Details
.field_remappings ⇒ Object
268 269 270 |
# File 'lib/stripe/resources/checkout/session.rb', line 268 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
264 265 266 |
# File 'lib/stripe/resources/checkout/session.rb', line 264 def self.inner_class_types @inner_class_types = {} end |