Class: Stripe::Checkout::Session::ConsentCollection::PaymentMethodReuseAgreement

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#positionObject (readonly)

Determines the position and visibility of the payment method reuse agreement in the UI. When set to ‘auto`, Stripe’s defaults will be used.

When set to ‘hidden`, the payment method reuse agreement text will always be hidden in the UI.



107
108
109
# File 'lib/stripe/resources/checkout/session.rb', line 107

def position
  @position
end