Class: Stripe::Checkout::Session::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdaptivePricing, AfterExpiration, AutomaticTax, ConsentCollection, CustomField, CustomText, CustomerUpdate, Discount, InvoiceCreation, LineItem, OptionalItem, PaymentIntentData, PaymentMethodData, PaymentMethodOptions, Permissions, PhoneNumberCollection, SavedPaymentMethodOptions, SetupIntentData, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, WalletOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adaptive_pricing: nil, after_expiration: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, cancel_url: nil, client_reference_id: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_text: nil, customer: nil, customer_creation: nil, customer_email: nil, customer_update: nil, discounts: nil, expand: nil, expires_at: nil, invoice_creation: nil, line_items: nil, locale: nil, metadata: nil, mode: nil, optional_items: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, permissions: nil, phone_number_collection: nil, redirect_on_completion: nil, return_url: nil, saved_payment_method_options: nil, setup_intent_data: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, success_url: nil, tax_id_collection: nil, ui_mode: nil, wallet_options: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



3164
3165
3166
3167
3168
3169
3170
3171
3172
3173
3174
3175
3176
3177
3178
3179
3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
3195
3196
3197
3198
3199
3200
3201
3202
3203
3204
3205
3206
3207
3208
3209
3210
3211
3212
3213
3214
3215
3216
3217
3218
3219
3220
3221
3222
3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
3234
3235
3236
3237
3238
3239
3240
3241
3242
3243
3244
3245
3246
3247
3248
3249
3250
3251
3252
3253
3254
# File 'lib/stripe/resources/checkout/session.rb', line 3164

def initialize(
  adaptive_pricing: nil,
  after_expiration: nil,
  allow_promotion_codes: nil,
  automatic_tax: nil,
  billing_address_collection: nil,
  cancel_url: nil,
  client_reference_id: nil,
  consent_collection: nil,
  currency: nil,
  custom_fields: nil,
  custom_text: nil,
  customer: nil,
  customer_creation: nil,
  customer_email: nil,
  customer_update: nil,
  discounts: nil,
  expand: nil,
  expires_at: nil,
  invoice_creation: nil,
  line_items: nil,
  locale: nil,
  metadata: nil,
  mode: nil,
  optional_items: nil,
  payment_intent_data: nil,
  payment_method_collection: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  permissions: nil,
  phone_number_collection: nil,
  redirect_on_completion: nil,
  return_url: nil,
  saved_payment_method_options: nil,
  setup_intent_data: nil,
  shipping_address_collection: nil,
  shipping_options: nil,
  submit_type: nil,
  subscription_data: nil,
  success_url: nil,
  tax_id_collection: nil,
  ui_mode: nil,
  wallet_options: nil
)
  @adaptive_pricing = adaptive_pricing
  @after_expiration = after_expiration
  @allow_promotion_codes = allow_promotion_codes
  @automatic_tax = automatic_tax
  @billing_address_collection = billing_address_collection
  @cancel_url = cancel_url
  @client_reference_id = client_reference_id
  @consent_collection = consent_collection
  @currency = currency
  @custom_fields = custom_fields
  @custom_text = custom_text
  @customer = customer
  @customer_creation = customer_creation
  @customer_email = customer_email
  @customer_update = customer_update
  @discounts = discounts
  @expand = expand
  @expires_at = expires_at
  @invoice_creation = invoice_creation
  @line_items = line_items
  @locale = locale
  @metadata = 
  @mode = mode
  @optional_items = optional_items
  @payment_intent_data = payment_intent_data
  @payment_method_collection = payment_method_collection
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @permissions = permissions
  @phone_number_collection = phone_number_collection
  @redirect_on_completion = redirect_on_completion
  @return_url = return_url
  @saved_payment_method_options = saved_payment_method_options
  @setup_intent_data = setup_intent_data
  @shipping_address_collection = shipping_address_collection
  @shipping_options = shipping_options
  @submit_type = submit_type
  @subscription_data = subscription_data
  @success_url = success_url
  @tax_id_collection = tax_id_collection
  @ui_mode = ui_mode
  @wallet_options = wallet_options
end

Instance Attribute Details

#adaptive_pricingObject

Settings for price localization with [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing).



3013
3014
3015
# File 'lib/stripe/resources/checkout/session.rb', line 3013

def adaptive_pricing
  @adaptive_pricing
end

#after_expirationObject

Configure actions after a Checkout Session has expired.



3015
3016
3017
# File 'lib/stripe/resources/checkout/session.rb', line 3015

def after_expiration
  @after_expiration
end

#allow_promotion_codesObject

Enables user redeemable promotion codes.



3017
3018
3019
# File 'lib/stripe/resources/checkout/session.rb', line 3017

def allow_promotion_codes
  @allow_promotion_codes
end

#automatic_taxObject

Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.



3019
3020
3021
# File 'lib/stripe/resources/checkout/session.rb', line 3019

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject

Specify whether Checkout should collect the customer’s billing address. Defaults to ‘auto`.



3021
3022
3023
# File 'lib/stripe/resources/checkout/session.rb', line 3021

def billing_address_collection
  @billing_address_collection
end

#cancel_urlObject

If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website. This parameter is not allowed if ui_mode is ‘embedded` or `custom`.



3023
3024
3025
# File 'lib/stripe/resources/checkout/session.rb', line 3023

def cancel_url
  @cancel_url
end

#client_reference_idObject

A unique string to reference the Checkout Session. This can be a customer ID, a cart ID, or similar, and can be used to reconcile the session with your internal systems.



3027
3028
3029
# File 'lib/stripe/resources/checkout/session.rb', line 3027

def client_reference_id
  @client_reference_id
end

Configure fields for the Checkout Session to gather active consent from customers.



3029
3030
3031
# File 'lib/stripe/resources/checkout/session.rb', line 3029

def consent_collection
  @consent_collection
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Required in ‘setup` mode when `payment_method_types` is not set.



3031
3032
3033
# File 'lib/stripe/resources/checkout/session.rb', line 3031

def currency
  @currency
end

#custom_fieldsObject

Collect additional information from your customer using custom fields. Up to 3 fields are supported.



3033
3034
3035
# File 'lib/stripe/resources/checkout/session.rb', line 3033

def custom_fields
  @custom_fields
end

#custom_textObject

Display additional text for your customers using custom text.



3035
3036
3037
# File 'lib/stripe/resources/checkout/session.rb', line 3035

def custom_text
  @custom_text
end

#customerObject

ID of an existing Customer, if one exists. In ‘payment` mode, the customer’s most recently saved card payment method will be used to prefill the email, name, card details, and billing address on the Checkout page. In `subscription` mode, the customer’s [default payment method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) will be used if it’s a card, otherwise the most recently saved card will be used. A valid billing address, billing name and billing email are required on the payment method for Checkout to prefill the customer’s card details.

If the Customer already has a valid [email](stripe.com/docs/api/customers/object#customer_object-email) set, the email will be prefilled and not editable in Checkout. If the Customer does not have a valid ‘email`, Checkout will set the email entered during the session on the Customer.

If blank for Checkout Sessions in ‘subscription` mode or with `customer_creation` set as `always` in `payment` mode, Checkout will create a new Customer object based on information provided during the payment flow.

You can set [‘payment_intent_data.setup_future_usage`](stripe.com/docs/api/checkout/sessions/create#create_checkout_session-payment_intent_data-setup_future_usage) to have Checkout automatically attach the payment method to the Customer you pass in for future reuse.



3047
3048
3049
# File 'lib/stripe/resources/checkout/session.rb', line 3047

def customer
  @customer
end

#customer_creationObject

Configure whether a Checkout Session creates a [Customer](stripe.com/docs/api/customers) during Session confirmation.

When a Customer is not created, you can still retrieve email, address, and other customer data entered in Checkout with [customer_details](stripe.com/docs/api/checkout/sessions/object#checkout_session_object-customer_details).

Sessions that don’t create Customers instead are grouped by [guest customers](stripe.com/docs/payments/checkout/guest-customers) in the Dashboard. Promotion codes limited to first time customers will return invalid for these Sessions.

Can only be set in ‘payment` and `setup` mode.



3057
3058
3059
# File 'lib/stripe/resources/checkout/session.rb', line 3057

def customer_creation
  @customer_creation
end

#customer_emailObject

If provided, this value will be used when the Customer object is created. If not provided, customers will be asked to enter their email address. Use this parameter to prefill customer data if you already have an email on file. To access information about the customer once a session is complete, use the ‘customer` field.



3063
3064
3065
# File 'lib/stripe/resources/checkout/session.rb', line 3063

def customer_email
  @customer_email
end

#customer_updateObject

Controls what fields on Customer can be updated by the Checkout Session. Can only be provided when ‘customer` is provided.



3065
3066
3067
# File 'lib/stripe/resources/checkout/session.rb', line 3065

def customer_update
  @customer_update
end

#discountsObject

The coupon or promotion code to apply to this Session. Currently, only up to one may be specified.



3067
3068
3069
# File 'lib/stripe/resources/checkout/session.rb', line 3067

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



3069
3070
3071
# File 'lib/stripe/resources/checkout/session.rb', line 3069

def expand
  @expand
end

#expires_atObject

The Epoch time in seconds at which the Checkout Session will expire. It can be anywhere from 30 minutes to 24 hours after Checkout Session creation. By default, this value is 24 hours from creation.



3071
3072
3073
# File 'lib/stripe/resources/checkout/session.rb', line 3071

def expires_at
  @expires_at
end

#invoice_creationObject

Generate a post-purchase Invoice for one-time payments.



3073
3074
3075
# File 'lib/stripe/resources/checkout/session.rb', line 3073

def invoice_creation
  @invoice_creation
end

#line_itemsObject

A list of items the customer is purchasing. Use this parameter to pass one-time or recurring [Prices](stripe.com/docs/api/prices).

For ‘payment` mode, there is a maximum of 100 line items, however it is recommended to consolidate line items if there are more than a few dozen.

For ‘subscription` mode, there is a maximum of 20 line items with recurring Prices and 20 line items with one-time Prices. Line items with one-time Prices will be on the initial invoice only.



3079
3080
3081
# File 'lib/stripe/resources/checkout/session.rb', line 3079

def line_items
  @line_items
end

#localeObject

The IETF language tag of the locale Checkout is displayed in. If blank or ‘auto`, the browser’s locale is used.



3081
3082
3083
# File 'lib/stripe/resources/checkout/session.rb', line 3081

def locale
  @locale
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3083
3084
3085
# File 'lib/stripe/resources/checkout/session.rb', line 3083

def 
  @metadata
end

#modeObject

The mode of the Checkout Session. Pass ‘subscription` if the Checkout Session includes at least one recurring item.



3085
3086
3087
# File 'lib/stripe/resources/checkout/session.rb', line 3085

def mode
  @mode
end

#optional_itemsObject

A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring [Prices](stripe.com/docs/api/prices).

There is a maximum of 10 optional items allowed on a Checkout Session, and the existing limits on the number of line items allowed on a Checkout Session apply to the combined number of line items and optional items.

For ‘payment` mode, there is a maximum of 100 combined line items and optional items, however it is recommended to consolidate items if there are more than a few dozen.

For ‘subscription` mode, there is a maximum of 20 line items and optional items with recurring Prices and 20 line items and optional items with one-time Prices.



3093
3094
3095
# File 'lib/stripe/resources/checkout/session.rb', line 3093

def optional_items
  @optional_items
end

#payment_intent_dataObject

A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.



3095
3096
3097
# File 'lib/stripe/resources/checkout/session.rb', line 3095

def payment_intent_data
  @payment_intent_data
end

#payment_method_collectionObject

Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0. This may occur if the Checkout Session includes a free trial or a discount.

Can only be set in ‘subscription` mode. Defaults to `always`.

If you’d like information on how to collect a payment method outside of Checkout, read the guide on configuring [subscriptions with a free trial](stripe.com/docs/payments/checkout/free-trials).



3102
3103
3104
# File 'lib/stripe/resources/checkout/session.rb', line 3102

def payment_method_collection
  @payment_method_collection
end

#payment_method_configurationObject

The ID of the payment method configuration to use with this Checkout session.



3104
3105
3106
# File 'lib/stripe/resources/checkout/session.rb', line 3104

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

This parameter allows you to set some attributes on the payment method created during a Checkout session.



3106
3107
3108
# File 'lib/stripe/resources/checkout/session.rb', line 3106

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration.



3108
3109
3110
# File 'lib/stripe/resources/checkout/session.rb', line 3108

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

A list of the types of payment methods (e.g., ‘card`) this Checkout Session can accept.

You can omit this attribute to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). See [Dynamic Payment Methods](stripe.com/docs/payments/payment-methods/integration-options#using-dynamic-payment-methods) for more details.

Read more about the supported payment methods and their requirements in our [payment method details guide](/docs/payments/checkout/payment-methods).

If multiple payment methods are passed, Checkout will dynamically reorder them to prioritize the most relevant payment methods based on the customer’s location and other characteristics.



3120
3121
3122
# File 'lib/stripe/resources/checkout/session.rb', line 3120

def payment_method_types
  @payment_method_types
end

#permissionsObject

This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object. Can only be set when creating ‘embedded` or `custom` sessions.

For specific permissions, please refer to their dedicated subsections, such as ‘permissions.update_shipping_details`.



3124
3125
3126
# File 'lib/stripe/resources/checkout/session.rb', line 3124

def permissions
  @permissions
end

#phone_number_collectionObject

Controls phone number collection settings for the session.

We recommend that you review your privacy policy and check with your legal contacts before using this feature. Learn more about [collecting phone numbers with Checkout](stripe.com/docs/payments/checkout/phone-numbers).



3129
3130
3131
# File 'lib/stripe/resources/checkout/session.rb', line 3129

def phone_number_collection
  @phone_number_collection
end

#redirect_on_completionObject

This parameter applies to ‘ui_mode: embedded`. Learn more about the [redirect behavior](stripe.com/docs/payments/checkout/custom-success-page?payment-ui=embedded-form) of embedded sessions. Defaults to `always`.



3131
3132
3133
# File 'lib/stripe/resources/checkout/session.rb', line 3131

def redirect_on_completion
  @redirect_on_completion
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. This parameter is required if ‘ui_mode` is `embedded` or `custom` and redirect-based payment methods are enabled on the session.



3135
3136
3137
# File 'lib/stripe/resources/checkout/session.rb', line 3135

def return_url
  @return_url
end

#saved_payment_method_optionsObject

Controls saved payment method settings for the session. Only available in ‘payment` and `subscription` mode.



3137
3138
3139
# File 'lib/stripe/resources/checkout/session.rb', line 3137

def saved_payment_method_options
  @saved_payment_method_options
end

#setup_intent_dataObject

A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in ‘setup` mode.



3139
3140
3141
# File 'lib/stripe/resources/checkout/session.rb', line 3139

def setup_intent_data
  @setup_intent_data
end

#shipping_address_collectionObject

When set, provides configuration for Checkout to collect a shipping address from a customer.



3141
3142
3143
# File 'lib/stripe/resources/checkout/session.rb', line 3141

def shipping_address_collection
  @shipping_address_collection
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



3143
3144
3145
# File 'lib/stripe/resources/checkout/session.rb', line 3143

def shipping_options
  @shipping_options
end

#submit_typeObject

Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button.

`submit_type` can only be specified on Checkout Sessions in

‘payment` or `subscription` mode. If blank or `auto`, `pay` is used.



3148
3149
3150
# File 'lib/stripe/resources/checkout/session.rb', line 3148

def submit_type
  @submit_type
end

#subscription_dataObject

A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.



3150
3151
3152
# File 'lib/stripe/resources/checkout/session.rb', line 3150

def subscription_data
  @subscription_data
end

#success_urlObject

The URL to which Stripe should send customers when payment or setup is complete. This parameter is not allowed if ui_mode is ‘embedded` or `custom`. If you’d like to use information from the successful Checkout Session on your page, read the guide on [customizing your success page](stripe.com/docs/payments/checkout/custom-success-page).



3156
3157
3158
# File 'lib/stripe/resources/checkout/session.rb', line 3156

def success_url
  @success_url
end

#tax_id_collectionObject

Controls tax ID collection during checkout.



3158
3159
3160
# File 'lib/stripe/resources/checkout/session.rb', line 3158

def tax_id_collection
  @tax_id_collection
end

#ui_modeObject

The UI mode of the Session. Defaults to ‘hosted`.



3160
3161
3162
# File 'lib/stripe/resources/checkout/session.rb', line 3160

def ui_mode
  @ui_mode
end

#wallet_optionsObject

Wallet-specific configuration.



3162
3163
3164
# File 'lib/stripe/resources/checkout/session.rb', line 3162

def wallet_options
  @wallet_options
end