Class: Stripe::Checkout::Session::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AdaptivePricing, AfterExpiration, AutomaticTax, ConsentCollection, CustomField, CustomText, CustomerUpdate, Discount, InvoiceCreation, LineItem, PaymentIntentData, PaymentMethodData, PaymentMethodOptions, Permissions, PhoneNumberCollection, SavedPaymentMethodOptions, SetupIntentData, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection
Instance Attribute Summary collapse
-
#adaptive_pricing ⇒ Object
Settings for price localization with [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing).
-
#after_expiration ⇒ Object
Configure actions after a Checkout Session has expired.
-
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
-
#billing_address_collection ⇒ Object
Specify whether Checkout should collect the customer’s billing address.
-
#cancel_url ⇒ Object
If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website.
-
#client_reference_id ⇒ Object
A unique string to reference the Checkout Session.
-
#consent_collection ⇒ Object
Configure fields for the Checkout Session to gather active consent from customers.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields.
-
#custom_text ⇒ Object
Display additional text for your customers using custom text.
-
#customer ⇒ Object
ID of an existing Customer, if one exists.
-
#customer_creation ⇒ Object
Configure whether a Checkout Session creates a [Customer](stripe.com/docs/api/customers) during Session confirmation.
-
#customer_email ⇒ Object
If provided, this value will be used when the Customer object is created.
-
#customer_update ⇒ Object
Controls what fields on Customer can be updated by the Checkout Session.
-
#discounts ⇒ Object
The coupon or promotion code to apply to this Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
The Epoch time in seconds at which the Checkout Session will expire.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#locale ⇒ Object
The IETF language tag of the locale Checkout is displayed in.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#mode ⇒ Object
The mode of the Checkout Session.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
-
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method.
-
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this Checkout session.
-
#payment_method_data ⇒ Object
This parameter allows you to set some attributes on the payment method created during a Checkout session.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration.
-
#payment_method_types ⇒ Object
A list of the types of payment methods (e.g., ‘card`) this Checkout Session can accept.
-
#permissions ⇒ Object
This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object.
-
#phone_number_collection ⇒ Object
Controls phone number collection settings for the session.
-
#redirect_on_completion ⇒ Object
This parameter applies to ‘ui_mode: embedded`.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#saved_payment_method_options ⇒ Object
Controls saved payment method settings for the session.
-
#setup_intent_data ⇒ Object
A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in ‘setup` mode.
-
#shipping_address_collection ⇒ Object
When set, provides configuration for Checkout to collect a shipping address from a customer.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
-
#submit_type ⇒ Object
Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
-
#success_url ⇒ Object
The URL to which Stripe should send customers when payment or setup is complete.
-
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
-
#ui_mode ⇒ Object
The UI mode of the Session.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(adaptive_pricing: nil, after_expiration: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, cancel_url: nil, client_reference_id: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_text: nil, customer: nil, customer_creation: nil, customer_email: nil, customer_update: nil, discounts: nil, expand: nil, expires_at: nil, invoice_creation: nil, line_items: nil, locale: nil, metadata: nil, mode: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, permissions: nil, phone_number_collection: nil, redirect_on_completion: nil, return_url: nil, saved_payment_method_options: nil, setup_intent_data: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, success_url: nil, tax_id_collection: nil, ui_mode: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 3332 3333 |
# File 'lib/stripe/resources/checkout/session.rb', line 3247 def initialize( adaptive_pricing: nil, after_expiration: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, cancel_url: nil, client_reference_id: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_text: nil, customer: nil, customer_creation: nil, customer_email: nil, customer_update: nil, discounts: nil, expand: nil, expires_at: nil, invoice_creation: nil, line_items: nil, locale: nil, metadata: nil, mode: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, permissions: nil, phone_number_collection: nil, redirect_on_completion: nil, return_url: nil, saved_payment_method_options: nil, setup_intent_data: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, success_url: nil, tax_id_collection: nil, ui_mode: nil ) @adaptive_pricing = adaptive_pricing @after_expiration = after_expiration @allow_promotion_codes = allow_promotion_codes @automatic_tax = automatic_tax @billing_address_collection = billing_address_collection @cancel_url = cancel_url @client_reference_id = client_reference_id @consent_collection = @currency = currency @custom_fields = custom_fields @custom_text = custom_text @customer = customer @customer_creation = customer_creation @customer_email = customer_email @customer_update = customer_update @discounts = discounts @expand = @expires_at = expires_at @invoice_creation = invoice_creation @line_items = line_items @locale = locale @metadata = @mode = mode @payment_intent_data = payment_intent_data @payment_method_collection = payment_method_collection @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @permissions = @phone_number_collection = phone_number_collection @redirect_on_completion = redirect_on_completion @return_url = return_url @saved_payment_method_options = @setup_intent_data = setup_intent_data @shipping_address_collection = shipping_address_collection @shipping_options = @submit_type = submit_type @subscription_data = subscription_data @success_url = success_url @tax_id_collection = tax_id_collection @ui_mode = ui_mode end |
Instance Attribute Details
#adaptive_pricing ⇒ Object
Settings for price localization with [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing).
3107 3108 3109 |
# File 'lib/stripe/resources/checkout/session.rb', line 3107 def adaptive_pricing @adaptive_pricing end |
#after_expiration ⇒ Object
Configure actions after a Checkout Session has expired.
3109 3110 3111 |
# File 'lib/stripe/resources/checkout/session.rb', line 3109 def after_expiration @after_expiration end |
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
3111 3112 3113 |
# File 'lib/stripe/resources/checkout/session.rb', line 3111 def allow_promotion_codes @allow_promotion_codes end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
3113 3114 3115 |
# File 'lib/stripe/resources/checkout/session.rb', line 3113 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object
Specify whether Checkout should collect the customer’s billing address. Defaults to ‘auto`.
3115 3116 3117 |
# File 'lib/stripe/resources/checkout/session.rb', line 3115 def billing_address_collection @billing_address_collection end |
#cancel_url ⇒ Object
If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website. This parameter is not allowed if ui_mode is ‘embedded` or `custom`.
3117 3118 3119 |
# File 'lib/stripe/resources/checkout/session.rb', line 3117 def cancel_url @cancel_url end |
#client_reference_id ⇒ Object
A unique string to reference the Checkout Session. This can be a customer ID, a cart ID, or similar, and can be used to reconcile the session with your internal systems.
3121 3122 3123 |
# File 'lib/stripe/resources/checkout/session.rb', line 3121 def client_reference_id @client_reference_id end |
#consent_collection ⇒ Object
Configure fields for the Checkout Session to gather active consent from customers.
3123 3124 3125 |
# File 'lib/stripe/resources/checkout/session.rb', line 3123 def @consent_collection end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Required in ‘setup` mode when `payment_method_types` is not set.
3125 3126 3127 |
# File 'lib/stripe/resources/checkout/session.rb', line 3125 def currency @currency end |
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields. Up to 3 fields are supported.
3127 3128 3129 |
# File 'lib/stripe/resources/checkout/session.rb', line 3127 def custom_fields @custom_fields end |
#custom_text ⇒ Object
Display additional text for your customers using custom text.
3129 3130 3131 |
# File 'lib/stripe/resources/checkout/session.rb', line 3129 def custom_text @custom_text end |
#customer ⇒ Object
ID of an existing Customer, if one exists. In ‘payment` mode, the customer’s most recently saved card payment method will be used to prefill the email, name, card details, and billing address on the Checkout page. In `subscription` mode, the customer’s [default payment method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) will be used if it’s a card, otherwise the most recently saved card will be used. A valid billing address, billing name and billing email are required on the payment method for Checkout to prefill the customer’s card details.
If the Customer already has a valid [email](stripe.com/docs/api/customers/object#customer_object-email) set, the email will be prefilled and not editable in Checkout. If the Customer does not have a valid ‘email`, Checkout will set the email entered during the session on the Customer.
If blank for Checkout Sessions in ‘subscription` mode or with `customer_creation` set as `always` in `payment` mode, Checkout will create a new Customer object based on information provided during the payment flow.
You can set [‘payment_intent_data.setup_future_usage`](stripe.com/docs/api/checkout/sessions/create#create_checkout_session-payment_intent_data-setup_future_usage) to have Checkout automatically attach the payment method to the Customer you pass in for future reuse.
3141 3142 3143 |
# File 'lib/stripe/resources/checkout/session.rb', line 3141 def customer @customer end |
#customer_creation ⇒ Object
Configure whether a Checkout Session creates a [Customer](stripe.com/docs/api/customers) during Session confirmation.
When a Customer is not created, you can still retrieve email, address, and other customer data entered in Checkout with [customer_details](stripe.com/docs/api/checkout/sessions/object#checkout_session_object-customer_details).
Sessions that don’t create Customers instead are grouped by [guest customers](stripe.com/docs/payments/checkout/guest-customers) in the Dashboard. Promotion codes limited to first time customers will return invalid for these Sessions.
Can only be set in ‘payment` and `setup` mode.
3151 3152 3153 |
# File 'lib/stripe/resources/checkout/session.rb', line 3151 def customer_creation @customer_creation end |
#customer_email ⇒ Object
If provided, this value will be used when the Customer object is created. If not provided, customers will be asked to enter their email address. Use this parameter to prefill customer data if you already have an email on file. To access information about the customer once a session is complete, use the ‘customer` field.
3157 3158 3159 |
# File 'lib/stripe/resources/checkout/session.rb', line 3157 def customer_email @customer_email end |
#customer_update ⇒ Object
Controls what fields on Customer can be updated by the Checkout Session. Can only be provided when ‘customer` is provided.
3159 3160 3161 |
# File 'lib/stripe/resources/checkout/session.rb', line 3159 def customer_update @customer_update end |
#discounts ⇒ Object
The coupon or promotion code to apply to this Session. Currently, only up to one may be specified.
3161 3162 3163 |
# File 'lib/stripe/resources/checkout/session.rb', line 3161 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3163 3164 3165 |
# File 'lib/stripe/resources/checkout/session.rb', line 3163 def @expand end |
#expires_at ⇒ Object
The Epoch time in seconds at which the Checkout Session will expire. It can be anywhere from 30 minutes to 24 hours after Checkout Session creation. By default, this value is 24 hours from creation.
3165 3166 3167 |
# File 'lib/stripe/resources/checkout/session.rb', line 3165 def expires_at @expires_at end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
3167 3168 3169 |
# File 'lib/stripe/resources/checkout/session.rb', line 3167 def invoice_creation @invoice_creation end |
#line_items ⇒ Object
A list of items the customer is purchasing. Use this parameter to pass one-time or recurring [Prices](stripe.com/docs/api/prices).
For ‘payment` mode, there is a maximum of 100 line items, however it is recommended to consolidate line items if there are more than a few dozen.
For ‘subscription` mode, there is a maximum of 20 line items with recurring Prices and 20 line items with one-time Prices. Line items with one-time Prices will be on the initial invoice only.
3173 3174 3175 |
# File 'lib/stripe/resources/checkout/session.rb', line 3173 def line_items @line_items end |
#locale ⇒ Object
The IETF language tag of the locale Checkout is displayed in. If blank or ‘auto`, the browser’s locale is used.
3175 3176 3177 |
# File 'lib/stripe/resources/checkout/session.rb', line 3175 def locale @locale end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3177 3178 3179 |
# File 'lib/stripe/resources/checkout/session.rb', line 3177 def @metadata end |
#mode ⇒ Object
The mode of the Checkout Session. Pass ‘subscription` if the Checkout Session includes at least one recurring item.
3179 3180 3181 |
# File 'lib/stripe/resources/checkout/session.rb', line 3179 def mode @mode end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
3181 3182 3183 |
# File 'lib/stripe/resources/checkout/session.rb', line 3181 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0. This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in ‘subscription` mode. Defaults to `always`.
If you’d like information on how to collect a payment method outside of Checkout, read the guide on configuring [subscriptions with a free trial](stripe.com/docs/payments/checkout/free-trials).
3188 3189 3190 |
# File 'lib/stripe/resources/checkout/session.rb', line 3188 def payment_method_collection @payment_method_collection end |
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this Checkout session.
3190 3191 3192 |
# File 'lib/stripe/resources/checkout/session.rb', line 3190 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
This parameter allows you to set some attributes on the payment method created during a Checkout session.
3192 3193 3194 |
# File 'lib/stripe/resources/checkout/session.rb', line 3192 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration.
3194 3195 3196 |
# File 'lib/stripe/resources/checkout/session.rb', line 3194 def @payment_method_options end |
#payment_method_types ⇒ Object
A list of the types of payment methods (e.g., ‘card`) this Checkout Session can accept.
You can omit this attribute to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). See [Dynamic Payment Methods](stripe.com/docs/payments/payment-methods/integration-options#using-dynamic-payment-methods) for more details.
Read more about the supported payment methods and their requirements in our [payment method details guide](/docs/payments/checkout/payment-methods).
If multiple payment methods are passed, Checkout will dynamically reorder them to prioritize the most relevant payment methods based on the customer’s location and other characteristics.
3206 3207 3208 |
# File 'lib/stripe/resources/checkout/session.rb', line 3206 def payment_method_types @payment_method_types end |
#permissions ⇒ Object
This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object.
For specific permissions, please refer to their dedicated subsections, such as ‘permissions.update.shipping_details`.
3210 3211 3212 |
# File 'lib/stripe/resources/checkout/session.rb', line 3210 def @permissions end |
#phone_number_collection ⇒ Object
Controls phone number collection settings for the session.
We recommend that you review your privacy policy and check with your legal contacts before using this feature. Learn more about [collecting phone numbers with Checkout](stripe.com/docs/payments/checkout/phone-numbers).
3215 3216 3217 |
# File 'lib/stripe/resources/checkout/session.rb', line 3215 def phone_number_collection @phone_number_collection end |
#redirect_on_completion ⇒ Object
This parameter applies to ‘ui_mode: embedded`. Learn more about the [redirect behavior](stripe.com/docs/payments/checkout/custom-success-page?payment-ui=embedded-form) of embedded sessions. Defaults to `always`.
3217 3218 3219 |
# File 'lib/stripe/resources/checkout/session.rb', line 3217 def redirect_on_completion @redirect_on_completion end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. This parameter is required if ‘ui_mode` is `embedded` or `custom` and redirect-based payment methods are enabled on the session.
3221 3222 3223 |
# File 'lib/stripe/resources/checkout/session.rb', line 3221 def return_url @return_url end |
#saved_payment_method_options ⇒ Object
Controls saved payment method settings for the session. Only available in ‘payment` and `subscription` mode.
3223 3224 3225 |
# File 'lib/stripe/resources/checkout/session.rb', line 3223 def @saved_payment_method_options end |
#setup_intent_data ⇒ Object
A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in ‘setup` mode.
3225 3226 3227 |
# File 'lib/stripe/resources/checkout/session.rb', line 3225 def setup_intent_data @setup_intent_data end |
#shipping_address_collection ⇒ Object
When set, provides configuration for Checkout to collect a shipping address from a customer.
3227 3228 3229 |
# File 'lib/stripe/resources/checkout/session.rb', line 3227 def shipping_address_collection @shipping_address_collection end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
3229 3230 3231 |
# File 'lib/stripe/resources/checkout/session.rb', line 3229 def @shipping_options end |
#submit_type ⇒ Object
Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button. ‘submit_type` can only be specified on Checkout Sessions in `payment` mode. If blank or `auto`, `pay` is used.
3233 3234 3235 |
# File 'lib/stripe/resources/checkout/session.rb', line 3233 def submit_type @submit_type end |
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
3235 3236 3237 |
# File 'lib/stripe/resources/checkout/session.rb', line 3235 def subscription_data @subscription_data end |
#success_url ⇒ Object
The URL to which Stripe should send customers when payment or setup is complete. This parameter is not allowed if ui_mode is ‘embedded` or `custom`. If you’d like to use information from the successful Checkout Session on your page, read the guide on [customizing your success page](stripe.com/docs/payments/checkout/custom-success-page).
3241 3242 3243 |
# File 'lib/stripe/resources/checkout/session.rb', line 3241 def success_url @success_url end |
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
3243 3244 3245 |
# File 'lib/stripe/resources/checkout/session.rb', line 3243 def tax_id_collection @tax_id_collection end |
#ui_mode ⇒ Object
The UI mode of the Session. Defaults to ‘hosted`.
3245 3246 3247 |
# File 'lib/stripe/resources/checkout/session.rb', line 3245 def ui_mode @ui_mode end |