Class: Stripe::Checkout::Session::CreateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1172 1173 1174 1175 |
# File 'lib/stripe/resources/checkout/session.rb', line 1172 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.
Enabling this parameter causes Checkout to collect any billing address information necessary for tax calculation.
1168 1169 1170 |
# File 'lib/stripe/resources/checkout/session.rb', line 1168 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
1170 1171 1172 |
# File 'lib/stripe/resources/checkout/session.rb', line 1170 def liability @liability end |