Class: Stripe::Checkout::Session::CreateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1255 1256 1257 1258 |
# File 'lib/stripe/resources/checkout/session.rb', line 1255 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.
Enabling this parameter causes Checkout to collect any billing address information necessary for tax calculation.
1251 1252 1253 |
# File 'lib/stripe/resources/checkout/session.rb', line 1251 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
1253 1254 1255 |
# File 'lib/stripe/resources/checkout/session.rb', line 1253 def liability @liability end |