Class: Stripe::Checkout::Session::CreateParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



1209
1210
1211
1212
# File 'lib/stripe/resources/checkout/session.rb', line 1209

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.

Enabling this parameter causes Checkout to collect any billing address information necessary for tax calculation.



1205
1206
1207
# File 'lib/stripe/resources/checkout/session.rb', line 1205

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



1207
1208
1209
# File 'lib/stripe/resources/checkout/session.rb', line 1207

def liability
  @liability
end