Class: Stripe::Checkout::Session::CreateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1202 1203 1204 1205 |
# File 'lib/stripe/resources/checkout/session.rb', line 1202 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Set to ‘true` to [calculate tax automatically](docs.stripe.com/tax) using the customer’s location.
Enabling this parameter causes Checkout to collect any billing address information necessary for tax calculation.
1198 1199 1200 |
# File 'lib/stripe/resources/checkout/session.rb', line 1198 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
1200 1201 1202 |
# File 'lib/stripe/resources/checkout/session.rb', line 1200 def liability @liability end |