Class: Stripe::Checkout::Session::CreateParams::ConsentCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::ConsentCollection
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: PaymentMethodReuseAgreement
Instance Attribute Summary collapse
-
#payment_method_reuse_agreement ⇒ Object
Determines the display of payment method reuse agreement text in the UI.
-
#promotions ⇒ Object
If set to ‘auto`, enables the collection of customer consent for promotional communications.
-
#terms_of_service ⇒ Object
If set to ‘required`, it requires customers to check a terms of service checkbox before being able to pay.
Instance Method Summary collapse
-
#initialize(payment_method_reuse_agreement: nil, promotions: nil, terms_of_service: nil) ⇒ ConsentCollection
constructor
A new instance of ConsentCollection.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_method_reuse_agreement: nil, promotions: nil, terms_of_service: nil) ⇒ ConsentCollection
Returns a new instance of ConsentCollection.
1416 1417 1418 1419 1420 1421 1422 1423 1424 |
# File 'lib/stripe/resources/checkout/session.rb', line 1416 def initialize( payment_method_reuse_agreement: nil, promotions: nil, terms_of_service: nil ) @payment_method_reuse_agreement = payment_method_reuse_agreement @promotions = promotions @terms_of_service = terms_of_service end |
Instance Attribute Details
#payment_method_reuse_agreement ⇒ Object
Determines the display of payment method reuse agreement text in the UI. If set to ‘hidden`, it will hide legal text related to the reuse of a payment method.
1405 1406 1407 |
# File 'lib/stripe/resources/checkout/session.rb', line 1405 def payment_method_reuse_agreement @payment_method_reuse_agreement end |
#promotions ⇒ Object
If set to ‘auto`, enables the collection of customer consent for promotional communications. The Checkout Session will determine whether to display an option to opt into promotional communication from the merchant depending on the customer’s locale. Only available to US merchants.
1410 1411 1412 |
# File 'lib/stripe/resources/checkout/session.rb', line 1410 def promotions @promotions end |
#terms_of_service ⇒ Object
If set to ‘required`, it requires customers to check a terms of service checkbox before being able to pay. There must be a valid terms of service URL set in your [Dashboard settings](dashboard.stripe.com/settings/public).
1414 1415 1416 |
# File 'lib/stripe/resources/checkout/session.rb', line 1414 def terms_of_service @terms_of_service end |