Class: Stripe::Checkout::Session::CreateParams::ConsentCollection::PaymentMethodReuseAgreement

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(position: nil) ⇒ PaymentMethodReuseAgreement

Returns a new instance of PaymentMethodReuseAgreement.



1182
1183
1184
# File 'lib/stripe/resources/checkout/session.rb', line 1182

def initialize(position: nil)
  @position = position
end

Instance Attribute Details

#positionObject

Determines the position and visibility of the payment method reuse agreement in the UI. When set to ‘auto`, Stripe’s defaults will be used. When set to ‘hidden`, the payment method reuse agreement text will always be hidden in the UI.



1180
1181
1182
# File 'lib/stripe/resources/checkout/session.rb', line 1180

def position
  @position
end