Class: Stripe::Checkout::Session::CreateParams::CustomField
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomField
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Dropdown, Label, Numeric, Text
Instance Attribute Summary collapse
-
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
-
#key ⇒ Object
String of your choice that your integration can use to reconcile this field.
-
#label ⇒ Object
The label for the field, displayed to the customer.
-
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
-
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session.
-
#text ⇒ Object
Configuration for ‘type=text` fields.
-
#type ⇒ Object
The type of the field.
Instance Method Summary collapse
-
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
constructor
A new instance of CustomField.
Methods inherited from RequestParams
Constructor Details
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
Returns a new instance of CustomField.
1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 |
# File 'lib/stripe/resources/checkout/session.rb', line 1515 def initialize( dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil ) @dropdown = dropdown @key = key @label = label @numeric = numeric @optional = optional @text = text @type = type end |
Instance Attribute Details
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
1501 1502 1503 |
# File 'lib/stripe/resources/checkout/session.rb', line 1501 def dropdown @dropdown end |
#key ⇒ Object
String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
1503 1504 1505 |
# File 'lib/stripe/resources/checkout/session.rb', line 1503 def key @key end |
#label ⇒ Object
The label for the field, displayed to the customer.
1505 1506 1507 |
# File 'lib/stripe/resources/checkout/session.rb', line 1505 def label @label end |
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
1507 1508 1509 |
# File 'lib/stripe/resources/checkout/session.rb', line 1507 def numeric @numeric end |
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.
1509 1510 1511 |
# File 'lib/stripe/resources/checkout/session.rb', line 1509 def optional @optional end |
#text ⇒ Object
Configuration for ‘type=text` fields.
1511 1512 1513 |
# File 'lib/stripe/resources/checkout/session.rb', line 1511 def text @text end |
#type ⇒ Object
The type of the field.
1513 1514 1515 |
# File 'lib/stripe/resources/checkout/session.rb', line 1513 def type @type end |