Class: Stripe::Checkout::Session::CreateParams::CustomField
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomField
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Dropdown, Label, Numeric, Text
Instance Attribute Summary collapse
-
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
-
#key ⇒ Object
String of your choice that your integration can use to reconcile this field.
-
#label ⇒ Object
The label for the field, displayed to the customer.
-
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
-
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session.
-
#text ⇒ Object
Configuration for ‘type=text` fields.
-
#type ⇒ Object
The type of the field.
Instance Method Summary collapse
-
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
constructor
A new instance of CustomField.
Methods inherited from RequestParams
Constructor Details
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
Returns a new instance of CustomField.
1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 |
# File 'lib/stripe/resources/checkout/session.rb', line 1372 def initialize( dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil ) @dropdown = dropdown @key = key @label = label @numeric = numeric @optional = optional @text = text @type = type end |
Instance Attribute Details
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
1358 1359 1360 |
# File 'lib/stripe/resources/checkout/session.rb', line 1358 def dropdown @dropdown end |
#key ⇒ Object
String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
1360 1361 1362 |
# File 'lib/stripe/resources/checkout/session.rb', line 1360 def key @key end |
#label ⇒ Object
The label for the field, displayed to the customer.
1362 1363 1364 |
# File 'lib/stripe/resources/checkout/session.rb', line 1362 def label @label end |
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
1364 1365 1366 |
# File 'lib/stripe/resources/checkout/session.rb', line 1364 def numeric @numeric end |
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.
1366 1367 1368 |
# File 'lib/stripe/resources/checkout/session.rb', line 1366 def optional @optional end |
#text ⇒ Object
Configuration for ‘type=text` fields.
1368 1369 1370 |
# File 'lib/stripe/resources/checkout/session.rb', line 1368 def text @text end |
#type ⇒ Object
The type of the field.
1370 1371 1372 |
# File 'lib/stripe/resources/checkout/session.rb', line 1370 def type @type end |