Class: Stripe::Checkout::Session::CreateParams::CustomField

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField

Returns a new instance of CustomField.



1362
1363
1364
1365
1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
# File 'lib/stripe/resources/checkout/session.rb', line 1362

def initialize(
  dropdown: nil,
  key: nil,
  label: nil,
  numeric: nil,
  optional: nil,
  text: nil,
  type: nil
)
  @dropdown = dropdown
  @key = key
  @label = label
  @numeric = numeric
  @optional = optional
  @text = text
  @type = type
end

Instance Attribute Details

Configuration for ‘type=dropdown` fields.



1348
1349
1350
# File 'lib/stripe/resources/checkout/session.rb', line 1348

def dropdown
  @dropdown
end

#keyObject

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



1350
1351
1352
# File 'lib/stripe/resources/checkout/session.rb', line 1350

def key
  @key
end

#labelObject

The label for the field, displayed to the customer.



1352
1353
1354
# File 'lib/stripe/resources/checkout/session.rb', line 1352

def label
  @label
end

#numericObject

Configuration for ‘type=numeric` fields.



1354
1355
1356
# File 'lib/stripe/resources/checkout/session.rb', line 1354

def numeric
  @numeric
end

#optionalObject

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



1356
1357
1358
# File 'lib/stripe/resources/checkout/session.rb', line 1356

def optional
  @optional
end

#textObject

Configuration for ‘type=text` fields.



1358
1359
1360
# File 'lib/stripe/resources/checkout/session.rb', line 1358

def text
  @text
end

#typeObject

The type of the field.



1360
1361
1362
# File 'lib/stripe/resources/checkout/session.rb', line 1360

def type
  @type
end