Class: Stripe::Checkout::Session::CreateParams::CustomField
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomField
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Dropdown, Label, Numeric, Text
Instance Attribute Summary collapse
-
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
-
#key ⇒ Object
String of your choice that your integration can use to reconcile this field.
-
#label ⇒ Object
The label for the field, displayed to the customer.
-
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
-
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session.
-
#text ⇒ Object
Configuration for ‘type=text` fields.
-
#type ⇒ Object
The type of the field.
Instance Method Summary collapse
-
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
constructor
A new instance of CustomField.
Methods inherited from RequestParams
Constructor Details
#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField
Returns a new instance of CustomField.
1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 |
# File 'lib/stripe/resources/checkout/session.rb', line 1336 def initialize( dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil ) @dropdown = dropdown @key = key @label = label @numeric = numeric @optional = optional @text = text @type = type end |
Instance Attribute Details
#dropdown ⇒ Object
Configuration for ‘type=dropdown` fields.
1322 1323 1324 |
# File 'lib/stripe/resources/checkout/session.rb', line 1322 def dropdown @dropdown end |
#key ⇒ Object
String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
1324 1325 1326 |
# File 'lib/stripe/resources/checkout/session.rb', line 1324 def key @key end |
#label ⇒ Object
The label for the field, displayed to the customer.
1326 1327 1328 |
# File 'lib/stripe/resources/checkout/session.rb', line 1326 def label @label end |
#numeric ⇒ Object
Configuration for ‘type=numeric` fields.
1328 1329 1330 |
# File 'lib/stripe/resources/checkout/session.rb', line 1328 def numeric @numeric end |
#optional ⇒ Object
Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.
1330 1331 1332 |
# File 'lib/stripe/resources/checkout/session.rb', line 1330 def optional @optional end |
#text ⇒ Object
Configuration for ‘type=text` fields.
1332 1333 1334 |
# File 'lib/stripe/resources/checkout/session.rb', line 1332 def text @text end |
#type ⇒ Object
The type of the field.
1334 1335 1336 |
# File 'lib/stripe/resources/checkout/session.rb', line 1334 def type @type end |