Class: Stripe::Checkout::Session::CreateParams::CustomField::Dropdown::Option
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomField::Dropdown::Option
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#label ⇒ Object
The label for the option, displayed to the customer.
-
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer.
Instance Method Summary collapse
-
#initialize(label: nil, value: nil) ⇒ Option
constructor
A new instance of Option.
Methods inherited from RequestParams
Constructor Details
#initialize(label: nil, value: nil) ⇒ Option
Returns a new instance of Option.
1205 1206 1207 1208 |
# File 'lib/stripe/resources/checkout/session.rb', line 1205 def initialize(label: nil, value: nil) @label = label @value = value end |
Instance Attribute Details
#label ⇒ Object
The label for the option, displayed to the customer. Up to 100 characters.
1201 1202 1203 |
# File 'lib/stripe/resources/checkout/session.rb', line 1201 def label @label end |
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.
1203 1204 1205 |
# File 'lib/stripe/resources/checkout/session.rb', line 1203 def value @value end |