Class: Stripe::Checkout::Session::CreateParams::CustomField::Dropdown::Option
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomField::Dropdown::Option
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#label ⇒ Object
The label for the option, displayed to the customer.
-
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer.
Instance Method Summary collapse
-
#initialize(label: nil, value: nil) ⇒ Option
constructor
A new instance of Option.
Methods inherited from RequestParams
Constructor Details
#initialize(label: nil, value: nil) ⇒ Option
Returns a new instance of Option.
1282 1283 1284 1285 |
# File 'lib/stripe/resources/checkout/session.rb', line 1282 def initialize(label: nil, value: nil) @label = label @value = value end |
Instance Attribute Details
#label ⇒ Object
The label for the option, displayed to the customer. Up to 100 characters.
1278 1279 1280 |
# File 'lib/stripe/resources/checkout/session.rb', line 1278 def label @label end |
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.
1280 1281 1282 |
# File 'lib/stripe/resources/checkout/session.rb', line 1280 def value @value end |