Class: Stripe::Checkout::Session::CreateParams::CustomField::Dropdown::Option

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(label: nil, value: nil) ⇒ Option

Returns a new instance of Option.



1186
1187
1188
1189
# File 'lib/stripe/resources/checkout/session.rb', line 1186

def initialize(label: nil, value: nil)
  @label = label
  @value = value
end

Instance Attribute Details

#labelObject

The label for the option, displayed to the customer. Up to 100 characters.



1182
1183
1184
# File 'lib/stripe/resources/checkout/session.rb', line 1182

def label
  @label
end

#valueObject

The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.



1184
1185
1186
# File 'lib/stripe/resources/checkout/session.rb', line 1184

def value
  @value
end