Class: Stripe::Checkout::Session::CreateParams::CustomField::Label
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomField::Label
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#custom ⇒ Object
Custom text for the label, displayed to the customer.
-
#type ⇒ Object
The type of the label.
Instance Method Summary collapse
-
#initialize(custom: nil, type: nil) ⇒ Label
constructor
A new instance of Label.
Methods inherited from RequestParams
Constructor Details
#initialize(custom: nil, type: nil) ⇒ Label
Returns a new instance of Label.
1295 1296 1297 1298 |
# File 'lib/stripe/resources/checkout/session.rb', line 1295 def initialize(custom: nil, type: nil) @custom = custom @type = type end |
Instance Attribute Details
#custom ⇒ Object
Custom text for the label, displayed to the customer. Up to 50 characters.
1291 1292 1293 |
# File 'lib/stripe/resources/checkout/session.rb', line 1291 def custom @custom end |
#type ⇒ Object
The type of the label.
1293 1294 1295 |
# File 'lib/stripe/resources/checkout/session.rb', line 1293 def type @type end |