Class: Stripe::Checkout::Session::CreateParams::CustomField::Label
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomField::Label
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#custom ⇒ Object
Custom text for the label, displayed to the customer.
-
#type ⇒ Object
The type of the label.
Instance Method Summary collapse
-
#initialize(custom: nil, type: nil) ⇒ Label
constructor
A new instance of Label.
Methods inherited from RequestParams
Constructor Details
#initialize(custom: nil, type: nil) ⇒ Label
Returns a new instance of Label.
1262 1263 1264 1265 |
# File 'lib/stripe/resources/checkout/session.rb', line 1262 def initialize(custom: nil, type: nil) @custom = custom @type = type end |
Instance Attribute Details
#custom ⇒ Object
Custom text for the label, displayed to the customer. Up to 50 characters.
1258 1259 1260 |
# File 'lib/stripe/resources/checkout/session.rb', line 1258 def custom @custom end |
#type ⇒ Object
The type of the label.
1260 1261 1262 |
# File 'lib/stripe/resources/checkout/session.rb', line 1260 def type @type end |