Class: Stripe::Checkout::Session::CreateParams::CustomerUpdate
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::CustomerUpdate
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#address ⇒ Object
Describes whether Checkout saves the billing address onto ‘customer.address`.
-
#name ⇒ Object
Describes whether Checkout saves the name onto ‘customer.name`.
-
#shipping ⇒ Object
Describes whether Checkout saves shipping information onto ‘customer.shipping`.
Instance Method Summary collapse
-
#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate
constructor
A new instance of CustomerUpdate.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate
Returns a new instance of CustomerUpdate.
1602 1603 1604 1605 1606 |
# File 'lib/stripe/resources/checkout/session.rb', line 1602 def initialize(address: nil, name: nil, shipping: nil) @address = address @name = name @shipping = shipping end |
Instance Attribute Details
#address ⇒ Object
Describes whether Checkout saves the billing address onto ‘customer.address`. To always collect a full billing address, use `billing_address_collection`. Defaults to `never`.
1595 1596 1597 |
# File 'lib/stripe/resources/checkout/session.rb', line 1595 def address @address end |
#name ⇒ Object
Describes whether Checkout saves the name onto ‘customer.name`. Defaults to `never`.
1597 1598 1599 |
# File 'lib/stripe/resources/checkout/session.rb', line 1597 def name @name end |
#shipping ⇒ Object
Describes whether Checkout saves shipping information onto ‘customer.shipping`. To collect shipping information, use `shipping_address_collection`. Defaults to `never`.
1600 1601 1602 |
# File 'lib/stripe/resources/checkout/session.rb', line 1600 def shipping @shipping end |