Class: Stripe::Checkout::Session::CreateParams::CustomerUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate

Returns a new instance of CustomerUpdate.



1374
1375
1376
1377
1378
# File 'lib/stripe/resources/checkout/session.rb', line 1374

def initialize(address: nil, name: nil, shipping: nil)
  @address = address
  @name = name
  @shipping = shipping
end

Instance Attribute Details

#addressObject

Describes whether Checkout saves the billing address onto ‘customer.address`. To always collect a full billing address, use `billing_address_collection`. Defaults to `never`.



1367
1368
1369
# File 'lib/stripe/resources/checkout/session.rb', line 1367

def address
  @address
end

#nameObject

Describes whether Checkout saves the name onto ‘customer.name`. Defaults to `never`.



1369
1370
1371
# File 'lib/stripe/resources/checkout/session.rb', line 1369

def name
  @name
end

#shippingObject

Describes whether Checkout saves shipping information onto ‘customer.shipping`. To collect shipping information, use `shipping_address_collection`. Defaults to `never`.



1372
1373
1374
# File 'lib/stripe/resources/checkout/session.rb', line 1372

def shipping
  @shipping
end