Class: Stripe::Checkout::Session::CreateParams::CustomerUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate

Returns a new instance of CustomerUpdate.



1345
1346
1347
1348
1349
# File 'lib/stripe/resources/checkout/session.rb', line 1345

def initialize(address: nil, name: nil, shipping: nil)
  @address = address
  @name = name
  @shipping = shipping
end

Instance Attribute Details

#addressObject

Describes whether Checkout saves the billing address onto ‘customer.address`. To always collect a full billing address, use `billing_address_collection`. Defaults to `never`.



1338
1339
1340
# File 'lib/stripe/resources/checkout/session.rb', line 1338

def address
  @address
end

#nameObject

Describes whether Checkout saves the name onto ‘customer.name`. Defaults to `never`.



1340
1341
1342
# File 'lib/stripe/resources/checkout/session.rb', line 1340

def name
  @name
end

#shippingObject

Describes whether Checkout saves shipping information onto ‘customer.shipping`. To collect shipping information, use `shipping_address_collection`. Defaults to `never`.



1343
1344
1345
# File 'lib/stripe/resources/checkout/session.rb', line 1343

def shipping
  @shipping
end