Class: Stripe::Checkout::Session::CreateParams::CustomerUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate

Returns a new instance of CustomerUpdate.



1423
1424
1425
1426
1427
# File 'lib/stripe/resources/checkout/session.rb', line 1423

def initialize(address: nil, name: nil, shipping: nil)
  @address = address
  @name = name
  @shipping = shipping
end

Instance Attribute Details

#addressObject

Describes whether Checkout saves the billing address onto ‘customer.address`. To always collect a full billing address, use `billing_address_collection`. Defaults to `never`.



1416
1417
1418
# File 'lib/stripe/resources/checkout/session.rb', line 1416

def address
  @address
end

#nameObject

Describes whether Checkout saves the name onto ‘customer.name`. Defaults to `never`.



1418
1419
1420
# File 'lib/stripe/resources/checkout/session.rb', line 1418

def name
  @name
end

#shippingObject

Describes whether Checkout saves shipping information onto ‘customer.shipping`. To collect shipping information, use `shipping_address_collection`. Defaults to `never`.



1421
1422
1423
# File 'lib/stripe/resources/checkout/session.rb', line 1421

def shipping
  @shipping
end