Class: Stripe::Checkout::Session::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::Discount
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The ID of the coupon to apply to this Session.
-
#promotion_code ⇒ Object
The ID of a promotion code to apply to this Session.
Instance Method Summary collapse
-
#initialize(coupon: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1472 1473 1474 1475 |
# File 'lib/stripe/resources/checkout/session.rb', line 1472 def initialize(coupon: nil, promotion_code: nil) @coupon = coupon @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The ID of the coupon to apply to this Session.
1468 1469 1470 |
# File 'lib/stripe/resources/checkout/session.rb', line 1468 def coupon @coupon end |
#promotion_code ⇒ Object
The ID of a promotion code to apply to this Session.
1470 1471 1472 |
# File 'lib/stripe/resources/checkout/session.rb', line 1470 def promotion_code @promotion_code end |