Class: Stripe::Checkout::Session::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1377
1378
1379
1380
# File 'lib/stripe/resources/checkout/session.rb', line 1377

def initialize(coupon: nil, promotion_code: nil)
  @coupon = coupon
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The ID of the coupon to apply to this Session.



1373
1374
1375
# File 'lib/stripe/resources/checkout/session.rb', line 1373

def coupon
  @coupon
end

#promotion_codeObject

The ID of a promotion code to apply to this Session.



1375
1376
1377
# File 'lib/stripe/resources/checkout/session.rb', line 1375

def promotion_code
  @promotion_code
end