Class: Stripe::Checkout::Session::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1358
1359
1360
1361
# File 'lib/stripe/resources/checkout/session.rb', line 1358

def initialize(coupon: nil, promotion_code: nil)
  @coupon = coupon
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The ID of the coupon to apply to this Session.



1354
1355
1356
# File 'lib/stripe/resources/checkout/session.rb', line 1354

def coupon
  @coupon
end

#promotion_codeObject

The ID of a promotion code to apply to this Session.



1356
1357
1358
# File 'lib/stripe/resources/checkout/session.rb', line 1356

def promotion_code
  @promotion_code
end