Class: Stripe::Checkout::Session::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1445
1446
1447
1448
# File 'lib/stripe/resources/checkout/session.rb', line 1445

def initialize(coupon: nil, promotion_code: nil)
  @coupon = coupon
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The ID of the coupon to apply to this Session.



1441
1442
1443
# File 'lib/stripe/resources/checkout/session.rb', line 1441

def coupon
  @coupon
end

#promotion_codeObject

The ID of a promotion code to apply to this Session.



1443
1444
1445
# File 'lib/stripe/resources/checkout/session.rb', line 1443

def promotion_code
  @promotion_code
end