Class: Stripe::Checkout::Session::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1436
1437
1438
1439
# File 'lib/stripe/resources/checkout/session.rb', line 1436

def initialize(coupon: nil, promotion_code: nil)
  @coupon = coupon
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The ID of the coupon to apply to this Session.



1432
1433
1434
# File 'lib/stripe/resources/checkout/session.rb', line 1432

def coupon
  @coupon
end

#promotion_codeObject

The ID of a promotion code to apply to this Session.



1434
1435
1436
# File 'lib/stripe/resources/checkout/session.rb', line 1434

def promotion_code
  @promotion_code
end