Class: Stripe::Checkout::Session::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1426
1427
1428
1429
# File 'lib/stripe/resources/checkout/session.rb', line 1426

def initialize(coupon: nil, promotion_code: nil)
  @coupon = coupon
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The ID of the coupon to apply to this Session.



1422
1423
1424
# File 'lib/stripe/resources/checkout/session.rb', line 1422

def coupon
  @coupon
end

#promotion_codeObject

The ID of a promotion code to apply to this Session.



1424
1425
1426
# File 'lib/stripe/resources/checkout/session.rb', line 1424

def promotion_code
  @promotion_code
end