Class: Stripe::Checkout::Session::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1626
1627
1628
1629
# File 'lib/stripe/resources/checkout/session.rb', line 1626

def initialize(coupon: nil, promotion_code: nil)
  @coupon = coupon
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The ID of the coupon to apply to this Session.



1621
1622
1623
# File 'lib/stripe/resources/checkout/session.rb', line 1621

def coupon
  @coupon
end

#promotion_codeObject

The ID of a promotion code to apply to this Session.



1624
1625
1626
# File 'lib/stripe/resources/checkout/session.rb', line 1624

def promotion_code
  @promotion_code
end