Class: Stripe::Checkout::Session::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::Discount
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The ID of the coupon to apply to this Session.
-
#promotion_code ⇒ Object
The ID of a promotion code to apply to this Session.
Instance Method Summary collapse
-
#initialize(coupon: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1412 1413 1414 1415 |
# File 'lib/stripe/resources/checkout/session.rb', line 1412 def initialize(coupon: nil, promotion_code: nil) @coupon = coupon @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The ID of the coupon to apply to this Session.
1408 1409 1410 |
# File 'lib/stripe/resources/checkout/session.rb', line 1408 def coupon @coupon end |
#promotion_code ⇒ Object
The ID of a promotion code to apply to this Session.
1410 1411 1412 |
# File 'lib/stripe/resources/checkout/session.rb', line 1410 def promotion_code @promotion_code end |