Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
# File 'lib/stripe/resources/checkout/session.rb', line 1706

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1692
1693
1694
# File 'lib/stripe/resources/checkout/session.rb', line 1692

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1694
1695
1696
# File 'lib/stripe/resources/checkout/session.rb', line 1694

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1696
1697
1698
# File 'lib/stripe/resources/checkout/session.rb', line 1696

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1698
1699
1700
# File 'lib/stripe/resources/checkout/session.rb', line 1698

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1700
1701
1702
# File 'lib/stripe/resources/checkout/session.rb', line 1700

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1702
1703
1704
# File 'lib/stripe/resources/checkout/session.rb', line 1702

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1704
1705
1706
# File 'lib/stripe/resources/checkout/session.rb', line 1704

def rendering_options
  @rendering_options
end