Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: CustomField, Issuer, RenderingOptions
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
-
#custom_fields ⇒ Object
Default custom fields to be displayed on invoices for this customer.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
-
#issuer ⇒ Object
The connected account that issues the invoice.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData
constructor
A new instance of InvoiceData.
Methods inherited from RequestParams
Constructor Details
#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData
Returns a new instance of InvoiceData.
1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 |
# File 'lib/stripe/resources/checkout/session.rb', line 1447 def initialize( account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil ) @account_tax_ids = account_tax_ids @custom_fields = custom_fields @description = description @footer = @issuer = issuer @metadata = @rendering_options = end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
1433 1434 1435 |
# File 'lib/stripe/resources/checkout/session.rb', line 1433 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object
Default custom fields to be displayed on invoices for this customer.
1435 1436 1437 |
# File 'lib/stripe/resources/checkout/session.rb', line 1435 def custom_fields @custom_fields end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1437 1438 1439 |
# File 'lib/stripe/resources/checkout/session.rb', line 1437 def description @description end |
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
1439 1440 1441 |
# File 'lib/stripe/resources/checkout/session.rb', line 1439 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
1441 1442 1443 |
# File 'lib/stripe/resources/checkout/session.rb', line 1441 def issuer @issuer end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1443 1444 1445 |
# File 'lib/stripe/resources/checkout/session.rb', line 1443 def @metadata end |
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
1445 1446 1447 |
# File 'lib/stripe/resources/checkout/session.rb', line 1445 def @rendering_options end |