Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
# File 'lib/stripe/resources/checkout/session.rb', line 1530

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1516
1517
1518
# File 'lib/stripe/resources/checkout/session.rb', line 1516

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1518
1519
1520
# File 'lib/stripe/resources/checkout/session.rb', line 1518

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1520
1521
1522
# File 'lib/stripe/resources/checkout/session.rb', line 1520

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1522
1523
1524
# File 'lib/stripe/resources/checkout/session.rb', line 1522

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1524
1525
1526
# File 'lib/stripe/resources/checkout/session.rb', line 1524

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1526
1527
1528
# File 'lib/stripe/resources/checkout/session.rb', line 1526

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1528
1529
1530
# File 'lib/stripe/resources/checkout/session.rb', line 1528

def rendering_options
  @rendering_options
end