Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
# File 'lib/stripe/resources/checkout/session.rb', line 1445

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1431
1432
1433
# File 'lib/stripe/resources/checkout/session.rb', line 1431

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1433
1434
1435
# File 'lib/stripe/resources/checkout/session.rb', line 1433

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1435
1436
1437
# File 'lib/stripe/resources/checkout/session.rb', line 1435

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1437
1438
1439
# File 'lib/stripe/resources/checkout/session.rb', line 1437

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1439
1440
1441
# File 'lib/stripe/resources/checkout/session.rb', line 1439

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1441
1442
1443
# File 'lib/stripe/resources/checkout/session.rb', line 1441

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1443
1444
1445
# File 'lib/stripe/resources/checkout/session.rb', line 1443

def rendering_options
  @rendering_options
end