Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
# File 'lib/stripe/resources/checkout/session.rb', line 1491

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1477
1478
1479
# File 'lib/stripe/resources/checkout/session.rb', line 1477

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1479
1480
1481
# File 'lib/stripe/resources/checkout/session.rb', line 1479

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1481
1482
1483
# File 'lib/stripe/resources/checkout/session.rb', line 1481

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1483
1484
1485
# File 'lib/stripe/resources/checkout/session.rb', line 1483

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1485
1486
1487
# File 'lib/stripe/resources/checkout/session.rb', line 1485

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1487
1488
1489
# File 'lib/stripe/resources/checkout/session.rb', line 1487

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1489
1490
1491
# File 'lib/stripe/resources/checkout/session.rb', line 1489

def rendering_options
  @rendering_options
end