Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData

Returns a new instance of InvoiceData.



1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
# File 'lib/stripe/resources/checkout/session.rb', line 1689

def initialize(
  account_tax_ids: nil,
  custom_fields: nil,
  description: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  rendering_options: nil
)
  @account_tax_ids = 
  @custom_fields = custom_fields
  @description = description
  @footer = footer
  @issuer = issuer
  @metadata = 
  @rendering_options = rendering_options
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice.



1669
1670
1671
# File 'lib/stripe/resources/checkout/session.rb', line 1669

def 
  @account_tax_ids
end

#custom_fieldsObject

Default custom fields to be displayed on invoices for this customer.



1672
1673
1674
# File 'lib/stripe/resources/checkout/session.rb', line 1672

def custom_fields
  @custom_fields
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1675
1676
1677
# File 'lib/stripe/resources/checkout/session.rb', line 1675

def description
  @description
end

Default footer to be displayed on invoices for this customer.



1678
1679
1680
# File 'lib/stripe/resources/checkout/session.rb', line 1678

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1681
1682
1683
# File 'lib/stripe/resources/checkout/session.rb', line 1681

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1684
1685
1686
# File 'lib/stripe/resources/checkout/session.rb', line 1684

def 
  @metadata
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



1687
1688
1689
# File 'lib/stripe/resources/checkout/session.rb', line 1687

def rendering_options
  @rendering_options
end