Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData::RenderingOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData::RenderingOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
-
#template ⇒ Object
ID of the invoice rendering template to use for this invoice.
Instance Method Summary collapse
-
#initialize(amount_tax_display: nil, template: nil) ⇒ RenderingOptions
constructor
A new instance of RenderingOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_tax_display: nil, template: nil) ⇒ RenderingOptions
Returns a new instance of RenderingOptions.
2601 2602 2603 2604 |
# File 'lib/stripe/resources/checkout/session.rb', line 2601 def initialize(amount_tax_display: nil, template: nil) @amount_tax_display = amount_tax_display @template = template end |
Instance Attribute Details
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.
2597 2598 2599 |
# File 'lib/stripe/resources/checkout/session.rb', line 2597 def amount_tax_display @amount_tax_display end |
#template ⇒ Object
ID of the invoice rendering template to use for this invoice.
2599 2600 2601 |
# File 'lib/stripe/resources/checkout/session.rb', line 2599 def template @template end |