Class: Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData::RenderingOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::InvoiceCreation::InvoiceData::RenderingOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
-
#template ⇒ Object
ID of the invoice rendering template to use for this invoice.
Instance Method Summary collapse
-
#initialize(amount_tax_display: nil, template: nil) ⇒ RenderingOptions
constructor
A new instance of RenderingOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_tax_display: nil, template: nil) ⇒ RenderingOptions
Returns a new instance of RenderingOptions.
1510 1511 1512 1513 |
# File 'lib/stripe/resources/checkout/session.rb', line 1510 def initialize(amount_tax_display: nil, template: nil) @amount_tax_display = amount_tax_display @template = template end |
Instance Attribute Details
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.
1506 1507 1508 |
# File 'lib/stripe/resources/checkout/session.rb', line 1506 def amount_tax_display @amount_tax_display end |
#template ⇒ Object
ID of the invoice rendering template to use for this invoice.
1508 1509 1510 |
# File 'lib/stripe/resources/checkout/session.rb', line 1508 def template @template end |