Class: Stripe::Checkout::Session::CreateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::LineItem
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AdjustableQuantity, PriceData
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
-
#dynamic_tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) that will be applied to this line item depending on the customer’s billing/shipping address.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
-
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, dynamic_tax_rates: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, dynamic_tax_rates: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 |
# File 'lib/stripe/resources/checkout/session.rb', line 1656 def initialize( adjustable_quantity: nil, dynamic_tax_rates: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @adjustable_quantity = adjustable_quantity @dynamic_tax_rates = dynamic_tax_rates @metadata = @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
1642 1643 1644 |
# File 'lib/stripe/resources/checkout/session.rb', line 1642 def adjustable_quantity @adjustable_quantity end |
#dynamic_tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) that will be applied to this line item depending on the customer’s billing/shipping address. We currently support the following countries: US, GB, AU, and all countries in the EU.
1644 1645 1646 |
# File 'lib/stripe/resources/checkout/session.rb', line 1644 def dynamic_tax_rates @dynamic_tax_rates end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1646 1647 1648 |
# File 'lib/stripe/resources/checkout/session.rb', line 1646 def @metadata end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object. One of ‘price` or `price_data` is required.
1648 1649 1650 |
# File 'lib/stripe/resources/checkout/session.rb', line 1648 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1650 1651 1652 |
# File 'lib/stripe/resources/checkout/session.rb', line 1650 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.
1652 1653 1654 |
# File 'lib/stripe/resources/checkout/session.rb', line 1652 def quantity @quantity end |
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
1654 1655 1656 |
# File 'lib/stripe/resources/checkout/session.rb', line 1654 def tax_rates @tax_rates end |