Class: Stripe::Checkout::Session::CreateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, dynamic_tax_rates: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
# File 'lib/stripe/resources/checkout/session.rb', line 1556

def initialize(
  adjustable_quantity: nil,
  dynamic_tax_rates: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @dynamic_tax_rates = dynamic_tax_rates
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



1544
1545
1546
# File 'lib/stripe/resources/checkout/session.rb', line 1544

def adjustable_quantity
  @adjustable_quantity
end

#dynamic_tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) that will be applied to this line item depending on the customer’s billing/shipping address. We currently support the following countries: US, GB, AU, and all countries in the EU.



1546
1547
1548
# File 'lib/stripe/resources/checkout/session.rb', line 1546

def dynamic_tax_rates
  @dynamic_tax_rates
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object. One of ‘price` or `price_data` is required.



1548
1549
1550
# File 'lib/stripe/resources/checkout/session.rb', line 1548

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1550
1551
1552
# File 'lib/stripe/resources/checkout/session.rb', line 1550

def price_data
  @price_data
end

#quantityObject

The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.



1552
1553
1554
# File 'lib/stripe/resources/checkout/session.rb', line 1552

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



1554
1555
1556
# File 'lib/stripe/resources/checkout/session.rb', line 1554

def tax_rates
  @tax_rates
end