Class: Stripe::Checkout::Session::CreateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, dynamic_tax_rates: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
# File 'lib/stripe/resources/checkout/session.rb', line 1537

def initialize(
  adjustable_quantity: nil,
  dynamic_tax_rates: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @dynamic_tax_rates = dynamic_tax_rates
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



1525
1526
1527
# File 'lib/stripe/resources/checkout/session.rb', line 1525

def adjustable_quantity
  @adjustable_quantity
end

#dynamic_tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) that will be applied to this line item depending on the customer’s billing/shipping address. We currently support the following countries: US, GB, AU, and all countries in the EU.



1527
1528
1529
# File 'lib/stripe/resources/checkout/session.rb', line 1527

def dynamic_tax_rates
  @dynamic_tax_rates
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object. One of ‘price` or `price_data` is required.



1529
1530
1531
# File 'lib/stripe/resources/checkout/session.rb', line 1529

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1531
1532
1533
# File 'lib/stripe/resources/checkout/session.rb', line 1531

def price_data
  @price_data
end

#quantityObject

The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.



1533
1534
1535
# File 'lib/stripe/resources/checkout/session.rb', line 1533

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



1535
1536
1537
# File 'lib/stripe/resources/checkout/session.rb', line 1535

def tax_rates
  @tax_rates
end