Class: Stripe::Checkout::Session::CreateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, dynamic_tax_rates: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
# File 'lib/stripe/resources/checkout/session.rb', line 1607

def initialize(
  adjustable_quantity: nil,
  dynamic_tax_rates: nil,
  metadata: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @dynamic_tax_rates = dynamic_tax_rates
  @metadata = 
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



1593
1594
1595
# File 'lib/stripe/resources/checkout/session.rb', line 1593

def adjustable_quantity
  @adjustable_quantity
end

#dynamic_tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) that will be applied to this line item depending on the customer’s billing/shipping address. We currently support the following countries: US, GB, AU, and all countries in the EU.



1595
1596
1597
# File 'lib/stripe/resources/checkout/session.rb', line 1595

def dynamic_tax_rates
  @dynamic_tax_rates
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1597
1598
1599
# File 'lib/stripe/resources/checkout/session.rb', line 1597

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object. One of ‘price` or `price_data` is required.



1599
1600
1601
# File 'lib/stripe/resources/checkout/session.rb', line 1599

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1601
1602
1603
# File 'lib/stripe/resources/checkout/session.rb', line 1601

def price_data
  @price_data
end

#quantityObject

The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.



1603
1604
1605
# File 'lib/stripe/resources/checkout/session.rb', line 1603

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



1605
1606
1607
# File 'lib/stripe/resources/checkout/session.rb', line 1605

def tax_rates
  @tax_rates
end