Class: Stripe::Checkout::Session::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1503
1504
1505
1506
1507
1508
1509
# File 'lib/stripe/resources/checkout/session.rb', line 1503

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1493
1494
1495
# File 'lib/stripe/resources/checkout/session.rb', line 1493

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1495
1496
1497
# File 'lib/stripe/resources/checkout/session.rb', line 1495

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1497
1498
1499
# File 'lib/stripe/resources/checkout/session.rb', line 1497

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1499
1500
1501
# File 'lib/stripe/resources/checkout/session.rb', line 1499

def name
  @name
end

#tax_codeObject



1501
1502
1503
# File 'lib/stripe/resources/checkout/session.rb', line 1501

def tax_code
  @tax_code
end