Class: Stripe::Checkout::Session::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1575
1576
1577
1578
1579
1580
1581
# File 'lib/stripe/resources/checkout/session.rb', line 1575

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1565
1566
1567
# File 'lib/stripe/resources/checkout/session.rb', line 1565

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1567
1568
1569
# File 'lib/stripe/resources/checkout/session.rb', line 1567

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1569
1570
1571
# File 'lib/stripe/resources/checkout/session.rb', line 1569

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1571
1572
1573
# File 'lib/stripe/resources/checkout/session.rb', line 1571

def name
  @name
end

#tax_codeObject



1573
1574
1575
# File 'lib/stripe/resources/checkout/session.rb', line 1573

def tax_code
  @tax_code
end