Class: Stripe::Checkout::Session::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1482
1483
1484
1485
1486
1487
1488
# File 'lib/stripe/resources/checkout/session.rb', line 1482

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1472
1473
1474
# File 'lib/stripe/resources/checkout/session.rb', line 1472

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1474
1475
1476
# File 'lib/stripe/resources/checkout/session.rb', line 1474

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1476
1477
1478
# File 'lib/stripe/resources/checkout/session.rb', line 1476

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1478
1479
1480
# File 'lib/stripe/resources/checkout/session.rb', line 1478

def name
  @name
end

#tax_codeObject



1480
1481
1482
# File 'lib/stripe/resources/checkout/session.rb', line 1480

def tax_code
  @tax_code
end