Class: Stripe::Checkout::Session::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1549
1550
1551
1552
1553
1554
1555
# File 'lib/stripe/resources/checkout/session.rb', line 1549

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1539
1540
1541
# File 'lib/stripe/resources/checkout/session.rb', line 1539

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1541
1542
1543
# File 'lib/stripe/resources/checkout/session.rb', line 1541

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1543
1544
1545
# File 'lib/stripe/resources/checkout/session.rb', line 1543

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1545
1546
1547
# File 'lib/stripe/resources/checkout/session.rb', line 1545

def name
  @name
end

#tax_codeObject



1547
1548
1549
# File 'lib/stripe/resources/checkout/session.rb', line 1547

def tax_code
  @tax_code
end