Class: Stripe::Checkout::Session::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1539
1540
1541
1542
1543
1544
1545
# File 'lib/stripe/resources/checkout/session.rb', line 1539

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1529
1530
1531
# File 'lib/stripe/resources/checkout/session.rb', line 1529

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1531
1532
1533
# File 'lib/stripe/resources/checkout/session.rb', line 1531

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1533
1534
1535
# File 'lib/stripe/resources/checkout/session.rb', line 1533

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1535
1536
1537
# File 'lib/stripe/resources/checkout/session.rb', line 1535

def name
  @name
end

#tax_codeObject



1537
1538
1539
# File 'lib/stripe/resources/checkout/session.rb', line 1537

def tax_code
  @tax_code
end