Class: Stripe::Checkout::Session::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1754
1755
1756
1757
1758
1759
1760
# File 'lib/stripe/resources/checkout/session.rb', line 1754

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1740
1741
1742
# File 'lib/stripe/resources/checkout/session.rb', line 1740

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1743
1744
1745
# File 'lib/stripe/resources/checkout/session.rb', line 1743

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1746
1747
1748
# File 'lib/stripe/resources/checkout/session.rb', line 1746

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1749
1750
1751
# File 'lib/stripe/resources/checkout/session.rb', line 1749

def name
  @name
end

#tax_codeObject



1752
1753
1754
# File 'lib/stripe/resources/checkout/session.rb', line 1752

def tax_code
  @tax_code
end