Class: Stripe::Checkout::Session::CreateParams::OptionalItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem

Returns a new instance of OptionalItem.



1667
1668
1669
1670
1671
# File 'lib/stripe/resources/checkout/session.rb', line 1667

def initialize(adjustable_quantity: nil, price: nil, quantity: nil)
  @adjustable_quantity = adjustable_quantity
  @price = price
  @quantity = quantity
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.



1661
1662
1663
# File 'lib/stripe/resources/checkout/session.rb', line 1661

def adjustable_quantity
  @adjustable_quantity
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices) or [Plan](stripe.com/docs/api/plans) object.



1663
1664
1665
# File 'lib/stripe/resources/checkout/session.rb', line 1663

def price
  @price
end

#quantityObject

The initial quantity of the line item created when a customer chooses to add this optional item to their order.



1665
1666
1667
# File 'lib/stripe/resources/checkout/session.rb', line 1665

def quantity
  @quantity
end