Class: Stripe::Checkout::Session::CreateParams::OptionalItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



1663
1664
1665
1666
1667
# File 'lib/stripe/resources/checkout/session.rb', line 1663

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any non-negative integer.



1657
1658
1659
# File 'lib/stripe/resources/checkout/session.rb', line 1657

def enabled
  @enabled
end

#maximumObject

The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.



1659
1660
1661
# File 'lib/stripe/resources/checkout/session.rb', line 1659

def maximum
  @maximum
end

#minimumObject

The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.



1661
1662
1663
# File 'lib/stripe/resources/checkout/session.rb', line 1661

def minimum
  @minimum
end