Class: Stripe::Checkout::Session::CreateParams::OptionalItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::OptionalItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase.
-
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
1563 1564 1565 1566 1567 |
# File 'lib/stripe/resources/checkout/session.rb', line 1563 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
1557 1558 1559 |
# File 'lib/stripe/resources/checkout/session.rb', line 1557 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.
1559 1560 1561 |
# File 'lib/stripe/resources/checkout/session.rb', line 1559 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.
1561 1562 1563 |
# File 'lib/stripe/resources/checkout/session.rb', line 1561 def minimum @minimum end |