Class: Stripe::Checkout::Session::CreateParams::PaymentIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_amount: nil, capture_method: nil, description: nil, metadata: nil, on_behalf_of: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentData

Returns a new instance of PaymentIntentData.



1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/stripe/resources/checkout/session.rb', line 1798

def initialize(
  application_fee_amount: nil,
  capture_method: nil,
  description: nil,
  metadata: nil,
  on_behalf_of: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



1750
1751
1752
# File 'lib/stripe/resources/checkout/session.rb', line 1750

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



1752
1753
1754
# File 'lib/stripe/resources/checkout/session.rb', line 1752

def capture_method
  @capture_method
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1754
1755
1756
# File 'lib/stripe/resources/checkout/session.rb', line 1754

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1756
1757
1758
# File 'lib/stripe/resources/checkout/session.rb', line 1756

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID for which these funds are intended. For details, see the PaymentIntents [use case for connected accounts](/docs/payments/connected-accounts).



1760
1761
1762
# File 'lib/stripe/resources/checkout/session.rb', line 1760

def on_behalf_of
  @on_behalf_of
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



1762
1763
1764
# File 'lib/stripe/resources/checkout/session.rb', line 1762

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to [make future payments](stripe.com/docs/payments/payment-intents#future-usage) with the payment method collected by this Checkout Session.

When setting this to ‘on_session`, Checkout will show a notice to the customer that their payment details will be saved.

When setting this to ‘off_session`, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.

If a Customer has been provided or Checkout creates a new Customer, Checkout will attach the payment method to the Customer.

If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session’s PaymentIntent.

When processing card payments, Checkout also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.



1783
1784
1785
# File 'lib/stripe/resources/checkout/session.rb', line 1783

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this payment.



1785
1786
1787
# File 'lib/stripe/resources/checkout/session.rb', line 1785

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



1789
1790
1791
# File 'lib/stripe/resources/checkout/session.rb', line 1789

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



1791
1792
1793
# File 'lib/stripe/resources/checkout/session.rb', line 1791

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters used to automatically create a Transfer when the payment succeeds. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



1794
1795
1796
# File 'lib/stripe/resources/checkout/session.rb', line 1794

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](stripe.com/docs/connect/separate-charges-and-transfers) for details.



1796
1797
1798
# File 'lib/stripe/resources/checkout/session.rb', line 1796

def transfer_group
  @transfer_group
end