Class: Stripe::Checkout::Session::CreateParams::PaymentIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_amount: nil, capture_method: nil, description: nil, metadata: nil, on_behalf_of: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentData

Returns a new instance of PaymentIntentData.



1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
# File 'lib/stripe/resources/checkout/session.rb', line 1727

def initialize(
  application_fee_amount: nil,
  capture_method: nil,
  description: nil,
  metadata: nil,
  on_behalf_of: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



1679
1680
1681
# File 'lib/stripe/resources/checkout/session.rb', line 1679

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



1681
1682
1683
# File 'lib/stripe/resources/checkout/session.rb', line 1681

def capture_method
  @capture_method
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1683
1684
1685
# File 'lib/stripe/resources/checkout/session.rb', line 1683

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1685
1686
1687
# File 'lib/stripe/resources/checkout/session.rb', line 1685

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID for which these funds are intended. For details, see the PaymentIntents [use case for connected accounts](/docs/payments/connected-accounts).



1689
1690
1691
# File 'lib/stripe/resources/checkout/session.rb', line 1689

def on_behalf_of
  @on_behalf_of
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



1691
1692
1693
# File 'lib/stripe/resources/checkout/session.rb', line 1691

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to [make future payments](stripe.com/docs/payments/payment-intents#future-usage) with the payment method collected by this Checkout Session.

When setting this to ‘on_session`, Checkout will show a notice to the customer that their payment details will be saved.

When setting this to ‘off_session`, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.

If a Customer has been provided or Checkout creates a new Customer, Checkout will attach the payment method to the Customer.

If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session’s PaymentIntent.

When processing card payments, Checkout also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.



1712
1713
1714
# File 'lib/stripe/resources/checkout/session.rb', line 1712

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this payment.



1714
1715
1716
# File 'lib/stripe/resources/checkout/session.rb', line 1714

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



1718
1719
1720
# File 'lib/stripe/resources/checkout/session.rb', line 1718

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



1720
1721
1722
# File 'lib/stripe/resources/checkout/session.rb', line 1720

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters used to automatically create a Transfer when the payment succeeds. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



1723
1724
1725
# File 'lib/stripe/resources/checkout/session.rb', line 1723

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](stripe.com/docs/connect/separate-charges-and-transfers) for details.



1725
1726
1727
# File 'lib/stripe/resources/checkout/session.rb', line 1725

def transfer_group
  @transfer_group
end