Class: Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
1645 1646 1647 1648 1649 1650 1651 |
# File 'lib/stripe/resources/checkout/session.rb', line 1645 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
1635 1636 1637 |
# File 'lib/stripe/resources/checkout/session.rb', line 1635 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
1637 1638 1639 |
# File 'lib/stripe/resources/checkout/session.rb', line 1637 def carrier @carrier end |
#name ⇒ Object
Recipient name.
1639 1640 1641 |
# File 'lib/stripe/resources/checkout/session.rb', line 1639 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
1641 1642 1643 |
# File 'lib/stripe/resources/checkout/session.rb', line 1641 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
1643 1644 1645 |
# File 'lib/stripe/resources/checkout/session.rb', line 1643 def tracking_number @tracking_number end |