Class: Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
1734 1735 1736 1737 1738 1739 1740 |
# File 'lib/stripe/resources/checkout/session.rb', line 1734 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
1724 1725 1726 |
# File 'lib/stripe/resources/checkout/session.rb', line 1724 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
1726 1727 1728 |
# File 'lib/stripe/resources/checkout/session.rb', line 1726 def carrier @carrier end |
#name ⇒ Object
Recipient name.
1728 1729 1730 |
# File 'lib/stripe/resources/checkout/session.rb', line 1728 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
1730 1731 1732 |
# File 'lib/stripe/resources/checkout/session.rb', line 1730 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
1732 1733 1734 |
# File 'lib/stripe/resources/checkout/session.rb', line 1732 def tracking_number @tracking_number end |