Class: Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
1717 1718 1719 1720 1721 1722 1723 |
# File 'lib/stripe/resources/checkout/session.rb', line 1717 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
1707 1708 1709 |
# File 'lib/stripe/resources/checkout/session.rb', line 1707 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
1709 1710 1711 |
# File 'lib/stripe/resources/checkout/session.rb', line 1709 def carrier @carrier end |
#name ⇒ Object
Recipient name.
1711 1712 1713 |
# File 'lib/stripe/resources/checkout/session.rb', line 1711 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
1713 1714 1715 |
# File 'lib/stripe/resources/checkout/session.rb', line 1713 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
1715 1716 1717 |
# File 'lib/stripe/resources/checkout/session.rb', line 1715 def tracking_number @tracking_number end |