Class: Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentIntentData::Shipping
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
1669 1670 1671 1672 1673 1674 1675 |
# File 'lib/stripe/resources/checkout/session.rb', line 1669 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
1659 1660 1661 |
# File 'lib/stripe/resources/checkout/session.rb', line 1659 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
1661 1662 1663 |
# File 'lib/stripe/resources/checkout/session.rb', line 1661 def carrier @carrier end |
#name ⇒ Object
Recipient name.
1663 1664 1665 |
# File 'lib/stripe/resources/checkout/session.rb', line 1663 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
1665 1666 1667 |
# File 'lib/stripe/resources/checkout/session.rb', line 1665 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
1667 1668 1669 |
# File 'lib/stripe/resources/checkout/session.rb', line 1667 def tracking_number @tracking_number end |