Class: Stripe::Checkout::Session::CreateParams::PaymentIntentData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1752
1753
1754
1755
# File 'lib/stripe/resources/checkout/session.rb', line 1752

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when a charge succeeds.



1745
1746
1747
# File 'lib/stripe/resources/checkout/session.rb', line 1745

def amount
  @amount
end

#destinationObject

If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.



1750
1751
1752
# File 'lib/stripe/resources/checkout/session.rb', line 1750

def destination
  @destination
end