Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, RevolutPay, SamsungPay, SepaDebit, Sofort, Swish, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
contains details about the Alipay payment method options.
-
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
-
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
-
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
-
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
-
#boleto ⇒ Object
contains details about the Boleto payment method options.
-
#card ⇒ Object
contains details about the Card payment method options.
-
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
-
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
-
#eps ⇒ Object
contains details about the EPS payment method options.
-
#fpx ⇒ Object
contains details about the FPX payment method options.
-
#giropay ⇒ Object
contains details about the Giropay payment method options.
-
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
-
#ideal ⇒ Object
contains details about the Ideal payment method options.
-
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
contains details about the Klarna payment method options.
-
#konbini ⇒ Object
contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
contains details about the Korean card payment method options.
-
#link ⇒ Object
contains details about the Link payment method options.
-
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
-
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
contains details about the OXXO payment method options.
-
#p24 ⇒ Object
contains details about the P24 payment method options.
-
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
-
#payco ⇒ Object
contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
contains details about the PayNow payment method options.
-
#paypal ⇒ Object
contains details about the PayPal payment method options.
-
#payto ⇒ Object
contains details about the PayTo payment method options.
-
#pix ⇒ Object
contains details about the Pix payment method options.
-
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
-
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
-
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
-
#sofort ⇒ Object
contains details about the Sofort payment method options.
-
#swish ⇒ Object
contains details about the Swish payment method options.
-
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
-
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 |
# File 'lib/stripe/resources/checkout/session.rb', line 2812 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @boleto = boleto @card = card @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
2732 2733 2734 |
# File 'lib/stripe/resources/checkout/session.rb', line 2732 def acss_debit @acss_debit end |
#affirm ⇒ Object
contains details about the Affirm payment method options.
2734 2735 2736 |
# File 'lib/stripe/resources/checkout/session.rb', line 2734 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
2736 2737 2738 |
# File 'lib/stripe/resources/checkout/session.rb', line 2736 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
contains details about the Alipay payment method options.
2738 2739 2740 |
# File 'lib/stripe/resources/checkout/session.rb', line 2738 def alipay @alipay end |
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
2740 2741 2742 |
# File 'lib/stripe/resources/checkout/session.rb', line 2740 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
2742 2743 2744 |
# File 'lib/stripe/resources/checkout/session.rb', line 2742 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
2744 2745 2746 |
# File 'lib/stripe/resources/checkout/session.rb', line 2744 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
2746 2747 2748 |
# File 'lib/stripe/resources/checkout/session.rb', line 2746 def bancontact @bancontact end |
#boleto ⇒ Object
contains details about the Boleto payment method options.
2748 2749 2750 |
# File 'lib/stripe/resources/checkout/session.rb', line 2748 def boleto @boleto end |
#card ⇒ Object
contains details about the Card payment method options.
2750 2751 2752 |
# File 'lib/stripe/resources/checkout/session.rb', line 2750 def card @card end |
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
2752 2753 2754 |
# File 'lib/stripe/resources/checkout/session.rb', line 2752 def cashapp @cashapp end |
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
2754 2755 2756 |
# File 'lib/stripe/resources/checkout/session.rb', line 2754 def customer_balance @customer_balance end |
#eps ⇒ Object
contains details about the EPS payment method options.
2756 2757 2758 |
# File 'lib/stripe/resources/checkout/session.rb', line 2756 def eps @eps end |
#fpx ⇒ Object
contains details about the FPX payment method options.
2758 2759 2760 |
# File 'lib/stripe/resources/checkout/session.rb', line 2758 def fpx @fpx end |
#giropay ⇒ Object
contains details about the Giropay payment method options.
2760 2761 2762 |
# File 'lib/stripe/resources/checkout/session.rb', line 2760 def giropay @giropay end |
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
2762 2763 2764 |
# File 'lib/stripe/resources/checkout/session.rb', line 2762 def grabpay @grabpay end |
#ideal ⇒ Object
contains details about the Ideal payment method options.
2764 2765 2766 |
# File 'lib/stripe/resources/checkout/session.rb', line 2764 def ideal @ideal end |
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
2766 2767 2768 |
# File 'lib/stripe/resources/checkout/session.rb', line 2766 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
contains details about the Klarna payment method options.
2768 2769 2770 |
# File 'lib/stripe/resources/checkout/session.rb', line 2768 def klarna @klarna end |
#konbini ⇒ Object
contains details about the Konbini payment method options.
2770 2771 2772 |
# File 'lib/stripe/resources/checkout/session.rb', line 2770 def konbini @konbini end |
#kr_card ⇒ Object
contains details about the Korean card payment method options.
2772 2773 2774 |
# File 'lib/stripe/resources/checkout/session.rb', line 2772 def kr_card @kr_card end |
#link ⇒ Object
contains details about the Link payment method options.
2774 2775 2776 |
# File 'lib/stripe/resources/checkout/session.rb', line 2774 def link @link end |
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
2776 2777 2778 |
# File 'lib/stripe/resources/checkout/session.rb', line 2776 def mobilepay @mobilepay end |
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
2778 2779 2780 |
# File 'lib/stripe/resources/checkout/session.rb', line 2778 def multibanco @multibanco end |
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
2780 2781 2782 |
# File 'lib/stripe/resources/checkout/session.rb', line 2780 def naver_pay @naver_pay end |
#oxxo ⇒ Object
contains details about the OXXO payment method options.
2782 2783 2784 |
# File 'lib/stripe/resources/checkout/session.rb', line 2782 def oxxo @oxxo end |
#p24 ⇒ Object
contains details about the P24 payment method options.
2784 2785 2786 |
# File 'lib/stripe/resources/checkout/session.rb', line 2784 def p24 @p24 end |
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
2786 2787 2788 |
# File 'lib/stripe/resources/checkout/session.rb', line 2786 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
contains details about the PAYCO payment method options.
2788 2789 2790 |
# File 'lib/stripe/resources/checkout/session.rb', line 2788 def payco @payco end |
#paynow ⇒ Object
contains details about the PayNow payment method options.
2790 2791 2792 |
# File 'lib/stripe/resources/checkout/session.rb', line 2790 def paynow @paynow end |
#paypal ⇒ Object
contains details about the PayPal payment method options.
2792 2793 2794 |
# File 'lib/stripe/resources/checkout/session.rb', line 2792 def paypal @paypal end |
#payto ⇒ Object
contains details about the PayTo payment method options.
2794 2795 2796 |
# File 'lib/stripe/resources/checkout/session.rb', line 2794 def payto @payto end |
#pix ⇒ Object
contains details about the Pix payment method options.
2796 2797 2798 |
# File 'lib/stripe/resources/checkout/session.rb', line 2796 def pix @pix end |
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
2798 2799 2800 |
# File 'lib/stripe/resources/checkout/session.rb', line 2798 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
2800 2801 2802 |
# File 'lib/stripe/resources/checkout/session.rb', line 2800 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
2802 2803 2804 |
# File 'lib/stripe/resources/checkout/session.rb', line 2802 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
contains details about the Sofort payment method options.
2804 2805 2806 |
# File 'lib/stripe/resources/checkout/session.rb', line 2804 def sofort @sofort end |
#swish ⇒ Object
contains details about the Swish payment method options.
2806 2807 2808 |
# File 'lib/stripe/resources/checkout/session.rb', line 2806 def swish @swish end |
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
2808 2809 2810 |
# File 'lib/stripe/resources/checkout/session.rb', line 2808 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
2810 2811 2812 |
# File 'lib/stripe/resources/checkout/session.rb', line 2810 def wechat_pay @wechat_pay end |