Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, RevolutPay, SamsungPay, SepaDebit, Sofort, Swish, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
contains details about the Alipay payment method options.
-
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
-
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
-
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
-
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
-
#boleto ⇒ Object
contains details about the Boleto payment method options.
-
#card ⇒ Object
contains details about the Card payment method options.
-
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
-
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
-
#eps ⇒ Object
contains details about the EPS payment method options.
-
#fpx ⇒ Object
contains details about the FPX payment method options.
-
#giropay ⇒ Object
contains details about the Giropay payment method options.
-
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
-
#ideal ⇒ Object
contains details about the Ideal payment method options.
-
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
contains details about the Klarna payment method options.
-
#konbini ⇒ Object
contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
contains details about the Korean card payment method options.
-
#link ⇒ Object
contains details about the Link payment method options.
-
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
-
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
contains details about the OXXO payment method options.
-
#p24 ⇒ Object
contains details about the P24 payment method options.
-
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
-
#payco ⇒ Object
contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
contains details about the PayNow payment method options.
-
#paypal ⇒ Object
contains details about the PayPal payment method options.
-
#payto ⇒ Object
contains details about the PayTo payment method options.
-
#pix ⇒ Object
contains details about the Pix payment method options.
-
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
-
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
-
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
-
#sofort ⇒ Object
contains details about the Sofort payment method options.
-
#swish ⇒ Object
contains details about the Swish payment method options.
-
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
-
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 2774 2775 2776 2777 2778 2779 2780 2781 2782 2783 2784 2785 2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 2837 2838 |
# File 'lib/stripe/resources/checkout/session.rb', line 2756 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @boleto = boleto @card = card @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
2676 2677 2678 |
# File 'lib/stripe/resources/checkout/session.rb', line 2676 def acss_debit @acss_debit end |
#affirm ⇒ Object
contains details about the Affirm payment method options.
2678 2679 2680 |
# File 'lib/stripe/resources/checkout/session.rb', line 2678 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
2680 2681 2682 |
# File 'lib/stripe/resources/checkout/session.rb', line 2680 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
contains details about the Alipay payment method options.
2682 2683 2684 |
# File 'lib/stripe/resources/checkout/session.rb', line 2682 def alipay @alipay end |
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
2684 2685 2686 |
# File 'lib/stripe/resources/checkout/session.rb', line 2684 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
2686 2687 2688 |
# File 'lib/stripe/resources/checkout/session.rb', line 2686 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
2688 2689 2690 |
# File 'lib/stripe/resources/checkout/session.rb', line 2688 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
2690 2691 2692 |
# File 'lib/stripe/resources/checkout/session.rb', line 2690 def bancontact @bancontact end |
#boleto ⇒ Object
contains details about the Boleto payment method options.
2692 2693 2694 |
# File 'lib/stripe/resources/checkout/session.rb', line 2692 def boleto @boleto end |
#card ⇒ Object
contains details about the Card payment method options.
2694 2695 2696 |
# File 'lib/stripe/resources/checkout/session.rb', line 2694 def card @card end |
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
2696 2697 2698 |
# File 'lib/stripe/resources/checkout/session.rb', line 2696 def cashapp @cashapp end |
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
2698 2699 2700 |
# File 'lib/stripe/resources/checkout/session.rb', line 2698 def customer_balance @customer_balance end |
#eps ⇒ Object
contains details about the EPS payment method options.
2700 2701 2702 |
# File 'lib/stripe/resources/checkout/session.rb', line 2700 def eps @eps end |
#fpx ⇒ Object
contains details about the FPX payment method options.
2702 2703 2704 |
# File 'lib/stripe/resources/checkout/session.rb', line 2702 def fpx @fpx end |
#giropay ⇒ Object
contains details about the Giropay payment method options.
2704 2705 2706 |
# File 'lib/stripe/resources/checkout/session.rb', line 2704 def giropay @giropay end |
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
2706 2707 2708 |
# File 'lib/stripe/resources/checkout/session.rb', line 2706 def grabpay @grabpay end |
#ideal ⇒ Object
contains details about the Ideal payment method options.
2708 2709 2710 |
# File 'lib/stripe/resources/checkout/session.rb', line 2708 def ideal @ideal end |
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
2710 2711 2712 |
# File 'lib/stripe/resources/checkout/session.rb', line 2710 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
contains details about the Klarna payment method options.
2712 2713 2714 |
# File 'lib/stripe/resources/checkout/session.rb', line 2712 def klarna @klarna end |
#konbini ⇒ Object
contains details about the Konbini payment method options.
2714 2715 2716 |
# File 'lib/stripe/resources/checkout/session.rb', line 2714 def konbini @konbini end |
#kr_card ⇒ Object
contains details about the Korean card payment method options.
2716 2717 2718 |
# File 'lib/stripe/resources/checkout/session.rb', line 2716 def kr_card @kr_card end |
#link ⇒ Object
contains details about the Link payment method options.
2718 2719 2720 |
# File 'lib/stripe/resources/checkout/session.rb', line 2718 def link @link end |
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
2720 2721 2722 |
# File 'lib/stripe/resources/checkout/session.rb', line 2720 def mobilepay @mobilepay end |
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
2722 2723 2724 |
# File 'lib/stripe/resources/checkout/session.rb', line 2722 def multibanco @multibanco end |
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
2724 2725 2726 |
# File 'lib/stripe/resources/checkout/session.rb', line 2724 def naver_pay @naver_pay end |
#oxxo ⇒ Object
contains details about the OXXO payment method options.
2726 2727 2728 |
# File 'lib/stripe/resources/checkout/session.rb', line 2726 def oxxo @oxxo end |
#p24 ⇒ Object
contains details about the P24 payment method options.
2728 2729 2730 |
# File 'lib/stripe/resources/checkout/session.rb', line 2728 def p24 @p24 end |
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
2730 2731 2732 |
# File 'lib/stripe/resources/checkout/session.rb', line 2730 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
contains details about the PAYCO payment method options.
2732 2733 2734 |
# File 'lib/stripe/resources/checkout/session.rb', line 2732 def payco @payco end |
#paynow ⇒ Object
contains details about the PayNow payment method options.
2734 2735 2736 |
# File 'lib/stripe/resources/checkout/session.rb', line 2734 def paynow @paynow end |
#paypal ⇒ Object
contains details about the PayPal payment method options.
2736 2737 2738 |
# File 'lib/stripe/resources/checkout/session.rb', line 2736 def paypal @paypal end |
#payto ⇒ Object
contains details about the PayTo payment method options.
2738 2739 2740 |
# File 'lib/stripe/resources/checkout/session.rb', line 2738 def payto @payto end |
#pix ⇒ Object
contains details about the Pix payment method options.
2740 2741 2742 |
# File 'lib/stripe/resources/checkout/session.rb', line 2740 def pix @pix end |
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
2742 2743 2744 |
# File 'lib/stripe/resources/checkout/session.rb', line 2742 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
2744 2745 2746 |
# File 'lib/stripe/resources/checkout/session.rb', line 2744 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
2746 2747 2748 |
# File 'lib/stripe/resources/checkout/session.rb', line 2746 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
contains details about the Sofort payment method options.
2748 2749 2750 |
# File 'lib/stripe/resources/checkout/session.rb', line 2748 def sofort @sofort end |
#swish ⇒ Object
contains details about the Swish payment method options.
2750 2751 2752 |
# File 'lib/stripe/resources/checkout/session.rb', line 2750 def swish @swish end |
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
2752 2753 2754 |
# File 'lib/stripe/resources/checkout/session.rb', line 2752 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
2754 2755 2756 |
# File 'lib/stripe/resources/checkout/session.rb', line 2754 def wechat_pay @wechat_pay end |