Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, RevolutPay, SamsungPay, SepaDebit, Sofort, Swish, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
contains details about the Alipay payment method options.
-
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
-
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
-
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
-
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
-
#boleto ⇒ Object
contains details about the Boleto payment method options.
-
#card ⇒ Object
contains details about the Card payment method options.
-
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
-
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
-
#eps ⇒ Object
contains details about the EPS payment method options.
-
#fpx ⇒ Object
contains details about the FPX payment method options.
-
#giropay ⇒ Object
contains details about the Giropay payment method options.
-
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
-
#ideal ⇒ Object
contains details about the Ideal payment method options.
-
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
contains details about the Klarna payment method options.
-
#konbini ⇒ Object
contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
contains details about the Korean card payment method options.
-
#link ⇒ Object
contains details about the Link payment method options.
-
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
-
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
contains details about the OXXO payment method options.
-
#p24 ⇒ Object
contains details about the P24 payment method options.
-
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
-
#payco ⇒ Object
contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
contains details about the PayNow payment method options.
-
#paypal ⇒ Object
contains details about the PayPal payment method options.
-
#payto ⇒ Object
contains details about the PayTo payment method options.
-
#pix ⇒ Object
contains details about the Pix payment method options.
-
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
-
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
-
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
-
#sofort ⇒ Object
contains details about the Sofort payment method options.
-
#swish ⇒ Object
contains details about the Swish payment method options.
-
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
-
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
2691 2692 2693 2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 2713 2714 2715 2716 2717 2718 2719 2720 2721 2722 2723 2724 2725 2726 2727 2728 2729 2730 2731 2732 2733 2734 2735 2736 2737 2738 2739 2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 2752 2753 2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 2773 |
# File 'lib/stripe/resources/checkout/session.rb', line 2691 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @boleto = boleto @card = card @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
2611 2612 2613 |
# File 'lib/stripe/resources/checkout/session.rb', line 2611 def acss_debit @acss_debit end |
#affirm ⇒ Object
contains details about the Affirm payment method options.
2613 2614 2615 |
# File 'lib/stripe/resources/checkout/session.rb', line 2613 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
2615 2616 2617 |
# File 'lib/stripe/resources/checkout/session.rb', line 2615 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
contains details about the Alipay payment method options.
2617 2618 2619 |
# File 'lib/stripe/resources/checkout/session.rb', line 2617 def alipay @alipay end |
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
2619 2620 2621 |
# File 'lib/stripe/resources/checkout/session.rb', line 2619 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
2621 2622 2623 |
# File 'lib/stripe/resources/checkout/session.rb', line 2621 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
2623 2624 2625 |
# File 'lib/stripe/resources/checkout/session.rb', line 2623 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
2625 2626 2627 |
# File 'lib/stripe/resources/checkout/session.rb', line 2625 def bancontact @bancontact end |
#boleto ⇒ Object
contains details about the Boleto payment method options.
2627 2628 2629 |
# File 'lib/stripe/resources/checkout/session.rb', line 2627 def boleto @boleto end |
#card ⇒ Object
contains details about the Card payment method options.
2629 2630 2631 |
# File 'lib/stripe/resources/checkout/session.rb', line 2629 def card @card end |
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
2631 2632 2633 |
# File 'lib/stripe/resources/checkout/session.rb', line 2631 def cashapp @cashapp end |
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
2633 2634 2635 |
# File 'lib/stripe/resources/checkout/session.rb', line 2633 def customer_balance @customer_balance end |
#eps ⇒ Object
contains details about the EPS payment method options.
2635 2636 2637 |
# File 'lib/stripe/resources/checkout/session.rb', line 2635 def eps @eps end |
#fpx ⇒ Object
contains details about the FPX payment method options.
2637 2638 2639 |
# File 'lib/stripe/resources/checkout/session.rb', line 2637 def fpx @fpx end |
#giropay ⇒ Object
contains details about the Giropay payment method options.
2639 2640 2641 |
# File 'lib/stripe/resources/checkout/session.rb', line 2639 def giropay @giropay end |
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
2641 2642 2643 |
# File 'lib/stripe/resources/checkout/session.rb', line 2641 def grabpay @grabpay end |
#ideal ⇒ Object
contains details about the Ideal payment method options.
2643 2644 2645 |
# File 'lib/stripe/resources/checkout/session.rb', line 2643 def ideal @ideal end |
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
2645 2646 2647 |
# File 'lib/stripe/resources/checkout/session.rb', line 2645 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
contains details about the Klarna payment method options.
2647 2648 2649 |
# File 'lib/stripe/resources/checkout/session.rb', line 2647 def klarna @klarna end |
#konbini ⇒ Object
contains details about the Konbini payment method options.
2649 2650 2651 |
# File 'lib/stripe/resources/checkout/session.rb', line 2649 def konbini @konbini end |
#kr_card ⇒ Object
contains details about the Korean card payment method options.
2651 2652 2653 |
# File 'lib/stripe/resources/checkout/session.rb', line 2651 def kr_card @kr_card end |
#link ⇒ Object
contains details about the Link payment method options.
2653 2654 2655 |
# File 'lib/stripe/resources/checkout/session.rb', line 2653 def link @link end |
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
2655 2656 2657 |
# File 'lib/stripe/resources/checkout/session.rb', line 2655 def mobilepay @mobilepay end |
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
2657 2658 2659 |
# File 'lib/stripe/resources/checkout/session.rb', line 2657 def multibanco @multibanco end |
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
2659 2660 2661 |
# File 'lib/stripe/resources/checkout/session.rb', line 2659 def naver_pay @naver_pay end |
#oxxo ⇒ Object
contains details about the OXXO payment method options.
2661 2662 2663 |
# File 'lib/stripe/resources/checkout/session.rb', line 2661 def oxxo @oxxo end |
#p24 ⇒ Object
contains details about the P24 payment method options.
2663 2664 2665 |
# File 'lib/stripe/resources/checkout/session.rb', line 2663 def p24 @p24 end |
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
2665 2666 2667 |
# File 'lib/stripe/resources/checkout/session.rb', line 2665 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
contains details about the PAYCO payment method options.
2667 2668 2669 |
# File 'lib/stripe/resources/checkout/session.rb', line 2667 def payco @payco end |
#paynow ⇒ Object
contains details about the PayNow payment method options.
2669 2670 2671 |
# File 'lib/stripe/resources/checkout/session.rb', line 2669 def paynow @paynow end |
#paypal ⇒ Object
contains details about the PayPal payment method options.
2671 2672 2673 |
# File 'lib/stripe/resources/checkout/session.rb', line 2671 def paypal @paypal end |
#payto ⇒ Object
contains details about the PayTo payment method options.
2673 2674 2675 |
# File 'lib/stripe/resources/checkout/session.rb', line 2673 def payto @payto end |
#pix ⇒ Object
contains details about the Pix payment method options.
2675 2676 2677 |
# File 'lib/stripe/resources/checkout/session.rb', line 2675 def pix @pix end |
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
2677 2678 2679 |
# File 'lib/stripe/resources/checkout/session.rb', line 2677 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
2679 2680 2681 |
# File 'lib/stripe/resources/checkout/session.rb', line 2679 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
2681 2682 2683 |
# File 'lib/stripe/resources/checkout/session.rb', line 2681 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
contains details about the Sofort payment method options.
2683 2684 2685 |
# File 'lib/stripe/resources/checkout/session.rb', line 2683 def sofort @sofort end |
#swish ⇒ Object
contains details about the Swish payment method options.
2685 2686 2687 |
# File 'lib/stripe/resources/checkout/session.rb', line 2685 def swish @swish end |
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
2687 2688 2689 |
# File 'lib/stripe/resources/checkout/session.rb', line 2687 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
2689 2690 2691 |
# File 'lib/stripe/resources/checkout/session.rb', line 2689 def wechat_pay @wechat_pay end |