Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Boleto, Card, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, RevolutPay, SamsungPay, SepaDebit, Sofort, Swish, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
contains details about the Alipay payment method options.
-
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
-
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
-
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
-
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
-
#boleto ⇒ Object
contains details about the Boleto payment method options.
-
#card ⇒ Object
contains details about the Card payment method options.
-
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
-
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
-
#eps ⇒ Object
contains details about the EPS payment method options.
-
#fpx ⇒ Object
contains details about the FPX payment method options.
-
#giropay ⇒ Object
contains details about the Giropay payment method options.
-
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
-
#ideal ⇒ Object
contains details about the Ideal payment method options.
-
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
contains details about the Klarna payment method options.
-
#konbini ⇒ Object
contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
contains details about the Korean card payment method options.
-
#link ⇒ Object
contains details about the Link payment method options.
-
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
-
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
contains details about the OXXO payment method options.
-
#p24 ⇒ Object
contains details about the P24 payment method options.
-
#payco ⇒ Object
contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
contains details about the PayNow payment method options.
-
#paypal ⇒ Object
contains details about the PayPal payment method options.
-
#payto ⇒ Object
contains details about the PayTo payment method options.
-
#pix ⇒ Object
contains details about the Pix payment method options.
-
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
-
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
-
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
-
#sofort ⇒ Object
contains details about the Sofort payment method options.
-
#swish ⇒ Object
contains details about the Swish payment method options.
-
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
-
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 |
# File 'lib/stripe/resources/checkout/session.rb', line 3007 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @boleto = boleto @card = card @cashapp = cashapp @customer_balance = customer_balance @eps = eps @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @payco = payco @paynow = paynow @paypal = paypal @payto = payto @pix = pix @revolut_pay = revolut_pay @samsung_pay = samsung_pay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
2891 2892 2893 |
# File 'lib/stripe/resources/checkout/session.rb', line 2891 def acss_debit @acss_debit end |
#affirm ⇒ Object
contains details about the Affirm payment method options.
2894 2895 2896 |
# File 'lib/stripe/resources/checkout/session.rb', line 2894 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
2897 2898 2899 |
# File 'lib/stripe/resources/checkout/session.rb', line 2897 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
contains details about the Alipay payment method options.
2900 2901 2902 |
# File 'lib/stripe/resources/checkout/session.rb', line 2900 def alipay @alipay end |
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
2903 2904 2905 |
# File 'lib/stripe/resources/checkout/session.rb', line 2903 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
2906 2907 2908 |
# File 'lib/stripe/resources/checkout/session.rb', line 2906 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
2909 2910 2911 |
# File 'lib/stripe/resources/checkout/session.rb', line 2909 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
2912 2913 2914 |
# File 'lib/stripe/resources/checkout/session.rb', line 2912 def bancontact @bancontact end |
#boleto ⇒ Object
contains details about the Boleto payment method options.
2915 2916 2917 |
# File 'lib/stripe/resources/checkout/session.rb', line 2915 def boleto @boleto end |
#card ⇒ Object
contains details about the Card payment method options.
2918 2919 2920 |
# File 'lib/stripe/resources/checkout/session.rb', line 2918 def card @card end |
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
2921 2922 2923 |
# File 'lib/stripe/resources/checkout/session.rb', line 2921 def cashapp @cashapp end |
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
2924 2925 2926 |
# File 'lib/stripe/resources/checkout/session.rb', line 2924 def customer_balance @customer_balance end |
#eps ⇒ Object
contains details about the EPS payment method options.
2927 2928 2929 |
# File 'lib/stripe/resources/checkout/session.rb', line 2927 def eps @eps end |
#fpx ⇒ Object
contains details about the FPX payment method options.
2930 2931 2932 |
# File 'lib/stripe/resources/checkout/session.rb', line 2930 def fpx @fpx end |
#giropay ⇒ Object
contains details about the Giropay payment method options.
2933 2934 2935 |
# File 'lib/stripe/resources/checkout/session.rb', line 2933 def giropay @giropay end |
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
2936 2937 2938 |
# File 'lib/stripe/resources/checkout/session.rb', line 2936 def grabpay @grabpay end |
#ideal ⇒ Object
contains details about the Ideal payment method options.
2939 2940 2941 |
# File 'lib/stripe/resources/checkout/session.rb', line 2939 def ideal @ideal end |
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
2942 2943 2944 |
# File 'lib/stripe/resources/checkout/session.rb', line 2942 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
contains details about the Klarna payment method options.
2945 2946 2947 |
# File 'lib/stripe/resources/checkout/session.rb', line 2945 def klarna @klarna end |
#konbini ⇒ Object
contains details about the Konbini payment method options.
2948 2949 2950 |
# File 'lib/stripe/resources/checkout/session.rb', line 2948 def konbini @konbini end |
#kr_card ⇒ Object
contains details about the Korean card payment method options.
2951 2952 2953 |
# File 'lib/stripe/resources/checkout/session.rb', line 2951 def kr_card @kr_card end |
#link ⇒ Object
contains details about the Link payment method options.
2954 2955 2956 |
# File 'lib/stripe/resources/checkout/session.rb', line 2954 def link @link end |
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
2957 2958 2959 |
# File 'lib/stripe/resources/checkout/session.rb', line 2957 def mobilepay @mobilepay end |
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
2960 2961 2962 |
# File 'lib/stripe/resources/checkout/session.rb', line 2960 def multibanco @multibanco end |
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
2963 2964 2965 |
# File 'lib/stripe/resources/checkout/session.rb', line 2963 def naver_pay @naver_pay end |
#oxxo ⇒ Object
contains details about the OXXO payment method options.
2966 2967 2968 |
# File 'lib/stripe/resources/checkout/session.rb', line 2966 def oxxo @oxxo end |
#p24 ⇒ Object
contains details about the P24 payment method options.
2969 2970 2971 |
# File 'lib/stripe/resources/checkout/session.rb', line 2969 def p24 @p24 end |
#payco ⇒ Object
contains details about the PAYCO payment method options.
2972 2973 2974 |
# File 'lib/stripe/resources/checkout/session.rb', line 2972 def payco @payco end |
#paynow ⇒ Object
contains details about the PayNow payment method options.
2975 2976 2977 |
# File 'lib/stripe/resources/checkout/session.rb', line 2975 def paynow @paynow end |
#paypal ⇒ Object
contains details about the PayPal payment method options.
2978 2979 2980 |
# File 'lib/stripe/resources/checkout/session.rb', line 2978 def paypal @paypal end |
#payto ⇒ Object
contains details about the PayTo payment method options.
2981 2982 2983 |
# File 'lib/stripe/resources/checkout/session.rb', line 2981 def payto @payto end |
#pix ⇒ Object
contains details about the Pix payment method options.
2984 2985 2986 |
# File 'lib/stripe/resources/checkout/session.rb', line 2984 def pix @pix end |
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
2987 2988 2989 |
# File 'lib/stripe/resources/checkout/session.rb', line 2987 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
2990 2991 2992 |
# File 'lib/stripe/resources/checkout/session.rb', line 2990 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
2993 2994 2995 |
# File 'lib/stripe/resources/checkout/session.rb', line 2993 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
contains details about the Sofort payment method options.
2996 2997 2998 |
# File 'lib/stripe/resources/checkout/session.rb', line 2996 def sofort @sofort end |
#swish ⇒ Object
contains details about the Swish payment method options.
2999 3000 3001 |
# File 'lib/stripe/resources/checkout/session.rb', line 2999 def swish @swish end |
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
3002 3003 3004 |
# File 'lib/stripe/resources/checkout/session.rb', line 3002 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
3005 3006 3007 |
# File 'lib/stripe/resources/checkout/session.rb', line 3005 def wechat_pay @wechat_pay end |