Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#verification_method ⇒ Object
Verification method for the intent.
Instance Method Summary collapse
-
#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, verification_method: nil) ⇒ AcssDebit
constructor
A new instance of AcssDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, verification_method: nil) ⇒ AcssDebit
Returns a new instance of AcssDebit.
1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 |
# File 'lib/stripe/resources/checkout/session.rb', line 1824 def initialize( currency: nil, mandate_options: nil, setup_future_usage: nil, verification_method: nil ) @currency = currency @mandate_options = @setup_future_usage = setup_future_usage @verification_method = verification_method end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). This is only accepted for Checkout Sessions in ‘setup` mode.
1810 1811 1812 |
# File 'lib/stripe/resources/checkout/session.rb', line 1810 def currency @currency end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
1812 1813 1814 |
# File 'lib/stripe/resources/checkout/session.rb', line 1812 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1820 1821 1822 |
# File 'lib/stripe/resources/checkout/session.rb', line 1820 def setup_future_usage @setup_future_usage end |
#verification_method ⇒ Object
Verification method for the intent
1822 1823 1824 |
# File 'lib/stripe/resources/checkout/session.rb', line 1822 def verification_method @verification_method end |