Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, verification_method: nil) ⇒ AcssDebit

Returns a new instance of AcssDebit.



1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
# File 'lib/stripe/resources/checkout/session.rb', line 1810

def initialize(
  currency: nil,
  mandate_options: nil,
  setup_future_usage: nil,
  verification_method: nil
)
  @currency = currency
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
  @verification_method = verification_method
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). This is only accepted for Checkout Sessions in ‘setup` mode.



1796
1797
1798
# File 'lib/stripe/resources/checkout/session.rb', line 1796

def currency
  @currency
end

#mandate_optionsObject

Additional fields for Mandate creation



1798
1799
1800
# File 'lib/stripe/resources/checkout/session.rb', line 1798

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



1806
1807
1808
# File 'lib/stripe/resources/checkout/session.rb', line 1806

def setup_future_usage
  @setup_future_usage
end

#verification_methodObject

Verification method for the intent



1808
1809
1810
# File 'lib/stripe/resources/checkout/session.rb', line 1808

def verification_method
  @verification_method
end