Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#verification_method ⇒ Object
Verification method for the intent.
Instance Method Summary collapse
-
#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, verification_method: nil) ⇒ AcssDebit
constructor
A new instance of AcssDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, verification_method: nil) ⇒ AcssDebit
Returns a new instance of AcssDebit.
1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 |
# File 'lib/stripe/resources/checkout/session.rb', line 1817 def initialize( currency: nil, mandate_options: nil, setup_future_usage: nil, verification_method: nil ) @currency = currency @mandate_options = @setup_future_usage = setup_future_usage @verification_method = verification_method end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). This is only accepted for Checkout Sessions in ‘setup` mode.
1803 1804 1805 |
# File 'lib/stripe/resources/checkout/session.rb', line 1803 def currency @currency end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
1805 1806 1807 |
# File 'lib/stripe/resources/checkout/session.rb', line 1805 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1813 1814 1815 |
# File 'lib/stripe/resources/checkout/session.rb', line 1813 def setup_future_usage @setup_future_usage end |
#verification_method ⇒ Object
Verification method for the intent
1815 1816 1817 |
# File 'lib/stripe/resources/checkout/session.rb', line 1815 def verification_method @verification_method end |