Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
# File 'lib/stripe/resources/checkout/session.rb', line 1805

def initialize(
  custom_mandate_url: nil,
  default_for: nil,
  interval_description: nil,
  payment_schedule: nil,
  transaction_type: nil
)
  @custom_mandate_url = custom_mandate_url
  @default_for = default_for
  @interval_description = interval_description
  @payment_schedule = payment_schedule
  @transaction_type = transaction_type
end

Instance Attribute Details

#custom_mandate_urlObject

A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.



1795
1796
1797
# File 'lib/stripe/resources/checkout/session.rb', line 1795

def custom_mandate_url
  @custom_mandate_url
end

#default_forObject

List of Stripe products where this mandate can be selected automatically. Only usable in ‘setup` mode.



1797
1798
1799
# File 'lib/stripe/resources/checkout/session.rb', line 1797

def default_for
  @default_for
end

#interval_descriptionObject

Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.



1799
1800
1801
# File 'lib/stripe/resources/checkout/session.rb', line 1799

def interval_description
  @interval_description
end

#payment_scheduleObject

Payment schedule for the mandate.



1801
1802
1803
# File 'lib/stripe/resources/checkout/session.rb', line 1801

def payment_schedule
  @payment_schedule
end

#transaction_typeObject

Transaction type of the mandate.



1803
1804
1805
# File 'lib/stripe/resources/checkout/session.rb', line 1803

def transaction_type
  @transaction_type
end