Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/stripe/resources/checkout/session.rb', line 1795 def initialize( custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @default_for = default_for @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
1785 1786 1787 |
# File 'lib/stripe/resources/checkout/session.rb', line 1785 def custom_mandate_url @custom_mandate_url end |
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically. Only usable in ‘setup` mode.
1787 1788 1789 |
# File 'lib/stripe/resources/checkout/session.rb', line 1787 def default_for @default_for end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
1789 1790 1791 |
# File 'lib/stripe/resources/checkout/session.rb', line 1789 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
1791 1792 1793 |
# File 'lib/stripe/resources/checkout/session.rb', line 1791 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
1793 1794 1795 |
# File 'lib/stripe/resources/checkout/session.rb', line 1793 def transaction_type @transaction_type end |