Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Installments, Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(installments: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil) ⇒ Card

Returns a new instance of Card.



1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
# File 'lib/stripe/resources/checkout/session.rb', line 1995

def initialize(
  installments: nil,
  request_extended_authorization: nil,
  request_incremental_authorization: nil,
  request_multicapture: nil,
  request_overcapture: nil,
  request_three_d_secure: nil,
  restrictions: nil,
  setup_future_usage: nil,
  statement_descriptor_suffix_kana: nil,
  statement_descriptor_suffix_kanji: nil
)
  @installments = installments
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization = request_incremental_authorization
  @request_multicapture = request_multicapture
  @request_overcapture = request_overcapture
  @request_three_d_secure = request_three_d_secure
  @restrictions = restrictions
  @setup_future_usage = setup_future_usage
  @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji
end

Instance Attribute Details

#installmentsObject

Installment options for card payments



1969
1970
1971
# File 'lib/stripe/resources/checkout/session.rb', line 1969

def installments
  @installments
end

#request_extended_authorizationObject

Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.



1971
1972
1973
# File 'lib/stripe/resources/checkout/session.rb', line 1971

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject

Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.



1973
1974
1975
# File 'lib/stripe/resources/checkout/session.rb', line 1973

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject

Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.



1975
1976
1977
# File 'lib/stripe/resources/checkout/session.rb', line 1975

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject

Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.



1977
1978
1979
# File 'lib/stripe/resources/checkout/session.rb', line 1977

def request_overcapture
  @request_overcapture
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



1979
1980
1981
# File 'lib/stripe/resources/checkout/session.rb', line 1979

def request_three_d_secure
  @request_three_d_secure
end

#restrictionsObject

Restrictions to apply to the card payment method. For example, you can block specific card brands.



1981
1982
1983
# File 'lib/stripe/resources/checkout/session.rb', line 1981

def restrictions
  @restrictions
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



1989
1990
1991
# File 'lib/stripe/resources/checkout/session.rb', line 1989

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



1991
1992
1993
# File 'lib/stripe/resources/checkout/session.rb', line 1991

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



1993
1994
1995
# File 'lib/stripe/resources/checkout/session.rb', line 1993

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end