Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil) ⇒ Installments

Returns a new instance of Installments.



1976
1977
1978
# File 'lib/stripe/resources/checkout/session.rb', line 1976

def initialize(enabled: nil)
  @enabled = enabled
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this Checkout Session. Setting to false will prevent any installment plan from applying to a payment.



1974
1975
1976
# File 'lib/stripe/resources/checkout/session.rb', line 1974

def enabled
  @enabled
end