Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::CustomerBalance::BankTransfer
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: EuBankTransfer
Instance Attribute Summary collapse
-
#eu_bank_transfer ⇒ Object
Configuration for eu_bank_transfer funding type.
-
#requested_address_types ⇒ Object
List of address types that should be returned in the financial_addresses response.
-
#type ⇒ Object
The list of bank transfer types that this PaymentIntent is allowed to use for funding.
Instance Method Summary collapse
-
#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer
constructor
A new instance of BankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer
Returns a new instance of BankTransfer.
2080 2081 2082 2083 2084 |
# File 'lib/stripe/resources/checkout/session.rb', line 2080 def initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) @eu_bank_transfer = eu_bank_transfer @requested_address_types = requested_address_types @type = type end |
Instance Attribute Details
#eu_bank_transfer ⇒ Object
Configuration for eu_bank_transfer funding type.
2072 2073 2074 |
# File 'lib/stripe/resources/checkout/session.rb', line 2072 def eu_bank_transfer @eu_bank_transfer end |
#requested_address_types ⇒ Object
List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
Permitted values include: ‘sort_code`, `zengin`, `iban`, or `spei`.
2076 2077 2078 |
# File 'lib/stripe/resources/checkout/session.rb', line 2076 def requested_address_types @requested_address_types end |
#type ⇒ Object
The list of bank transfer types that this PaymentIntent is allowed to use for funding.
2078 2079 2080 |
# File 'lib/stripe/resources/checkout/session.rb', line 2078 def type @type end |