Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



2295
2296
2297
2298
# File 'lib/stripe/resources/checkout/session.rb', line 2295

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



2291
2292
2293
# File 'lib/stripe/resources/checkout/session.rb', line 2291

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



2293
2294
2295
# File 'lib/stripe/resources/checkout/session.rb', line 2293

def date
  @date
end