Class: Stripe::Checkout::Session::CreateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
# File 'lib/stripe/resources/checkout/session.rb', line 2406

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



2392
2393
2394
# File 'lib/stripe/resources/checkout/session.rb', line 2392

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



2394
2395
2396
# File 'lib/stripe/resources/checkout/session.rb', line 2394

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



2396
2397
2398
# File 'lib/stripe/resources/checkout/session.rb', line 2396

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



2398
2399
2400
# File 'lib/stripe/resources/checkout/session.rb', line 2398

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



2400
2401
2402
# File 'lib/stripe/resources/checkout/session.rb', line 2400

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



2402
2403
2404
# File 'lib/stripe/resources/checkout/session.rb', line 2402

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



2404
2405
2406
# File 'lib/stripe/resources/checkout/session.rb', line 2404

def start_date
  @start_date
end