Class: Stripe::Checkout::Session::CreateParams::Permissions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Update

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions

Returns a new instance of Permissions.



4098
4099
4100
4101
4102
4103
4104
4105
4106
4107
4108
# File 'lib/stripe/resources/checkout/session.rb', line 4098

def initialize(
  update: nil,
  update_discounts: nil,
  update_line_items: nil,
  update_shipping_details: nil
)
  @update = update
  @update_discounts = update_discounts
  @update_line_items = update_line_items
  @update_shipping_details = update_shipping_details
end

Instance Attribute Details

#updateObject

Permissions for updating the Checkout Session.



4080
4081
4082
# File 'lib/stripe/resources/checkout/session.rb', line 4080

def update
  @update
end

#update_discountsObject

Determines which entity is allowed to update the discounts (coupons or promotion codes) that apply to this session.

Default is ‘client_only`. Stripe Checkout client will automatically handle discount updates. If set to `server_only`, only your server is allowed to update discounts.



4084
4085
4086
# File 'lib/stripe/resources/checkout/session.rb', line 4084

def update_discounts
  @update_discounts
end

#update_line_itemsObject

Determines which entity is allowed to update the line items.

Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.

When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



4090
4091
4092
# File 'lib/stripe/resources/checkout/session.rb', line 4090

def update_line_items
  @update_line_items
end

#update_shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.

When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



4096
4097
4098
# File 'lib/stripe/resources/checkout/session.rb', line 4096

def update_shipping_details
  @update_shipping_details
end