Class: Stripe::Checkout::Session::CreateParams::Permissions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::Permissions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Update
Instance Attribute Summary collapse
-
#update ⇒ Object
Permissions for updating the Checkout Session.
-
#update_discounts ⇒ Object
Determines which entity is allowed to update the discounts (coupons or promotion codes) that apply to this session.
-
#update_line_items ⇒ Object
Determines which entity is allowed to update the line items.
-
#update_shipping_details ⇒ Object
Determines which entity is allowed to update the shipping details.
Instance Method Summary collapse
-
#initialize(update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions
constructor
A new instance of Permissions.
Methods inherited from RequestParams
Constructor Details
#initialize(update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions
Returns a new instance of Permissions.
2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 |
# File 'lib/stripe/resources/checkout/session.rb', line 2958 def initialize( update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil ) @update = update @update_discounts = update_discounts @update_line_items = update_line_items @update_shipping_details = update_shipping_details end |
Instance Attribute Details
#update ⇒ Object
Permissions for updating the Checkout Session.
2940 2941 2942 |
# File 'lib/stripe/resources/checkout/session.rb', line 2940 def update @update end |
#update_discounts ⇒ Object
Determines which entity is allowed to update the discounts (coupons or promotion codes) that apply to this session.
Default is ‘client_only`. Stripe Checkout client will automatically handle discount updates. If set to `server_only`, only your server is allowed to update discounts.
2944 2945 2946 |
# File 'lib/stripe/resources/checkout/session.rb', line 2944 def update_discounts @update_discounts end |
#update_line_items ⇒ Object
Determines which entity is allowed to update the line items.
Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.
When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.
2950 2951 2952 |
# File 'lib/stripe/resources/checkout/session.rb', line 2950 def update_line_items @update_line_items end |
#update_shipping_details ⇒ Object
Determines which entity is allowed to update the shipping details.
Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.
When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.
2956 2957 2958 |
# File 'lib/stripe/resources/checkout/session.rb', line 2956 def update_shipping_details @update_shipping_details end |