Class: Stripe::Checkout::Session::CreateParams::Permissions::Update

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(line_items: nil, shipping_details: nil) ⇒ Update

Returns a new instance of Update.



2818
2819
2820
2821
# File 'lib/stripe/resources/checkout/session.rb', line 2818

def initialize(line_items: nil, shipping_details: nil)
  @line_items = line_items
  @shipping_details = shipping_details
end

Instance Attribute Details

#line_itemsObject

Determines which entity is allowed to update the line items.

Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.

When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



2810
2811
2812
# File 'lib/stripe/resources/checkout/session.rb', line 2810

def line_items
  @line_items
end

#shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.

When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



2816
2817
2818
# File 'lib/stripe/resources/checkout/session.rb', line 2816

def shipping_details
  @shipping_details
end