Class: Stripe::Checkout::Session::CreateParams::SavedPaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::SavedPaymentMethodOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#allow_redisplay_filters ⇒ Object
Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer.
-
#payment_method_remove ⇒ Object
Enable customers to choose if they wish to remove their saved payment methods.
-
#payment_method_save ⇒ Object
Enable customers to choose if they wish to save their payment method for future use.
Instance Method Summary collapse
-
#initialize(allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions
constructor
A new instance of SavedPaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions
Returns a new instance of SavedPaymentMethodOptions.
2990 2991 2992 2993 2994 2995 2996 2997 2998 |
# File 'lib/stripe/resources/checkout/session.rb', line 2990 def initialize( allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil ) @allow_redisplay_filters = allow_redisplay_filters @payment_method_remove = payment_method_remove @payment_method_save = payment_method_save end |
Instance Attribute Details
#allow_redisplay_filters ⇒ Object
Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.
2984 2985 2986 |
# File 'lib/stripe/resources/checkout/session.rb', line 2984 def allow_redisplay_filters @allow_redisplay_filters end |
#payment_method_remove ⇒ Object
Enable customers to choose if they wish to remove their saved payment methods. Disabled by default.
2986 2987 2988 |
# File 'lib/stripe/resources/checkout/session.rb', line 2986 def payment_method_remove @payment_method_remove end |
#payment_method_save ⇒ Object
Enable customers to choose if they wish to save their payment method for future use. Disabled by default.
2988 2989 2990 |
# File 'lib/stripe/resources/checkout/session.rb', line 2988 def payment_method_save @payment_method_save end |