Class: Stripe::Checkout::Session::CreateParams::SavedPaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay_filters: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions

Returns a new instance of SavedPaymentMethodOptions.



2909
2910
2911
2912
# File 'lib/stripe/resources/checkout/session.rb', line 2909

def initialize(allow_redisplay_filters: nil, payment_method_save: nil)
  @allow_redisplay_filters = allow_redisplay_filters
  @payment_method_save = payment_method_save
end

Instance Attribute Details

#allow_redisplay_filtersObject

Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.



2905
2906
2907
# File 'lib/stripe/resources/checkout/session.rb', line 2905

def allow_redisplay_filters
  @allow_redisplay_filters
end

#payment_method_saveObject

Enable customers to choose if they wish to save their payment method for future use. Disabled by default.



2907
2908
2909
# File 'lib/stripe/resources/checkout/session.rb', line 2907

def payment_method_save
  @payment_method_save
end