Class: Stripe::Checkout::Session::CreateParams::SavedPaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay_filters: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions

Returns a new instance of SavedPaymentMethodOptions.



2900
2901
2902
2903
# File 'lib/stripe/resources/checkout/session.rb', line 2900

def initialize(allow_redisplay_filters: nil, payment_method_save: nil)
  @allow_redisplay_filters = allow_redisplay_filters
  @payment_method_save = payment_method_save
end

Instance Attribute Details

#allow_redisplay_filtersObject

Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.



2896
2897
2898
# File 'lib/stripe/resources/checkout/session.rb', line 2896

def allow_redisplay_filters
  @allow_redisplay_filters
end

#payment_method_saveObject

Enable customers to choose if they wish to save their payment method for future use. Disabled by default.



2898
2899
2900
# File 'lib/stripe/resources/checkout/session.rb', line 2898

def payment_method_save
  @payment_method_save
end