Class: Stripe::Checkout::Session::CreateParams::SavedPaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay_filters: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions

Returns a new instance of SavedPaymentMethodOptions.



2821
2822
2823
2824
# File 'lib/stripe/resources/checkout/session.rb', line 2821

def initialize(allow_redisplay_filters: nil, payment_method_save: nil)
  @allow_redisplay_filters = allow_redisplay_filters
  @payment_method_save = payment_method_save
end

Instance Attribute Details

#allow_redisplay_filtersObject

Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.



2817
2818
2819
# File 'lib/stripe/resources/checkout/session.rb', line 2817

def allow_redisplay_filters
  @allow_redisplay_filters
end

#payment_method_saveObject

Enable customers to choose if they wish to save their payment method for future use. Disabled by default.



2819
2820
2821
# File 'lib/stripe/resources/checkout/session.rb', line 2819

def payment_method_save
  @payment_method_save
end