Class: Stripe::Checkout::Session::CreateParams::SavedPaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay_filters: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions

Returns a new instance of SavedPaymentMethodOptions.



3135
3136
3137
3138
# File 'lib/stripe/resources/checkout/session.rb', line 3135

def initialize(allow_redisplay_filters: nil, payment_method_save: nil)
  @allow_redisplay_filters = allow_redisplay_filters
  @payment_method_save = payment_method_save
end

Instance Attribute Details

#allow_redisplay_filtersObject

Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.



3130
3131
3132
# File 'lib/stripe/resources/checkout/session.rb', line 3130

def allow_redisplay_filters
  @allow_redisplay_filters
end

#payment_method_saveObject

Enable customers to choose if they wish to save their payment method for future use. Disabled by default.



3133
3134
3135
# File 'lib/stripe/resources/checkout/session.rb', line 3133

def payment_method_save
  @payment_method_save
end