Class: Stripe::Checkout::Session::CreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



3009
3010
3011
3012
3013
# File 'lib/stripe/resources/checkout/session.rb', line 3009

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



3003
3004
3005
# File 'lib/stripe/resources/checkout/session.rb', line 3003

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3005
3006
3007
# File 'lib/stripe/resources/checkout/session.rb', line 3005

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



3007
3008
3009
# File 'lib/stripe/resources/checkout/session.rb', line 3007

def on_behalf_of
  @on_behalf_of
end