Class: Stripe::Checkout::Session::CreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



2977
2978
2979
2980
2981
# File 'lib/stripe/resources/checkout/session.rb', line 2977

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2971
2972
2973
# File 'lib/stripe/resources/checkout/session.rb', line 2971

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2973
2974
2975
# File 'lib/stripe/resources/checkout/session.rb', line 2973

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



2975
2976
2977
# File 'lib/stripe/resources/checkout/session.rb', line 2975

def on_behalf_of
  @on_behalf_of
end