Class: Stripe::Checkout::Session::CreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



2737
2738
2739
2740
2741
# File 'lib/stripe/resources/checkout/session.rb', line 2737

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2731
2732
2733
# File 'lib/stripe/resources/checkout/session.rb', line 2731

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2733
2734
2735
# File 'lib/stripe/resources/checkout/session.rb', line 2733

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



2735
2736
2737
# File 'lib/stripe/resources/checkout/session.rb', line 2735

def on_behalf_of
  @on_behalf_of
end