Class: Stripe::Checkout::Session::CreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



2835
2836
2837
2838
2839
# File 'lib/stripe/resources/checkout/session.rb', line 2835

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2829
2830
2831
# File 'lib/stripe/resources/checkout/session.rb', line 2829

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2831
2832
2833
# File 'lib/stripe/resources/checkout/session.rb', line 2831

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



2833
2834
2835
# File 'lib/stripe/resources/checkout/session.rb', line 2833

def on_behalf_of
  @on_behalf_of
end