Class: Stripe::Checkout::Session::CreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



3151
3152
3153
3154
3155
# File 'lib/stripe/resources/checkout/session.rb', line 3151

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



3143
3144
3145
# File 'lib/stripe/resources/checkout/session.rb', line 3143

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3146
3147
3148
# File 'lib/stripe/resources/checkout/session.rb', line 3146

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



3149
3150
3151
# File 'lib/stripe/resources/checkout/session.rb', line 3149

def on_behalf_of
  @on_behalf_of
end