Class: Stripe::Checkout::Session::CreateParams::ShippingOption

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: ShippingRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption

Returns a new instance of ShippingOption.



3126
3127
3128
3129
# File 'lib/stripe/resources/checkout/session.rb', line 3126

def initialize(shipping_rate: nil, shipping_rate_data: nil)
  @shipping_rate = shipping_rate
  @shipping_rate_data = shipping_rate_data
end

Instance Attribute Details

#shipping_rateObject

The ID of the Shipping Rate to use for this shipping option.



3122
3123
3124
# File 'lib/stripe/resources/checkout/session.rb', line 3122

def shipping_rate
  @shipping_rate
end

#shipping_rate_dataObject

Parameters to be passed to Shipping Rate creation for this shipping option.



3124
3125
3126
# File 'lib/stripe/resources/checkout/session.rb', line 3124

def shipping_rate_data
  @shipping_rate_data
end