Class: Stripe::Checkout::Session::CreateParams::SubscriptionData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



3168
3169
3170
3171
# File 'lib/stripe/resources/checkout/session.rb', line 3168

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



3164
3165
3166
# File 'lib/stripe/resources/checkout/session.rb', line 3164

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



3166
3167
3168
# File 'lib/stripe/resources/checkout/session.rb', line 3166

def destination
  @destination
end