Class: Stripe::Checkout::Session::CreateParams::SubscriptionData::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::SubscriptionData::TransferData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
2972 2973 2974 2975 |
# File 'lib/stripe/resources/checkout/session.rb', line 2972 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
2968 2969 2970 |
# File 'lib/stripe/resources/checkout/session.rb', line 2968 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
2970 2971 2972 |
# File 'lib/stripe/resources/checkout/session.rb', line 2970 def destination @destination end |