Class: Stripe::Checkout::Session::CreateParams::SubscriptionData::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::SubscriptionData::TransferData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
3073 3074 3075 3076 |
# File 'lib/stripe/resources/checkout/session.rb', line 3073 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
3069 3070 3071 |
# File 'lib/stripe/resources/checkout/session.rb', line 3069 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
3071 3072 3073 |
# File 'lib/stripe/resources/checkout/session.rb', line 3071 def destination @destination end |