Class: Stripe::Checkout::Session::CreateParams::SubscriptionData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2965
2966
2967
2968
# File 'lib/stripe/resources/checkout/session.rb', line 2965

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



2961
2962
2963
# File 'lib/stripe/resources/checkout/session.rb', line 2961

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2963
2964
2965
# File 'lib/stripe/resources/checkout/session.rb', line 2963

def destination
  @destination
end