Class: Stripe::Checkout::Session::CreateParams::WalletOptions::Link
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::CreateParams::WalletOptions::Link
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#display ⇒ Object
Specifies whether Checkout should display Link as a payment option.
Instance Method Summary collapse
-
#initialize(display: nil) ⇒ Link
constructor
A new instance of Link.
Methods inherited from RequestParams
Constructor Details
#initialize(display: nil) ⇒ Link
Returns a new instance of Link.
3177 3178 3179 |
# File 'lib/stripe/resources/checkout/session.rb', line 3177 def initialize(display: nil) @display = display end |
Instance Attribute Details
#display ⇒ Object
Specifies whether Checkout should display Link as a payment option. By default, Checkout will display all the supported wallets that the Checkout Session was created with. This is the ‘auto` behavior, and it is the default choice.
3175 3176 3177 |
# File 'lib/stripe/resources/checkout/session.rb', line 3175 def display @display end |