Class: Stripe::Checkout::Session::CreateParams::WalletOptions::Link

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(display: nil) ⇒ Link

Returns a new instance of Link.



3173
3174
3175
# File 'lib/stripe/resources/checkout/session.rb', line 3173

def initialize(display: nil)
  @display = display
end

Instance Attribute Details

#displayObject

Specifies whether Checkout should display Link as a payment option. By default, Checkout will display all the supported wallets that the Checkout Session was created with. This is the ‘auto` behavior, and it is the default choice.



3171
3172
3173
# File 'lib/stripe/resources/checkout/session.rb', line 3171

def display
  @display
end