Class: Stripe::Checkout::Session::CurrentAttempt

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: BillingDetails, PaymentMethodDetails, ShippingDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_detailsObject (readonly)

The customer’s billing information, if provided.



566
567
568
# File 'lib/stripe/resources/checkout/session.rb', line 566

def billing_details
  @billing_details
end

#emailObject (readonly)

The customer’s email.



568
569
570
# File 'lib/stripe/resources/checkout/session.rb', line 568

def email
  @email
end

#idObject (readonly)

The attempt ID you will pass to the [Checkout Session approve](api/checkout/sessions/approve) endpoint to approve the attempt.



570
571
572
# File 'lib/stripe/resources/checkout/session.rb', line 570

def id
  @id
end

#payment_method_detailsObject (readonly)

Information about the payment method the customer is attempting to pay with. Relevant payment method information is provided when available. Some payment details are only available after the payment has completed and can’t be returned in the manual approval flow.



572
573
574
# File 'lib/stripe/resources/checkout/session.rb', line 572

def payment_method_details
  @payment_method_details
end

#phoneObject (readonly)

The customer’s phone number.



574
575
576
# File 'lib/stripe/resources/checkout/session.rb', line 574

def phone
  @phone
end

#shipping_detailsObject (readonly)

The customer’s shipping information, if provided.



576
577
578
# File 'lib/stripe/resources/checkout/session.rb', line 576

def shipping_details
  @shipping_details
end

Class Method Details

.field_remappingsObject



586
587
588
# File 'lib/stripe/resources/checkout/session.rb', line 586

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



578
579
580
581
582
583
584
# File 'lib/stripe/resources/checkout/session.rb', line 578

def self.inner_class_types
  @inner_class_types = {
    billing_details: BillingDetails,
    payment_method_details: PaymentMethodDetails,
    shipping_details: ShippingDetails,
  }
end