Class: Stripe::Checkout::Session::CurrentAttempt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CurrentAttempt
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: BillingDetails, PaymentMethodDetails, ShippingDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
readonly
The customer’s billing information, if provided.
-
#email ⇒ Object
readonly
The customer’s email.
-
#id ⇒ Object
readonly
The attempt ID you will pass to the [Checkout Session approve](api/checkout/sessions/approve) endpoint to approve the attempt.
-
#payment_method_details ⇒ Object
readonly
Information about the payment method the customer is attempting to pay with.
-
#phone ⇒ Object
readonly
The customer’s phone number.
-
#shipping_details ⇒ Object
readonly
The customer’s shipping information, if provided.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_details ⇒ Object (readonly)
The customer’s billing information, if provided.
545 546 547 |
# File 'lib/stripe/resources/checkout/session.rb', line 545 def billing_details @billing_details end |
#email ⇒ Object (readonly)
The customer’s email.
547 548 549 |
# File 'lib/stripe/resources/checkout/session.rb', line 547 def email @email end |
#id ⇒ Object (readonly)
The attempt ID you will pass to the [Checkout Session approve](api/checkout/sessions/approve) endpoint to approve the attempt.
549 550 551 |
# File 'lib/stripe/resources/checkout/session.rb', line 549 def id @id end |
#payment_method_details ⇒ Object (readonly)
Information about the payment method the customer is attempting to pay with. Relevant payment method information is provided when available. Some payment details are only available after the payment has completed and can’t be returned in the manual approval flow.
551 552 553 |
# File 'lib/stripe/resources/checkout/session.rb', line 551 def payment_method_details @payment_method_details end |
#phone ⇒ Object (readonly)
The customer’s phone number.
553 554 555 |
# File 'lib/stripe/resources/checkout/session.rb', line 553 def phone @phone end |
#shipping_details ⇒ Object (readonly)
The customer’s shipping information, if provided.
555 556 557 |
# File 'lib/stripe/resources/checkout/session.rb', line 555 def shipping_details @shipping_details end |
Class Method Details
.field_remappings ⇒ Object
565 566 567 |
# File 'lib/stripe/resources/checkout/session.rb', line 565 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
557 558 559 560 561 562 563 |
# File 'lib/stripe/resources/checkout/session.rb', line 557 def self.inner_class_types @inner_class_types = { billing_details: BillingDetails, payment_method_details: PaymentMethodDetails, shipping_details: ShippingDetails, } end |