Class: Stripe::Checkout::Session::CurrentAttempt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CurrentAttempt
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: BillingDetails, PaymentMethodDetails, ShippingDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
readonly
The customer’s billing information, if provided.
-
#email ⇒ Object
readonly
The customer’s email.
-
#id ⇒ Object
readonly
The attempt ID you will pass to the [Checkout Session approve](api/checkout/sessions/approve) endpoint to approve the attempt.
-
#payment_method_details ⇒ Object
readonly
Information about the payment method the customer is attempting to pay with.
-
#phone ⇒ Object
readonly
The customer’s phone number.
-
#shipping_details ⇒ Object
readonly
The customer’s shipping information, if provided.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_details ⇒ Object (readonly)
The customer’s billing information, if provided.
2360 2361 2362 |
# File 'lib/stripe/resources/checkout/session.rb', line 2360 def billing_details @billing_details end |
#email ⇒ Object (readonly)
The customer’s email.
2362 2363 2364 |
# File 'lib/stripe/resources/checkout/session.rb', line 2362 def email @email end |
#id ⇒ Object (readonly)
The attempt ID you will pass to the [Checkout Session approve](api/checkout/sessions/approve) endpoint to approve the attempt.
2364 2365 2366 |
# File 'lib/stripe/resources/checkout/session.rb', line 2364 def id @id end |
#payment_method_details ⇒ Object (readonly)
Information about the payment method the customer is attempting to pay with.
2366 2367 2368 |
# File 'lib/stripe/resources/checkout/session.rb', line 2366 def payment_method_details @payment_method_details end |
#phone ⇒ Object (readonly)
The customer’s phone number.
2368 2369 2370 |
# File 'lib/stripe/resources/checkout/session.rb', line 2368 def phone @phone end |
#shipping_details ⇒ Object (readonly)
The customer’s shipping information, if provided.
2370 2371 2372 |
# File 'lib/stripe/resources/checkout/session.rb', line 2370 def shipping_details @shipping_details end |
Class Method Details
.field_remappings ⇒ Object
2380 2381 2382 |
# File 'lib/stripe/resources/checkout/session.rb', line 2380 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2372 2373 2374 2375 2376 2377 2378 |
# File 'lib/stripe/resources/checkout/session.rb', line 2372 def self.inner_class_types @inner_class_types = { billing_details: BillingDetails, payment_method_details: PaymentMethodDetails, shipping_details: ShippingDetails, } end |