Class: Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AuBecsDebit, BacsDebit, Boleto, Card, Link, SepaDebit, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allow_redisplayObject (readonly)

Indicates whether this payment method can be shown again to its customer in a checkout flow.



494
495
496
# File 'lib/stripe/resources/checkout/session.rb', line 494

def allow_redisplay
  @allow_redisplay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



496
497
498
# File 'lib/stripe/resources/checkout/session.rb', line 496

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



498
499
500
# File 'lib/stripe/resources/checkout/session.rb', line 498

def bacs_debit
  @bacs_debit
end

#boletoObject (readonly)

Attribute for field boleto



500
501
502
# File 'lib/stripe/resources/checkout/session.rb', line 500

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



502
503
504
# File 'lib/stripe/resources/checkout/session.rb', line 502

def card
  @card
end

Attribute for field link



504
505
506
# File 'lib/stripe/resources/checkout/session.rb', line 504

def link
  @link
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



506
507
508
# File 'lib/stripe/resources/checkout/session.rb', line 506

def sepa_debit
  @sepa_debit
end

#typeObject (readonly)

The type of payment method the customer is attempting to pay with. An additional hash is included in the payment method details with a name matching this value. It contains additional information specific to the payment method type.



508
509
510
# File 'lib/stripe/resources/checkout/session.rb', line 508

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



510
511
512
# File 'lib/stripe/resources/checkout/session.rb', line 510

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



524
525
526
# File 'lib/stripe/resources/checkout/session.rb', line 524

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



512
513
514
515
516
517
518
519
520
521
522
# File 'lib/stripe/resources/checkout/session.rb', line 512

def self.inner_class_types
  @inner_class_types = {
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    boleto: Boleto,
    card: Card,
    link: Link,
    sepa_debit: SepaDebit,
    us_bank_account: UsBankAccount,
  }
end