Class: Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AuBecsDebit, BacsDebit, Boleto, Card, Link, SepaDebit, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
readonly
Indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#type ⇒ Object
readonly
The type of payment method the customer is attempting to pay with.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#allow_redisplay ⇒ Object (readonly)
Indicates whether this payment method can be shown again to its customer in a checkout flow.
473 474 475 |
# File 'lib/stripe/resources/checkout/session.rb', line 473 def allow_redisplay @allow_redisplay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
475 476 477 |
# File 'lib/stripe/resources/checkout/session.rb', line 475 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
477 478 479 |
# File 'lib/stripe/resources/checkout/session.rb', line 477 def bacs_debit @bacs_debit end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
479 480 481 |
# File 'lib/stripe/resources/checkout/session.rb', line 479 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
481 482 483 |
# File 'lib/stripe/resources/checkout/session.rb', line 481 def card @card end |
#link ⇒ Object (readonly)
Attribute for field link
483 484 485 |
# File 'lib/stripe/resources/checkout/session.rb', line 483 def link @link end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
485 486 487 |
# File 'lib/stripe/resources/checkout/session.rb', line 485 def sepa_debit @sepa_debit end |
#type ⇒ Object (readonly)
The type of payment method the customer is attempting to pay with. An additional hash is included in the payment method details with a name matching this value. It contains additional information specific to the payment method type.
487 488 489 |
# File 'lib/stripe/resources/checkout/session.rb', line 487 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
489 490 491 |
# File 'lib/stripe/resources/checkout/session.rb', line 489 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
503 504 505 |
# File 'lib/stripe/resources/checkout/session.rb', line 503 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
491 492 493 494 495 496 497 498 499 500 501 |
# File 'lib/stripe/resources/checkout/session.rb', line 491 def self.inner_class_types @inner_class_types = { au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, boleto: Boleto, card: Card, link: Link, sepa_debit: SepaDebit, us_bank_account: UsBankAccount, } end |