Class: Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CurrentAttempt::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Card
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#allow_redisplay ⇒ Object
readonly
Indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#type ⇒ Object
readonly
The type of payment method the customer is attempting to pay with.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#allow_redisplay ⇒ Object (readonly)
Indicates whether this payment method can be shown again to its customer in a checkout flow.
2308 2309 2310 |
# File 'lib/stripe/resources/checkout/session.rb', line 2308 def allow_redisplay @allow_redisplay end |
#card ⇒ Object (readonly)
Attribute for field card
2310 2311 2312 |
# File 'lib/stripe/resources/checkout/session.rb', line 2310 def card @card end |
#type ⇒ Object (readonly)
The type of payment method the customer is attempting to pay with. An additional hash is included in the payment method details with a name matching this value. It contains additional information specific to the payment method type.
2312 2313 2314 |
# File 'lib/stripe/resources/checkout/session.rb', line 2312 def type @type end |
Class Method Details
.field_remappings ⇒ Object
2318 2319 2320 |
# File 'lib/stripe/resources/checkout/session.rb', line 2318 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2314 2315 2316 |
# File 'lib/stripe/resources/checkout/session.rb', line 2314 def self.inner_class_types @inner_class_types = { card: Card } end |