Class: Stripe::Checkout::Session::CustomField

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

Attribute for field dropdown



398
399
400
# File 'lib/stripe/resources/checkout/session.rb', line 398

def dropdown
  @dropdown
end

#keyObject (readonly)

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



400
401
402
# File 'lib/stripe/resources/checkout/session.rb', line 400

def key
  @key
end

#labelObject (readonly)

Attribute for field label



402
403
404
# File 'lib/stripe/resources/checkout/session.rb', line 402

def label
  @label
end

#numericObject (readonly)

Attribute for field numeric



404
405
406
# File 'lib/stripe/resources/checkout/session.rb', line 404

def numeric
  @numeric
end

#optionalObject (readonly)

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



406
407
408
# File 'lib/stripe/resources/checkout/session.rb', line 406

def optional
  @optional
end

#textObject (readonly)

Attribute for field text



408
409
410
# File 'lib/stripe/resources/checkout/session.rb', line 408

def text
  @text
end

#typeObject (readonly)

The type of the field.



410
411
412
# File 'lib/stripe/resources/checkout/session.rb', line 410

def type
  @type
end

Class Method Details

.field_remappingsObject



416
417
418
# File 'lib/stripe/resources/checkout/session.rb', line 416

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



412
413
414
# File 'lib/stripe/resources/checkout/session.rb', line 412

def self.inner_class_types
  @inner_class_types = { dropdown: Dropdown, label: Label, numeric: Numeric, text: Text }
end