Class: Stripe::Checkout::Session::CustomField
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CustomField
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Dropdown, Label, Numeric, Text
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#dropdown ⇒ Object
readonly
Attribute for field dropdown.
-
#key ⇒ Object
readonly
String of your choice that your integration can use to reconcile this field.
-
#label ⇒ Object
readonly
Attribute for field label.
-
#numeric ⇒ Object
readonly
Attribute for field numeric.
-
#optional ⇒ Object
readonly
Whether the customer is required to complete the field before completing the Checkout Session.
-
#text ⇒ Object
readonly
Attribute for field text.
-
#type ⇒ Object
readonly
The type of the field.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#dropdown ⇒ Object (readonly)
Attribute for field dropdown
676 677 678 |
# File 'lib/stripe/resources/checkout/session.rb', line 676 def dropdown @dropdown end |
#key ⇒ Object (readonly)
String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.
678 679 680 |
# File 'lib/stripe/resources/checkout/session.rb', line 678 def key @key end |
#label ⇒ Object (readonly)
Attribute for field label
680 681 682 |
# File 'lib/stripe/resources/checkout/session.rb', line 680 def label @label end |
#numeric ⇒ Object (readonly)
Attribute for field numeric
682 683 684 |
# File 'lib/stripe/resources/checkout/session.rb', line 682 def numeric @numeric end |
#optional ⇒ Object (readonly)
Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.
684 685 686 |
# File 'lib/stripe/resources/checkout/session.rb', line 684 def optional @optional end |
#text ⇒ Object (readonly)
Attribute for field text
686 687 688 |
# File 'lib/stripe/resources/checkout/session.rb', line 686 def text @text end |
#type ⇒ Object (readonly)
The type of the field.
688 689 690 |
# File 'lib/stripe/resources/checkout/session.rb', line 688 def type @type end |
Class Method Details
.field_remappings ⇒ Object
694 695 696 |
# File 'lib/stripe/resources/checkout/session.rb', line 694 def self.field_remappings @field_remappings = {} end |