Class: Stripe::Checkout::Session::CustomField::Dropdown::Option

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#labelObject (readonly)

The label for the option, displayed to the customer. Up to 100 characters.



317
318
319
# File 'lib/stripe/resources/checkout/session.rb', line 317

def label
  @label
end

#valueObject (readonly)

The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.



319
320
321
# File 'lib/stripe/resources/checkout/session.rb', line 319

def value
  @value
end

Class Method Details

.field_remappingsObject



325
326
327
# File 'lib/stripe/resources/checkout/session.rb', line 325

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



321
322
323
# File 'lib/stripe/resources/checkout/session.rb', line 321

def self.inner_class_types
  @inner_class_types = {}
end