Class: Stripe::Checkout::Session::CustomerDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Address, TaxId

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The customer’s address after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.



535
536
537
# File 'lib/stripe/resources/checkout/session.rb', line 535

def address
  @address
end

#business_nameObject (readonly)

The customer’s business name after a completed Checkout Session.



537
538
539
# File 'lib/stripe/resources/checkout/session.rb', line 537

def business_name
  @business_name
end

#emailObject (readonly)

The email associated with the Customer, if one exists, on the Checkout Session after a completed Checkout Session or at time of session expiry. Otherwise, if the customer has consented to promotional content, this value is the most recent valid email provided by the customer on the Checkout form.



540
541
542
# File 'lib/stripe/resources/checkout/session.rb', line 540

def email
  @email
end

#individual_nameObject (readonly)

The customer’s individual name after a completed Checkout Session.



542
543
544
# File 'lib/stripe/resources/checkout/session.rb', line 542

def individual_name
  @individual_name
end

#nameObject (readonly)

The customer’s name after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.



544
545
546
# File 'lib/stripe/resources/checkout/session.rb', line 544

def name
  @name
end

#phoneObject (readonly)

The customer’s phone number after a completed Checkout Session.



546
547
548
# File 'lib/stripe/resources/checkout/session.rb', line 546

def phone
  @phone
end

#tax_exemptObject (readonly)

The customer’s tax exempt status after a completed Checkout Session.



548
549
550
# File 'lib/stripe/resources/checkout/session.rb', line 548

def tax_exempt
  @tax_exempt
end

#tax_idsObject (readonly)

The customer’s tax IDs after a completed Checkout Session.



550
551
552
# File 'lib/stripe/resources/checkout/session.rb', line 550

def tax_ids
  @tax_ids
end

Class Method Details

.field_remappingsObject



556
557
558
# File 'lib/stripe/resources/checkout/session.rb', line 556

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



552
553
554
# File 'lib/stripe/resources/checkout/session.rb', line 552

def self.inner_class_types
  @inner_class_types = { address: Address, tax_ids: TaxId }
end