Class: Stripe::Checkout::Session::CustomerDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Address, TaxId

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The customer’s address after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.



792
793
794
# File 'lib/stripe/resources/checkout/session.rb', line 792

def address
  @address
end

#business_nameObject (readonly)

The customer’s business name after a completed Checkout Session.



794
795
796
# File 'lib/stripe/resources/checkout/session.rb', line 794

def business_name
  @business_name
end

#emailObject (readonly)

The email associated with the Customer, if one exists, on the Checkout Session after a completed Checkout Session or at time of session expiry. Otherwise, if the customer has consented to promotional content, this value is the most recent valid email provided by the customer on the Checkout form.



797
798
799
# File 'lib/stripe/resources/checkout/session.rb', line 797

def email
  @email
end

#individual_nameObject (readonly)

The customer’s individual name after a completed Checkout Session.



799
800
801
# File 'lib/stripe/resources/checkout/session.rb', line 799

def individual_name
  @individual_name
end

#nameObject (readonly)

The customer’s name after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.



801
802
803
# File 'lib/stripe/resources/checkout/session.rb', line 801

def name
  @name
end

#phoneObject (readonly)

The customer’s phone number after a completed Checkout Session.



803
804
805
# File 'lib/stripe/resources/checkout/session.rb', line 803

def phone
  @phone
end

#tax_exemptObject (readonly)

The customer’s tax exempt status after a completed Checkout Session.



805
806
807
# File 'lib/stripe/resources/checkout/session.rb', line 805

def tax_exempt
  @tax_exempt
end

#tax_idsObject (readonly)

The customer’s tax IDs after a completed Checkout Session.



807
808
809
# File 'lib/stripe/resources/checkout/session.rb', line 807

def tax_ids
  @tax_ids
end

Class Method Details

.field_remappingsObject



813
814
815
# File 'lib/stripe/resources/checkout/session.rb', line 813

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



809
810
811
# File 'lib/stripe/resources/checkout/session.rb', line 809

def self.inner_class_types
  @inner_class_types = { address: Address, tax_ids: TaxId }
end