Class: Stripe::Checkout::Session::CustomerDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CustomerDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The customer’s address after a completed Checkout Session.
-
#business_name ⇒ Object
readonly
The customer’s business name after a completed Checkout Session.
-
#email ⇒ Object
readonly
The email associated with the Customer, if one exists, on the Checkout Session after a completed Checkout Session or at time of session expiry.
-
#individual_name ⇒ Object
readonly
The customer’s individual name after a completed Checkout Session.
-
#name ⇒ Object
readonly
The customer’s name after a completed Checkout Session.
-
#phone ⇒ Object
readonly
The customer’s phone number after a completed Checkout Session.
-
#tax_exempt ⇒ Object
readonly
The customer’s tax exempt status after a completed Checkout Session.
-
#tax_ids ⇒ Object
readonly
The customer’s tax IDs after a completed Checkout Session.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The customer’s address after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.
792 793 794 |
# File 'lib/stripe/resources/checkout/session.rb', line 792 def address @address end |
#business_name ⇒ Object (readonly)
The customer’s business name after a completed Checkout Session.
794 795 796 |
# File 'lib/stripe/resources/checkout/session.rb', line 794 def business_name @business_name end |
#email ⇒ Object (readonly)
The email associated with the Customer, if one exists, on the Checkout Session after a completed Checkout Session or at time of session expiry. Otherwise, if the customer has consented to promotional content, this value is the most recent valid email provided by the customer on the Checkout form.
797 798 799 |
# File 'lib/stripe/resources/checkout/session.rb', line 797 def email @email end |
#individual_name ⇒ Object (readonly)
The customer’s individual name after a completed Checkout Session.
799 800 801 |
# File 'lib/stripe/resources/checkout/session.rb', line 799 def individual_name @individual_name end |
#name ⇒ Object (readonly)
The customer’s name after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.
801 802 803 |
# File 'lib/stripe/resources/checkout/session.rb', line 801 def name @name end |
#phone ⇒ Object (readonly)
The customer’s phone number after a completed Checkout Session.
803 804 805 |
# File 'lib/stripe/resources/checkout/session.rb', line 803 def phone @phone end |
#tax_exempt ⇒ Object (readonly)
The customer’s tax exempt status after a completed Checkout Session.
805 806 807 |
# File 'lib/stripe/resources/checkout/session.rb', line 805 def tax_exempt @tax_exempt end |
#tax_ids ⇒ Object (readonly)
The customer’s tax IDs after a completed Checkout Session.
807 808 809 |
# File 'lib/stripe/resources/checkout/session.rb', line 807 def tax_ids @tax_ids end |
Class Method Details
.field_remappings ⇒ Object
813 814 815 |
# File 'lib/stripe/resources/checkout/session.rb', line 813 def self.field_remappings @field_remappings = {} end |