Class: Stripe::Checkout::Session::CustomerDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::CustomerDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The customer’s address after a completed Checkout Session.
-
#business_name ⇒ Object
readonly
The customer’s business name after a completed Checkout Session.
-
#email ⇒ Object
readonly
The email associated with the Customer, if one exists, on the Checkout Session after a completed Checkout Session or at time of session expiry.
-
#individual_name ⇒ Object
readonly
The customer’s individual name after a completed Checkout Session.
-
#name ⇒ Object
readonly
The customer’s name after a completed Checkout Session.
-
#phone ⇒ Object
readonly
The customer’s phone number after a completed Checkout Session.
-
#tax_exempt ⇒ Object
readonly
The customer’s tax exempt status after a completed Checkout Session.
-
#tax_ids ⇒ Object
readonly
The customer’s tax IDs after a completed Checkout Session.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The customer’s address after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.
531 532 533 |
# File 'lib/stripe/resources/checkout/session.rb', line 531 def address @address end |
#business_name ⇒ Object (readonly)
The customer’s business name after a completed Checkout Session.
533 534 535 |
# File 'lib/stripe/resources/checkout/session.rb', line 533 def business_name @business_name end |
#email ⇒ Object (readonly)
The email associated with the Customer, if one exists, on the Checkout Session after a completed Checkout Session or at time of session expiry. Otherwise, if the customer has consented to promotional content, this value is the most recent valid email provided by the customer on the Checkout form.
536 537 538 |
# File 'lib/stripe/resources/checkout/session.rb', line 536 def email @email end |
#individual_name ⇒ Object (readonly)
The customer’s individual name after a completed Checkout Session.
538 539 540 |
# File 'lib/stripe/resources/checkout/session.rb', line 538 def individual_name @individual_name end |
#name ⇒ Object (readonly)
The customer’s name after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.
540 541 542 |
# File 'lib/stripe/resources/checkout/session.rb', line 540 def name @name end |
#phone ⇒ Object (readonly)
The customer’s phone number after a completed Checkout Session.
542 543 544 |
# File 'lib/stripe/resources/checkout/session.rb', line 542 def phone @phone end |
#tax_exempt ⇒ Object (readonly)
The customer’s tax exempt status after a completed Checkout Session.
544 545 546 |
# File 'lib/stripe/resources/checkout/session.rb', line 544 def tax_exempt @tax_exempt end |
#tax_ids ⇒ Object (readonly)
The customer’s tax IDs after a completed Checkout Session.
546 547 548 |
# File 'lib/stripe/resources/checkout/session.rb', line 546 def tax_ids @tax_ids end |
Class Method Details
.field_remappings ⇒ Object
552 553 554 |
# File 'lib/stripe/resources/checkout/session.rb', line 552 def self.field_remappings @field_remappings = {} end |