Class: Stripe::Checkout::Session::CustomerDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Address, TaxId

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

The customer’s address after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.



241
242
243
# File 'lib/stripe/resources/checkout/session.rb', line 241

def address
  @address
end

#emailObject (readonly)

The email associated with the Customer, if one exists, on the Checkout Session after a completed Checkout Session or at time of session expiry. Otherwise, if the customer has consented to promotional content, this value is the most recent valid email provided by the customer on the Checkout form.



244
245
246
# File 'lib/stripe/resources/checkout/session.rb', line 244

def email
  @email
end

#nameObject (readonly)

The customer’s name after a completed Checkout Session. Note: This property is populated only for sessions on or after March 30, 2022.



246
247
248
# File 'lib/stripe/resources/checkout/session.rb', line 246

def name
  @name
end

#phoneObject (readonly)

The customer’s phone number after a completed Checkout Session.



248
249
250
# File 'lib/stripe/resources/checkout/session.rb', line 248

def phone
  @phone
end

#tax_exemptObject (readonly)

The customer’s tax exempt status after a completed Checkout Session.



250
251
252
# File 'lib/stripe/resources/checkout/session.rb', line 250

def tax_exempt
  @tax_exempt
end

#tax_idsObject (readonly)

The customer’s tax IDs after a completed Checkout Session.



252
253
254
# File 'lib/stripe/resources/checkout/session.rb', line 252

def tax_ids
  @tax_ids
end