Class: Stripe::Checkout::Session::InvoiceCreation::InvoiceData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CustomField, Issuer, RenderingOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_tax_idsObject (readonly)

The account tax IDs associated with the invoice.



285
286
287
# File 'lib/stripe/resources/checkout/session.rb', line 285

def 
  @account_tax_ids
end

#custom_fieldsObject (readonly)

Custom fields displayed on the invoice.



287
288
289
# File 'lib/stripe/resources/checkout/session.rb', line 287

def custom_fields
  @custom_fields
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



289
290
291
# File 'lib/stripe/resources/checkout/session.rb', line 289

def description
  @description
end

Footer displayed on the invoice.



291
292
293
# File 'lib/stripe/resources/checkout/session.rb', line 291

def footer
  @footer
end

#issuerObject (readonly)

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



293
294
295
# File 'lib/stripe/resources/checkout/session.rb', line 293

def issuer
  @issuer
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



295
296
297
# File 'lib/stripe/resources/checkout/session.rb', line 295

def 
  @metadata
end

#rendering_optionsObject (readonly)

Options for invoice PDF rendering.



297
298
299
# File 'lib/stripe/resources/checkout/session.rb', line 297

def rendering_options
  @rendering_options
end