Class: Stripe::Checkout::Session::ListLineItemsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListLineItemsParams

Returns a new instance of ListLineItemsParams.



3757
3758
3759
3760
3761
3762
# File 'lib/stripe/resources/checkout/session.rb', line 3757

def initialize(ending_before: nil, expand: nil, limit: nil, starting_after: nil)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



3749
3750
3751
# File 'lib/stripe/resources/checkout/session.rb', line 3749

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



3751
3752
3753
# File 'lib/stripe/resources/checkout/session.rb', line 3751

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



3753
3754
3755
# File 'lib/stripe/resources/checkout/session.rb', line 3753

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



3755
3756
3757
# File 'lib/stripe/resources/checkout/session.rb', line 3755

def starting_after
  @starting_after
end