Class: Stripe::Checkout::Session::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::ListParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Created, CustomerDetails
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
-
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
-
#customer_account ⇒ Object
Only return the Checkout Sessions for the Account specified.
-
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
-
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
-
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 |
# File 'lib/stripe/resources/checkout/session.rb', line 2158 def initialize( created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil ) @created = created @customer = customer @customer_account = customer_account @customer_details = customer_details @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @payment_link = payment_link @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
2134 2135 2136 |
# File 'lib/stripe/resources/checkout/session.rb', line 2134 def created @created end |
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
2136 2137 2138 |
# File 'lib/stripe/resources/checkout/session.rb', line 2136 def customer @customer end |
#customer_account ⇒ Object
Only return the Checkout Sessions for the Account specified.
2138 2139 2140 |
# File 'lib/stripe/resources/checkout/session.rb', line 2138 def customer_account @customer_account end |
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
2140 2141 2142 |
# File 'lib/stripe/resources/checkout/session.rb', line 2140 def customer_details @customer_details end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
2142 2143 2144 |
# File 'lib/stripe/resources/checkout/session.rb', line 2142 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2144 2145 2146 |
# File 'lib/stripe/resources/checkout/session.rb', line 2144 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2146 2147 2148 |
# File 'lib/stripe/resources/checkout/session.rb', line 2146 def limit @limit end |
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
2148 2149 2150 |
# File 'lib/stripe/resources/checkout/session.rb', line 2148 def payment_intent @payment_intent end |
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
2150 2151 2152 |
# File 'lib/stripe/resources/checkout/session.rb', line 2150 def payment_link @payment_link end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
2152 2153 2154 |
# File 'lib/stripe/resources/checkout/session.rb', line 2152 def starting_after @starting_after end |
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
2154 2155 2156 |
# File 'lib/stripe/resources/checkout/session.rb', line 2154 def status @status end |
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
2156 2157 2158 |
# File 'lib/stripe/resources/checkout/session.rb', line 2156 def subscription @subscription end |