Class: Stripe::Checkout::Session::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::ListParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Created, CustomerDetails
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
-
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
-
#customer_account ⇒ Object
Only return the Checkout Sessions for the Account specified.
-
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
-
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
-
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 |
# File 'lib/stripe/resources/checkout/session.rb', line 1243 def initialize( created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil ) @created = created @customer = customer @customer_account = customer_account @customer_details = customer_details @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @payment_link = payment_link @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
1219 1220 1221 |
# File 'lib/stripe/resources/checkout/session.rb', line 1219 def created @created end |
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
1221 1222 1223 |
# File 'lib/stripe/resources/checkout/session.rb', line 1221 def customer @customer end |
#customer_account ⇒ Object
Only return the Checkout Sessions for the Account specified.
1223 1224 1225 |
# File 'lib/stripe/resources/checkout/session.rb', line 1223 def customer_account @customer_account end |
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
1225 1226 1227 |
# File 'lib/stripe/resources/checkout/session.rb', line 1225 def customer_details @customer_details end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1227 1228 1229 |
# File 'lib/stripe/resources/checkout/session.rb', line 1227 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1229 1230 1231 |
# File 'lib/stripe/resources/checkout/session.rb', line 1229 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1231 1232 1233 |
# File 'lib/stripe/resources/checkout/session.rb', line 1231 def limit @limit end |
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
1233 1234 1235 |
# File 'lib/stripe/resources/checkout/session.rb', line 1233 def payment_intent @payment_intent end |
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
1235 1236 1237 |
# File 'lib/stripe/resources/checkout/session.rb', line 1235 def payment_link @payment_link end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1237 1238 1239 |
# File 'lib/stripe/resources/checkout/session.rb', line 1237 def starting_after @starting_after end |
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
1239 1240 1241 |
# File 'lib/stripe/resources/checkout/session.rb', line 1239 def status @status end |
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
1241 1242 1243 |
# File 'lib/stripe/resources/checkout/session.rb', line 1241 def subscription @subscription end |