Class: Stripe::Checkout::Session::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Created, CustomerDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
# File 'lib/stripe/resources/checkout/session.rb', line 1094

def initialize(
  created: nil,
  customer: nil,
  customer_details: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  payment_link: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @created = created
  @customer = customer
  @customer_details = customer_details
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @payment_link = payment_link
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#createdObject

Only return Checkout Sessions that were created during the given date interval.



1072
1073
1074
# File 'lib/stripe/resources/checkout/session.rb', line 1072

def created
  @created
end

#customerObject

Only return the Checkout Sessions for the Customer specified.



1074
1075
1076
# File 'lib/stripe/resources/checkout/session.rb', line 1074

def customer
  @customer
end

#customer_detailsObject

Only return the Checkout Sessions for the Customer details specified.



1076
1077
1078
# File 'lib/stripe/resources/checkout/session.rb', line 1076

def customer_details
  @customer_details
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1078
1079
1080
# File 'lib/stripe/resources/checkout/session.rb', line 1078

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1080
1081
1082
# File 'lib/stripe/resources/checkout/session.rb', line 1080

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1082
1083
1084
# File 'lib/stripe/resources/checkout/session.rb', line 1082

def limit
  @limit
end

#payment_intentObject

Only return the Checkout Session for the PaymentIntent specified.



1084
1085
1086
# File 'lib/stripe/resources/checkout/session.rb', line 1084

def payment_intent
  @payment_intent
end

Only return the Checkout Sessions for the Payment Link specified.



1086
1087
1088
# File 'lib/stripe/resources/checkout/session.rb', line 1086

def payment_link
  @payment_link
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1088
1089
1090
# File 'lib/stripe/resources/checkout/session.rb', line 1088

def starting_after
  @starting_after
end

#statusObject

Only return the Checkout Sessions matching the given status.



1090
1091
1092
# File 'lib/stripe/resources/checkout/session.rb', line 1090

def status
  @status
end

#subscriptionObject

Only return the Checkout Session for the subscription specified.



1092
1093
1094
# File 'lib/stripe/resources/checkout/session.rb', line 1092

def subscription
  @subscription
end