Class: Stripe::Checkout::Session::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Created, CustomerDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
# File 'lib/stripe/resources/checkout/session.rb', line 1175

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  customer_details: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  payment_link: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @customer_details = customer_details
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @payment_link = payment_link
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#createdObject

Only return Checkout Sessions that were created during the given date interval.



1151
1152
1153
# File 'lib/stripe/resources/checkout/session.rb', line 1151

def created
  @created
end

#customerObject

Only return the Checkout Sessions for the Customer specified.



1153
1154
1155
# File 'lib/stripe/resources/checkout/session.rb', line 1153

def customer
  @customer
end

#customer_accountObject

Only return the Checkout Sessions for the Account specified.



1155
1156
1157
# File 'lib/stripe/resources/checkout/session.rb', line 1155

def 
  @customer_account
end

#customer_detailsObject

Only return the Checkout Sessions for the Customer details specified.



1157
1158
1159
# File 'lib/stripe/resources/checkout/session.rb', line 1157

def customer_details
  @customer_details
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1159
1160
1161
# File 'lib/stripe/resources/checkout/session.rb', line 1159

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1161
1162
1163
# File 'lib/stripe/resources/checkout/session.rb', line 1161

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1163
1164
1165
# File 'lib/stripe/resources/checkout/session.rb', line 1163

def limit
  @limit
end

#payment_intentObject

Only return the Checkout Session for the PaymentIntent specified.



1165
1166
1167
# File 'lib/stripe/resources/checkout/session.rb', line 1165

def payment_intent
  @payment_intent
end

Only return the Checkout Sessions for the Payment Link specified.



1167
1168
1169
# File 'lib/stripe/resources/checkout/session.rb', line 1167

def payment_link
  @payment_link
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1169
1170
1171
# File 'lib/stripe/resources/checkout/session.rb', line 1169

def starting_after
  @starting_after
end

#statusObject

Only return the Checkout Sessions matching the given status.



1171
1172
1173
# File 'lib/stripe/resources/checkout/session.rb', line 1171

def status
  @status
end

#subscriptionObject

Only return the Checkout Session for the subscription specified.



1173
1174
1175
# File 'lib/stripe/resources/checkout/session.rb', line 1173

def subscription
  @subscription
end