Class: Stripe::Checkout::Session::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::ListParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Created, CustomerDetails
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
-
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
-
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
-
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
-
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 |
# File 'lib/stripe/resources/checkout/session.rb', line 1063 def initialize( created: nil, customer: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil ) @created = created @customer = customer @customer_details = customer_details @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @payment_link = payment_link @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
1041 1042 1043 |
# File 'lib/stripe/resources/checkout/session.rb', line 1041 def created @created end |
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
1043 1044 1045 |
# File 'lib/stripe/resources/checkout/session.rb', line 1043 def customer @customer end |
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
1045 1046 1047 |
# File 'lib/stripe/resources/checkout/session.rb', line 1045 def customer_details @customer_details end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1047 1048 1049 |
# File 'lib/stripe/resources/checkout/session.rb', line 1047 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1049 1050 1051 |
# File 'lib/stripe/resources/checkout/session.rb', line 1049 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1051 1052 1053 |
# File 'lib/stripe/resources/checkout/session.rb', line 1051 def limit @limit end |
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
1053 1054 1055 |
# File 'lib/stripe/resources/checkout/session.rb', line 1053 def payment_intent @payment_intent end |
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
1055 1056 1057 |
# File 'lib/stripe/resources/checkout/session.rb', line 1055 def payment_link @payment_link end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1057 1058 1059 |
# File 'lib/stripe/resources/checkout/session.rb', line 1057 def starting_after @starting_after end |
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
1059 1060 1061 |
# File 'lib/stripe/resources/checkout/session.rb', line 1059 def status @status end |
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
1061 1062 1063 |
# File 'lib/stripe/resources/checkout/session.rb', line 1061 def subscription @subscription end |