Class: Stripe::Checkout::Session::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::ListParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Created, CustomerDetails
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
-
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
-
#customer_account ⇒ Object
Only return the Checkout Sessions for the Account specified.
-
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
-
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
-
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 |
# File 'lib/stripe/resources/checkout/session.rb', line 1148 def initialize( created: nil, customer: nil, customer_account: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil ) @created = created @customer = customer @customer_account = customer_account @customer_details = customer_details @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @payment_link = payment_link @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
1124 1125 1126 |
# File 'lib/stripe/resources/checkout/session.rb', line 1124 def created @created end |
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
1126 1127 1128 |
# File 'lib/stripe/resources/checkout/session.rb', line 1126 def customer @customer end |
#customer_account ⇒ Object
Only return the Checkout Sessions for the Account specified.
1128 1129 1130 |
# File 'lib/stripe/resources/checkout/session.rb', line 1128 def customer_account @customer_account end |
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
1130 1131 1132 |
# File 'lib/stripe/resources/checkout/session.rb', line 1130 def customer_details @customer_details end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1132 1133 1134 |
# File 'lib/stripe/resources/checkout/session.rb', line 1132 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1134 1135 1136 |
# File 'lib/stripe/resources/checkout/session.rb', line 1134 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1136 1137 1138 |
# File 'lib/stripe/resources/checkout/session.rb', line 1136 def limit @limit end |
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
1138 1139 1140 |
# File 'lib/stripe/resources/checkout/session.rb', line 1138 def payment_intent @payment_intent end |
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
1140 1141 1142 |
# File 'lib/stripe/resources/checkout/session.rb', line 1140 def payment_link @payment_link end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1142 1143 1144 |
# File 'lib/stripe/resources/checkout/session.rb', line 1142 def starting_after @starting_after end |
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
1144 1145 1146 |
# File 'lib/stripe/resources/checkout/session.rb', line 1144 def status @status end |
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
1146 1147 1148 |
# File 'lib/stripe/resources/checkout/session.rb', line 1146 def subscription @subscription end |