Class: Stripe::Checkout::Session::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Created, CustomerDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
# File 'lib/stripe/resources/checkout/session.rb', line 1117

def initialize(
  created: nil,
  customer: nil,
  customer_details: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  payment_link: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @created = created
  @customer = customer
  @customer_details = customer_details
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @payment_link = payment_link
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#createdObject

Only return Checkout Sessions that were created during the given date interval.



1095
1096
1097
# File 'lib/stripe/resources/checkout/session.rb', line 1095

def created
  @created
end

#customerObject

Only return the Checkout Sessions for the Customer specified.



1097
1098
1099
# File 'lib/stripe/resources/checkout/session.rb', line 1097

def customer
  @customer
end

#customer_detailsObject

Only return the Checkout Sessions for the Customer details specified.



1099
1100
1101
# File 'lib/stripe/resources/checkout/session.rb', line 1099

def customer_details
  @customer_details
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1101
1102
1103
# File 'lib/stripe/resources/checkout/session.rb', line 1101

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1103
1104
1105
# File 'lib/stripe/resources/checkout/session.rb', line 1103

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1105
1106
1107
# File 'lib/stripe/resources/checkout/session.rb', line 1105

def limit
  @limit
end

#payment_intentObject

Only return the Checkout Session for the PaymentIntent specified.



1107
1108
1109
# File 'lib/stripe/resources/checkout/session.rb', line 1107

def payment_intent
  @payment_intent
end

Only return the Checkout Sessions for the Payment Link specified.



1109
1110
1111
# File 'lib/stripe/resources/checkout/session.rb', line 1109

def payment_link
  @payment_link
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1111
1112
1113
# File 'lib/stripe/resources/checkout/session.rb', line 1111

def starting_after
  @starting_after
end

#statusObject

Only return the Checkout Sessions matching the given status.



1113
1114
1115
# File 'lib/stripe/resources/checkout/session.rb', line 1113

def status
  @status
end

#subscriptionObject

Only return the Checkout Session for the subscription specified.



1115
1116
1117
# File 'lib/stripe/resources/checkout/session.rb', line 1115

def subscription
  @subscription
end