Class: Stripe::Checkout::Session::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::ListParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Created, CustomerDetails
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
-
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
-
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
-
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
-
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 |
# File 'lib/stripe/resources/checkout/session.rb', line 1307 def initialize( created: nil, customer: nil, customer_details: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, payment_link: nil, starting_after: nil, status: nil, subscription: nil ) @created = created @customer = customer @customer_details = customer_details @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @payment_link = payment_link @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#created ⇒ Object
Only return Checkout Sessions that were created during the given date interval.
1275 1276 1277 |
# File 'lib/stripe/resources/checkout/session.rb', line 1275 def created @created end |
#customer ⇒ Object
Only return the Checkout Sessions for the Customer specified.
1278 1279 1280 |
# File 'lib/stripe/resources/checkout/session.rb', line 1278 def customer @customer end |
#customer_details ⇒ Object
Only return the Checkout Sessions for the Customer details specified.
1281 1282 1283 |
# File 'lib/stripe/resources/checkout/session.rb', line 1281 def customer_details @customer_details end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1284 1285 1286 |
# File 'lib/stripe/resources/checkout/session.rb', line 1284 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1287 1288 1289 |
# File 'lib/stripe/resources/checkout/session.rb', line 1287 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1290 1291 1292 |
# File 'lib/stripe/resources/checkout/session.rb', line 1290 def limit @limit end |
#payment_intent ⇒ Object
Only return the Checkout Session for the PaymentIntent specified.
1293 1294 1295 |
# File 'lib/stripe/resources/checkout/session.rb', line 1293 def payment_intent @payment_intent end |
#payment_link ⇒ Object
Only return the Checkout Sessions for the Payment Link specified.
1296 1297 1298 |
# File 'lib/stripe/resources/checkout/session.rb', line 1296 def payment_link @payment_link end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1299 1300 1301 |
# File 'lib/stripe/resources/checkout/session.rb', line 1299 def starting_after @starting_after end |
#status ⇒ Object
Only return the Checkout Sessions matching the given status.
1302 1303 1304 |
# File 'lib/stripe/resources/checkout/session.rb', line 1302 def status @status end |
#subscription ⇒ Object
Only return the Checkout Session for the subscription specified.
1305 1306 1307 |
# File 'lib/stripe/resources/checkout/session.rb', line 1305 def subscription @subscription end |