Class: Stripe::Checkout::Session::OptionalItem::AdjustableQuantity
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::OptionalItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enabled ⇒ Object
readonly
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
readonly
The maximum quantity of this item the customer can purchase.
-
#minimum ⇒ Object
readonly
The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enabled ⇒ Object (readonly)
Set to true if the quantity can be adjusted to any non-negative integer.
980 981 982 |
# File 'lib/stripe/resources/checkout/session.rb', line 980 def enabled @enabled end |
#maximum ⇒ Object (readonly)
The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.
982 983 984 |
# File 'lib/stripe/resources/checkout/session.rb', line 982 def maximum @maximum end |
#minimum ⇒ Object (readonly)
The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.
984 985 986 |
# File 'lib/stripe/resources/checkout/session.rb', line 984 def minimum @minimum end |
Class Method Details
.field_remappings ⇒ Object
990 991 992 |
# File 'lib/stripe/resources/checkout/session.rb', line 990 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
986 987 988 |
# File 'lib/stripe/resources/checkout/session.rb', line 986 def self.inner_class_types @inner_class_types = {} end |