Class: Stripe::Checkout::Session::OptionalItem::AdjustableQuantity
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::OptionalItem::AdjustableQuantity
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#enabled ⇒ Object
readonly
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
readonly
The maximum quantity of this item the customer can purchase.
-
#minimum ⇒ Object
readonly
The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#enabled ⇒ Object (readonly)
Set to true if the quantity can be adjusted to any non-negative integer.
310 311 312 |
# File 'lib/stripe/resources/checkout/session.rb', line 310 def enabled @enabled end |
#maximum ⇒ Object (readonly)
The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.
312 313 314 |
# File 'lib/stripe/resources/checkout/session.rb', line 312 def maximum @maximum end |
#minimum ⇒ Object (readonly)
The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.
314 315 316 |
# File 'lib/stripe/resources/checkout/session.rb', line 314 def minimum @minimum end |