Class: Stripe::Checkout::Session::OptionalItem::AdjustableQuantity

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#enabledObject (readonly)

Set to true if the quantity can be adjusted to any non-negative integer.



306
307
308
# File 'lib/stripe/resources/checkout/session.rb', line 306

def enabled
  @enabled
end

#maximumObject (readonly)

The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.



308
309
310
# File 'lib/stripe/resources/checkout/session.rb', line 308

def maximum
  @maximum
end

#minimumObject (readonly)

The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.



310
311
312
# File 'lib/stripe/resources/checkout/session.rb', line 310

def minimum
  @minimum
end