Class: Stripe::Checkout::Session::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Installments, Restrictions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#installments ⇒ Object
readonly
Attribute for field installments.
-
#request_decremental_authorization ⇒ Object
readonly
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
-
#request_incremental_authorization ⇒ Object
readonly
Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.
-
#request_multicapture ⇒ Object
readonly
Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.
-
#request_overcapture ⇒ Object
readonly
Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication).
-
#restrictions ⇒ Object
readonly
Attribute for field restrictions.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
1047 1048 1049 |
# File 'lib/stripe/resources/checkout/session.rb', line 1047 def capture_method @capture_method end |
#installments ⇒ Object (readonly)
Attribute for field installments
1049 1050 1051 |
# File 'lib/stripe/resources/checkout/session.rb', line 1049 def installments @installments end |
#request_decremental_authorization ⇒ Object (readonly)
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
1051 1052 1053 |
# File 'lib/stripe/resources/checkout/session.rb', line 1051 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
1053 1054 1055 |
# File 'lib/stripe/resources/checkout/session.rb', line 1053 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object (readonly)
Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.
1055 1056 1057 |
# File 'lib/stripe/resources/checkout/session.rb', line 1055 def @request_incremental_authorization end |
#request_multicapture ⇒ Object (readonly)
Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.
1057 1058 1059 |
# File 'lib/stripe/resources/checkout/session.rb', line 1057 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object (readonly)
Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.
1059 1060 1061 |
# File 'lib/stripe/resources/checkout/session.rb', line 1059 def request_overcapture @request_overcapture end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
1061 1062 1063 |
# File 'lib/stripe/resources/checkout/session.rb', line 1061 def request_three_d_secure @request_three_d_secure end |
#restrictions ⇒ Object (readonly)
Attribute for field restrictions
1063 1064 1065 |
# File 'lib/stripe/resources/checkout/session.rb', line 1063 def restrictions @restrictions end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1071 1072 1073 |
# File 'lib/stripe/resources/checkout/session.rb', line 1071 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
1073 1074 1075 |
# File 'lib/stripe/resources/checkout/session.rb', line 1073 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
1075 1076 1077 |
# File 'lib/stripe/resources/checkout/session.rb', line 1075 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
Class Method Details
.field_remappings ⇒ Object
1081 1082 1083 |
# File 'lib/stripe/resources/checkout/session.rb', line 1081 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1077 1078 1079 |
# File 'lib/stripe/resources/checkout/session.rb', line 1077 def self.inner_class_types @inner_class_types = { installments: Installments, restrictions: Restrictions } end |