Class: Stripe::Checkout::Session::PaymentMethodOptions::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Installments, Restrictions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer’s account.



1304
1305
1306
# File 'lib/stripe/resources/checkout/session.rb', line 1304

def capture_method
  @capture_method
end

#installmentsObject (readonly)

Attribute for field installments



1306
1307
1308
# File 'lib/stripe/resources/checkout/session.rb', line 1306

def installments
  @installments
end

#request_decremental_authorizationObject (readonly)

Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.



1308
1309
1310
# File 'lib/stripe/resources/checkout/session.rb', line 1308

def request_decremental_authorization
  @request_decremental_authorization
end

#request_extended_authorizationObject (readonly)

Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.



1310
1311
1312
# File 'lib/stripe/resources/checkout/session.rb', line 1310

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject (readonly)

Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.



1312
1313
1314
# File 'lib/stripe/resources/checkout/session.rb', line 1312

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject (readonly)

Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.



1314
1315
1316
# File 'lib/stripe/resources/checkout/session.rb', line 1314

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject (readonly)

Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.



1316
1317
1318
# File 'lib/stripe/resources/checkout/session.rb', line 1316

def request_overcapture
  @request_overcapture
end

#request_three_d_secureObject (readonly)

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



1318
1319
1320
# File 'lib/stripe/resources/checkout/session.rb', line 1318

def request_three_d_secure
  @request_three_d_secure
end

#restrictionsObject (readonly)

Attribute for field restrictions



1320
1321
1322
# File 'lib/stripe/resources/checkout/session.rb', line 1320

def restrictions
  @restrictions
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



1328
1329
1330
# File 'lib/stripe/resources/checkout/session.rb', line 1328

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject (readonly)

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



1330
1331
1332
# File 'lib/stripe/resources/checkout/session.rb', line 1330

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject (readonly)

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



1332
1333
1334
# File 'lib/stripe/resources/checkout/session.rb', line 1332

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end

Class Method Details

.field_remappingsObject



1338
1339
1340
# File 'lib/stripe/resources/checkout/session.rb', line 1338

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1334
1335
1336
# File 'lib/stripe/resources/checkout/session.rb', line 1334

def self.inner_class_types
  @inner_class_types = { installments: Installments, restrictions: Restrictions }
end