Class: Stripe::Checkout::Session::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Installments, Restrictions
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#installments ⇒ Object
readonly
Attribute for field installments.
-
#request_decremental_authorization ⇒ Object
readonly
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
-
#request_extended_authorization ⇒ Object
readonly
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
-
#request_incremental_authorization ⇒ Object
readonly
Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.
-
#request_multicapture ⇒ Object
readonly
Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.
-
#request_overcapture ⇒ Object
readonly
Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.
-
#request_three_d_secure ⇒ Object
readonly
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication).
-
#restrictions ⇒ Object
readonly
Attribute for field restrictions.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
readonly
Provides information about a card payment that customers see on their statements.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#installments ⇒ Object (readonly)
Attribute for field installments
489 490 491 |
# File 'lib/stripe/resources/checkout/session.rb', line 489 def installments @installments end |
#request_decremental_authorization ⇒ Object (readonly)
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
491 492 493 |
# File 'lib/stripe/resources/checkout/session.rb', line 491 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object (readonly)
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
493 494 495 |
# File 'lib/stripe/resources/checkout/session.rb', line 493 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object (readonly)
Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.
495 496 497 |
# File 'lib/stripe/resources/checkout/session.rb', line 495 def @request_incremental_authorization end |
#request_multicapture ⇒ Object (readonly)
Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.
497 498 499 |
# File 'lib/stripe/resources/checkout/session.rb', line 497 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object (readonly)
Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.
499 500 501 |
# File 'lib/stripe/resources/checkout/session.rb', line 499 def request_overcapture @request_overcapture end |
#request_three_d_secure ⇒ Object (readonly)
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
501 502 503 |
# File 'lib/stripe/resources/checkout/session.rb', line 501 def request_three_d_secure @request_three_d_secure end |
#restrictions ⇒ Object (readonly)
Attribute for field restrictions
503 504 505 |
# File 'lib/stripe/resources/checkout/session.rb', line 503 def restrictions @restrictions end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
511 512 513 |
# File 'lib/stripe/resources/checkout/session.rb', line 511 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
513 514 515 |
# File 'lib/stripe/resources/checkout/session.rb', line 513 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object (readonly)
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
515 516 517 |
# File 'lib/stripe/resources/checkout/session.rb', line 515 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |