Class: Stripe::Checkout::Session::PaymentMethodOptions::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer's account.



1503
1504
1505
# File 'lib/stripe/resources/checkout/session.rb', line 1503

def capture_method
  @capture_method
end

#preferred_localeObject (readonly)

Preferred locale of the PayPal checkout page that the customer is redirected to.



1505
1506
1507
# File 'lib/stripe/resources/checkout/session.rb', line 1505

def preferred_locale
  @preferred_locale
end

#referenceObject (readonly)

A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



1507
1508
1509
# File 'lib/stripe/resources/checkout/session.rb', line 1507

def reference
  @reference
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1515
1516
1517
# File 'lib/stripe/resources/checkout/session.rb', line 1515

def setup_future_usage
  @setup_future_usage
end

#subsellersObject (readonly)

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when separate charges and transfers are used.



1517
1518
1519
# File 'lib/stripe/resources/checkout/session.rb', line 1517

def subsellers
  @subsellers
end

Class Method Details

.field_remappingsObject



1523
1524
1525
# File 'lib/stripe/resources/checkout/session.rb', line 1523

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1519
1520
1521
# File 'lib/stripe/resources/checkout/session.rb', line 1519

def self.inner_class_types
  @inner_class_types = {}
end