Class: Stripe::Checkout::Session::PaymentMethodOptions::Paypal
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#preferred_locale ⇒ Object
readonly
Preferred locale of the PayPal checkout page that the customer is redirected to.
-
#reference ⇒ Object
readonly
A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#subsellers ⇒ Object
readonly
The Stripe connected account IDs of the sellers on the platform for this transaction (optional).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
708 709 710 |
# File 'lib/stripe/resources/checkout/session.rb', line 708 def capture_method @capture_method end |
#preferred_locale ⇒ Object (readonly)
Preferred locale of the PayPal checkout page that the customer is redirected to.
710 711 712 |
# File 'lib/stripe/resources/checkout/session.rb', line 710 def preferred_locale @preferred_locale end |
#reference ⇒ Object (readonly)
A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
712 713 714 |
# File 'lib/stripe/resources/checkout/session.rb', line 712 def reference @reference end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
720 721 722 |
# File 'lib/stripe/resources/checkout/session.rb', line 720 def setup_future_usage @setup_future_usage end |
#subsellers ⇒ Object (readonly)
The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.
722 723 724 |
# File 'lib/stripe/resources/checkout/session.rb', line 722 def subsellers @subsellers end |