Class: Stripe::Checkout::Session::PaymentMethodOptions::Payto::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount that will be collected. It is required when amount_type is fixed.



1954
1955
1956
# File 'lib/stripe/resources/checkout/session.rb', line 1954

def amount
  @amount
end

#amount_typeObject (readonly)

The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.



1956
1957
1958
# File 'lib/stripe/resources/checkout/session.rb', line 1956

def amount_type
  @amount_type
end

#end_dateObject (readonly)

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



1958
1959
1960
# File 'lib/stripe/resources/checkout/session.rb', line 1958

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

The periodicity at which payments will be collected. Defaults to adhoc.



1960
1961
1962
# File 'lib/stripe/resources/checkout/session.rb', line 1960

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject (readonly)

The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.



1962
1963
1964
# File 'lib/stripe/resources/checkout/session.rb', line 1962

def payments_per_period
  @payments_per_period
end

#purposeObject (readonly)

The purpose for which payments are made. Has a default value based on your merchant category code.



1964
1965
1966
# File 'lib/stripe/resources/checkout/session.rb', line 1964

def purpose
  @purpose
end

#start_dateObject (readonly)

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



1966
1967
1968
# File 'lib/stripe/resources/checkout/session.rb', line 1966

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



1972
1973
1974
# File 'lib/stripe/resources/checkout/session.rb', line 1972

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1968
1969
1970
# File 'lib/stripe/resources/checkout/session.rb', line 1968

def self.inner_class_types
  @inner_class_types = {}
end