Class: Stripe::Checkout::Session::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount that will be collected.
-
#amount_type ⇒ Object
readonly
The type of amount that will be collected.
-
#end_date ⇒ Object
readonly
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
readonly
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
readonly
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
readonly
The purpose for which payments are made.
-
#start_date ⇒ Object
readonly
Date, in YYYY-MM-DD format, from which payments will be collected.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount that will be collected. It is required when amount_type is fixed.
1531 1532 1533 |
# File 'lib/stripe/resources/checkout/session.rb', line 1531 def amount @amount end |
#amount_type ⇒ Object (readonly)
The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.
1533 1534 1535 |
# File 'lib/stripe/resources/checkout/session.rb', line 1533 def amount_type @amount_type end |
#end_date ⇒ Object (readonly)
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
1535 1536 1537 |
# File 'lib/stripe/resources/checkout/session.rb', line 1535 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
The periodicity at which payments will be collected. Defaults to adhoc.
1537 1538 1539 |
# File 'lib/stripe/resources/checkout/session.rb', line 1537 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object (readonly)
The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.
1539 1540 1541 |
# File 'lib/stripe/resources/checkout/session.rb', line 1539 def payments_per_period @payments_per_period end |
#purpose ⇒ Object (readonly)
The purpose for which payments are made. Has a default value based on your merchant category code.
1541 1542 1543 |
# File 'lib/stripe/resources/checkout/session.rb', line 1541 def purpose @purpose end |
#start_date ⇒ Object (readonly)
Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.
1543 1544 1545 |
# File 'lib/stripe/resources/checkout/session.rb', line 1543 def start_date @start_date end |
Class Method Details
.field_remappings ⇒ Object
1549 1550 1551 |
# File 'lib/stripe/resources/checkout/session.rb', line 1549 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1545 1546 1547 |
# File 'lib/stripe/resources/checkout/session.rb', line 1545 def self.inner_class_types @inner_class_types = {} end |