Class: Stripe::Checkout::Session::PaymentMethodOptions::Payto::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



748
749
750
# File 'lib/stripe/resources/checkout/session.rb', line 748

def amount
  @amount
end

#amount_typeObject (readonly)

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



750
751
752
# File 'lib/stripe/resources/checkout/session.rb', line 750

def amount_type
  @amount_type
end

#end_dateObject (readonly)

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



752
753
754
# File 'lib/stripe/resources/checkout/session.rb', line 752

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

The periodicity at which payments will be collected.



754
755
756
# File 'lib/stripe/resources/checkout/session.rb', line 754

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject (readonly)

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



756
757
758
# File 'lib/stripe/resources/checkout/session.rb', line 756

def payments_per_period
  @payments_per_period
end

#purposeObject (readonly)

The purpose for which payments are made. Defaults to retail.



758
759
760
# File 'lib/stripe/resources/checkout/session.rb', line 758

def purpose
  @purpose
end

#start_dateObject (readonly)

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



760
761
762
# File 'lib/stripe/resources/checkout/session.rb', line 760

def start_date
  @start_date
end