Class: Stripe::Checkout::Session::PaymentMethodOptions::Pix

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: MandateOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



2024
2025
2026
# File 'lib/stripe/resources/checkout/session.rb', line 2024

def amount_includes_iof
  @amount_includes_iof
end

#expires_after_secondsObject (readonly)

The number of seconds after which Pix payment will expire.



2026
2027
2028
# File 'lib/stripe/resources/checkout/session.rb', line 2026

def expires_after_seconds
  @expires_after_seconds
end

#mandate_optionsObject (readonly)

Attribute for field mandate_options



2028
2029
2030
# File 'lib/stripe/resources/checkout/session.rb', line 2028

def mandate_options
  @mandate_options
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



2036
2037
2038
# File 'lib/stripe/resources/checkout/session.rb', line 2036

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



2042
2043
2044
# File 'lib/stripe/resources/checkout/session.rb', line 2042

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2038
2039
2040
# File 'lib/stripe/resources/checkout/session.rb', line 2038

def self.inner_class_types
  @inner_class_types = { mandate_options: MandateOptions }
end