Class: Stripe::Checkout::Session::PaymentMethodOptions::Pix

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: MandateOptions

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



1576
1577
1578
# File 'lib/stripe/resources/checkout/session.rb', line 1576

def amount_includes_iof
  @amount_includes_iof
end

#expires_after_secondsObject (readonly)

The number of seconds after which Pix payment will expire.



1578
1579
1580
# File 'lib/stripe/resources/checkout/session.rb', line 1578

def expires_after_seconds
  @expires_after_seconds
end

#mandate_optionsObject (readonly)

Attribute for field mandate_options



1580
1581
1582
# File 'lib/stripe/resources/checkout/session.rb', line 1580

def mandate_options
  @mandate_options
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1588
1589
1590
# File 'lib/stripe/resources/checkout/session.rb', line 1588

def setup_future_usage
  @setup_future_usage
end

Class Method Details

.field_remappingsObject



1594
1595
1596
# File 'lib/stripe/resources/checkout/session.rb', line 1594

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1590
1591
1592
# File 'lib/stripe/resources/checkout/session.rb', line 1590

def self.inner_class_types
  @inner_class_types = { mandate_options: MandateOptions }
end