Class: Stripe::Checkout::Session::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



1868
1869
1870
# File 'lib/stripe/resources/checkout/session.rb', line 1868

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



1870
1871
1872
# File 'lib/stripe/resources/checkout/session.rb', line 1870

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



1872
1873
1874
# File 'lib/stripe/resources/checkout/session.rb', line 1872

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



1874
1875
1876
# File 'lib/stripe/resources/checkout/session.rb', line 1874

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



1876
1877
1878
# File 'lib/stripe/resources/checkout/session.rb', line 1876

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



1878
1879
1880
# File 'lib/stripe/resources/checkout/session.rb', line 1878

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



1880
1881
1882
# File 'lib/stripe/resources/checkout/session.rb', line 1880

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



1882
1883
1884
# File 'lib/stripe/resources/checkout/session.rb', line 1882

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



1888
1889
1890
# File 'lib/stripe/resources/checkout/session.rb', line 1888

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1884
1885
1886
# File 'lib/stripe/resources/checkout/session.rb', line 1884

def self.inner_class_types
  @inner_class_types = {}
end