Class: Stripe::Checkout::Session::PaymentMethodOptions::Pix::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



1401
1402
1403
# File 'lib/stripe/resources/checkout/session.rb', line 1401

def amount
  @amount
end

#amount_includes_iofObject (readonly)

Determines if the amount includes the IOF tax.



1403
1404
1405
# File 'lib/stripe/resources/checkout/session.rb', line 1403

def amount_includes_iof
  @amount_includes_iof
end

#amount_typeObject (readonly)

Type of amount.



1405
1406
1407
# File 'lib/stripe/resources/checkout/session.rb', line 1405

def amount_type
  @amount_type
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.



1407
1408
1409
# File 'lib/stripe/resources/checkout/session.rb', line 1407

def currency
  @currency
end

#end_dateObject (readonly)

Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.



1409
1410
1411
# File 'lib/stripe/resources/checkout/session.rb', line 1409

def end_date
  @end_date
end

#payment_scheduleObject (readonly)

Schedule at which the future payments will be charged.



1411
1412
1413
# File 'lib/stripe/resources/checkout/session.rb', line 1411

def payment_schedule
  @payment_schedule
end

#referenceObject (readonly)

Subscription name displayed to buyers in their bank app.



1413
1414
1415
# File 'lib/stripe/resources/checkout/session.rb', line 1413

def reference
  @reference
end

#start_dateObject (readonly)

Start date of the mandate, in ‘YYYY-MM-DD`.



1415
1416
1417
# File 'lib/stripe/resources/checkout/session.rb', line 1415

def start_date
  @start_date
end

Class Method Details

.field_remappingsObject



1421
1422
1423
# File 'lib/stripe/resources/checkout/session.rb', line 1421

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1417
1418
1419
# File 'lib/stripe/resources/checkout/session.rb', line 1417

def self.inner_class_types
  @inner_class_types = {}
end