Class: Stripe::Checkout::Session::PaymentMethodOptions::Upi::MandateOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::Upi::MandateOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount to be charged for future payments.
-
#amount_type ⇒ Object
readonly
One of
fixedormaximum. -
#description ⇒ Object
readonly
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
readonly
End date of the mandate or subscription.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount to be charged for future payments.
1777 1778 1779 |
# File 'lib/stripe/resources/checkout/session.rb', line 1777 def amount @amount end |
#amount_type ⇒ Object (readonly)
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
1779 1780 1781 |
# File 'lib/stripe/resources/checkout/session.rb', line 1779 def amount_type @amount_type end |
#description ⇒ Object (readonly)
A description of the mandate or subscription that is meant to be displayed to the customer.
1781 1782 1783 |
# File 'lib/stripe/resources/checkout/session.rb', line 1781 def description @description end |
#end_date ⇒ Object (readonly)
End date of the mandate or subscription.
1783 1784 1785 |
# File 'lib/stripe/resources/checkout/session.rb', line 1783 def end_date @end_date end |
Class Method Details
.field_remappings ⇒ Object
1789 1790 1791 |
# File 'lib/stripe/resources/checkout/session.rb', line 1789 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1785 1786 1787 |
# File 'lib/stripe/resources/checkout/session.rb', line 1785 def self.inner_class_types @inner_class_types = {} end |