Class: Stripe::Checkout::Session::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Filters, ManualEntry
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#filters ⇒ Object
readonly
Attribute for field filters.
-
#manual_entry ⇒ Object
readonly
Attribute for field manual_entry.
-
#permissions ⇒ Object
readonly
The list of permissions to request.
-
#prefetch ⇒ Object
readonly
Data features requested to be retrieved upon account creation.
-
#return_url ⇒ Object
readonly
For webview integrations only.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#filters ⇒ Object (readonly)
Attribute for field filters
897 898 899 |
# File 'lib/stripe/resources/checkout/session.rb', line 897 def filters @filters end |
#manual_entry ⇒ Object (readonly)
Attribute for field manual_entry
899 900 901 |
# File 'lib/stripe/resources/checkout/session.rb', line 899 def manual_entry @manual_entry end |
#permissions ⇒ Object (readonly)
The list of permissions to request. The ‘payment_method` permission must be included.
901 902 903 |
# File 'lib/stripe/resources/checkout/session.rb', line 901 def @permissions end |
#prefetch ⇒ Object (readonly)
Data features requested to be retrieved upon account creation.
903 904 905 |
# File 'lib/stripe/resources/checkout/session.rb', line 903 def prefetch @prefetch end |
#return_url ⇒ Object (readonly)
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
905 906 907 |
# File 'lib/stripe/resources/checkout/session.rb', line 905 def return_url @return_url end |