Class: Stripe::Checkout::Session::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#filtersObject (readonly)

Attribute for field filters



857
858
859
# File 'lib/stripe/resources/checkout/session.rb', line 857

def filters
  @filters
end

#manual_entryObject (readonly)

Attribute for field manual_entry



859
860
861
# File 'lib/stripe/resources/checkout/session.rb', line 859

def manual_entry
  @manual_entry
end

#permissionsObject (readonly)

The list of permissions to request. The ‘payment_method` permission must be included.



861
862
863
# File 'lib/stripe/resources/checkout/session.rb', line 861

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



863
864
865
# File 'lib/stripe/resources/checkout/session.rb', line 863

def prefetch
  @prefetch
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



865
866
867
# File 'lib/stripe/resources/checkout/session.rb', line 865

def return_url
  @return_url
end