Class: Stripe::Checkout::Session::PaymentMethodOptions::WechatPay
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::PaymentMethodOptions::WechatPay
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#app_id ⇒ Object
readonly
The app ID registered with WeChat Pay.
-
#client ⇒ Object
readonly
The client type that the end customer will pay from.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#app_id ⇒ Object (readonly)
The app ID registered with WeChat Pay. Only required when client is iOS or Android.
1912 1913 1914 |
# File 'lib/stripe/resources/checkout/session.rb', line 1912 def app_id @app_id end |
#client ⇒ Object (readonly)
The client type that the end customer will pay from
1914 1915 1916 |
# File 'lib/stripe/resources/checkout/session.rb', line 1914 def client @client end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1922 1923 1924 |
# File 'lib/stripe/resources/checkout/session.rb', line 1922 def setup_future_usage @setup_future_usage end |
Class Method Details
.field_remappings ⇒ Object
1928 1929 1930 |
# File 'lib/stripe/resources/checkout/session.rb', line 1928 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1924 1925 1926 |
# File 'lib/stripe/resources/checkout/session.rb', line 1924 def self.inner_class_types @inner_class_types = {} end |