Class: Stripe::Checkout::Session::Permissions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::Permissions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Update
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#update ⇒ Object
readonly
Permissions for updating the Checkout Session.
-
#update_line_items ⇒ Object
readonly
Determines which entity is allowed to update the line items.
-
#update_shipping_details ⇒ Object
readonly
Determines which entity is allowed to update the shipping details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#update ⇒ Object (readonly)
Permissions for updating the Checkout Session.
1964 1965 1966 |
# File 'lib/stripe/resources/checkout/session.rb', line 1964 def update @update end |
#update_line_items ⇒ Object (readonly)
Determines which entity is allowed to update the line items.
Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.
When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.
1970 1971 1972 |
# File 'lib/stripe/resources/checkout/session.rb', line 1970 def update_line_items @update_line_items end |
#update_shipping_details ⇒ Object (readonly)
Determines which entity is allowed to update the shipping details.
Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.
When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.
1976 1977 1978 |
# File 'lib/stripe/resources/checkout/session.rb', line 1976 def update_shipping_details @update_shipping_details end |
Class Method Details
.field_remappings ⇒ Object
1982 1983 1984 |
# File 'lib/stripe/resources/checkout/session.rb', line 1982 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1978 1979 1980 |
# File 'lib/stripe/resources/checkout/session.rb', line 1978 def self.inner_class_types @inner_class_types = { update: Update } end |