Class: Stripe::Checkout::Session::Permissions::Update
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::Permissions::Update
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Determines which entity is allowed to update the line items.
-
#shipping_details ⇒ Object
readonly
Determines which entity is allowed to update the shipping details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#line_items ⇒ Object (readonly)
Determines which entity is allowed to update the line items.
Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.
When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.
2006 2007 2008 |
# File 'lib/stripe/resources/checkout/session.rb', line 2006 def line_items @line_items end |
#shipping_details ⇒ Object (readonly)
Determines which entity is allowed to update the shipping details.
Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.
When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.
2012 2013 2014 |
# File 'lib/stripe/resources/checkout/session.rb', line 2012 def shipping_details @shipping_details end |
Class Method Details
.field_remappings ⇒ Object
2018 2019 2020 |
# File 'lib/stripe/resources/checkout/session.rb', line 2018 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2014 2015 2016 |
# File 'lib/stripe/resources/checkout/session.rb', line 2014 def self.inner_class_types @inner_class_types = {} end |