Class: Stripe::Checkout::Session::Permissions::Update
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::Permissions::Update
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Determines which entity is allowed to update the line items.
-
#shipping_details ⇒ Object
readonly
Determines which entity is allowed to update the shipping details.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#line_items ⇒ Object (readonly)
Determines which entity is allowed to update the line items.
Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.
When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.
1007 1008 1009 |
# File 'lib/stripe/resources/checkout/session.rb', line 1007 def line_items @line_items end |
#shipping_details ⇒ Object (readonly)
Determines which entity is allowed to update the shipping details.
Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.
When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.
1013 1014 1015 |
# File 'lib/stripe/resources/checkout/session.rb', line 1013 def shipping_details @shipping_details end |