Class: Stripe::Checkout::Session::RetrieveParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::RetrieveParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ RetrieveParams
constructor
A new instance of RetrieveParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ RetrieveParams
Returns a new instance of RetrieveParams.
3293 3294 3295 |
# File 'lib/stripe/resources/checkout/session.rb', line 3293 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3291 3292 3293 |
# File 'lib/stripe/resources/checkout/session.rb', line 3291 def @expand end |