Class: Stripe::Checkout::Session::SavedPaymentMethodOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::SavedPaymentMethodOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#allow_redisplay_filters ⇒ Object
readonly
Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer.
-
#payment_method_remove ⇒ Object
readonly
Enable customers to choose if they wish to remove their saved payment methods.
-
#payment_method_save ⇒ Object
readonly
Enable customers to choose if they wish to save their payment method for future use.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#allow_redisplay_filters ⇒ Object (readonly)
Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.
2076 2077 2078 |
# File 'lib/stripe/resources/checkout/session.rb', line 2076 def allow_redisplay_filters @allow_redisplay_filters end |
#payment_method_remove ⇒ Object (readonly)
Enable customers to choose if they wish to remove their saved payment methods. Disabled by default.
2078 2079 2080 |
# File 'lib/stripe/resources/checkout/session.rb', line 2078 def payment_method_remove @payment_method_remove end |
#payment_method_save ⇒ Object (readonly)
Enable customers to choose if they wish to save their payment method for future use. Disabled by default.
2080 2081 2082 |
# File 'lib/stripe/resources/checkout/session.rb', line 2080 def payment_method_save @payment_method_save end |
Class Method Details
.field_remappings ⇒ Object
2086 2087 2088 |
# File 'lib/stripe/resources/checkout/session.rb', line 2086 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2082 2083 2084 |
# File 'lib/stripe/resources/checkout/session.rb', line 2082 def self.inner_class_types @inner_class_types = {} end |