Class: Stripe::Checkout::Session::ShippingCost

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_subtotalObject (readonly)

Total shipping cost before any discounts or taxes are applied.



2143
2144
2145
# File 'lib/stripe/resources/checkout/session.rb', line 2143

def amount_subtotal
  @amount_subtotal
end

#amount_taxObject (readonly)

Total tax amount applied due to shipping costs. If no tax was applied, defaults to 0.



2145
2146
2147
# File 'lib/stripe/resources/checkout/session.rb', line 2145

def amount_tax
  @amount_tax
end

#amount_totalObject (readonly)

Total shipping cost after discounts and taxes are applied.



2147
2148
2149
# File 'lib/stripe/resources/checkout/session.rb', line 2147

def amount_total
  @amount_total
end

#shipping_rateObject (readonly)

The ID of the ShippingRate for this order.



2149
2150
2151
# File 'lib/stripe/resources/checkout/session.rb', line 2149

def shipping_rate
  @shipping_rate
end

#taxesObject (readonly)

The taxes applied to the shipping rate.



2151
2152
2153
# File 'lib/stripe/resources/checkout/session.rb', line 2151

def taxes
  @taxes
end

Class Method Details

.field_remappingsObject



2157
2158
2159
# File 'lib/stripe/resources/checkout/session.rb', line 2157

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2153
2154
2155
# File 'lib/stripe/resources/checkout/session.rb', line 2153

def self.inner_class_types
  @inner_class_types = { taxes: Tax }
end