Class: Stripe::Checkout::Session::ShippingCost

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_subtotalObject (readonly)

Total shipping cost before any discounts or taxes are applied.



2081
2082
2083
# File 'lib/stripe/resources/checkout/session.rb', line 2081

def amount_subtotal
  @amount_subtotal
end

#amount_taxObject (readonly)

Total tax amount applied due to shipping costs. If no tax was applied, defaults to 0.



2083
2084
2085
# File 'lib/stripe/resources/checkout/session.rb', line 2083

def amount_tax
  @amount_tax
end

#amount_totalObject (readonly)

Total shipping cost after discounts and taxes are applied.



2085
2086
2087
# File 'lib/stripe/resources/checkout/session.rb', line 2085

def amount_total
  @amount_total
end

#shipping_rateObject (readonly)

The ID of the ShippingRate for this order.



2087
2088
2089
# File 'lib/stripe/resources/checkout/session.rb', line 2087

def shipping_rate
  @shipping_rate
end

#taxesObject (readonly)

The taxes applied to the shipping rate.



2089
2090
2091
# File 'lib/stripe/resources/checkout/session.rb', line 2089

def taxes
  @taxes
end

Class Method Details

.field_remappingsObject



2095
2096
2097
# File 'lib/stripe/resources/checkout/session.rb', line 2095

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2091
2092
2093
# File 'lib/stripe/resources/checkout/session.rb', line 2091

def self.inner_class_types
  @inner_class_types = { taxes: Tax }
end