Class: Stripe::Checkout::Session::ShippingCost
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::ShippingCost
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_subtotal ⇒ Object
readonly
Total shipping cost before any discounts or taxes are applied.
-
#amount_tax ⇒ Object
readonly
Total tax amount applied due to shipping costs.
-
#amount_total ⇒ Object
readonly
Total shipping cost after discounts and taxes are applied.
-
#shipping_rate ⇒ Object
readonly
The ID of the ShippingRate for this order.
-
#taxes ⇒ Object
readonly
The taxes applied to the shipping rate.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_subtotal ⇒ Object (readonly)
Total shipping cost before any discounts or taxes are applied.
1872 1873 1874 |
# File 'lib/stripe/resources/checkout/session.rb', line 1872 def amount_subtotal @amount_subtotal end |
#amount_tax ⇒ Object (readonly)
Total tax amount applied due to shipping costs. If no tax was applied, defaults to 0.
1874 1875 1876 |
# File 'lib/stripe/resources/checkout/session.rb', line 1874 def amount_tax @amount_tax end |
#amount_total ⇒ Object (readonly)
Total shipping cost after discounts and taxes are applied.
1876 1877 1878 |
# File 'lib/stripe/resources/checkout/session.rb', line 1876 def amount_total @amount_total end |
#shipping_rate ⇒ Object (readonly)
The ID of the ShippingRate for this order.
1878 1879 1880 |
# File 'lib/stripe/resources/checkout/session.rb', line 1878 def shipping_rate @shipping_rate end |
#taxes ⇒ Object (readonly)
The taxes applied to the shipping rate.
1880 1881 1882 |
# File 'lib/stripe/resources/checkout/session.rb', line 1880 def taxes @taxes end |
Class Method Details
.field_remappings ⇒ Object
1886 1887 1888 |
# File 'lib/stripe/resources/checkout/session.rb', line 1886 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1882 1883 1884 |
# File 'lib/stripe/resources/checkout/session.rb', line 1882 def self.inner_class_types @inner_class_types = { taxes: Tax } end |