Class: Stripe::Checkout::Session::ShippingCost

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Tax

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_subtotalObject (readonly)

Total shipping cost before any discounts or taxes are applied.



990
991
992
# File 'lib/stripe/resources/checkout/session.rb', line 990

def amount_subtotal
  @amount_subtotal
end

#amount_taxObject (readonly)

Total tax amount applied due to shipping costs. If no tax was applied, defaults to 0.



992
993
994
# File 'lib/stripe/resources/checkout/session.rb', line 992

def amount_tax
  @amount_tax
end

#amount_totalObject (readonly)

Total shipping cost after discounts and taxes are applied.



994
995
996
# File 'lib/stripe/resources/checkout/session.rb', line 994

def amount_total
  @amount_total
end

#shipping_rateObject (readonly)

The ID of the ShippingRate for this order.



996
997
998
# File 'lib/stripe/resources/checkout/session.rb', line 996

def shipping_rate
  @shipping_rate
end

#taxesObject (readonly)

The taxes applied to the shipping rate.



998
999
1000
# File 'lib/stripe/resources/checkout/session.rb', line 998

def taxes
  @taxes
end