Class: Stripe::Checkout::Session::ShippingCost::Tax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount of tax applied for this rate.



2203
2204
2205
# File 'lib/stripe/resources/checkout/session.rb', line 2203

def amount
  @amount
end

#rateObject (readonly)

Tax rates can be applied to invoices, subscriptions and Checkout Sessions to collect tax.

Related guide: Tax rates



2207
2208
2209
# File 'lib/stripe/resources/checkout/session.rb', line 2207

def rate
  @rate
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



2209
2210
2211
# File 'lib/stripe/resources/checkout/session.rb', line 2209

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



2211
2212
2213
# File 'lib/stripe/resources/checkout/session.rb', line 2211

def taxable_amount
  @taxable_amount
end

Class Method Details

.field_remappingsObject



2217
2218
2219
# File 'lib/stripe/resources/checkout/session.rb', line 2217

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2213
2214
2215
# File 'lib/stripe/resources/checkout/session.rb', line 2213

def self.inner_class_types
  @inner_class_types = {}
end