Class: Stripe::Checkout::Session::ShippingCost::Tax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount of tax applied for this rate.



2052
2053
2054
# File 'lib/stripe/resources/checkout/session.rb', line 2052

def amount
  @amount
end

#rateObject (readonly)

Tax rates can be applied to [invoices](/invoicing/taxes/tax-rates), [subscriptions](/billing/taxes/tax-rates) and [Checkout Sessions](/payments/checkout/use-manual-tax-rates) to collect tax.

Related guide: [Tax rates](/billing/taxes/tax-rates)



2056
2057
2058
# File 'lib/stripe/resources/checkout/session.rb', line 2056

def rate
  @rate
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



2058
2059
2060
# File 'lib/stripe/resources/checkout/session.rb', line 2058

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



2060
2061
2062
# File 'lib/stripe/resources/checkout/session.rb', line 2060

def taxable_amount
  @taxable_amount
end

Class Method Details

.field_remappingsObject



2066
2067
2068
# File 'lib/stripe/resources/checkout/session.rb', line 2066

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2062
2063
2064
# File 'lib/stripe/resources/checkout/session.rb', line 2062

def self.inner_class_types
  @inner_class_types = {}
end