Class: Stripe::Checkout::Session::ShippingCost::Tax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount of tax applied for this rate.



1879
1880
1881
# File 'lib/stripe/resources/checkout/session.rb', line 1879

def amount
  @amount
end

#rateObject (readonly)

Tax rates can be applied to [invoices](/invoicing/taxes/tax-rates), [subscriptions](/billing/taxes/tax-rates) and [Checkout Sessions](/payments/checkout/use-manual-tax-rates) to collect tax.

Related guide: [Tax rates](/billing/taxes/tax-rates)



1883
1884
1885
# File 'lib/stripe/resources/checkout/session.rb', line 1883

def rate
  @rate
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



1885
1886
1887
# File 'lib/stripe/resources/checkout/session.rb', line 1885

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



1887
1888
1889
# File 'lib/stripe/resources/checkout/session.rb', line 1887

def taxable_amount
  @taxable_amount
end

Class Method Details

.field_remappingsObject



1893
1894
1895
# File 'lib/stripe/resources/checkout/session.rb', line 1893

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1889
1890
1891
# File 'lib/stripe/resources/checkout/session.rb', line 1889

def self.inner_class_types
  @inner_class_types = {}
end