Class: Stripe::Checkout::Session::ShippingCost::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::ShippingCost::Tax
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount of tax applied for this rate.
-
#rate ⇒ Object
readonly
Tax rates can be applied to [invoices](stripe.com/docs/billing/invoices/tax-rates), [subscriptions](stripe.com/docs/billing/subscriptions/taxes) and [Checkout Sessions](stripe.com/docs/payments/checkout/set-up-a-subscription#tax-rates) to collect tax.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in cents (or local equivalent).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount of tax applied for this rate.
965 966 967 |
# File 'lib/stripe/resources/checkout/session.rb', line 965 def amount @amount end |
#rate ⇒ Object (readonly)
Tax rates can be applied to [invoices](stripe.com/docs/billing/invoices/tax-rates), [subscriptions](stripe.com/docs/billing/subscriptions/taxes) and [Checkout Sessions](stripe.com/docs/payments/checkout/set-up-a-subscription#tax-rates) to collect tax.
Related guide: [Tax rates](stripe.com/docs/billing/taxes/tax-rates)
969 970 971 |
# File 'lib/stripe/resources/checkout/session.rb', line 969 def rate @rate end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
971 972 973 |
# File 'lib/stripe/resources/checkout/session.rb', line 971 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in cents (or local equivalent).
973 974 975 |
# File 'lib/stripe/resources/checkout/session.rb', line 973 def taxable_amount @taxable_amount end |