Class: Stripe::Checkout::Session::ShippingDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::ShippingDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Address
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#carrier ⇒ Object
readonly
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
readonly
Recipient name.
-
#phone ⇒ Object
readonly
Recipient phone (including extension).
-
#tracking_number ⇒ Object
readonly
The tracking number for a physical product, obtained from the delivery service.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
1010 1011 1012 |
# File 'lib/stripe/resources/checkout/session.rb', line 1010 def address @address end |
#carrier ⇒ Object (readonly)
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
1012 1013 1014 |
# File 'lib/stripe/resources/checkout/session.rb', line 1012 def carrier @carrier end |
#name ⇒ Object (readonly)
Recipient name.
1014 1015 1016 |
# File 'lib/stripe/resources/checkout/session.rb', line 1014 def name @name end |
#phone ⇒ Object (readonly)
Recipient phone (including extension).
1016 1017 1018 |
# File 'lib/stripe/resources/checkout/session.rb', line 1016 def phone @phone end |
#tracking_number ⇒ Object (readonly)
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
1018 1019 1020 |
# File 'lib/stripe/resources/checkout/session.rb', line 1018 def tracking_number @tracking_number end |