Class: Stripe::Checkout::Session::TotalDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Breakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_discountObject (readonly)

This is the sum of all the discounts.



2171
2172
2173
# File 'lib/stripe/resources/checkout/session.rb', line 2171

def amount_discount
  @amount_discount
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



2173
2174
2175
# File 'lib/stripe/resources/checkout/session.rb', line 2173

def amount_shipping
  @amount_shipping
end

#amount_taxObject (readonly)

This is the sum of all the tax amounts.



2175
2176
2177
# File 'lib/stripe/resources/checkout/session.rb', line 2175

def amount_tax
  @amount_tax
end

#breakdownObject (readonly)

Attribute for field breakdown



2177
2178
2179
# File 'lib/stripe/resources/checkout/session.rb', line 2177

def breakdown
  @breakdown
end

Class Method Details

.field_remappingsObject



2183
2184
2185
# File 'lib/stripe/resources/checkout/session.rb', line 2183

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2179
2180
2181
# File 'lib/stripe/resources/checkout/session.rb', line 2179

def self.inner_class_types
  @inner_class_types = { breakdown: Breakdown }
end