Class: Stripe::Checkout::Session::TotalDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::TotalDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Breakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_discount ⇒ Object
readonly
This is the sum of all the discounts.
-
#amount_shipping ⇒ Object
readonly
This is the sum of all the shipping amounts.
-
#amount_tax ⇒ Object
readonly
This is the sum of all the tax amounts.
-
#breakdown ⇒ Object
readonly
Attribute for field breakdown.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_discount ⇒ Object (readonly)
This is the sum of all the discounts.
2001 2002 2003 |
# File 'lib/stripe/resources/checkout/session.rb', line 2001 def amount_discount @amount_discount end |
#amount_shipping ⇒ Object (readonly)
This is the sum of all the shipping amounts.
2003 2004 2005 |
# File 'lib/stripe/resources/checkout/session.rb', line 2003 def amount_shipping @amount_shipping end |
#amount_tax ⇒ Object (readonly)
This is the sum of all the tax amounts.
2005 2006 2007 |
# File 'lib/stripe/resources/checkout/session.rb', line 2005 def amount_tax @amount_tax end |
#breakdown ⇒ Object (readonly)
Attribute for field breakdown
2007 2008 2009 |
# File 'lib/stripe/resources/checkout/session.rb', line 2007 def breakdown @breakdown end |
Class Method Details
.field_remappings ⇒ Object
2013 2014 2015 |
# File 'lib/stripe/resources/checkout/session.rb', line 2013 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2009 2010 2011 |
# File 'lib/stripe/resources/checkout/session.rb', line 2009 def self.inner_class_types @inner_class_types = { breakdown: Breakdown } end |