Class: Stripe::Checkout::Session::TotalDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::TotalDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Breakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_discount ⇒ Object
readonly
This is the sum of all the discounts.
-
#amount_shipping ⇒ Object
readonly
This is the sum of all the shipping amounts.
-
#amount_tax ⇒ Object
readonly
This is the sum of all the tax amounts.
-
#breakdown ⇒ Object
readonly
Attribute for field breakdown.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_discount ⇒ Object (readonly)
This is the sum of all the discounts.
1975 1976 1977 |
# File 'lib/stripe/resources/checkout/session.rb', line 1975 def amount_discount @amount_discount end |
#amount_shipping ⇒ Object (readonly)
This is the sum of all the shipping amounts.
1977 1978 1979 |
# File 'lib/stripe/resources/checkout/session.rb', line 1977 def amount_shipping @amount_shipping end |
#amount_tax ⇒ Object (readonly)
This is the sum of all the tax amounts.
1979 1980 1981 |
# File 'lib/stripe/resources/checkout/session.rb', line 1979 def amount_tax @amount_tax end |
#breakdown ⇒ Object (readonly)
Attribute for field breakdown
1981 1982 1983 |
# File 'lib/stripe/resources/checkout/session.rb', line 1981 def breakdown @breakdown end |
Class Method Details
.field_remappings ⇒ Object
1987 1988 1989 |
# File 'lib/stripe/resources/checkout/session.rb', line 1987 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1983 1984 1985 |
# File 'lib/stripe/resources/checkout/session.rb', line 1983 def self.inner_class_types @inner_class_types = { breakdown: Breakdown } end |