Class: Stripe::Checkout::Session::TotalDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::TotalDetails
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: Breakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_discount ⇒ Object
readonly
This is the sum of all the discounts.
-
#amount_shipping ⇒ Object
readonly
This is the sum of all the shipping amounts.
-
#amount_tax ⇒ Object
readonly
This is the sum of all the tax amounts.
-
#breakdown ⇒ Object
readonly
Attribute for field breakdown.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_discount ⇒ Object (readonly)
This is the sum of all the discounts.
1127 1128 1129 |
# File 'lib/stripe/resources/checkout/session.rb', line 1127 def amount_discount @amount_discount end |
#amount_shipping ⇒ Object (readonly)
This is the sum of all the shipping amounts.
1129 1130 1131 |
# File 'lib/stripe/resources/checkout/session.rb', line 1129 def amount_shipping @amount_shipping end |
#amount_tax ⇒ Object (readonly)
This is the sum of all the tax amounts.
1131 1132 1133 |
# File 'lib/stripe/resources/checkout/session.rb', line 1131 def amount_tax @amount_tax end |
#breakdown ⇒ Object (readonly)
Attribute for field breakdown
1133 1134 1135 |
# File 'lib/stripe/resources/checkout/session.rb', line 1133 def breakdown @breakdown end |