Class: Stripe::Checkout::Session::TotalDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: Breakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_discountObject (readonly)

This is the sum of all the discounts.



1058
1059
1060
# File 'lib/stripe/resources/checkout/session.rb', line 1058

def amount_discount
  @amount_discount
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



1060
1061
1062
# File 'lib/stripe/resources/checkout/session.rb', line 1060

def amount_shipping
  @amount_shipping
end

#amount_taxObject (readonly)

This is the sum of all the tax amounts.



1062
1063
1064
# File 'lib/stripe/resources/checkout/session.rb', line 1062

def amount_tax
  @amount_tax
end

#breakdownObject (readonly)

Attribute for field breakdown



1064
1065
1066
# File 'lib/stripe/resources/checkout/session.rb', line 1064

def breakdown
  @breakdown
end