Class: Stripe::Checkout::Session::TotalDetails::Breakdown::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Checkout::Session::TotalDetails::Breakdown::Tax
- Defined in:
- lib/stripe/resources/checkout/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount of tax applied for this rate.
-
#rate ⇒ Object
readonly
Tax rates can be applied to [invoices](/invoicing/taxes/tax-rates), [subscriptions](/billing/taxes/tax-rates) and [Checkout Sessions](/payments/checkout/use-manual-tax-rates) to collect tax.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in cents (or local equivalent).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount of tax applied for this rate.
2534 2535 2536 |
# File 'lib/stripe/resources/checkout/session.rb', line 2534 def amount @amount end |
#rate ⇒ Object (readonly)
Tax rates can be applied to [invoices](/invoicing/taxes/tax-rates), [subscriptions](/billing/taxes/tax-rates) and [Checkout Sessions](/payments/checkout/use-manual-tax-rates) to collect tax.
Related guide: [Tax rates](/billing/taxes/tax-rates)
2538 2539 2540 |
# File 'lib/stripe/resources/checkout/session.rb', line 2538 def rate @rate end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
2540 2541 2542 |
# File 'lib/stripe/resources/checkout/session.rb', line 2540 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in cents (or local equivalent).
2542 2543 2544 |
# File 'lib/stripe/resources/checkout/session.rb', line 2542 def taxable_amount @taxable_amount end |
Class Method Details
.field_remappings ⇒ Object
2548 2549 2550 |
# File 'lib/stripe/resources/checkout/session.rb', line 2548 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2544 2545 2546 |
# File 'lib/stripe/resources/checkout/session.rb', line 2544 def self.inner_class_types @inner_class_types = {} end |