Class: Stripe::Checkout::Session::TotalDetails::Breakdown::Tax

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount of tax applied for this rate.



2152
2153
2154
# File 'lib/stripe/resources/checkout/session.rb', line 2152

def amount
  @amount
end

#rateObject (readonly)

Tax rates can be applied to [invoices](/invoicing/taxes/tax-rates), [subscriptions](/billing/taxes/tax-rates) and [Checkout Sessions](/payments/checkout/use-manual-tax-rates) to collect tax.

Related guide: [Tax rates](/billing/taxes/tax-rates)



2156
2157
2158
# File 'lib/stripe/resources/checkout/session.rb', line 2156

def rate
  @rate
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



2158
2159
2160
# File 'lib/stripe/resources/checkout/session.rb', line 2158

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



2160
2161
2162
# File 'lib/stripe/resources/checkout/session.rb', line 2160

def taxable_amount
  @taxable_amount
end

Class Method Details

.field_remappingsObject



2166
2167
2168
# File 'lib/stripe/resources/checkout/session.rb', line 2166

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2162
2163
2164
# File 'lib/stripe/resources/checkout/session.rb', line 2162

def self.inner_class_types
  @inner_class_types = {}
end