Class: Stripe::Checkout::Session::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: CollectedInformation, ShippingOption
Instance Attribute Summary collapse
-
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
Instance Method Summary collapse
-
#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
3507 3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 |
# File 'lib/stripe/resources/checkout/session.rb', line 3507 def initialize( collected_information: nil, expand: nil, metadata: nil, shipping_options: nil ) @collected_information = collected_information @expand = @metadata = @shipping_options = end |
Instance Attribute Details
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.
3499 3500 3501 |
# File 'lib/stripe/resources/checkout/session.rb', line 3499 def collected_information @collected_information end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3501 3502 3503 |
# File 'lib/stripe/resources/checkout/session.rb', line 3501 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3503 3504 3505 |
# File 'lib/stripe/resources/checkout/session.rb', line 3503 def @metadata end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
3505 3506 3507 |
# File 'lib/stripe/resources/checkout/session.rb', line 3505 def @shipping_options end |