Class: Stripe::Checkout::Session::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CollectedInformation, LineItem, ShippingOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



3792
3793
3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
# File 'lib/stripe/resources/checkout/session.rb', line 3792

def initialize(
  collected_information: nil,
  expand: nil,
  line_items: nil,
  metadata: nil,
  shipping_options: nil
)
  @collected_information = collected_information
  @expand = expand
  @line_items = line_items
  @metadata = 
  @shipping_options = shipping_options
end

Instance Attribute Details

#collected_informationObject

Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.



3770
3771
3772
# File 'lib/stripe/resources/checkout/session.rb', line 3770

def collected_information
  @collected_information
end

#expandObject

Specifies which fields in the response should be expanded.



3772
3773
3774
# File 'lib/stripe/resources/checkout/session.rb', line 3772

def expand
  @expand
end

#line_itemsObject

A list of items the customer is purchasing.

When updating line items, you must retransmit the entire array of line items.

To retain an existing line item, specify its ‘id`.

To update an existing line item, specify its ‘id` along with the new values of the fields to update.

To add a new line item, specify one of ‘price` or `price_data` and `quantity`.

To remove an existing line item, omit the line item’s ID from the retransmitted array.

To reorder a line item, specify it at the desired position in the retransmitted array.



3786
3787
3788
# File 'lib/stripe/resources/checkout/session.rb', line 3786

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3788
3789
3790
# File 'lib/stripe/resources/checkout/session.rb', line 3788

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



3790
3791
3792
# File 'lib/stripe/resources/checkout/session.rb', line 3790

def shipping_options
  @shipping_options
end