Class: Stripe::Checkout::Session::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: CollectedInformation, ShippingOption
Instance Attribute Summary collapse
-
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
Instance Method Summary collapse
-
#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 |
# File 'lib/stripe/resources/checkout/session.rb', line 3472 def initialize( collected_information: nil, expand: nil, metadata: nil, shipping_options: nil ) @collected_information = collected_information @expand = @metadata = @shipping_options = end |
Instance Attribute Details
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.
3464 3465 3466 |
# File 'lib/stripe/resources/checkout/session.rb', line 3464 def collected_information @collected_information end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3466 3467 3468 |
# File 'lib/stripe/resources/checkout/session.rb', line 3466 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3468 3469 3470 |
# File 'lib/stripe/resources/checkout/session.rb', line 3468 def @metadata end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
3470 3471 3472 |
# File 'lib/stripe/resources/checkout/session.rb', line 3470 def @shipping_options end |