Class: Stripe::Checkout::Session::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CollectedInformation, ShippingOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



3422
3423
3424
3425
3426
3427
3428
3429
3430
3431
3432
# File 'lib/stripe/resources/checkout/session.rb', line 3422

def initialize(
  collected_information: nil,
  expand: nil,
  metadata: nil,
  shipping_options: nil
)
  @collected_information = collected_information
  @expand = expand
  @metadata = 
  @shipping_options = shipping_options
end

Instance Attribute Details

#collected_informationObject

Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.



3414
3415
3416
# File 'lib/stripe/resources/checkout/session.rb', line 3414

def collected_information
  @collected_information
end

#expandObject

Specifies which fields in the response should be expanded.



3416
3417
3418
# File 'lib/stripe/resources/checkout/session.rb', line 3416

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3418
3419
3420
# File 'lib/stripe/resources/checkout/session.rb', line 3418

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



3420
3421
3422
# File 'lib/stripe/resources/checkout/session.rb', line 3420

def shipping_options
  @shipping_options
end