Class: Stripe::Checkout::Session::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CollectedInformation, ShippingOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



3408
3409
3410
3411
3412
3413
3414
3415
3416
3417
3418
# File 'lib/stripe/resources/checkout/session.rb', line 3408

def initialize(
  collected_information: nil,
  expand: nil,
  metadata: nil,
  shipping_options: nil
)
  @collected_information = collected_information
  @expand = expand
  @metadata = 
  @shipping_options = shipping_options
end

Instance Attribute Details

#collected_informationObject

Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.



3400
3401
3402
# File 'lib/stripe/resources/checkout/session.rb', line 3400

def collected_information
  @collected_information
end

#expandObject

Specifies which fields in the response should be expanded.



3402
3403
3404
# File 'lib/stripe/resources/checkout/session.rb', line 3402

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3404
3405
3406
# File 'lib/stripe/resources/checkout/session.rb', line 3404

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



3406
3407
3408
# File 'lib/stripe/resources/checkout/session.rb', line 3406

def shipping_options
  @shipping_options
end