Class: Stripe::Checkout::Session::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CollectedInformation, ShippingOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



3376
3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
# File 'lib/stripe/resources/checkout/session.rb', line 3376

def initialize(
  collected_information: nil,
  expand: nil,
  metadata: nil,
  shipping_options: nil
)
  @collected_information = collected_information
  @expand = expand
  @metadata = 
  @shipping_options = shipping_options
end

Instance Attribute Details

#collected_informationObject

Information about the customer collected within the Checkout Session.



3368
3369
3370
# File 'lib/stripe/resources/checkout/session.rb', line 3368

def collected_information
  @collected_information
end

#expandObject

Specifies which fields in the response should be expanded.



3370
3371
3372
# File 'lib/stripe/resources/checkout/session.rb', line 3370

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3372
3373
3374
# File 'lib/stripe/resources/checkout/session.rb', line 3372

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



3374
3375
3376
# File 'lib/stripe/resources/checkout/session.rb', line 3374

def shipping_options
  @shipping_options
end