Class: Stripe::Checkout::Session::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: CollectedInformation, LineItem, ShippingOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



3569
3570
3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
# File 'lib/stripe/resources/checkout/session.rb', line 3569

def initialize(
  collected_information: nil,
  expand: nil,
  line_items: nil,
  metadata: nil,
  shipping_options: nil
)
  @collected_information = collected_information
  @expand = expand
  @line_items = line_items
  @metadata = 
  @shipping_options = shipping_options
end

Instance Attribute Details

#collected_informationObject

Information about the customer collected within the Checkout Session.



3547
3548
3549
# File 'lib/stripe/resources/checkout/session.rb', line 3547

def collected_information
  @collected_information
end

#expandObject

Specifies which fields in the response should be expanded.



3549
3550
3551
# File 'lib/stripe/resources/checkout/session.rb', line 3549

def expand
  @expand
end

#line_itemsObject

A list of items the customer is purchasing.

When updating line items, you must retransmit the entire array of line items.

To retain an existing line item, specify its ‘id`.

To update an existing line item, specify its ‘id` along with the new values of the fields to update.

To add a new line item, specify a ‘price` and `quantity`. We don’t currently support recurring prices.

To remove an existing line item, omit the line item’s ID from the retransmitted array.

To reorder a line item, specify it at the desired position in the retransmitted array.



3563
3564
3565
# File 'lib/stripe/resources/checkout/session.rb', line 3563

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3565
3566
3567
# File 'lib/stripe/resources/checkout/session.rb', line 3565

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



3567
3568
3569
# File 'lib/stripe/resources/checkout/session.rb', line 3567

def shipping_options
  @shipping_options
end