Class: Stripe::Checkout::Session::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: CollectedInformation, LineItem, ShippingOption
Instance Attribute Summary collapse
-
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
Instance Method Summary collapse
-
#initialize(collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
3508 3509 3510 3511 3512 3513 3514 3515 3516 3517 3518 3519 3520 |
# File 'lib/stripe/resources/checkout/session.rb', line 3508 def initialize( collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil ) @collected_information = collected_information @expand = @line_items = line_items @metadata = @shipping_options = end |
Instance Attribute Details
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
3486 3487 3488 |
# File 'lib/stripe/resources/checkout/session.rb', line 3486 def collected_information @collected_information end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3488 3489 3490 |
# File 'lib/stripe/resources/checkout/session.rb', line 3488 def @expand end |
#line_items ⇒ Object
A list of items the customer is purchasing.
When updating line items, you must retransmit the entire array of line items.
To retain an existing line item, specify its ‘id`.
To update an existing line item, specify its ‘id` along with the new values of the fields to update.
To add a new line item, specify a ‘price` and `quantity`. We don’t currently support recurring prices.
To remove an existing line item, omit the line item’s ID from the retransmitted array.
To reorder a line item, specify it at the desired position in the retransmitted array.
3502 3503 3504 |
# File 'lib/stripe/resources/checkout/session.rb', line 3502 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3504 3505 3506 |
# File 'lib/stripe/resources/checkout/session.rb', line 3504 def @metadata end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
3506 3507 3508 |
# File 'lib/stripe/resources/checkout/session.rb', line 3506 def @shipping_options end |