Class: Stripe::Checkout::Session::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams::LineItem
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AdjustableQuantity, PriceData
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
-
#id ⇒ Object
ID of an existing line item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices).
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
-
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 |
# File 'lib/stripe/resources/checkout/session.rb', line 3645 def initialize( adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @adjustable_quantity = adjustable_quantity @id = id @metadata = @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
3631 3632 3633 |
# File 'lib/stripe/resources/checkout/session.rb', line 3631 def adjustable_quantity @adjustable_quantity end |
#id ⇒ Object
ID of an existing line item.
3633 3634 3635 |
# File 'lib/stripe/resources/checkout/session.rb', line 3633 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3635 3636 3637 |
# File 'lib/stripe/resources/checkout/session.rb', line 3635 def @metadata end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices). One of ‘price` or `price_data` is required when creating a new line item.
3637 3638 3639 |
# File 'lib/stripe/resources/checkout/session.rb', line 3637 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required when creating a new line item.
3639 3640 3641 |
# File 'lib/stripe/resources/checkout/session.rb', line 3639 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.
3641 3642 3643 |
# File 'lib/stripe/resources/checkout/session.rb', line 3641 def quantity @quantity end |
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
3643 3644 3645 |
# File 'lib/stripe/resources/checkout/session.rb', line 3643 def tax_rates @tax_rates end |