Class: Stripe::Checkout::Session::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



3585
3586
3587
3588
3589
3590
3591
3592
3593
3594
3595
3596
3597
3598
3599
3600
3601
# File 'lib/stripe/resources/checkout/session.rb', line 3585

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



3571
3572
3573
# File 'lib/stripe/resources/checkout/session.rb', line 3571

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



3573
3574
3575
# File 'lib/stripe/resources/checkout/session.rb', line 3573

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3575
3576
3577
# File 'lib/stripe/resources/checkout/session.rb', line 3575

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices). One of ‘price` or `price_data` is required when creating a new line item.



3577
3578
3579
# File 'lib/stripe/resources/checkout/session.rb', line 3577

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required when creating a new line item.



3579
3580
3581
# File 'lib/stripe/resources/checkout/session.rb', line 3579

def price_data
  @price_data
end

#quantityObject

The quantity of the line item being purchased.



3581
3582
3583
# File 'lib/stripe/resources/checkout/session.rb', line 3581

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



3583
3584
3585
# File 'lib/stripe/resources/checkout/session.rb', line 3583

def tax_rates
  @tax_rates
end