Class: Stripe::Checkout::Session::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



3512
3513
3514
3515
3516
3517
3518
3519
3520
3521
3522
3523
3524
3525
3526
# File 'lib/stripe/resources/checkout/session.rb', line 3512

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



3500
3501
3502
# File 'lib/stripe/resources/checkout/session.rb', line 3500

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



3502
3503
3504
# File 'lib/stripe/resources/checkout/session.rb', line 3502

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3504
3505
3506
# File 'lib/stripe/resources/checkout/session.rb', line 3504

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices).



3506
3507
3508
# File 'lib/stripe/resources/checkout/session.rb', line 3506

def price
  @price
end

#quantityObject

The quantity of the line item being purchased.



3508
3509
3510
# File 'lib/stripe/resources/checkout/session.rb', line 3508

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



3510
3511
3512
# File 'lib/stripe/resources/checkout/session.rb', line 3510

def tax_rates
  @tax_rates
end