Class: Stripe::Checkout::Session::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



3482
3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
3495
3496
# File 'lib/stripe/resources/checkout/session.rb', line 3482

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



3470
3471
3472
# File 'lib/stripe/resources/checkout/session.rb', line 3470

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



3472
3473
3474
# File 'lib/stripe/resources/checkout/session.rb', line 3472

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3474
3475
3476
# File 'lib/stripe/resources/checkout/session.rb', line 3474

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices).



3476
3477
3478
# File 'lib/stripe/resources/checkout/session.rb', line 3476

def price
  @price
end

#quantityObject

The quantity of the line item being purchased.



3478
3479
3480
# File 'lib/stripe/resources/checkout/session.rb', line 3478

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



3480
3481
3482
# File 'lib/stripe/resources/checkout/session.rb', line 3480

def tax_rates
  @tax_rates
end