Class: Stripe::Checkout::Session::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



3424
3425
3426
3427
3428
3429
3430
3431
3432
3433
3434
3435
3436
3437
3438
# File 'lib/stripe/resources/checkout/session.rb', line 3424

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



3412
3413
3414
# File 'lib/stripe/resources/checkout/session.rb', line 3412

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



3414
3415
3416
# File 'lib/stripe/resources/checkout/session.rb', line 3414

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3416
3417
3418
# File 'lib/stripe/resources/checkout/session.rb', line 3416

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices).



3418
3419
3420
# File 'lib/stripe/resources/checkout/session.rb', line 3418

def price
  @price
end

#quantityObject

The quantity of the line item being purchased.



3420
3421
3422
# File 'lib/stripe/resources/checkout/session.rb', line 3420

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



3422
3423
3424
# File 'lib/stripe/resources/checkout/session.rb', line 3422

def tax_rates
  @tax_rates
end