Class: Stripe::Checkout::Session::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams::LineItem
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
-
#id ⇒ Object
ID of an existing line item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices).
-
#quantity ⇒ Object
The quantity of the line item being purchased.
-
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/stripe/resources/checkout/session.rb', line 3397 def initialize( adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil ) @adjustable_quantity = adjustable_quantity @id = id @metadata = @price = price @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
3385 3386 3387 |
# File 'lib/stripe/resources/checkout/session.rb', line 3385 def adjustable_quantity @adjustable_quantity end |
#id ⇒ Object
ID of an existing line item.
3387 3388 3389 |
# File 'lib/stripe/resources/checkout/session.rb', line 3387 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3389 3390 3391 |
# File 'lib/stripe/resources/checkout/session.rb', line 3389 def @metadata end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices).
3391 3392 3393 |
# File 'lib/stripe/resources/checkout/session.rb', line 3391 def price @price end |
#quantity ⇒ Object
The quantity of the line item being purchased.
3393 3394 3395 |
# File 'lib/stripe/resources/checkout/session.rb', line 3393 def quantity @quantity end |
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
3395 3396 3397 |
# File 'lib/stripe/resources/checkout/session.rb', line 3395 def tax_rates @tax_rates end |