Class: Stripe::Checkout::Session::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



3794
3795
3796
3797
3798
3799
3800
3801
3802
3803
3804
3805
3806
3807
3808
# File 'lib/stripe/resources/checkout/session.rb', line 3794

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



3777
3778
3779
# File 'lib/stripe/resources/checkout/session.rb', line 3777

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



3780
3781
3782
# File 'lib/stripe/resources/checkout/session.rb', line 3780

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3783
3784
3785
# File 'lib/stripe/resources/checkout/session.rb', line 3783

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices).



3786
3787
3788
# File 'lib/stripe/resources/checkout/session.rb', line 3786

def price
  @price
end

#quantityObject

The quantity of the line item being purchased.



3789
3790
3791
# File 'lib/stripe/resources/checkout/session.rb', line 3789

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



3792
3793
3794
# File 'lib/stripe/resources/checkout/session.rb', line 3792

def tax_rates
  @tax_rates
end