Class: Stripe::Checkout::Session::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
# File 'lib/stripe/resources/checkout/session.rb', line 3377

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



3365
3366
3367
# File 'lib/stripe/resources/checkout/session.rb', line 3365

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



3367
3368
3369
# File 'lib/stripe/resources/checkout/session.rb', line 3367

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3369
3370
3371
# File 'lib/stripe/resources/checkout/session.rb', line 3369

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices).



3371
3372
3373
# File 'lib/stripe/resources/checkout/session.rb', line 3371

def price
  @price
end

#quantityObject

The quantity of the line item being purchased.



3373
3374
3375
# File 'lib/stripe/resources/checkout/session.rb', line 3373

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



3375
3376
3377
# File 'lib/stripe/resources/checkout/session.rb', line 3375

def tax_rates
  @tax_rates
end