Class: Stripe::Checkout::Session::UpdateParams::LineItem::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: ProductData, Recurring

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(currency: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



3690
3691
3692
3693
3694
3695
3696
3697
3698
3699
3700
3701
3702
3703
3704
3705
3706
# File 'lib/stripe/resources/checkout/session.rb', line 3690

def initialize(
  currency: nil,
  product: nil,
  product_data: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @product_data = product_data
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



3676
3677
3678
# File 'lib/stripe/resources/checkout/session.rb', line 3676

def currency
  @currency
end

#productObject

The ID of the [Product](docs.stripe.com/api/products) that this [Price](docs.stripe.com/api/prices) will belong to. One of ‘product` or `product_data` is required.



3678
3679
3680
# File 'lib/stripe/resources/checkout/session.rb', line 3678

def product
  @product
end

#product_dataObject

Data used to generate a new [Product](docs.stripe.com/api/products) object inline. One of ‘product` or `product_data` is required.



3680
3681
3682
# File 'lib/stripe/resources/checkout/session.rb', line 3680

def product_data
  @product_data
end

#recurringObject

The recurring components of a price such as ‘interval` and `interval_count`.



3682
3683
3684
# File 'lib/stripe/resources/checkout/session.rb', line 3682

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



3684
3685
3686
# File 'lib/stripe/resources/checkout/session.rb', line 3684

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A non-negative integer in cents (or local equivalent) representing how much to charge. One of ‘unit_amount` or `unit_amount_decimal` is required.



3686
3687
3688
# File 'lib/stripe/resources/checkout/session.rb', line 3686

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



3688
3689
3690
# File 'lib/stripe/resources/checkout/session.rb', line 3688

def unit_amount_decimal
  @unit_amount_decimal
end