Class: Stripe::Checkout::Session::UpdateParams::LineItem::PriceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams::LineItem::PriceData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: ProductData, Recurring
Instance Attribute Summary collapse
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#product ⇒ Object
The ID of the [Product](docs.stripe.com/api/products) that this [Price](docs.stripe.com/api/prices) will belong to.
-
#product_data ⇒ Object
Data used to generate a new [Product](docs.stripe.com/api/products) object inline.
-
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#unit_amount ⇒ Object
A non-negative integer in cents (or local equivalent) representing how much to charge.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(currency: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
constructor
A new instance of PriceData.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData
Returns a new instance of PriceData.
3612 3613 3614 3615 3616 3617 3618 3619 3620 3621 3622 3623 3624 3625 3626 3627 3628 |
# File 'lib/stripe/resources/checkout/session.rb', line 3612 def initialize( currency: nil, product: nil, product_data: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil ) @currency = currency @product = product @product_data = product_data @recurring = recurring @tax_behavior = tax_behavior @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3598 3599 3600 |
# File 'lib/stripe/resources/checkout/session.rb', line 3598 def currency @currency end |
#product ⇒ Object
The ID of the [Product](docs.stripe.com/api/products) that this [Price](docs.stripe.com/api/prices) will belong to. One of ‘product` or `product_data` is required.
3600 3601 3602 |
# File 'lib/stripe/resources/checkout/session.rb', line 3600 def product @product end |
#product_data ⇒ Object
Data used to generate a new [Product](docs.stripe.com/api/products) object inline. One of ‘product` or `product_data` is required.
3602 3603 3604 |
# File 'lib/stripe/resources/checkout/session.rb', line 3602 def product_data @product_data end |
#recurring ⇒ Object
The recurring components of a price such as ‘interval` and `interval_count`.
3604 3605 3606 |
# File 'lib/stripe/resources/checkout/session.rb', line 3604 def recurring @recurring end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
3606 3607 3608 |
# File 'lib/stripe/resources/checkout/session.rb', line 3606 def tax_behavior @tax_behavior end |
#unit_amount ⇒ Object
A non-negative integer in cents (or local equivalent) representing how much to charge. One of ‘unit_amount` or `unit_amount_decimal` is required.
3608 3609 3610 |
# File 'lib/stripe/resources/checkout/session.rb', line 3608 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
3610 3611 3612 |
# File 'lib/stripe/resources/checkout/session.rb', line 3610 def unit_amount_decimal @unit_amount_decimal end |