Class: Stripe::Checkout::Session::UpdateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



4799
4800
4801
4802
4803
4804
4805
# File 'lib/stripe/resources/checkout/session.rb', line 4799

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



4789
4790
4791
# File 'lib/stripe/resources/checkout/session.rb', line 4789

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



4791
4792
4793
# File 'lib/stripe/resources/checkout/session.rb', line 4791

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4793
4794
4795
# File 'lib/stripe/resources/checkout/session.rb', line 4793

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



4795
4796
4797
# File 'lib/stripe/resources/checkout/session.rb', line 4795

def name
  @name
end

#tax_codeObject



4797
4798
4799
# File 'lib/stripe/resources/checkout/session.rb', line 4797

def tax_code
  @tax_code
end