Class: Stripe::Checkout::Session::UpdateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



3531
3532
3533
3534
3535
3536
3537
# File 'lib/stripe/resources/checkout/session.rb', line 3531

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



3521
3522
3523
# File 'lib/stripe/resources/checkout/session.rb', line 3521

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



3523
3524
3525
# File 'lib/stripe/resources/checkout/session.rb', line 3523

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3525
3526
3527
# File 'lib/stripe/resources/checkout/session.rb', line 3525

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



3527
3528
3529
# File 'lib/stripe/resources/checkout/session.rb', line 3527

def name
  @name
end

#tax_codeObject



3529
3530
3531
# File 'lib/stripe/resources/checkout/session.rb', line 3529

def tax_code
  @tax_code
end