Class: Stripe::Checkout::Session::UpdateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



3517
3518
3519
3520
3521
3522
3523
# File 'lib/stripe/resources/checkout/session.rb', line 3517

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



3507
3508
3509
# File 'lib/stripe/resources/checkout/session.rb', line 3507

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



3509
3510
3511
# File 'lib/stripe/resources/checkout/session.rb', line 3509

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3511
3512
3513
# File 'lib/stripe/resources/checkout/session.rb', line 3511

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



3513
3514
3515
# File 'lib/stripe/resources/checkout/session.rb', line 3513

def name
  @name
end

#tax_codeObject



3515
3516
3517
# File 'lib/stripe/resources/checkout/session.rb', line 3515

def tax_code
  @tax_code
end