Class: Stripe::Checkout::Session::UpdateParams::ShippingOption::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
3349
3350
3351
3352
3353
3354
3355
# File 'lib/stripe/resources/checkout/session.rb', line 3339

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



3325
3326
3327
# File 'lib/stripe/resources/checkout/session.rb', line 3325

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



3327
3328
3329
# File 'lib/stripe/resources/checkout/session.rb', line 3327

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



3329
3330
3331
# File 'lib/stripe/resources/checkout/session.rb', line 3329

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3331
3332
3333
# File 'lib/stripe/resources/checkout/session.rb', line 3331

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



3333
3334
3335
# File 'lib/stripe/resources/checkout/session.rb', line 3333

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A [tax code](stripe.com/docs/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.



3335
3336
3337
# File 'lib/stripe/resources/checkout/session.rb', line 3335

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



3337
3338
3339
# File 'lib/stripe/resources/checkout/session.rb', line 3337

def type
  @type
end