Class: Stripe::Checkout::Session::UpdateParams::ShippingOption::ShippingRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams::ShippingOption::ShippingRateData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Defined Under Namespace
Classes: DeliveryEstimate, FixedAmount
Instance Attribute Summary collapse
-
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer.
-
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer.
-
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#type ⇒ Object
The type of calculation to use on the shipping rate.
Instance Method Summary collapse
-
#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData
constructor
A new instance of ShippingRateData.
Methods inherited from RequestParams
Constructor Details
#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData
Returns a new instance of ShippingRateData.
3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 |
# File 'lib/stripe/resources/checkout/session.rb', line 3491 def initialize( delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil ) @delivery_estimate = delivery_estimate @display_name = display_name @fixed_amount = fixed_amount @metadata = @tax_behavior = tax_behavior @tax_code = tax_code @type = type end |
Instance Attribute Details
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.
3477 3478 3479 |
# File 'lib/stripe/resources/checkout/session.rb', line 3477 def delivery_estimate @delivery_estimate end |
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.
3479 3480 3481 |
# File 'lib/stripe/resources/checkout/session.rb', line 3479 def display_name @display_name end |
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.
3481 3482 3483 |
# File 'lib/stripe/resources/checkout/session.rb', line 3481 def fixed_amount @fixed_amount end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3483 3484 3485 |
# File 'lib/stripe/resources/checkout/session.rb', line 3483 def @metadata end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
3485 3486 3487 |
# File 'lib/stripe/resources/checkout/session.rb', line 3485 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.
3487 3488 3489 |
# File 'lib/stripe/resources/checkout/session.rb', line 3487 def tax_code @tax_code end |
#type ⇒ Object
The type of calculation to use on the shipping rate.
3489 3490 3491 |
# File 'lib/stripe/resources/checkout/session.rb', line 3489 def type @type end |