Class: Stripe::Checkout::Session::UpdateParams::ShippingOption::ShippingRateData::FixedAmount::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams::ShippingOption::ShippingRateData::FixedAmount::CurrencyOptions
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
Instance Method Summary collapse
-
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
3458 3459 3460 3461 |
# File 'lib/stripe/resources/checkout/session.rb', line 3458 def initialize(amount: nil, tax_behavior: nil) @amount = amount @tax_behavior = tax_behavior end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
3454 3455 3456 |
# File 'lib/stripe/resources/checkout/session.rb', line 3454 def amount @amount end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
3456 3457 3458 |
# File 'lib/stripe/resources/checkout/session.rb', line 3456 def tax_behavior @tax_behavior end |