Class: Stripe::Checkout::Session::UpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/checkout/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



4083
4084
4085
4086
# File 'lib/stripe/resources/checkout/session.rb', line 4083

def initialize(trial_end: nil, trial_period_days: nil)
  @trial_end = trial_end
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.



4079
4080
4081
# File 'lib/stripe/resources/checkout/session.rb', line 4079

def trial_end
  @trial_end
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



4081
4082
4083
# File 'lib/stripe/resources/checkout/session.rb', line 4081

def trial_period_days
  @trial_period_days
end