Class: Stripe::Checkout::Session::UpdateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::Session::UpdateParams::SubscriptionData
- Defined in:
- lib/stripe/resources/checkout/session.rb
Instance Attribute Summary collapse
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
Instance Method Summary collapse
-
#initialize(trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
Constructor Details
#initialize(trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
4998 4999 5000 5001 |
# File 'lib/stripe/resources/checkout/session.rb', line 4998 def initialize(trial_end: nil, trial_period_days: nil) @trial_end = trial_end @trial_period_days = trial_period_days end |
Instance Attribute Details
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.
4994 4995 4996 |
# File 'lib/stripe/resources/checkout/session.rb', line 4994 def trial_end @trial_end end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.
4996 4997 4998 |
# File 'lib/stripe/resources/checkout/session.rb', line 4996 def trial_period_days @trial_period_days end |