Class: Stripe::Checkout::SessionApproveParams::PaymentIntentData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionApproveParams::PaymentIntentData
- Defined in:
- lib/stripe/params/checkout/session_approve_params.rb
Instance Attribute Summary collapse
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
Instance Method Summary collapse
-
#initialize(application_fee_amount: nil) ⇒ PaymentIntentData
constructor
A new instance of PaymentIntentData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(application_fee_amount: nil) ⇒ PaymentIntentData
Returns a new instance of PaymentIntentData.
11 12 13 |
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 11 def initialize(application_fee_amount: nil) @application_fee_amount = application_fee_amount end |
Instance Attribute Details
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
9 10 11 |
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 9 def application_fee_amount @application_fee_amount end |