Class: Stripe::Checkout::SessionApproveParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_approve_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application_fee_percent: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



20
21
22
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 20

def initialize(application_fee_percent: nil)
  @application_fee_percent = application_fee_percent
end

Instance Attribute Details

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. To use an application fee percent, the request must be made on behalf of another account, using the ‘Stripe-Account` header or an OAuth key. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



18
19
20
# File 'lib/stripe/params/checkout/session_approve_params.rb', line 18

def application_fee_percent
  @application_fee_percent
end