Class: Stripe::Checkout::SessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: AdaptivePricing, AfterExpiration, AutomaticSurcharge, AutomaticTax, BrandingSettings, CheckoutItem, ConsentCollection, CustomField, CustomText, CustomerUpdate, Discount, InvoiceCreation, Item, LineItem, ManagedPayments, NameCollection, OptionalItem, PaymentIntentData, PaymentMethodData, PaymentMethodOptions, Permissions, PhoneNumberCollection, SavedPaymentMethodOptions, SetupIntentData, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, WalletOptions
Instance Attribute Summary collapse
-
#adaptive_pricing ⇒ Object
Settings for price localization with Adaptive Pricing.
-
#after_expiration ⇒ Object
Configure actions after a Checkout Session has expired.
-
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
-
#approval_method ⇒ Object
Determines whether the customer's attempt to pay must be manually approved.
-
#automatic_surcharge ⇒ Object
Settings for automatic surcharge calculation for this session.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
-
#billing_address_collection ⇒ Object
Specify whether Checkout should collect the customer's billing address.
-
#branding_settings ⇒ Object
The branding settings for the Checkout Session.
-
#cancel_url ⇒ Object
If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website.
-
#checkout_items ⇒ Object
Attribute for param field checkout_items.
-
#client_reference_id ⇒ Object
A unique string to reference the Checkout Session.
-
#consent_collection ⇒ Object
Configure fields for the Checkout Session to gather active consent from customers.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields.
-
#custom_payment_method_types ⇒ Object
A list of custom payment methods (e.g.,
cpmt_123) this Checkout Session can accept. -
#custom_text ⇒ Object
Display additional text for your customers using custom text.
-
#customer ⇒ Object
ID of an existing Customer, if one exists.
-
#customer_account ⇒ Object
ID of an existing Account, if one exists.
-
#customer_creation ⇒ Object
Configure whether a Checkout Session creates a Customer during Session confirmation.
-
#customer_email ⇒ Object
If provided, this value will be used when the Customer object is created.
-
#customer_update ⇒ Object
Controls what fields on Customer can be updated by the Checkout Session.
-
#discounts ⇒ Object
The coupon or promotion code to apply to this Session.
-
#excluded_payment_method_types ⇒ Object
A list of the types of payment methods (e.g.,
card) that should be excluded from this Checkout Session. -
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
The Epoch time in seconds at which the Checkout Session will expire.
-
#integration_identifier ⇒ Object
The integration identifier for this Checkout Session.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#items ⇒ Object
A list of items the customer will purchase.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#locale ⇒ Object
The IETF language tag of the locale Checkout is displayed in.
-
#managed_payments ⇒ Object
Settings for Managed Payments for this Checkout Session and resulting PaymentIntents, Invoices, and Subscriptions.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#mode ⇒ Object
The mode of the Checkout Session.
-
#name_collection ⇒ Object
Controls name collection settings for the session.
-
#optional_items ⇒ Object
A list of optional items the customer can add to their order at checkout.
-
#origin_context ⇒ Object
Where the user is coming from.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in
paymentmode. -
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method.
-
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this Checkout session.
-
#payment_method_data ⇒ Object
This parameter allows you to set some attributes on the payment method created during a Checkout session.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration.
-
#payment_method_types ⇒ Object
A list of the types of payment methods (e.g.,
card) this Checkout Session can accept. -
#permissions ⇒ Object
This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object.
-
#phone_number_collection ⇒ Object
Controls phone number collection settings for the session.
-
#redirect_on_completion ⇒ Object
This parameter applies to
ui_mode: embedded_page. -
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site.
-
#saved_payment_method_options ⇒ Object
Controls saved payment method settings for the session.
-
#setup_intent_data ⇒ Object
A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in
setupmode. -
#shipping_address_collection ⇒ Object
When set, provides configuration for Checkout to collect a shipping address from a customer.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
-
#submit_type ⇒ Object
Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in
subscriptionmode. -
#success_url ⇒ Object
The URL to which Stripe should send customers when payment or setup is complete.
-
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
-
#ui_mode ⇒ Object
The UI mode of the Session.
-
#wallet_options ⇒ Object
Wallet-specific configuration.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(adaptive_pricing: nil, after_expiration: nil, allow_promotion_codes: nil, approval_method: nil, automatic_surcharge: nil, automatic_tax: nil, billing_address_collection: nil, branding_settings: nil, cancel_url: nil, client_reference_id: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_payment_method_types: nil, custom_text: nil, customer: nil, customer_account: nil, customer_creation: nil, customer_email: nil, customer_update: nil, discounts: nil, excluded_payment_method_types: nil, expand: nil, expires_at: nil, integration_identifier: nil, invoice_creation: nil, items: nil, line_items: nil, locale: nil, managed_payments: nil, metadata: nil, mode: nil, name_collection: nil, optional_items: nil, origin_context: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, permissions: nil, phone_number_collection: nil, redirect_on_completion: nil, return_url: nil, saved_payment_method_options: nil, setup_intent_data: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, success_url: nil, tax_id_collection: nil, ui_mode: nil, wallet_options: nil, checkout_items: nil) ⇒ SessionCreateParams
Returns a new instance of SessionCreateParams.
3166 3167 3168 3169 3170 3171 3172 3173 3174 3175 3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 3193 3194 3195 3196 3197 3198 3199 3200 3201 3202 3203 3204 3205 3206 3207 3208 3209 3210 3211 3212 3213 3214 3215 3216 3217 3218 3219 3220 3221 3222 3223 3224 3225 3226 3227 3228 3229 3230 3231 3232 3233 3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 3250 3251 3252 3253 3254 3255 3256 3257 3258 3259 3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3166 def initialize( adaptive_pricing: nil, after_expiration: nil, allow_promotion_codes: nil, approval_method: nil, automatic_surcharge: nil, automatic_tax: nil, billing_address_collection: nil, branding_settings: nil, cancel_url: nil, client_reference_id: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_payment_method_types: nil, custom_text: nil, customer: nil, customer_account: nil, customer_creation: nil, customer_email: nil, customer_update: nil, discounts: nil, excluded_payment_method_types: nil, expand: nil, expires_at: nil, integration_identifier: nil, invoice_creation: nil, items: nil, line_items: nil, locale: nil, managed_payments: nil, metadata: nil, mode: nil, name_collection: nil, optional_items: nil, origin_context: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, permissions: nil, phone_number_collection: nil, redirect_on_completion: nil, return_url: nil, saved_payment_method_options: nil, setup_intent_data: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, success_url: nil, tax_id_collection: nil, ui_mode: nil, wallet_options: nil, checkout_items: nil ) @adaptive_pricing = adaptive_pricing @after_expiration = after_expiration @allow_promotion_codes = allow_promotion_codes @approval_method = approval_method @automatic_surcharge = automatic_surcharge @automatic_tax = automatic_tax @billing_address_collection = billing_address_collection @branding_settings = branding_settings @cancel_url = cancel_url @client_reference_id = client_reference_id @consent_collection = @currency = currency @custom_fields = custom_fields @custom_payment_method_types = custom_payment_method_types @custom_text = custom_text @customer = customer @customer_account = customer_account @customer_creation = customer_creation @customer_email = customer_email @customer_update = customer_update @discounts = discounts @excluded_payment_method_types = excluded_payment_method_types @expand = @expires_at = expires_at @integration_identifier = integration_identifier @invoice_creation = invoice_creation @items = items @line_items = line_items @locale = locale @managed_payments = managed_payments @metadata = @mode = mode @name_collection = name_collection @optional_items = optional_items @origin_context = origin_context @payment_intent_data = payment_intent_data @payment_method_collection = payment_method_collection @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @permissions = @phone_number_collection = phone_number_collection @redirect_on_completion = redirect_on_completion @return_url = return_url @saved_payment_method_options = @setup_intent_data = setup_intent_data @shipping_address_collection = shipping_address_collection @shipping_options = @submit_type = submit_type @subscription_data = subscription_data @success_url = success_url @tax_id_collection = tax_id_collection @ui_mode = ui_mode @wallet_options = @checkout_items = checkout_items end |
Instance Attribute Details
#adaptive_pricing ⇒ Object
Settings for price localization with Adaptive Pricing.
2976 2977 2978 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2976 def adaptive_pricing @adaptive_pricing end |
#after_expiration ⇒ Object
Configure actions after a Checkout Session has expired. You can't set this parameter if ui_mode is elements.
2978 2979 2980 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2978 def after_expiration @after_expiration end |
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
2980 2981 2982 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2980 def allow_promotion_codes @allow_promotion_codes end |
#approval_method ⇒ Object
Determines whether the customer's attempt to pay must be manually approved.
Default is auto, when the customer's attempt to pay is approved automatically with no action required on your server.
When set to manual, you must approve the customer's attempt to pay by calling approve from your server.
2986 2987 2988 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2986 def approval_method @approval_method end |
#automatic_surcharge ⇒ Object
Settings for automatic surcharge calculation for this session.
2988 2989 2990 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2988 def automatic_surcharge @automatic_surcharge end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
2990 2991 2992 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2990 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object
Specify whether Checkout should collect the customer's billing address. Defaults to auto.
2992 2993 2994 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2992 def billing_address_collection @billing_address_collection end |
#branding_settings ⇒ Object
The branding settings for the Checkout Session. This parameter is not allowed if ui_mode is elements.
2994 2995 2996 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2994 def branding_settings @branding_settings end |
#cancel_url ⇒ Object
If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website. This parameter is not allowed if ui_mode is embedded_page or elements.
2996 2997 2998 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2996 def cancel_url @cancel_url end |
#checkout_items ⇒ Object
Attribute for param field checkout_items
3164 3165 3166 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3164 def checkout_items @checkout_items end |
#client_reference_id ⇒ Object
A unique string to reference the Checkout Session. This can be a customer ID, a cart ID, or similar, and can be used to reconcile the session with your internal systems.
3000 3001 3002 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3000 def client_reference_id @client_reference_id end |
#consent_collection ⇒ Object
Configure fields for the Checkout Session to gather active consent from customers.
3002 3003 3004 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3002 def @consent_collection end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency. Required in setup mode when payment_method_types is not set.
3004 3005 3006 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3004 def currency @currency end |
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can't set this parameter if ui_mode is custom.
3006 3007 3008 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3006 def custom_fields @custom_fields end |
#custom_payment_method_types ⇒ Object
A list of custom payment methods (e.g., cpmt_123) this Checkout Session can accept.
You can add custom payment methods to your account through the dashboard under Settings > Custom Payment Methods.
Read more about custom payment methods in checkout in our custom payment method types guide.
3012 3013 3014 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3012 def custom_payment_method_types @custom_payment_method_types end |
#custom_text ⇒ Object
Display additional text for your customers using custom text. You can't set this parameter if ui_mode is custom.
3014 3015 3016 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3014 def custom_text @custom_text end |
#customer ⇒ Object
ID of an existing Customer, if one exists. In payment mode, the customer’s most recently saved card
payment method will be used to prefill the email, name, card details, and billing address
on the Checkout page. In subscription mode, the customer’s default payment method
will be used if it’s a card, otherwise the most recently saved card will be used. A valid billing address, billing name and billing email are required on the payment method for Checkout to prefill the customer's card details.
If the Customer already has a valid email set, the email will be prefilled and not editable in Checkout.
If the Customer does not have a valid email, Checkout will set the email entered during the session on the Customer.
If blank for Checkout Sessions in subscription mode or with customer_creation set as always in payment mode, Checkout will create a new Customer object based on information provided during the payment flow.
You can set payment_intent_data.setup_future_usage to have Checkout automatically attach the payment method to the Customer you pass in for future reuse.
3026 3027 3028 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3026 def customer @customer end |
#customer_account ⇒ Object
ID of an existing Account, if one exists. Has the same behavior as customer.
3028 3029 3030 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3028 def customer_account @customer_account end |
#customer_creation ⇒ Object
Configure whether a Checkout Session creates a Customer during Session confirmation.
When a Customer is not created, you can still retrieve email, address, and other customer data entered in Checkout with customer_details.
Sessions that don't create Customers instead are grouped by guest customers in the Dashboard. Promotion codes limited to first time customers will return invalid for these Sessions.
Can only be set in payment and setup mode.
3038 3039 3040 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3038 def customer_creation @customer_creation end |
#customer_email ⇒ Object
If provided, this value will be used when the Customer object is created.
If not provided, customers will be asked to enter their email address.
Use this parameter to prefill customer data if you already have an email
on file. To access information about the customer once a session is
complete, use the customer field.
3044 3045 3046 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3044 def customer_email @customer_email end |
#customer_update ⇒ Object
Controls what fields on Customer can be updated by the Checkout Session. Can only be provided when customer is provided.
3046 3047 3048 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3046 def customer_update @customer_update end |
#discounts ⇒ Object
The coupon or promotion code to apply to this Session. Currently, only up to one may be specified.
3048 3049 3050 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3048 def discounts @discounts end |
#excluded_payment_method_types ⇒ Object
A list of the types of payment methods (e.g., card) that should be excluded from this Checkout Session. This should only be used when payment methods for this Checkout Session are managed through the Stripe Dashboard.
3050 3051 3052 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3050 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3052 3053 3054 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3052 def @expand end |
#expires_at ⇒ Object
The Epoch time in seconds at which the Checkout Session will expire. It can be anywhere from 30 minutes to 24 hours after Checkout Session creation. By default, this value is 24 hours from creation.
3054 3055 3056 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3054 def expires_at @expires_at end |
#integration_identifier ⇒ Object
The integration identifier for this Checkout Session. Multiple Checkout Sessions can have the same integration identifier.
3056 3057 3058 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3056 def integration_identifier @integration_identifier end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
3058 3059 3060 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3058 def invoice_creation @invoice_creation end |
#items ⇒ Object
A list of items the customer will purchase.
3060 3061 3062 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3060 def items @items end |
#line_items ⇒ Object
A list of items the customer is purchasing. Use this parameter to pass one-time or recurring Prices. The parameter is required for payment and subscription mode.
For payment mode, there is a maximum of 100 line items, however it is recommended to consolidate line items if there are more than a few dozen.
For subscription mode, there is a maximum of 20 line items with recurring Prices and 20 line items with one-time Prices. Line items with one-time Prices will be on the initial invoice only.
3066 3067 3068 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3066 def line_items @line_items end |
#locale ⇒ Object
The IETF language tag of the locale Checkout is displayed in. If blank or auto, the browser's locale is used.
3068 3069 3070 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3068 def locale @locale end |
#managed_payments ⇒ Object
Settings for Managed Payments for this Checkout Session and resulting PaymentIntents, Invoices, and Subscriptions.
3070 3071 3072 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3070 def managed_payments @managed_payments end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
3072 3073 3074 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3072 def @metadata end |
#mode ⇒ Object
The mode of the Checkout Session. Pass subscription if the Checkout Session includes at least one recurring item.
3074 3075 3076 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3074 def mode @mode end |
#name_collection ⇒ Object
Controls name collection settings for the session.
You can configure Checkout to collect your customers' business names, individual names, or both. Each name field can be either required or optional.
If a Customer is created or provided, the names can be saved to the Customer object as well.
3080 3081 3082 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3080 def name_collection @name_collection end |
#optional_items ⇒ Object
A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring Prices.
There is a maximum of 10 optional items allowed on a Checkout Session, and the existing limits on the number of line items allowed on a Checkout Session apply to the combined number of line items and optional items.
For payment mode, there is a maximum of 100 combined line items and optional items, however it is recommended to consolidate items if there are more than a few dozen.
For subscription mode, there is a maximum of 20 line items and optional items with recurring Prices and 20 line items and optional items with one-time Prices.
You can't set this parameter if ui_mode is custom.
3090 3091 3092 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3090 def optional_items @optional_items end |
#origin_context ⇒ Object
Where the user is coming from. This informs the optimizations that are applied to the session. You can't set this parameter if ui_mode is elements.
3092 3093 3094 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3092 def origin_context @origin_context end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in payment mode.
3094 3095 3096 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3094 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method. When set to if_required, Checkout will not collect a payment method when the total due for the session is 0.
This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in subscription mode. Defaults to always.
If you'd like information on how to collect a payment method outside of Checkout, read the guide on configuring subscriptions with a free trial.
3101 3102 3103 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3101 def payment_method_collection @payment_method_collection end |
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this Checkout session.
3103 3104 3105 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3103 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
This parameter allows you to set some attributes on the payment method created during a Checkout session.
3105 3106 3107 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3105 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration.
3107 3108 3109 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3107 def @payment_method_options end |
#payment_method_types ⇒ Object
A list of the types of payment methods (e.g., card) this Checkout Session can accept.
You can omit this attribute to manage your payment methods from the Stripe Dashboard. See Dynamic Payment Methods for more details.
Read more about the supported payment methods and their requirements in our payment method details guide.
If multiple payment methods are passed, Checkout will dynamically reorder them to prioritize the most relevant payment methods based on the customer's location and other characteristics.
3119 3120 3121 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3119 def payment_method_types @payment_method_types end |
#permissions ⇒ Object
This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object. Can only be set when creating embedded or custom sessions.
For specific permissions, please refer to their dedicated subsections, such as permissions.update_shipping_details.
3123 3124 3125 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3123 def @permissions end |
#phone_number_collection ⇒ Object
Controls phone number collection settings for the session.
We recommend that you review your privacy policy and check with your legal contacts before using this feature. Learn more about collecting phone numbers with Checkout.
3128 3129 3130 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3128 def phone_number_collection @phone_number_collection end |
#redirect_on_completion ⇒ Object
This parameter applies to ui_mode: embedded_page. Learn more about the redirect behavior of embedded sessions. Defaults to always.
3130 3131 3132 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3130 def redirect_on_completion @redirect_on_completion end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the
payment method's app or site. This parameter is required if ui_mode is embedded_page or elements
and redirect-based payment methods are enabled on the session.
3134 3135 3136 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3134 def return_url @return_url end |
#saved_payment_method_options ⇒ Object
Controls saved payment method settings for the session. Only available in payment and subscription mode.
3136 3137 3138 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3136 def @saved_payment_method_options end |
#setup_intent_data ⇒ Object
A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in setup mode.
3138 3139 3140 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3138 def setup_intent_data @setup_intent_data end |
#shipping_address_collection ⇒ Object
When set, provides configuration for Checkout to collect a shipping address from a customer.
3140 3141 3142 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3140 def shipping_address_collection @shipping_address_collection end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
3142 3143 3144 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3142 def @shipping_options end |
#submit_type ⇒ Object
Describes the type of transaction being performed by Checkout in order
to customize relevant text on the page, such as the submit button.
submit_type can only be specified on Checkout Sessions in
payment or subscription mode. If blank or auto, pay is used.
You can't set this parameter if ui_mode is elements.
3148 3149 3150 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3148 def submit_type @submit_type end |
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in subscription mode.
3150 3151 3152 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3150 def subscription_data @subscription_data end |
#success_url ⇒ Object
The URL to which Stripe should send customers when payment or setup
is complete.
This parameter is not allowed if ui_mode is embedded_page or elements. If you'd like to use
information from the successful Checkout Session on your page, read the
guide on customizing your success page.
3156 3157 3158 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3156 def success_url @success_url end |
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
3158 3159 3160 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3158 def tax_id_collection @tax_id_collection end |
#ui_mode ⇒ Object
The UI mode of the Session. Defaults to hosted_page.
3160 3161 3162 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3160 def ui_mode @ui_mode end |
#wallet_options ⇒ Object
Wallet-specific configuration.
3162 3163 3164 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3162 def @wallet_options end |
Class Method Details
.field_encodings ⇒ Object
3282 3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 3282 def self.field_encodings @field_encodings = { items: { kind: :array, element: { kind: :object, fields: { subscription: { kind: :object, fields: { items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string }, }, }, }, }, }, }, }, }, }, line_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |