Class: Stripe::Checkout::SessionCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: AdaptivePricing, AfterExpiration, AutomaticTax, BrandingSettings, ConsentCollection, CustomField, CustomText, CustomerUpdate, Discount, InvoiceCreation, LineItem, ManagedPayments, NameCollection, OptionalItem, PaymentIntentData, PaymentMethodData, PaymentMethodOptions, Permissions, PhoneNumberCollection, SavedPaymentMethodOptions, SetupIntentData, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, WalletOptions

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(adaptive_pricing: nil, after_expiration: nil, allow_promotion_codes: nil, automatic_tax: nil, billing_address_collection: nil, branding_settings: nil, cancel_url: nil, client_reference_id: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_text: nil, customer: nil, customer_account: nil, customer_creation: nil, customer_email: nil, customer_update: nil, discounts: nil, excluded_payment_method_types: nil, expand: nil, expires_at: nil, integration_identifier: nil, invoice_creation: nil, line_items: nil, locale: nil, managed_payments: nil, metadata: nil, mode: nil, name_collection: nil, optional_items: nil, origin_context: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, permissions: nil, phone_number_collection: nil, redirect_on_completion: nil, return_url: nil, saved_payment_method_options: nil, setup_intent_data: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, success_url: nil, tax_id_collection: nil, ui_mode: nil, wallet_options: nil) ⇒ SessionCreateParams

Returns a new instance of SessionCreateParams.



2758
2759
2760
2761
2762
2763
2764
2765
2766
2767
2768
2769
2770
2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
2809
2810
2811
2812
2813
2814
2815
2816
2817
2818
2819
2820
2821
2822
2823
2824
2825
2826
2827
2828
2829
2830
2831
2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
2859
2860
2861
2862
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2758

def initialize(
  adaptive_pricing: nil,
  after_expiration: nil,
  allow_promotion_codes: nil,
  automatic_tax: nil,
  billing_address_collection: nil,
  branding_settings: nil,
  cancel_url: nil,
  client_reference_id: nil,
  consent_collection: nil,
  currency: nil,
  custom_fields: nil,
  custom_text: nil,
  customer: nil,
  customer_account: nil,
  customer_creation: nil,
  customer_email: nil,
  customer_update: nil,
  discounts: nil,
  excluded_payment_method_types: nil,
  expand: nil,
  expires_at: nil,
  integration_identifier: nil,
  invoice_creation: nil,
  line_items: nil,
  locale: nil,
  managed_payments: nil,
  metadata: nil,
  mode: nil,
  name_collection: nil,
  optional_items: nil,
  origin_context: nil,
  payment_intent_data: nil,
  payment_method_collection: nil,
  payment_method_configuration: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  permissions: nil,
  phone_number_collection: nil,
  redirect_on_completion: nil,
  return_url: nil,
  saved_payment_method_options: nil,
  setup_intent_data: nil,
  shipping_address_collection: nil,
  shipping_options: nil,
  submit_type: nil,
  subscription_data: nil,
  success_url: nil,
  tax_id_collection: nil,
  ui_mode: nil,
  wallet_options: nil
)
  @adaptive_pricing = adaptive_pricing
  @after_expiration = after_expiration
  @allow_promotion_codes = allow_promotion_codes
  @automatic_tax = automatic_tax
  @billing_address_collection = billing_address_collection
  @branding_settings = branding_settings
  @cancel_url = cancel_url
  @client_reference_id = client_reference_id
  @consent_collection = consent_collection
  @currency = currency
  @custom_fields = custom_fields
  @custom_text = custom_text
  @customer = customer
  @customer_account = 
  @customer_creation = customer_creation
  @customer_email = customer_email
  @customer_update = customer_update
  @discounts = discounts
  @excluded_payment_method_types = excluded_payment_method_types
  @expand = expand
  @expires_at = expires_at
  @integration_identifier = integration_identifier
  @invoice_creation = invoice_creation
  @line_items = line_items
  @locale = locale
  @managed_payments = managed_payments
  @metadata = 
  @mode = mode
  @name_collection = name_collection
  @optional_items = optional_items
  @origin_context = origin_context
  @payment_intent_data = payment_intent_data
  @payment_method_collection = payment_method_collection
  @payment_method_configuration = payment_method_configuration
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @permissions = permissions
  @phone_number_collection = phone_number_collection
  @redirect_on_completion = redirect_on_completion
  @return_url = return_url
  @saved_payment_method_options = saved_payment_method_options
  @setup_intent_data = setup_intent_data
  @shipping_address_collection = shipping_address_collection
  @shipping_options = shipping_options
  @submit_type = submit_type
  @subscription_data = subscription_data
  @success_url = success_url
  @tax_id_collection = tax_id_collection
  @ui_mode = ui_mode
  @wallet_options = wallet_options
end

Instance Attribute Details

#adaptive_pricingObject

Settings for price localization with Adaptive Pricing.



2586
2587
2588
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2586

def adaptive_pricing
  @adaptive_pricing
end

#after_expirationObject

Configure actions after a Checkout Session has expired. You can't set this parameter if ui_mode is elements.



2588
2589
2590
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2588

def after_expiration
  @after_expiration
end

#allow_promotion_codesObject

Enables user redeemable promotion codes.



2590
2591
2592
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2590

def allow_promotion_codes
  @allow_promotion_codes
end

#automatic_taxObject

Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.



2592
2593
2594
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2592

def automatic_tax
  @automatic_tax
end

#billing_address_collectionObject

Specify whether Checkout should collect the customer's billing address. Defaults to auto.



2594
2595
2596
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2594

def billing_address_collection
  @billing_address_collection
end

#branding_settingsObject

The branding settings for the Checkout Session. This parameter is not allowed if ui_mode is elements.



2596
2597
2598
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2596

def branding_settings
  @branding_settings
end

#cancel_urlObject

If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website. This parameter is not allowed if ui_mode is embedded_page or elements.



2598
2599
2600
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2598

def cancel_url
  @cancel_url
end

#client_reference_idObject

A unique string to reference the Checkout Session. This can be a customer ID, a cart ID, or similar, and can be used to reconcile the session with your internal systems.



2602
2603
2604
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2602

def client_reference_id
  @client_reference_id
end

Configure fields for the Checkout Session to gather active consent from customers.



2604
2605
2606
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2604

def consent_collection
  @consent_collection
end

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency. Required in setup mode when payment_method_types is not set.



2606
2607
2608
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2606

def currency
  @currency
end

#custom_fieldsObject

Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can't set this parameter if ui_mode is custom.



2608
2609
2610
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2608

def custom_fields
  @custom_fields
end

#custom_textObject

Display additional text for your customers using custom text. You can't set this parameter if ui_mode is custom.



2610
2611
2612
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2610

def custom_text
  @custom_text
end

#customerObject

ID of an existing Customer, if one exists. In payment mode, the customer’s most recently saved card payment method will be used to prefill the email, name, card details, and billing address on the Checkout page. In subscription mode, the customer’s default payment method will be used if it’s a card, otherwise the most recently saved card will be used. A valid billing address, billing name and billing email are required on the payment method for Checkout to prefill the customer's card details.

If the Customer already has a valid email set, the email will be prefilled and not editable in Checkout. If the Customer does not have a valid email, Checkout will set the email entered during the session on the Customer.

If blank for Checkout Sessions in subscription mode or with customer_creation set as always in payment mode, Checkout will create a new Customer object based on information provided during the payment flow.

You can set payment_intent_data.setup_future_usage to have Checkout automatically attach the payment method to the Customer you pass in for future reuse.



2622
2623
2624
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2622

def customer
  @customer
end

#customer_accountObject

ID of an existing Account, if one exists. Has the same behavior as customer.



2624
2625
2626
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2624

def 
  @customer_account
end

#customer_creationObject

Configure whether a Checkout Session creates a Customer during Session confirmation.

When a Customer is not created, you can still retrieve email, address, and other customer data entered in Checkout with customer_details.

Sessions that don't create Customers instead are grouped by guest customers in the Dashboard. Promotion codes limited to first time customers will return invalid for these Sessions.

Can only be set in payment and setup mode.



2634
2635
2636
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2634

def customer_creation
  @customer_creation
end

#customer_emailObject

If provided, this value will be used when the Customer object is created. If not provided, customers will be asked to enter their email address. Use this parameter to prefill customer data if you already have an email on file. To access information about the customer once a session is complete, use the customer field.



2640
2641
2642
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2640

def customer_email
  @customer_email
end

#customer_updateObject

Controls what fields on Customer can be updated by the Checkout Session. Can only be provided when customer is provided.



2642
2643
2644
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2642

def customer_update
  @customer_update
end

#discountsObject

The coupon or promotion code to apply to this Session. Currently, only up to one may be specified.



2644
2645
2646
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2644

def discounts
  @discounts
end

#excluded_payment_method_typesObject

A list of the types of payment methods (e.g., card) that should be excluded from this Checkout Session. This should only be used when payment methods for this Checkout Session are managed through the Stripe Dashboard.



2646
2647
2648
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2646

def excluded_payment_method_types
  @excluded_payment_method_types
end

#expandObject

Specifies which fields in the response should be expanded.



2648
2649
2650
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2648

def expand
  @expand
end

#expires_atObject

The Epoch time in seconds at which the Checkout Session will expire. It can be anywhere from 30 minutes to 24 hours after Checkout Session creation. By default, this value is 24 hours from creation.



2650
2651
2652
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2650

def expires_at
  @expires_at
end

#integration_identifierObject

The integration identifier for this Checkout Session. Multiple Checkout Sessions can have the same integration identifier.



2652
2653
2654
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2652

def integration_identifier
  @integration_identifier
end

#invoice_creationObject

Generate a post-purchase Invoice for one-time payments.



2654
2655
2656
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2654

def invoice_creation
  @invoice_creation
end

#line_itemsObject

A list of items the customer is purchasing. Use this parameter to pass one-time or recurring Prices. The parameter is required for payment and subscription mode.

For payment mode, there is a maximum of 100 line items, however it is recommended to consolidate line items if there are more than a few dozen.

For subscription mode, there is a maximum of 20 line items with recurring Prices and 20 line items with one-time Prices. Line items with one-time Prices will be on the initial invoice only.



2660
2661
2662
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2660

def line_items
  @line_items
end

#localeObject

The IETF language tag of the locale Checkout is displayed in. If blank or auto, the browser's locale is used.



2662
2663
2664
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2662

def locale
  @locale
end

#managed_paymentsObject

Settings for Managed Payments for this Checkout Session and resulting PaymentIntents, Invoices, and Subscriptions.



2664
2665
2666
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2664

def managed_payments
  @managed_payments
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



2666
2667
2668
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2666

def 
  @metadata
end

#modeObject

The mode of the Checkout Session. Pass subscription if the Checkout Session includes at least one recurring item.



2668
2669
2670
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2668

def mode
  @mode
end

#name_collectionObject

Controls name collection settings for the session.

You can configure Checkout to collect your customers' business names, individual names, or both. Each name field can be either required or optional.

If a Customer is created or provided, the names can be saved to the Customer object as well.



2674
2675
2676
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2674

def name_collection
  @name_collection
end

#optional_itemsObject

A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring Prices.

There is a maximum of 10 optional items allowed on a Checkout Session, and the existing limits on the number of line items allowed on a Checkout Session apply to the combined number of line items and optional items.

For payment mode, there is a maximum of 100 combined line items and optional items, however it is recommended to consolidate items if there are more than a few dozen.

For subscription mode, there is a maximum of 20 line items and optional items with recurring Prices and 20 line items and optional items with one-time Prices.

You can't set this parameter if ui_mode is custom.



2684
2685
2686
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2684

def optional_items
  @optional_items
end

#origin_contextObject

Where the user is coming from. This informs the optimizations that are applied to the session. You can't set this parameter if ui_mode is elements.



2686
2687
2688
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2686

def origin_context
  @origin_context
end

#payment_intent_dataObject

A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in payment mode.



2688
2689
2690
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2688

def payment_intent_data
  @payment_intent_data
end

#payment_method_collectionObject

Specify whether Checkout should collect a payment method. When set to if_required, Checkout will not collect a payment method when the total due for the session is 0. This may occur if the Checkout Session includes a free trial or a discount.

Can only be set in subscription mode. Defaults to always.

If you'd like information on how to collect a payment method outside of Checkout, read the guide on configuring subscriptions with a free trial.



2695
2696
2697
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2695

def payment_method_collection
  @payment_method_collection
end

#payment_method_configurationObject

The ID of the payment method configuration to use with this Checkout session.



2697
2698
2699
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2697

def payment_method_configuration
  @payment_method_configuration
end

#payment_method_dataObject

This parameter allows you to set some attributes on the payment method created during a Checkout session.



2699
2700
2701
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2699

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration.



2701
2702
2703
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2701

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

A list of the types of payment methods (e.g., card) this Checkout Session can accept.

You can omit this attribute to manage your payment methods from the Stripe Dashboard. See Dynamic Payment Methods for more details.

Read more about the supported payment methods and their requirements in our payment method details guide.

If multiple payment methods are passed, Checkout will dynamically reorder them to prioritize the most relevant payment methods based on the customer's location and other characteristics.



2713
2714
2715
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2713

def payment_method_types
  @payment_method_types
end

#permissionsObject

This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object. Can only be set when creating embedded or custom sessions.

For specific permissions, please refer to their dedicated subsections, such as permissions.update_shipping_details.



2717
2718
2719
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2717

def permissions
  @permissions
end

#phone_number_collectionObject

Controls phone number collection settings for the session.

We recommend that you review your privacy policy and check with your legal contacts before using this feature. Learn more about collecting phone numbers with Checkout.



2722
2723
2724
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2722

def phone_number_collection
  @phone_number_collection
end

#redirect_on_completionObject

This parameter applies to ui_mode: embedded_page. Learn more about the redirect behavior of embedded sessions. Defaults to always.



2724
2725
2726
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2724

def redirect_on_completion
  @redirect_on_completion
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method's app or site. This parameter is required if ui_mode is embedded_page or elements and redirect-based payment methods are enabled on the session.



2728
2729
2730
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2728

def return_url
  @return_url
end

#saved_payment_method_optionsObject

Controls saved payment method settings for the session. Only available in payment and subscription mode.



2730
2731
2732
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2730

def saved_payment_method_options
  @saved_payment_method_options
end

#setup_intent_dataObject

A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in setup mode.



2732
2733
2734
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2732

def setup_intent_data
  @setup_intent_data
end

#shipping_address_collectionObject

When set, provides configuration for Checkout to collect a shipping address from a customer.



2734
2735
2736
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2734

def shipping_address_collection
  @shipping_address_collection
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



2736
2737
2738
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2736

def shipping_options
  @shipping_options
end

#submit_typeObject

Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button. submit_type can only be specified on Checkout Sessions in payment or subscription mode. If blank or auto, pay is used. You can't set this parameter if ui_mode is elements.



2742
2743
2744
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2742

def submit_type
  @submit_type
end

#subscription_dataObject

A subset of parameters to be passed to subscription creation for Checkout Sessions in subscription mode.



2744
2745
2746
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2744

def subscription_data
  @subscription_data
end

#success_urlObject

The URL to which Stripe should send customers when payment or setup is complete. This parameter is not allowed if ui_mode is embedded_page or elements. If you'd like to use information from the successful Checkout Session on your page, read the guide on customizing your success page.



2750
2751
2752
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2750

def success_url
  @success_url
end

#tax_id_collectionObject

Controls tax ID collection during checkout.



2752
2753
2754
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2752

def tax_id_collection
  @tax_id_collection
end

#ui_modeObject

The UI mode of the Session. Defaults to hosted_page.



2754
2755
2756
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2754

def ui_mode
  @ui_mode
end

#wallet_optionsObject

Wallet-specific configuration.



2756
2757
2758
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2756

def wallet_options
  @wallet_options
end

Class Method Details

.field_encodingsObject



2864
2865
2866
2867
2868
2869
2870
2871
2872
2873
2874
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2864

def self.field_encodings
  @field_encodings = {
    line_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
  }
end