Class: Stripe::Checkout::SessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: AdaptivePricing, AfterExpiration, AutomaticSurcharge, AutomaticTax, BrandingSettings, CheckoutItem, ConsentCollection, CustomField, CustomText, CustomerUpdate, Discount, InvoiceCreation, LineItem, ManagedPayments, NameCollection, OptionalItem, PaymentIntentData, PaymentMethodData, PaymentMethodOptions, Permissions, PhoneNumberCollection, SavedPaymentMethodOptions, SetupIntentData, ShippingAddressCollection, ShippingOption, SubscriptionData, TaxIdCollection, WalletOptions
Instance Attribute Summary collapse
-
#adaptive_pricing ⇒ Object
Settings for price localization with [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing).
-
#after_expiration ⇒ Object
Configure actions after a Checkout Session has expired.
-
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
-
#approval_method ⇒ Object
Determines whether the customer’s attempt to pay must be manually approved.
-
#automatic_surcharge ⇒ Object
Settings for automatic surcharge calculation for this session.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
-
#billing_address_collection ⇒ Object
Specify whether Checkout should collect the customer’s billing address.
-
#branding_settings ⇒ Object
The branding settings for the Checkout Session.
-
#cancel_url ⇒ Object
If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website.
-
#checkout_items ⇒ Object
Attribute for param field checkout_items.
-
#client_reference_id ⇒ Object
A unique string to reference the Checkout Session.
-
#consent_collection ⇒ Object
Configure fields for the Checkout Session to gather active consent from customers.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields.
-
#custom_payment_method_types ⇒ Object
A list of custom payment methods (e.g., ‘cpmt_123`) this Checkout Session can accept.
-
#custom_text ⇒ Object
Display additional text for your customers using custom text.
-
#customer ⇒ Object
ID of an existing Customer, if one exists.
-
#customer_account ⇒ Object
ID of an existing Account, if one exists.
-
#customer_creation ⇒ Object
Configure whether a Checkout Session creates a [Customer](docs.stripe.com/api/customers) during Session confirmation.
-
#customer_email ⇒ Object
If provided, this value will be used when the Customer object is created.
-
#customer_update ⇒ Object
Controls what fields on Customer can be updated by the Checkout Session.
-
#discounts ⇒ Object
The coupon or promotion code to apply to this Session.
-
#excluded_payment_method_types ⇒ Object
A list of the types of payment methods (e.g., ‘card`) that should be excluded from this Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
The Epoch time in seconds at which the Checkout Session will expire.
-
#integration_identifier ⇒ Object
The integration identifier for this Checkout Session.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#locale ⇒ Object
The IETF language tag of the locale Checkout is displayed in.
-
#managed_payments ⇒ Object
Settings for Managed Payments for this Checkout Session and resulting [PaymentIntents](/api/payment_intents/object), [Invoices](/api/invoices/object), and [Subscriptions](/api/subscriptions/object).
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#mode ⇒ Object
The mode of the Checkout Session.
-
#name_collection ⇒ Object
Controls name collection settings for the session.
-
#optional_items ⇒ Object
A list of optional items the customer can add to their order at checkout.
-
#origin_context ⇒ Object
Where the user is coming from.
-
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
-
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method.
-
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this Checkout session.
-
#payment_method_data ⇒ Object
This parameter allows you to set some attributes on the payment method created during a Checkout session.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration.
-
#payment_method_types ⇒ Object
A list of the types of payment methods (e.g., ‘card`) this Checkout Session can accept.
-
#permissions ⇒ Object
This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object.
-
#phone_number_collection ⇒ Object
Controls phone number collection settings for the session.
-
#redirect_on_completion ⇒ Object
This parameter applies to ‘ui_mode: embedded`.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#saved_payment_method_options ⇒ Object
Controls saved payment method settings for the session.
-
#setup_intent_data ⇒ Object
A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in ‘setup` mode.
-
#shipping_address_collection ⇒ Object
When set, provides configuration for Checkout to collect a shipping address from a customer.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
-
#submit_type ⇒ Object
Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button.
-
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
-
#success_url ⇒ Object
The URL to which Stripe should send customers when payment or setup is complete.
-
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
-
#ui_mode ⇒ Object
The UI mode of the Session.
-
#wallet_options ⇒ Object
Wallet-specific configuration.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(adaptive_pricing: nil, after_expiration: nil, allow_promotion_codes: nil, approval_method: nil, automatic_surcharge: nil, automatic_tax: nil, billing_address_collection: nil, branding_settings: nil, cancel_url: nil, client_reference_id: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_payment_method_types: nil, custom_text: nil, customer: nil, customer_account: nil, customer_creation: nil, customer_email: nil, customer_update: nil, discounts: nil, excluded_payment_method_types: nil, expand: nil, expires_at: nil, integration_identifier: nil, invoice_creation: nil, line_items: nil, locale: nil, managed_payments: nil, metadata: nil, mode: nil, name_collection: nil, optional_items: nil, origin_context: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, permissions: nil, phone_number_collection: nil, redirect_on_completion: nil, return_url: nil, saved_payment_method_options: nil, setup_intent_data: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, success_url: nil, tax_id_collection: nil, ui_mode: nil, wallet_options: nil, checkout_items: nil) ⇒ SessionCreateParams
Returns a new instance of SessionCreateParams.
2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 2872 2873 2874 2875 2876 2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2806 def initialize( adaptive_pricing: nil, after_expiration: nil, allow_promotion_codes: nil, approval_method: nil, automatic_surcharge: nil, automatic_tax: nil, billing_address_collection: nil, branding_settings: nil, cancel_url: nil, client_reference_id: nil, consent_collection: nil, currency: nil, custom_fields: nil, custom_payment_method_types: nil, custom_text: nil, customer: nil, customer_account: nil, customer_creation: nil, customer_email: nil, customer_update: nil, discounts: nil, excluded_payment_method_types: nil, expand: nil, expires_at: nil, integration_identifier: nil, invoice_creation: nil, line_items: nil, locale: nil, managed_payments: nil, metadata: nil, mode: nil, name_collection: nil, optional_items: nil, origin_context: nil, payment_intent_data: nil, payment_method_collection: nil, payment_method_configuration: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, permissions: nil, phone_number_collection: nil, redirect_on_completion: nil, return_url: nil, saved_payment_method_options: nil, setup_intent_data: nil, shipping_address_collection: nil, shipping_options: nil, submit_type: nil, subscription_data: nil, success_url: nil, tax_id_collection: nil, ui_mode: nil, wallet_options: nil, checkout_items: nil ) @adaptive_pricing = adaptive_pricing @after_expiration = after_expiration @allow_promotion_codes = allow_promotion_codes @approval_method = approval_method @automatic_surcharge = automatic_surcharge @automatic_tax = automatic_tax @billing_address_collection = billing_address_collection @branding_settings = branding_settings @cancel_url = cancel_url @client_reference_id = client_reference_id @consent_collection = @currency = currency @custom_fields = custom_fields @custom_payment_method_types = custom_payment_method_types @custom_text = custom_text @customer = customer @customer_account = customer_account @customer_creation = customer_creation @customer_email = customer_email @customer_update = customer_update @discounts = discounts @excluded_payment_method_types = excluded_payment_method_types @expand = @expires_at = expires_at @integration_identifier = integration_identifier @invoice_creation = invoice_creation @line_items = line_items @locale = locale @managed_payments = managed_payments @metadata = @mode = mode @name_collection = name_collection @optional_items = optional_items @origin_context = origin_context @payment_intent_data = payment_intent_data @payment_method_collection = payment_method_collection @payment_method_configuration = payment_method_configuration @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @permissions = @phone_number_collection = phone_number_collection @redirect_on_completion = redirect_on_completion @return_url = return_url @saved_payment_method_options = @setup_intent_data = setup_intent_data @shipping_address_collection = shipping_address_collection @shipping_options = @submit_type = submit_type @subscription_data = subscription_data @success_url = success_url @tax_id_collection = tax_id_collection @ui_mode = ui_mode @wallet_options = @checkout_items = checkout_items end |
Instance Attribute Details
#adaptive_pricing ⇒ Object
Settings for price localization with [Adaptive Pricing](docs.stripe.com/payments/checkout/adaptive-pricing).
2616 2617 2618 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2616 def adaptive_pricing @adaptive_pricing end |
#after_expiration ⇒ Object
Configure actions after a Checkout Session has expired. You can’t set this parameter if ‘ui_mode` is `custom`.
2618 2619 2620 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2618 def after_expiration @after_expiration end |
#allow_promotion_codes ⇒ Object
Enables user redeemable promotion codes.
2620 2621 2622 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2620 def allow_promotion_codes @allow_promotion_codes end |
#approval_method ⇒ Object
Determines whether the customer’s attempt to pay must be manually approved.
Default is ‘auto`, when the customer’s attempt to pay is approved automatically with no action required on your server.
When set to ‘manual`, you must approve the customer’s attempt to pay by calling [approve](api/checkout/sessions/approve) from your server.
2626 2627 2628 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2626 def approval_method @approval_method end |
#automatic_surcharge ⇒ Object
Settings for automatic surcharge calculation for this session.
2628 2629 2630 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2628 def automatic_surcharge @automatic_surcharge end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
2630 2631 2632 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2630 def automatic_tax @automatic_tax end |
#billing_address_collection ⇒ Object
Specify whether Checkout should collect the customer’s billing address. Defaults to ‘auto`.
2632 2633 2634 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2632 def billing_address_collection @billing_address_collection end |
#branding_settings ⇒ Object
The branding settings for the Checkout Session. This parameter is not allowed if ui_mode is ‘custom`.
2634 2635 2636 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2634 def branding_settings @branding_settings end |
#cancel_url ⇒ Object
If set, Checkout displays a back button and customers will be directed to this URL if they decide to cancel payment and return to your website. This parameter is not allowed if ui_mode is ‘embedded` or `custom`.
2636 2637 2638 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2636 def cancel_url @cancel_url end |
#checkout_items ⇒ Object
Attribute for param field checkout_items
2804 2805 2806 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2804 def checkout_items @checkout_items end |
#client_reference_id ⇒ Object
A unique string to reference the Checkout Session. This can be a customer ID, a cart ID, or similar, and can be used to reconcile the session with your internal systems.
2640 2641 2642 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2640 def client_reference_id @client_reference_id end |
#consent_collection ⇒ Object
Configure fields for the Checkout Session to gather active consent from customers.
2642 2643 2644 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2642 def @consent_collection end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Required in ‘setup` mode when `payment_method_types` is not set.
2644 2645 2646 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2644 def currency @currency end |
#custom_fields ⇒ Object
Collect additional information from your customer using custom fields. Up to 3 fields are supported. You can’t set this parameter if ‘ui_mode` is `custom`.
2646 2647 2648 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2646 def custom_fields @custom_fields end |
#custom_payment_method_types ⇒ Object
A list of custom payment methods (e.g., ‘cpmt_123`) this Checkout Session can accept.
You can add custom payment methods to your account through the dashboard under Settings > Custom Payment Methods.
Read more about custom payment methods in checkout in our [custom payment method types guide](docs.stripe.com/payments/payment-methods/custom-payment-methods).
2652 2653 2654 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2652 def custom_payment_method_types @custom_payment_method_types end |
#custom_text ⇒ Object
Display additional text for your customers using custom text. You can’t set this parameter if ‘ui_mode` is `custom`.
2654 2655 2656 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2654 def custom_text @custom_text end |
#customer ⇒ Object
ID of an existing Customer, if one exists. In ‘payment` mode, the customer’s most recently saved card payment method will be used to prefill the email, name, card details, and billing address on the Checkout page. In `subscription` mode, the customer’s [default payment method](docs.stripe.com/api/customers/update#update_customer-invoice_settings-default_payment_method) will be used if it’s a card, otherwise the most recently saved card will be used. A valid billing address, billing name and billing email are required on the payment method for Checkout to prefill the customer’s card details.
If the Customer already has a valid [email](docs.stripe.com/api/customers/object#customer_object-email) set, the email will be prefilled and not editable in Checkout. If the Customer does not have a valid ‘email`, Checkout will set the email entered during the session on the Customer.
If blank for Checkout Sessions in ‘subscription` mode or with `customer_creation` set as `always` in `payment` mode, Checkout will create a new Customer object based on information provided during the payment flow.
You can set [‘payment_intent_data.setup_future_usage`](docs.stripe.com/api/checkout/sessions/create#create_checkout_session-payment_intent_data-setup_future_usage) to have Checkout automatically attach the payment method to the Customer you pass in for future reuse.
2666 2667 2668 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2666 def customer @customer end |
#customer_account ⇒ Object
ID of an existing Account, if one exists. Has the same behavior as ‘customer`.
2668 2669 2670 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2668 def customer_account @customer_account end |
#customer_creation ⇒ Object
Configure whether a Checkout Session creates a [Customer](docs.stripe.com/api/customers) during Session confirmation.
When a Customer is not created, you can still retrieve email, address, and other customer data entered in Checkout with [customer_details](docs.stripe.com/api/checkout/sessions/object#checkout_session_object-customer_details).
Sessions that don’t create Customers instead are grouped by [guest customers](docs.stripe.com/payments/checkout/guest-customers) in the Dashboard. Promotion codes limited to first time customers will return invalid for these Sessions.
Can only be set in ‘payment` and `setup` mode.
2678 2679 2680 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2678 def customer_creation @customer_creation end |
#customer_email ⇒ Object
If provided, this value will be used when the Customer object is created. If not provided, customers will be asked to enter their email address. Use this parameter to prefill customer data if you already have an email on file. To access information about the customer once a session is complete, use the ‘customer` field.
2684 2685 2686 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2684 def customer_email @customer_email end |
#customer_update ⇒ Object
Controls what fields on Customer can be updated by the Checkout Session. Can only be provided when ‘customer` is provided.
2686 2687 2688 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2686 def customer_update @customer_update end |
#discounts ⇒ Object
The coupon or promotion code to apply to this Session. Currently, only up to one may be specified.
2688 2689 2690 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2688 def discounts @discounts end |
#excluded_payment_method_types ⇒ Object
A list of the types of payment methods (e.g., ‘card`) that should be excluded from this Checkout Session. This should only be used when payment methods for this Checkout Session are managed through the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).
2690 2691 2692 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2690 def excluded_payment_method_types @excluded_payment_method_types end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2692 2693 2694 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2692 def @expand end |
#expires_at ⇒ Object
The Epoch time in seconds at which the Checkout Session will expire. It can be anywhere from 30 minutes to 24 hours after Checkout Session creation. By default, this value is 24 hours from creation.
2694 2695 2696 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2694 def expires_at @expires_at end |
#integration_identifier ⇒ Object
The integration identifier for this Checkout Session. Multiple Checkout Sessions can have the same integration identifier.
2696 2697 2698 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2696 def integration_identifier @integration_identifier end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
2698 2699 2700 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2698 def invoice_creation @invoice_creation end |
#line_items ⇒ Object
A list of items the customer is purchasing. Use this parameter to pass one-time or recurring [Prices](docs.stripe.com/api/prices). The parameter is required for ‘payment` and `subscription` mode.
For ‘payment` mode, there is a maximum of 100 line items, however it is recommended to consolidate line items if there are more than a few dozen.
For ‘subscription` mode, there is a maximum of 20 line items with recurring Prices and 20 line items with one-time Prices. Line items with one-time Prices will be on the initial invoice only.
2704 2705 2706 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2704 def line_items @line_items end |
#locale ⇒ Object
The IETF language tag of the locale Checkout is displayed in. If blank or ‘auto`, the browser’s locale is used.
2706 2707 2708 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2706 def locale @locale end |
#managed_payments ⇒ Object
Settings for Managed Payments for this Checkout Session and resulting [PaymentIntents](/api/payment_intents/object), [Invoices](/api/invoices/object), and [Subscriptions](/api/subscriptions/object).
2708 2709 2710 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2708 def managed_payments @managed_payments end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2710 2711 2712 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2710 def @metadata end |
#mode ⇒ Object
The mode of the Checkout Session. Pass ‘subscription` if the Checkout Session includes at least one recurring item.
2712 2713 2714 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2712 def mode @mode end |
#name_collection ⇒ Object
Controls name collection settings for the session.
You can configure Checkout to collect your customers’ business names, individual names, or both. Each name field can be either required or optional.
If a [Customer](docs.stripe.com/api/customers) is created or provided, the names can be saved to the Customer object as well.
You can’t set this parameter if ‘ui_mode` is `custom`.
2720 2721 2722 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2720 def name_collection @name_collection end |
#optional_items ⇒ Object
A list of optional items the customer can add to their order at checkout. Use this parameter to pass one-time or recurring [Prices](docs.stripe.com/api/prices).
There is a maximum of 10 optional items allowed on a Checkout Session, and the existing limits on the number of line items allowed on a Checkout Session apply to the combined number of line items and optional items.
For ‘payment` mode, there is a maximum of 100 combined line items and optional items, however it is recommended to consolidate items if there are more than a few dozen.
For ‘subscription` mode, there is a maximum of 20 line items and optional items with recurring Prices and 20 line items and optional items with one-time Prices.
You can’t set this parameter if ‘ui_mode` is `custom`.
2730 2731 2732 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2730 def optional_items @optional_items end |
#origin_context ⇒ Object
Where the user is coming from. This informs the optimizations that are applied to the session. You can’t set this parameter if ‘ui_mode` is `custom`.
2732 2733 2734 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2732 def origin_context @origin_context end |
#payment_intent_data ⇒ Object
A subset of parameters to be passed to PaymentIntent creation for Checkout Sessions in ‘payment` mode.
2734 2735 2736 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2734 def payment_intent_data @payment_intent_data end |
#payment_method_collection ⇒ Object
Specify whether Checkout should collect a payment method. When set to ‘if_required`, Checkout will not collect a payment method when the total due for the session is 0. This may occur if the Checkout Session includes a free trial or a discount.
Can only be set in ‘subscription` mode. Defaults to `always`.
If you’d like information on how to collect a payment method outside of Checkout, read the guide on configuring [subscriptions with a free trial](docs.stripe.com/payments/checkout/free-trials).
2741 2742 2743 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2741 def payment_method_collection @payment_method_collection end |
#payment_method_configuration ⇒ Object
The ID of the payment method configuration to use with this Checkout session.
2743 2744 2745 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2743 def payment_method_configuration @payment_method_configuration end |
#payment_method_data ⇒ Object
This parameter allows you to set some attributes on the payment method created during a Checkout session.
2745 2746 2747 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2745 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration.
2747 2748 2749 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2747 def @payment_method_options end |
#payment_method_types ⇒ Object
A list of the types of payment methods (e.g., ‘card`) this Checkout Session can accept.
You can omit this attribute to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). See [Dynamic Payment Methods](docs.stripe.com/payments/payment-methods/integration-options#using-dynamic-payment-methods) for more details.
Read more about the supported payment methods and their requirements in our [payment method details guide](/docs/payments/checkout/payment-methods).
If multiple payment methods are passed, Checkout will dynamically reorder them to prioritize the most relevant payment methods based on the customer’s location and other characteristics.
2759 2760 2761 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2759 def payment_method_types @payment_method_types end |
#permissions ⇒ Object
This property is used to set up permissions for various actions (e.g., update) on the CheckoutSession object. Can only be set when creating ‘embedded` or `custom` sessions.
For specific permissions, please refer to their dedicated subsections, such as ‘permissions.update_shipping_details`.
2763 2764 2765 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2763 def @permissions end |
#phone_number_collection ⇒ Object
Controls phone number collection settings for the session.
We recommend that you review your privacy policy and check with your legal contacts before using this feature. Learn more about [collecting phone numbers with Checkout](docs.stripe.com/payments/checkout/phone-numbers).
2768 2769 2770 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2768 def phone_number_collection @phone_number_collection end |
#redirect_on_completion ⇒ Object
This parameter applies to ‘ui_mode: embedded`. Learn more about the [redirect behavior](docs.stripe.com/payments/checkout/custom-success-page?payment-ui=embedded-form) of embedded sessions. Defaults to `always`.
2770 2771 2772 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2770 def redirect_on_completion @redirect_on_completion end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. This parameter is required if ‘ui_mode` is `embedded` or `custom` and redirect-based payment methods are enabled on the session.
2774 2775 2776 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2774 def return_url @return_url end |
#saved_payment_method_options ⇒ Object
Controls saved payment method settings for the session. Only available in ‘payment` and `subscription` mode.
2776 2777 2778 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2776 def @saved_payment_method_options end |
#setup_intent_data ⇒ Object
A subset of parameters to be passed to SetupIntent creation for Checkout Sessions in ‘setup` mode.
2778 2779 2780 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2778 def setup_intent_data @setup_intent_data end |
#shipping_address_collection ⇒ Object
When set, provides configuration for Checkout to collect a shipping address from a customer.
2780 2781 2782 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2780 def shipping_address_collection @shipping_address_collection end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
2782 2783 2784 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2782 def @shipping_options end |
#submit_type ⇒ Object
Describes the type of transaction being performed by Checkout in order to customize relevant text on the page, such as the submit button.
`submit_type` can only be specified on Checkout Sessions in
‘payment` or `subscription` mode. If blank or `auto`, `pay` is used. You can’t set this parameter if ‘ui_mode` is `custom`.
2788 2789 2790 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2788 def submit_type @submit_type end |
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
2790 2791 2792 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2790 def subscription_data @subscription_data end |
#success_url ⇒ Object
The URL to which Stripe should send customers when payment or setup is complete. This parameter is not allowed if ui_mode is ‘embedded` or `custom`. If you’d like to use information from the successful Checkout Session on your page, read the guide on [customizing your success page](docs.stripe.com/payments/checkout/custom-success-page).
2796 2797 2798 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2796 def success_url @success_url end |
#tax_id_collection ⇒ Object
Controls tax ID collection during checkout.
2798 2799 2800 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2798 def tax_id_collection @tax_id_collection end |
#ui_mode ⇒ Object
The UI mode of the Session. Defaults to ‘hosted`.
2800 2801 2802 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2800 def ui_mode @ui_mode end |
#wallet_options ⇒ Object
Wallet-specific configuration.
2802 2803 2804 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2802 def @wallet_options end |
Class Method Details
.field_encodings ⇒ Object
2920 2921 2922 2923 2924 2925 2926 2927 2928 2929 2930 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2920 def self.field_encodings @field_encodings = { line_items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |