Class: Stripe::Checkout::SessionCreateParams::BrandingSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::BrandingSettings
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#background_color ⇒ Object
A hex color value starting with
#representing the background color for the Checkout Session. -
#border_style ⇒ Object
The border style for the Checkout Session.
-
#button_color ⇒ Object
A hex color value starting with
#representing the button color for the Checkout Session. -
#display_name ⇒ Object
A string to override the business name shown on the Checkout Session.
-
#font_family ⇒ Object
The font family for the Checkout Session corresponding to one of the supported font families.
-
#icon ⇒ Object
The icon for the Checkout Session.
-
#logo ⇒ Object
The logo for the Checkout Session.
Instance Method Summary collapse
-
#initialize(background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil) ⇒ BrandingSettings
constructor
A new instance of BrandingSettings.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil) ⇒ BrandingSettings
Returns a new instance of BrandingSettings.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 130 def initialize( background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil ) @background_color = background_color @border_style = border_style @button_color = @display_name = display_name @font_family = font_family @icon = icon @logo = logo end |
Instance Attribute Details
#background_color ⇒ Object
A hex color value starting with # representing the background color for the Checkout Session.
116 117 118 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 116 def background_color @background_color end |
#border_style ⇒ Object
The border style for the Checkout Session.
118 119 120 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 118 def border_style @border_style end |
#button_color ⇒ Object
A hex color value starting with # representing the button color for the Checkout Session.
120 121 122 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 120 def @button_color end |
#display_name ⇒ Object
A string to override the business name shown on the Checkout Session. This only shows at the top of the Checkout page, and your business name still appears in terms, receipts, and other places.
122 123 124 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 122 def display_name @display_name end |
#font_family ⇒ Object
The font family for the Checkout Session corresponding to one of the supported font families.
124 125 126 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 124 def font_family @font_family end |
#icon ⇒ Object
The icon for the Checkout Session. For best results, use a square image.
126 127 128 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 126 def icon @icon end |
#logo ⇒ Object
The logo for the Checkout Session.
128 129 130 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 128 def logo @logo end |