Class: Stripe::Checkout::SessionCreateParams::BrandingSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Icon, Logo

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil) ⇒ BrandingSettings

Returns a new instance of BrandingSettings.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/stripe/params/checkout/session_create_params.rb', line 123

def initialize(
  background_color: nil,
  border_style: nil,
  button_color: nil,
  display_name: nil,
  font_family: nil,
  icon: nil,
  logo: nil
)
  @background_color = background_color
  @border_style = border_style
  @button_color = button_color
  @display_name = display_name
  @font_family = font_family
  @icon = icon
  @logo = 
end

Instance Attribute Details

#background_colorObject

A hex color value starting with ‘#` representing the background color for the Checkout Session.



109
110
111
# File 'lib/stripe/params/checkout/session_create_params.rb', line 109

def background_color
  @background_color
end

#border_styleObject

The border style for the Checkout Session.



111
112
113
# File 'lib/stripe/params/checkout/session_create_params.rb', line 111

def border_style
  @border_style
end

#button_colorObject

A hex color value starting with ‘#` representing the button color for the Checkout Session.



113
114
115
# File 'lib/stripe/params/checkout/session_create_params.rb', line 113

def button_color
  @button_color
end

#display_nameObject

A string to override the business name shown on the Checkout Session. This only shows at the top of the Checkout page, and your business name still appears in terms, receipts, and other places.



115
116
117
# File 'lib/stripe/params/checkout/session_create_params.rb', line 115

def display_name
  @display_name
end

#font_familyObject

The font family for the Checkout Session corresponding to one of the [supported font families](docs.stripe.com/payments/checkout/customization/appearance?payment-ui=stripe-hosted#font-compatibility).



117
118
119
# File 'lib/stripe/params/checkout/session_create_params.rb', line 117

def font_family
  @font_family
end

#iconObject

The icon for the Checkout Session. For best results, use a square image.



119
120
121
# File 'lib/stripe/params/checkout/session_create_params.rb', line 119

def icon
  @icon
end

#logoObject

The logo for the Checkout Session.



121
122
123
# File 'lib/stripe/params/checkout/session_create_params.rb', line 121

def 
  @logo
end