Class: Stripe::Checkout::SessionCreateParams::BrandingSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::BrandingSettings
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#background_color ⇒ Object
A hex color value starting with ‘#` representing the background color for the Checkout Session.
-
#border_style ⇒ Object
The border style for the Checkout Session.
-
#button_color ⇒ Object
A hex color value starting with ‘#` representing the button color for the Checkout Session.
-
#display_name ⇒ Object
A string to override the business name shown on the Checkout Session.
-
#font_family ⇒ Object
The font family for the Checkout Session corresponding to one of the [supported font families](docs.stripe.com/payments/checkout/customization/appearance?payment-ui=stripe-hosted#font-compatibility).
-
#icon ⇒ Object
The icon for the Checkout Session.
-
#logo ⇒ Object
The logo for the Checkout Session.
Instance Method Summary collapse
-
#initialize(background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil) ⇒ BrandingSettings
constructor
A new instance of BrandingSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil) ⇒ BrandingSettings
Returns a new instance of BrandingSettings.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 108 def initialize( background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil ) @background_color = background_color @border_style = border_style @button_color = @display_name = display_name @font_family = font_family @icon = icon @logo = logo end |
Instance Attribute Details
#background_color ⇒ Object
A hex color value starting with ‘#` representing the background color for the Checkout Session.
94 95 96 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 94 def background_color @background_color end |
#border_style ⇒ Object
The border style for the Checkout Session.
96 97 98 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 96 def border_style @border_style end |
#button_color ⇒ Object
A hex color value starting with ‘#` representing the button color for the Checkout Session.
98 99 100 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 98 def @button_color end |
#display_name ⇒ Object
A string to override the business name shown on the Checkout Session.
100 101 102 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 100 def display_name @display_name end |
#font_family ⇒ Object
The font family for the Checkout Session corresponding to one of the [supported font families](docs.stripe.com/payments/checkout/customization/appearance?payment-ui=stripe-hosted#font-compatibility).
102 103 104 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 102 def font_family @font_family end |
#icon ⇒ Object
The icon for the Checkout Session. You cannot set both ‘logo` and `icon`.
104 105 106 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 104 def icon @icon end |
#logo ⇒ Object
The logo for the Checkout Session. You cannot set both ‘logo` and `icon`.
106 107 108 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 106 def logo @logo end |