Class: Stripe::Checkout::SessionCreateParams::BrandingSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Icon, Logo

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(background_color: nil, border_style: nil, button_color: nil, display_name: nil, font_family: nil, icon: nil, logo: nil) ⇒ BrandingSettings

Returns a new instance of BrandingSettings.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/stripe/params/checkout/session_create_params.rb', line 108

def initialize(
  background_color: nil,
  border_style: nil,
  button_color: nil,
  display_name: nil,
  font_family: nil,
  icon: nil,
  logo: nil
)
  @background_color = background_color
  @border_style = border_style
  @button_color = button_color
  @display_name = display_name
  @font_family = font_family
  @icon = icon
  @logo = 
end

Instance Attribute Details

#background_colorObject

A hex color value starting with ‘#` representing the background color for the Checkout Session.



94
95
96
# File 'lib/stripe/params/checkout/session_create_params.rb', line 94

def background_color
  @background_color
end

#border_styleObject

The border style for the Checkout Session.



96
97
98
# File 'lib/stripe/params/checkout/session_create_params.rb', line 96

def border_style
  @border_style
end

#button_colorObject

A hex color value starting with ‘#` representing the button color for the Checkout Session.



98
99
100
# File 'lib/stripe/params/checkout/session_create_params.rb', line 98

def button_color
  @button_color
end

#display_nameObject

A string to override the business name shown on the Checkout Session.



100
101
102
# File 'lib/stripe/params/checkout/session_create_params.rb', line 100

def display_name
  @display_name
end

#font_familyObject

The font family for the Checkout Session corresponding to one of the [supported font families](docs.stripe.com/payments/checkout/customization/appearance?payment-ui=stripe-hosted#font-compatibility).



102
103
104
# File 'lib/stripe/params/checkout/session_create_params.rb', line 102

def font_family
  @font_family
end

#iconObject

The icon for the Checkout Session. You cannot set both ‘logo` and `icon`.



104
105
106
# File 'lib/stripe/params/checkout/session_create_params.rb', line 104

def icon
  @icon
end

#logoObject

The logo for the Checkout Session. You cannot set both ‘logo` and `icon`.



106
107
108
# File 'lib/stripe/params/checkout/session_create_params.rb', line 106

def 
  @logo
end