Class: Stripe::Checkout::SessionCreateParams::ConsentCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::ConsentCollection
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: PaymentMethodReuseAgreement
Instance Attribute Summary collapse
-
#payment_method_reuse_agreement ⇒ Object
Determines the display of payment method reuse agreement text in the UI.
-
#promotions ⇒ Object
If set to ‘auto`, enables the collection of customer consent for promotional communications.
-
#terms_of_service ⇒ Object
If set to ‘required`, it requires customers to check a terms of service checkbox before being able to pay.
Instance Method Summary collapse
-
#initialize(payment_method_reuse_agreement: nil, promotions: nil, terms_of_service: nil) ⇒ ConsentCollection
constructor
A new instance of ConsentCollection.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payment_method_reuse_agreement: nil, promotions: nil, terms_of_service: nil) ⇒ ConsentCollection
Returns a new instance of ConsentCollection.
237 238 239 240 241 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 237 def initialize(payment_method_reuse_agreement: nil, promotions: nil, terms_of_service: nil) @payment_method_reuse_agreement = payment_method_reuse_agreement @promotions = promotions @terms_of_service = terms_of_service end |
Instance Attribute Details
#payment_method_reuse_agreement ⇒ Object
Determines the display of payment method reuse agreement text in the UI. If set to ‘hidden`, it will hide legal text related to the reuse of a payment method.
228 229 230 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 228 def payment_method_reuse_agreement @payment_method_reuse_agreement end |
#promotions ⇒ Object
If set to ‘auto`, enables the collection of customer consent for promotional communications. The Checkout Session will determine whether to display an option to opt into promotional communication from the merchant depending on the customer’s locale. Only available to US merchants and US customers.
232 233 234 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 232 def promotions @promotions end |
#terms_of_service ⇒ Object
If set to ‘required`, it requires customers to check a terms of service checkbox before being able to pay. There must be a valid terms of service URL set in your [Dashboard settings](dashboard.stripe.com/settings/public).
235 236 237 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 235 def terms_of_service @terms_of_service end |