Class: Stripe::Checkout::SessionCreateParams::CustomField::Dropdown::Option

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(label: nil, value: nil) ⇒ Option

Returns a new instance of Option.



237
238
239
240
# File 'lib/stripe/params/checkout/session_create_params.rb', line 237

def initialize(label: nil, value: nil)
  @label = label
  @value = value
end

Instance Attribute Details

#labelObject

The label for the option, displayed to the customer. Up to 100 characters.



233
234
235
# File 'lib/stripe/params/checkout/session_create_params.rb', line 233

def label
  @label
end

#valueObject

The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.



235
236
237
# File 'lib/stripe/params/checkout/session_create_params.rb', line 235

def value
  @value
end