Class: Stripe::Checkout::SessionCreateParams::CustomText

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText

Returns a new instance of CustomText.



373
374
375
376
377
378
379
380
381
382
383
# File 'lib/stripe/params/checkout/session_create_params.rb', line 373

def initialize(
  after_submit: nil,
  shipping_address: nil,
  submit: nil,
  terms_of_service_acceptance: nil
)
  @after_submit = after_submit
  @shipping_address = shipping_address
  @submit = submit
  @terms_of_service_acceptance = terms_of_service_acceptance
end

Instance Attribute Details

#after_submitObject

Custom text that should be displayed after the payment confirmation button.



365
366
367
# File 'lib/stripe/params/checkout/session_create_params.rb', line 365

def after_submit
  @after_submit
end

#shipping_addressObject

Custom text that should be displayed alongside shipping address collection.



367
368
369
# File 'lib/stripe/params/checkout/session_create_params.rb', line 367

def shipping_address
  @shipping_address
end

#submitObject

Custom text that should be displayed alongside the payment confirmation button.



369
370
371
# File 'lib/stripe/params/checkout/session_create_params.rb', line 369

def submit
  @submit
end

#terms_of_service_acceptanceObject

Custom text that should be displayed in place of the default terms of service agreement text.



371
372
373
# File 'lib/stripe/params/checkout/session_create_params.rb', line 371

def terms_of_service_acceptance
  @terms_of_service_acceptance
end