Class: Stripe::Checkout::SessionCreateParams::CustomerUpdate

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, name: nil, shipping: nil) ⇒ CustomerUpdate

Returns a new instance of CustomerUpdate.



396
397
398
399
400
# File 'lib/stripe/params/checkout/session_create_params.rb', line 396

def initialize(address: nil, name: nil, shipping: nil)
  @address = address
  @name = name
  @shipping = shipping
end

Instance Attribute Details

#addressObject

Describes whether Checkout saves the billing address onto ‘customer.address`. To always collect a full billing address, use `billing_address_collection`. Defaults to `never`.



389
390
391
# File 'lib/stripe/params/checkout/session_create_params.rb', line 389

def address
  @address
end

#nameObject

Describes whether Checkout saves the name onto ‘customer.name`. Defaults to `never`.



391
392
393
# File 'lib/stripe/params/checkout/session_create_params.rb', line 391

def name
  @name
end

#shippingObject

Describes whether Checkout saves shipping information onto ‘customer.shipping`. To collect shipping information, use `shipping_address_collection`. Defaults to `never`.



394
395
396
# File 'lib/stripe/params/checkout/session_create_params.rb', line 394

def shipping
  @shipping
end