Class: Stripe::Checkout::SessionCreateParams::Discount::CouponData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::Discount::CouponData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).
-
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).
-
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts.
-
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).
Instance Method Summary collapse
-
#initialize(amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CouponData
constructor
A new instance of CouponData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CouponData
Returns a new instance of CouponData.
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 418 def initialize( amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil ) @amount_off = amount_off @currency = currency @duration = duration @metadata = @name = name @percent_off = percent_off end |
Instance Attribute Details
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).
406 407 408 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 406 def amount_off @amount_off end |
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).
408 409 410 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 408 def currency @currency end |
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription. Defaults to ‘once`.
410 411 412 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 410 def duration @duration end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
412 413 414 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 412 def @metadata end |
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the ‘id` is shown if `name` is not set.
414 415 416 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 414 def name @name end |
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).
416 417 418 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 416 def percent_off @percent_off end |