Class: Stripe::Checkout::SessionCreateParams::InvoiceCreation::InvoiceData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::InvoiceCreation::InvoiceData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: CustomField, Issuer, RenderingOptions
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
-
#custom_fields ⇒ Object
Default custom fields to be displayed on invoices for this customer.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
-
#issuer ⇒ Object
The connected account that issues the invoice.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData
constructor
A new instance of InvoiceData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil) ⇒ InvoiceData
Returns a new instance of InvoiceData.
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 500 def initialize( account_tax_ids: nil, custom_fields: nil, description: nil, footer: nil, issuer: nil, metadata: nil, rendering_options: nil ) @account_tax_ids = account_tax_ids @custom_fields = custom_fields @description = description @footer = @issuer = issuer @metadata = @rendering_options = end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
486 487 488 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 486 def account_tax_ids @account_tax_ids end |
#custom_fields ⇒ Object
Default custom fields to be displayed on invoices for this customer.
488 489 490 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 488 def custom_fields @custom_fields end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
490 491 492 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 490 def description @description end |
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
492 493 494 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 492 def @footer end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
494 495 496 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 494 def issuer @issuer end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
496 497 498 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 496 def @metadata end |
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
498 499 500 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 498 def @rendering_options end |