Class: Stripe::Checkout::SessionCreateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: AdjustableQuantity, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(adjustable_quantity: nil, dynamic_tax_rates: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/stripe/params/checkout/session_create_params.rb', line 580

def initialize(
  adjustable_quantity: nil,
  dynamic_tax_rates: nil,
  metadata: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @dynamic_tax_rates = dynamic_tax_rates
  @metadata = 
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



566
567
568
# File 'lib/stripe/params/checkout/session_create_params.rb', line 566

def adjustable_quantity
  @adjustable_quantity
end

#dynamic_tax_ratesObject

The [tax rates](docs.stripe.com/api/tax_rates) that will be applied to this line item depending on the customer’s billing/shipping address. We currently support the following countries: US, GB, AU, and all countries in the EU. You can’t set this parameter if ‘ui_mode` is `custom`.



568
569
570
# File 'lib/stripe/params/checkout/session_create_params.rb', line 568

def dynamic_tax_rates
  @dynamic_tax_rates
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



570
571
572
# File 'lib/stripe/params/checkout/session_create_params.rb', line 570

def 
  @metadata
end

#priceObject

The ID of the [Price](docs.stripe.com/api/prices) or [Plan](docs.stripe.com/api/plans) object. One of ‘price` or `price_data` is required.



572
573
574
# File 'lib/stripe/params/checkout/session_create_params.rb', line 572

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



574
575
576
# File 'lib/stripe/params/checkout/session_create_params.rb', line 574

def price_data
  @price_data
end

#quantityObject

The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.



576
577
578
# File 'lib/stripe/params/checkout/session_create_params.rb', line 576

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](docs.stripe.com/api/tax_rates) which apply to this line item.



578
579
580
# File 'lib/stripe/params/checkout/session_create_params.rb', line 578

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



598
599
600
601
602
# File 'lib/stripe/params/checkout/session_create_params.rb', line 598

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end