Class: Stripe::Checkout::SessionCreateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: AdjustableQuantity, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, dynamic_tax_rates: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/stripe/params/checkout/session_create_params.rb', line 561

def initialize(
  adjustable_quantity: nil,
  dynamic_tax_rates: nil,
  metadata: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @dynamic_tax_rates = dynamic_tax_rates
  @metadata = 
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



547
548
549
# File 'lib/stripe/params/checkout/session_create_params.rb', line 547

def adjustable_quantity
  @adjustable_quantity
end

#dynamic_tax_ratesObject

The [tax rates](docs.stripe.com/api/tax_rates) that will be applied to this line item depending on the customer’s billing/shipping address. We currently support the following countries: US, GB, AU, and all countries in the EU. You can’t set this parameter if ‘ui_mode` is `custom`.



549
550
551
# File 'lib/stripe/params/checkout/session_create_params.rb', line 549

def dynamic_tax_rates
  @dynamic_tax_rates
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



551
552
553
# File 'lib/stripe/params/checkout/session_create_params.rb', line 551

def 
  @metadata
end

#priceObject

The ID of the [Price](docs.stripe.com/api/prices) or [Plan](docs.stripe.com/api/plans) object. One of ‘price` or `price_data` is required.



553
554
555
# File 'lib/stripe/params/checkout/session_create_params.rb', line 553

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



555
556
557
# File 'lib/stripe/params/checkout/session_create_params.rb', line 555

def price_data
  @price_data
end

#quantityObject

The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.



557
558
559
# File 'lib/stripe/params/checkout/session_create_params.rb', line 557

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](docs.stripe.com/api/tax_rates) which apply to this line item.



559
560
561
# File 'lib/stripe/params/checkout/session_create_params.rb', line 559

def tax_rates
  @tax_rates
end