Class: Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: TaxDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
The product's description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
The product's name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A tax code ID.
-
#tax_details ⇒ Object
Tax details for this product, including the tax code and an optional performance location.
-
#unit_label ⇒ Object
A label that represents units of this product.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil) ⇒ ProductData
Returns a new instance of ProductData.
871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 871 def initialize( description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil ) @description = description @images = images @metadata = @name = name @tax_code = tax_code @tax_details = tax_details @unit_label = unit_label end |
Instance Attribute Details
#description ⇒ Object
The product's description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
857 858 859 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 857 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
859 860 861 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 859 def images @images end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
861 862 863 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 861 def @metadata end |
#name ⇒ Object
The product's name, meant to be displayable to the customer.
863 864 865 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 863 def name @name end |
#tax_code ⇒ Object
A tax code ID.
865 866 867 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 865 def tax_code @tax_code end |
#tax_details ⇒ Object
Tax details for this product, including the tax code and an optional performance location.
867 868 869 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 867 def tax_details @tax_details end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers' receipts, invoices, Checkout, and the customer portal.
869 870 871 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 869 def unit_label @unit_label end |