Class: Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil) ⇒ ProductData

Returns a new instance of ProductData.



588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
# File 'lib/stripe/params/checkout/session_create_params.rb', line 588

def initialize(
  description: nil,
  images: nil,
  metadata: nil,
  name: nil,
  tax_code: nil,
  tax_details: nil,
  unit_label: nil
)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
  @tax_details = tax_details
  @unit_label = unit_label
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



574
575
576
# File 'lib/stripe/params/checkout/session_create_params.rb', line 574

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



576
577
578
# File 'lib/stripe/params/checkout/session_create_params.rb', line 576

def images
  @images
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



578
579
580
# File 'lib/stripe/params/checkout/session_create_params.rb', line 578

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



580
581
582
# File 'lib/stripe/params/checkout/session_create_params.rb', line 580

def name
  @name
end

#tax_codeObject



582
583
584
# File 'lib/stripe/params/checkout/session_create_params.rb', line 582

def tax_code
  @tax_code
end

#tax_detailsObject

Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.



584
585
586
# File 'lib/stripe/params/checkout/session_create_params.rb', line 584

def tax_details
  @tax_details
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



586
587
588
# File 'lib/stripe/params/checkout/session_create_params.rb', line 586

def unit_label
  @unit_label
end