Class: Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, tax_details: nil, unit_label: nil) ⇒ ProductData

Returns a new instance of ProductData.



573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
# File 'lib/stripe/params/checkout/session_create_params.rb', line 573

def initialize(
  description: nil,
  images: nil,
  metadata: nil,
  name: nil,
  tax_code: nil,
  tax_details: nil,
  unit_label: nil
)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
  @tax_details = tax_details
  @unit_label = unit_label
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



559
560
561
# File 'lib/stripe/params/checkout/session_create_params.rb', line 559

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



561
562
563
# File 'lib/stripe/params/checkout/session_create_params.rb', line 561

def images
  @images
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



563
564
565
# File 'lib/stripe/params/checkout/session_create_params.rb', line 563

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



565
566
567
# File 'lib/stripe/params/checkout/session_create_params.rb', line 565

def name
  @name
end

#tax_codeObject



567
568
569
# File 'lib/stripe/params/checkout/session_create_params.rb', line 567

def tax_code
  @tax_code
end

#tax_detailsObject

Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.



569
570
571
# File 'lib/stripe/params/checkout/session_create_params.rb', line 569

def tax_details
  @tax_details
end

#unit_labelObject

A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.



571
572
573
# File 'lib/stripe/params/checkout/session_create_params.rb', line 571

def unit_label
  @unit_label
end