Class: Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
-
#unit_label ⇒ Object
A label that represents units of this product.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil) ⇒ ProductData
Returns a new instance of ProductData.
485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 485 def initialize( description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil ) @description = description @images = images @metadata = @name = name @tax_code = tax_code @unit_label = unit_label end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
473 474 475 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 473 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
475 476 477 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 475 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
477 478 479 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 477 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
479 480 481 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 479 def name @name end |
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
481 482 483 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 481 def tax_code @tax_code end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.
483 484 485 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 483 def unit_label @unit_label end |