Class: Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: TaxDetails
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
-
#tax_details ⇒ Object
Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.
-
#unit_label ⇒ Object
A label that represents units of this product.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil, tax_details: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil, tax_details: nil) ⇒ ProductData
Returns a new instance of ProductData.
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 573 def initialize( description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil, tax_details: nil ) @description = description @images = images @metadata = @name = name @tax_code = tax_code @unit_label = unit_label @tax_details = tax_details end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
559 560 561 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 559 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
561 562 563 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 561 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
563 564 565 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 563 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
565 566 567 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 565 def name @name end |
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
567 568 569 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 567 def tax_code @tax_code end |
#tax_details ⇒ Object
Tax details for this product, including the [tax code](/tax/tax-codes) and an optional performance location.
571 572 573 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 571 def tax_details @tax_details end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.
569 570 571 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 569 def unit_label @unit_label end |