Class: Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::LineItem::PriceData::ProductData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#unit_label ⇒ Object
A label that represents units of this product.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil) ⇒ ProductData
Returns a new instance of ProductData.
560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 560 def initialize( description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil ) @description = description @images = images @metadata = @name = name @tax_code = tax_code @unit_label = unit_label end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
548 549 550 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 548 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
550 551 552 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 550 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
552 553 554 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 552 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
554 555 556 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 554 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
556 557 558 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 556 def tax_code @tax_code end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.
558 559 560 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 558 def unit_label @unit_label end |