Class: Stripe::Checkout::SessionCreateParams::NameCollection::Business
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::NameCollection::Business
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable business name collection on the Checkout Session.
-
#optional ⇒ Object
Whether the customer is required to provide a business name before completing the Checkout Session.
Instance Method Summary collapse
-
#initialize(enabled: nil, optional: nil) ⇒ Business
constructor
A new instance of Business.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, optional: nil) ⇒ Business
Returns a new instance of Business.
621 622 623 624 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 621 def initialize(enabled: nil, optional: nil) @enabled = enabled @optional = optional end |
Instance Attribute Details
#enabled ⇒ Object
Enable business name collection on the Checkout Session. Defaults to ‘false`.
617 618 619 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 617 def enabled @enabled end |
#optional ⇒ Object
Whether the customer is required to provide a business name before completing the Checkout Session. Defaults to ‘false`.
619 620 621 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 619 def optional @optional end |