Class: Stripe::Checkout::SessionCreateParams::OptionalItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(adjustable_quantity: nil, price: nil, quantity: nil) ⇒ OptionalItem

Returns a new instance of OptionalItem.



614
615
616
617
618
# File 'lib/stripe/params/checkout/session_create_params.rb', line 614

def initialize(adjustable_quantity: nil, price: nil, quantity: nil)
  @adjustable_quantity = adjustable_quantity
  @price = price
  @quantity = quantity
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for the customer to adjust the quantity of the line item created when a customer chooses to add this optional item to their order.



608
609
610
# File 'lib/stripe/params/checkout/session_create_params.rb', line 608

def adjustable_quantity
  @adjustable_quantity
end

#priceObject

The ID of the [Price](docs.stripe.com/api/prices) or [Plan](docs.stripe.com/api/plans) object.



610
611
612
# File 'lib/stripe/params/checkout/session_create_params.rb', line 610

def price
  @price
end

#quantityObject

The initial quantity of the line item created when a customer chooses to add this optional item to their order.



612
613
614
# File 'lib/stripe/params/checkout/session_create_params.rb', line 612

def quantity
  @quantity
end