Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Shipping, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application_fee_amount: nil, capture_method: nil, description: nil, metadata: nil, on_behalf_of: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentData

Returns a new instance of PaymentIntentData.



789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
# File 'lib/stripe/params/checkout/session_create_params.rb', line 789

def initialize(
  application_fee_amount: nil,
  capture_method: nil,
  description: nil,
  metadata: nil,
  on_behalf_of: nil,
  receipt_email: nil,
  setup_future_usage: nil,
  shipping: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil,
  transfer_group: nil
)
  @application_fee_amount = application_fee_amount
  @capture_method = capture_method
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
  @receipt_email = receipt_email
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
  @transfer_group = transfer_group
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.



741
742
743
# File 'lib/stripe/params/checkout/session_create_params.rb', line 741

def application_fee_amount
  @application_fee_amount
end

#capture_methodObject

Controls when the funds will be captured from the customer's account.



743
744
745
# File 'lib/stripe/params/checkout/session_create_params.rb', line 743

def capture_method
  @capture_method
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



745
746
747
# File 'lib/stripe/params/checkout/session_create_params.rb', line 745

def description
  @description
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



747
748
749
# File 'lib/stripe/params/checkout/session_create_params.rb', line 747

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account ID for which these funds are intended. For details, see the PaymentIntents use case for connected accounts.



751
752
753
# File 'lib/stripe/params/checkout/session_create_params.rb', line 751

def on_behalf_of
  @on_behalf_of
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your email settings.



753
754
755
# File 'lib/stripe/params/checkout/session_create_params.rb', line 753

def receipt_email
  @receipt_email
end

#setup_future_usageObject

Indicates that you intend to make future payments with the payment method collected by this Checkout Session.

When setting this to on_session, Checkout will show a notice to the customer that their payment details will be saved.

When setting this to off_session, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.

If a Customer has been provided or Checkout creates a new Customer, Checkout will attach the payment method to the Customer.

If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session's PaymentIntent.

When processing card payments, Checkout also uses setup_future_usage to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.



774
775
776
# File 'lib/stripe/params/checkout/session_create_params.rb', line 774

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this payment.



776
777
778
# File 'lib/stripe/params/checkout/session_create_params.rb', line 776

def shipping
  @shipping
end

#statement_descriptorObject

Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.



780
781
782
# File 'lib/stripe/params/checkout/session_create_params.rb', line 780

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.



782
783
784
# File 'lib/stripe/params/checkout/session_create_params.rb', line 782

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters used to automatically create a Transfer when the payment succeeds. For more information, see the PaymentIntents use case for connected accounts.



785
786
787
# File 'lib/stripe/params/checkout/session_create_params.rb', line 785

def transfer_data
  @transfer_data
end

#transfer_groupObject

A string that identifies the resulting payment as part of a group. See the PaymentIntents use case for connected accounts for details.



787
788
789
# File 'lib/stripe/params/checkout/session_create_params.rb', line 787

def transfer_group
  @transfer_group
end