Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



1090
1091
1092
1093
1094
1095
1096
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1090

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



1080
1081
1082
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1080

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



1082
1083
1084
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1082

def carrier
  @carrier
end

#nameObject

Recipient name.



1084
1085
1086
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1084

def name
  @name
end

#phoneObject

Recipient phone (including extension).



1086
1087
1088
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1086

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



1088
1089
1090
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1088

def tracking_number
  @tracking_number
end