Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
811 812 813 814 815 816 817 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 811 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
801 802 803 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 801 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
803 804 805 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 803 def carrier @carrier end |
#name ⇒ Object
Recipient name.
805 806 807 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 805 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
807 808 809 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 807 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
809 810 811 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 809 def tracking_number @tracking_number end |