Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



721
722
723
724
725
726
727
# File 'lib/stripe/params/checkout/session_create_params.rb', line 721

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



711
712
713
# File 'lib/stripe/params/checkout/session_create_params.rb', line 711

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



713
714
715
# File 'lib/stripe/params/checkout/session_create_params.rb', line 713

def carrier
  @carrier
end

#nameObject

Recipient name.



715
716
717
# File 'lib/stripe/params/checkout/session_create_params.rb', line 715

def name
  @name
end

#phoneObject

Recipient phone (including extension).



717
718
719
# File 'lib/stripe/params/checkout/session_create_params.rb', line 717

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



719
720
721
# File 'lib/stripe/params/checkout/session_create_params.rb', line 719

def tracking_number
  @tracking_number
end