Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



664
665
666
667
668
669
670
# File 'lib/stripe/params/checkout/session_create_params.rb', line 664

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



654
655
656
# File 'lib/stripe/params/checkout/session_create_params.rb', line 654

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



656
657
658
# File 'lib/stripe/params/checkout/session_create_params.rb', line 656

def carrier
  @carrier
end

#nameObject

Recipient name.



658
659
660
# File 'lib/stripe/params/checkout/session_create_params.rb', line 658

def name
  @name
end

#phoneObject

Recipient phone (including extension).



660
661
662
# File 'lib/stripe/params/checkout/session_create_params.rb', line 660

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



662
663
664
# File 'lib/stripe/params/checkout/session_create_params.rb', line 662

def tracking_number
  @tracking_number
end