Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



786
787
788
789
790
791
792
# File 'lib/stripe/params/checkout/session_create_params.rb', line 786

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



776
777
778
# File 'lib/stripe/params/checkout/session_create_params.rb', line 776

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



778
779
780
# File 'lib/stripe/params/checkout/session_create_params.rb', line 778

def carrier
  @carrier
end

#nameObject

Recipient name.



780
781
782
# File 'lib/stripe/params/checkout/session_create_params.rb', line 780

def name
  @name
end

#phoneObject

Recipient phone (including extension).



782
783
784
# File 'lib/stripe/params/checkout/session_create_params.rb', line 782

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



784
785
786
# File 'lib/stripe/params/checkout/session_create_params.rb', line 784

def tracking_number
  @tracking_number
end