Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



777
778
779
780
781
782
783
# File 'lib/stripe/params/checkout/session_create_params.rb', line 777

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



767
768
769
# File 'lib/stripe/params/checkout/session_create_params.rb', line 767

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



769
770
771
# File 'lib/stripe/params/checkout/session_create_params.rb', line 769

def carrier
  @carrier
end

#nameObject

Recipient name.



771
772
773
# File 'lib/stripe/params/checkout/session_create_params.rb', line 771

def name
  @name
end

#phoneObject

Recipient phone (including extension).



773
774
775
# File 'lib/stripe/params/checkout/session_create_params.rb', line 773

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



775
776
777
# File 'lib/stripe/params/checkout/session_create_params.rb', line 775

def tracking_number
  @tracking_number
end