Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentIntentData::Shipping
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
687 688 689 690 691 692 693 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 687 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
677 678 679 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 677 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
679 680 681 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 679 def carrier @carrier end |
#name ⇒ Object
Recipient name.
681 682 683 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 681 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
683 684 685 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 683 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
685 686 687 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 685 def tracking_number @tracking_number end |