Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentIntentData::TransferData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
-
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
735 736 737 738 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 735 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
728 729 730 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 728 def amount @amount end |
#destination ⇒ Object
If specified, successful charges will be attributed to the destination
account for tax reporting, and the funds from charges will be transferred
to the destination account. The ID of the resulting transfer will be
returned on the successful charge's transfer field.
733 734 735 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 733 def destination @destination end |