Class: Stripe::Checkout::SessionCreateParams::PaymentIntentData::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentIntentData::TransferData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
-
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
814 815 816 817 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 814 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
807 808 809 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 807 def amount @amount end |
#destination ⇒ Object
If specified, successful charges will be attributed to the destination account for tax reporting, and the funds from charges will be transferred to the destination account. The ID of the resulting transfer will be returned on the successful charge’s ‘transfer` field.
812 813 814 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 812 def destination @destination end |