Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, Boleto, Card, Cashapp, CustomerBalance, DemoPay, Eps, Fpx, Giropay, Grabpay, Ideal, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, UsBankAccount, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
-
#affirm ⇒ Object
contains details about the Affirm payment method options.
-
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
-
#alipay ⇒ Object
contains details about the Alipay payment method options.
-
#alma ⇒ Object
contains details about the Alma payment method options.
-
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
-
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
-
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
-
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
-
#billie ⇒ Object
contains details about the Billie payment method options.
-
#boleto ⇒ Object
contains details about the Boleto payment method options.
-
#card ⇒ Object
contains details about the Card payment method options.
-
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
-
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
-
#demo_pay ⇒ Object
contains details about the DemoPay payment method options.
-
#eps ⇒ Object
contains details about the EPS payment method options.
-
#fpx ⇒ Object
contains details about the FPX payment method options.
-
#giropay ⇒ Object
contains details about the Giropay payment method options.
-
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
-
#ideal ⇒ Object
contains details about the Ideal payment method options.
-
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
-
#klarna ⇒ Object
contains details about the Klarna payment method options.
-
#konbini ⇒ Object
contains details about the Konbini payment method options.
-
#kr_card ⇒ Object
contains details about the Korean card payment method options.
-
#link ⇒ Object
contains details about the Link payment method options.
-
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
-
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
-
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
-
#oxxo ⇒ Object
contains details about the OXXO payment method options.
-
#p24 ⇒ Object
contains details about the P24 payment method options.
-
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
-
#payco ⇒ Object
contains details about the PAYCO payment method options.
-
#paynow ⇒ Object
contains details about the PayNow payment method options.
-
#paypal ⇒ Object
contains details about the PayPal payment method options.
-
#pix ⇒ Object
contains details about the Pix payment method options.
-
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
-
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
-
#satispay ⇒ Object
contains details about the Satispay payment method options.
-
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
-
#sofort ⇒ Object
contains details about the Sofort payment method options.
-
#swish ⇒ Object
contains details about the Swish payment method options.
-
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
-
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, demo_pay: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1756 def initialize( acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, boleto: nil, card: nil, cashapp: nil, customer_balance: nil, demo_pay: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, pix: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, us_bank_account: nil, wechat_pay: nil ) @acss_debit = acss_debit @affirm = affirm @afterpay_clearpay = afterpay_clearpay @alipay = alipay @alma = alma @amazon_pay = amazon_pay @au_becs_debit = au_becs_debit @bacs_debit = bacs_debit @bancontact = bancontact @billie = billie @boleto = boleto @card = card @cashapp = cashapp @customer_balance = customer_balance @demo_pay = demo_pay @eps = eps @fpx = fpx @giropay = giropay @grabpay = grabpay @ideal = ideal @kakao_pay = kakao_pay @klarna = klarna @konbini = konbini @kr_card = kr_card @link = link @mobilepay = mobilepay @multibanco = multibanco @naver_pay = naver_pay @oxxo = oxxo @p24 = p24 @pay_by_bank = pay_by_bank @payco = payco @paynow = paynow @paypal = paypal @pix = pix @revolut_pay = revolut_pay @samsung_pay = samsung_pay @satispay = satispay @sepa_debit = sepa_debit @sofort = sofort @swish = swish @us_bank_account = us_bank_account @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
contains details about the ACSS Debit payment method options.
1670 1671 1672 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1670 def acss_debit @acss_debit end |
#affirm ⇒ Object
contains details about the Affirm payment method options.
1672 1673 1674 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1672 def affirm @affirm end |
#afterpay_clearpay ⇒ Object
contains details about the Afterpay Clearpay payment method options.
1674 1675 1676 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1674 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
contains details about the Alipay payment method options.
1676 1677 1678 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1676 def alipay @alipay end |
#alma ⇒ Object
contains details about the Alma payment method options.
1678 1679 1680 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1678 def alma @alma end |
#amazon_pay ⇒ Object
contains details about the AmazonPay payment method options.
1680 1681 1682 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1680 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object
contains details about the AU Becs Debit payment method options.
1682 1683 1684 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1682 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object
contains details about the Bacs Debit payment method options.
1684 1685 1686 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1684 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object
contains details about the Bancontact payment method options.
1686 1687 1688 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1686 def bancontact @bancontact end |
#billie ⇒ Object
contains details about the Billie payment method options.
1688 1689 1690 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1688 def billie @billie end |
#boleto ⇒ Object
contains details about the Boleto payment method options.
1690 1691 1692 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1690 def boleto @boleto end |
#card ⇒ Object
contains details about the Card payment method options.
1692 1693 1694 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1692 def card @card end |
#cashapp ⇒ Object
contains details about the Cashapp Pay payment method options.
1694 1695 1696 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1694 def cashapp @cashapp end |
#customer_balance ⇒ Object
contains details about the Customer Balance payment method options.
1696 1697 1698 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1696 def customer_balance @customer_balance end |
#demo_pay ⇒ Object
contains details about the DemoPay payment method options.
1698 1699 1700 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1698 def demo_pay @demo_pay end |
#eps ⇒ Object
contains details about the EPS payment method options.
1700 1701 1702 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1700 def eps @eps end |
#fpx ⇒ Object
contains details about the FPX payment method options.
1702 1703 1704 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1702 def fpx @fpx end |
#giropay ⇒ Object
contains details about the Giropay payment method options.
1704 1705 1706 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1704 def giropay @giropay end |
#grabpay ⇒ Object
contains details about the Grabpay payment method options.
1706 1707 1708 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1706 def grabpay @grabpay end |
#ideal ⇒ Object
contains details about the Ideal payment method options.
1708 1709 1710 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1708 def ideal @ideal end |
#kakao_pay ⇒ Object
contains details about the Kakao Pay payment method options.
1710 1711 1712 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1710 def kakao_pay @kakao_pay end |
#klarna ⇒ Object
contains details about the Klarna payment method options.
1712 1713 1714 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1712 def klarna @klarna end |
#konbini ⇒ Object
contains details about the Konbini payment method options.
1714 1715 1716 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1714 def konbini @konbini end |
#kr_card ⇒ Object
contains details about the Korean card payment method options.
1716 1717 1718 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1716 def kr_card @kr_card end |
#link ⇒ Object
contains details about the Link payment method options.
1718 1719 1720 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1718 def link @link end |
#mobilepay ⇒ Object
contains details about the Mobilepay payment method options.
1720 1721 1722 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1720 def mobilepay @mobilepay end |
#multibanco ⇒ Object
contains details about the Multibanco payment method options.
1722 1723 1724 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1722 def multibanco @multibanco end |
#naver_pay ⇒ Object
contains details about the Naver Pay payment method options.
1724 1725 1726 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1724 def naver_pay @naver_pay end |
#oxxo ⇒ Object
contains details about the OXXO payment method options.
1726 1727 1728 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1726 def oxxo @oxxo end |
#p24 ⇒ Object
contains details about the P24 payment method options.
1728 1729 1730 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1728 def p24 @p24 end |
#pay_by_bank ⇒ Object
contains details about the Pay By Bank payment method options.
1730 1731 1732 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1730 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object
contains details about the PAYCO payment method options.
1732 1733 1734 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1732 def payco @payco end |
#paynow ⇒ Object
contains details about the PayNow payment method options.
1734 1735 1736 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1734 def paynow @paynow end |
#paypal ⇒ Object
contains details about the PayPal payment method options.
1736 1737 1738 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1736 def paypal @paypal end |
#pix ⇒ Object
contains details about the Pix payment method options.
1738 1739 1740 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1738 def pix @pix end |
#revolut_pay ⇒ Object
contains details about the RevolutPay payment method options.
1740 1741 1742 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1740 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object
contains details about the Samsung Pay payment method options.
1742 1743 1744 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1742 def samsung_pay @samsung_pay end |
#satispay ⇒ Object
contains details about the Satispay payment method options.
1744 1745 1746 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1744 def satispay @satispay end |
#sepa_debit ⇒ Object
contains details about the Sepa Debit payment method options.
1746 1747 1748 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1746 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
contains details about the Sofort payment method options.
1748 1749 1750 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1748 def sofort @sofort end |
#swish ⇒ Object
contains details about the Swish payment method options.
1750 1751 1752 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1750 def swish @swish end |
#us_bank_account ⇒ Object
contains details about the Us Bank Account payment method options.
1752 1753 1754 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1752 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object
contains details about the WeChat Pay payment method options.
1754 1755 1756 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1754 def wechat_pay @wechat_pay end |