Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::AcssDebit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(currency: nil, mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ AcssDebit

Returns a new instance of AcssDebit.



874
875
876
877
878
879
880
881
882
883
884
885
886
# File 'lib/stripe/params/checkout/session_create_params.rb', line 874

def initialize(
  currency: nil,
  mandate_options: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @currency = currency
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency. This is only accepted for Checkout Sessions in setup mode.



858
859
860
# File 'lib/stripe/params/checkout/session_create_params.rb', line 858

def currency
  @currency
end

#mandate_optionsObject

Additional fields for Mandate creation



860
861
862
# File 'lib/stripe/params/checkout/session_create_params.rb', line 860

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



868
869
870
# File 'lib/stripe/params/checkout/session_create_params.rb', line 868

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



870
871
872
# File 'lib/stripe/params/checkout/session_create_params.rb', line 870

def target_date
  @target_date
end

#verification_methodObject

Verification method for the intent



872
873
874
# File 'lib/stripe/params/checkout/session_create_params.rb', line 872

def verification_method
  @verification_method
end