Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::AcssDebit::MandateOptions
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step.
-
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically.
-
#interval_description ⇒ Object
Description of the mandate interval.
-
#payment_schedule ⇒ Object
Payment schedule for the mandate.
-
#transaction_type ⇒ Object
Transaction type of the mandate.
Instance Method Summary collapse
-
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
937 938 939 940 941 942 943 944 945 946 947 948 949 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 937 def initialize( custom_mandate_url: nil, default_for: nil, interval_description: nil, payment_schedule: nil, transaction_type: nil ) @custom_mandate_url = custom_mandate_url @default_for = default_for @interval_description = interval_description @payment_schedule = payment_schedule @transaction_type = transaction_type end |
Instance Attribute Details
#custom_mandate_url ⇒ Object
A URL for custom mandate text to render during confirmation step. The URL will be rendered with additional GET parameters ‘payment_intent` and `payment_intent_client_secret` when confirming a Payment Intent, or `setup_intent` and `setup_intent_client_secret` when confirming a Setup Intent.
927 928 929 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 927 def custom_mandate_url @custom_mandate_url end |
#default_for ⇒ Object
List of Stripe products where this mandate can be selected automatically. Only usable in ‘setup` mode.
929 930 931 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 929 def default_for @default_for end |
#interval_description ⇒ Object
Description of the mandate interval. Only required if ‘payment_schedule’ parameter is ‘interval’ or ‘combined’.
931 932 933 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 931 def interval_description @interval_description end |
#payment_schedule ⇒ Object
Payment schedule for the mandate.
933 934 935 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 933 def payment_schedule @payment_schedule end |
#transaction_type ⇒ Object
Transaction type of the mandate.
935 936 937 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 935 def transaction_type @transaction_type end |