Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::BacsDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::BacsDebit
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil) ⇒ BacsDebit
constructor
A new instance of BacsDebit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil) ⇒ BacsDebit
Returns a new instance of BacsDebit.
1007 1008 1009 1010 1011 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1007 def initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil) @mandate_options = @setup_future_usage = setup_future_usage @target_date = target_date end |
Instance Attribute Details
#mandate_options ⇒ Object
Additional fields for Mandate creation
995 996 997 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 995 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1003 1004 1005 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1003 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
1005 1006 1007 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1005 def target_date @target_date end |