Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Blik::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expires_after: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1043
1044
1045
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1043

def initialize(expires_after: nil)
  @expires_after = expires_after
end

Instance Attribute Details

#expires_afterObject

Date when the mandate expires and no further payments will be charged. If not provided, the mandate will be set to be indefinite.



1041
1042
1043
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1041

def expires_after
  @expires_after
end