Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Blik::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Blik::MandateOptions
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#expires_after ⇒ Object
Date when the mandate expires and no further payments will be charged.
Instance Method Summary collapse
-
#initialize(expires_after: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expires_after: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1047 1048 1049 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1047 def initialize(expires_after: nil) @expires_after = expires_after end |
Instance Attribute Details
#expires_after ⇒ Object
Date when the mandate expires and no further payments will be charged. If not provided, the mandate will be set to be indefinite.
1045 1046 1047 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1045 def expires_after @expires_after end |