Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: Installments, Restrictions
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#installments ⇒ Object
Installment options for card payments.
-
#request_decremental_authorization ⇒ Object
Request ability to capture beyond the standard authorization validity window for this CheckoutSession.
-
#request_extended_authorization ⇒ Object
Request ability to capture beyond the standard authorization validity window for this CheckoutSession.
-
#request_incremental_authorization ⇒ Object
Request ability to increment the authorization for this CheckoutSession.
-
#request_multicapture ⇒ Object
Request ability to make multiple captures for this CheckoutSession.
-
#request_overcapture ⇒ Object
Request ability to overcapture for this CheckoutSession.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements.
-
#restrictions ⇒ Object
Restrictions to apply to the card payment method.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, installments: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil) ⇒ Card
Returns a new instance of Card.
1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1509 def initialize( capture_method: nil, installments: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil ) @capture_method = capture_method @installments = installments @request_decremental_authorization = @request_extended_authorization = @request_incremental_authorization = @request_multicapture = request_multicapture @request_overcapture = request_overcapture @request_three_d_secure = request_three_d_secure @restrictions = restrictions @setup_future_usage = setup_future_usage @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
1479 1480 1481 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1479 def capture_method @capture_method end |
#installments ⇒ Object
Installment options for card payments
1481 1482 1483 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1481 def installments @installments end |
#request_decremental_authorization ⇒ Object
Request ability to capture beyond the standard authorization validity window for this CheckoutSession.
1483 1484 1485 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1483 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object
Request ability to capture beyond the standard authorization validity window for this CheckoutSession.
1485 1486 1487 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1485 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object
Request ability to increment the authorization for this CheckoutSession.
1487 1488 1489 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1487 def @request_incremental_authorization end |
#request_multicapture ⇒ Object
Request ability to make multiple captures for this CheckoutSession.
1489 1490 1491 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1489 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object
Request ability to overcapture for this CheckoutSession.
1491 1492 1493 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1491 def request_overcapture @request_overcapture end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and other requirements. However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on manually requesting 3D Secure for more information on how this configuration interacts with Radar and our SCA Engine.
1493 1494 1495 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1493 def request_three_d_secure @request_three_d_secure end |
#restrictions ⇒ Object
Restrictions to apply to the card payment method. For example, you can block specific card brands. You can't set this parameter if ui_mode is custom.
1495 1496 1497 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1495 def restrictions @restrictions end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1503 1504 1505 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1503 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
1505 1506 1507 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1505 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
1507 1508 1509 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1507 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |