Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Installments, Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, installments: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil) ⇒ Card

Returns a new instance of Card.



1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1210

def initialize(
  capture_method: nil,
  installments: nil,
  request_decremental_authorization: nil,
  request_extended_authorization: nil,
  request_incremental_authorization: nil,
  request_multicapture: nil,
  request_overcapture: nil,
  request_three_d_secure: nil,
  restrictions: nil,
  setup_future_usage: nil,
  statement_descriptor_suffix_kana: nil,
  statement_descriptor_suffix_kanji: nil
)
  @capture_method = capture_method
  @installments = installments
  @request_decremental_authorization = request_decremental_authorization
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization = request_incremental_authorization
  @request_multicapture = request_multicapture
  @request_overcapture = request_overcapture
  @request_three_d_secure = request_three_d_secure
  @restrictions = restrictions
  @setup_future_usage = setup_future_usage
  @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



1180
1181
1182
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1180

def capture_method
  @capture_method
end

#installmentsObject

Installment options for card payments



1182
1183
1184
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1182

def installments
  @installments
end

#request_decremental_authorizationObject

Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.



1184
1185
1186
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1184

def request_decremental_authorization
  @request_decremental_authorization
end

#request_extended_authorizationObject

Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.



1186
1187
1188
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1186

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject

Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.



1188
1189
1190
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1188

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject

Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.



1190
1191
1192
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1190

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject

Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.



1192
1193
1194
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1192

def request_overcapture
  @request_overcapture
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



1194
1195
1196
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1194

def request_three_d_secure
  @request_three_d_secure
end

#restrictionsObject

Restrictions to apply to the card payment method. For example, you can block specific card brands. You can’t set this parameter if ‘ui_mode` is `custom`.



1196
1197
1198
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1196

def restrictions
  @restrictions
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



1204
1205
1206
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1204

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



1206
1207
1208
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1206

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



1208
1209
1210
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1208

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end