Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: Installments, Restrictions
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#installments ⇒ Object
Installment options for card payments.
-
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
-
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.
-
#request_multicapture ⇒ Object
Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.
-
#request_overcapture ⇒ Object
Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication).
-
#restrictions ⇒ Object
Restrictions to apply to the card payment method.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements.
Instance Method Summary collapse
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, installments: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil) ⇒ Card
Returns a new instance of Card.
1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1051 def initialize( capture_method: nil, installments: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil ) @capture_method = capture_method @installments = installments = = @request_multicapture = request_multicapture @request_overcapture = request_overcapture @request_three_d_secure = request_three_d_secure @restrictions = restrictions @setup_future_usage = setup_future_usage @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
1023 1024 1025 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1023 def capture_method @capture_method end |
#installments ⇒ Object
Installment options for card payments
1025 1026 1027 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1025 def installments @installments end |
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.
1027 1028 1029 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1027 def end |
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.
1029 1030 1031 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1029 def end |
#request_multicapture ⇒ Object
Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.
1031 1032 1033 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1031 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object
Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.
1033 1034 1035 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1033 def request_overcapture @request_overcapture end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](docs.stripe.com/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to automatic. Read our guide on [manually requesting 3D Secure](docs.stripe.com/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
1035 1036 1037 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1035 def request_three_d_secure @request_three_d_secure end |
#restrictions ⇒ Object
Restrictions to apply to the card payment method. For example, you can block specific card brands. You can’t set this parameter if ui_mode is custom.
1037 1038 1039 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1037 def restrictions @restrictions end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1045 1046 1047 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1045 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
1047 1048 1049 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1047 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
1049 1050 1051 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1049 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |