Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card::Restrictions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card::Restrictions
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#brands_blocked ⇒ Object
Specify the card brands to block in the Checkout Session.
Instance Method Summary collapse
-
#initialize(brands_blocked: nil) ⇒ Restrictions
constructor
A new instance of Restrictions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(brands_blocked: nil) ⇒ Restrictions
Returns a new instance of Restrictions.
1095 1096 1097 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1095 def initialize(brands_blocked: nil) @brands_blocked = brands_blocked end |
Instance Attribute Details
#brands_blocked ⇒ Object
Specify the card brands to block in the Checkout Session. If a customer enters or selects a card belonging to a blocked brand, they can’t complete the Session.
1093 1094 1095 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1093 def brands_blocked @brands_blocked end |