Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Card::Restrictions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(brands_blocked: nil) ⇒ Restrictions

Returns a new instance of Restrictions.



1116
1117
1118
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1116

def initialize(brands_blocked: nil)
  @brands_blocked = brands_blocked
end

Instance Attribute Details

#brands_blockedObject

Specify the card brands to block in the Checkout Session. If a customer enters or selects a card belonging to a blocked brand, they can’t complete the Session.



1114
1115
1116
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1114

def brands_blocked
  @brands_blocked
end