Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: Subscription
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#subscriptions ⇒ Object
Subscription details if the Checkout Session sets up a future subscription.
Instance Method Summary collapse
-
#initialize(capture_method: nil, setup_future_usage: nil, subscriptions: nil) ⇒ Klarna
constructor
A new instance of Klarna.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, setup_future_usage: nil, subscriptions: nil) ⇒ Klarna
Returns a new instance of Klarna.
1320 1321 1322 1323 1324 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1320 def initialize(capture_method: nil, setup_future_usage: nil, subscriptions: nil) @capture_method = capture_method @setup_future_usage = setup_future_usage @subscriptions = subscriptions end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
1308 1309 1310 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1308 def capture_method @capture_method end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1316 1317 1318 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1316 def setup_future_usage @setup_future_usage end |
#subscriptions ⇒ Object
Subscription details if the Checkout Session sets up a future subscription.
1318 1319 1320 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1318 def subscriptions @subscriptions end |