Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1369 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
1359 1360 1361 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1359 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
1361 1362 1363 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1361 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
1363 1364 1365 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1363 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
1365 1366 1367 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1365 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
1367 1368 1369 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1367 def reference @reference end |