Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1433
1434
1435
1436
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1433

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1429
1430
1431
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1429

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1431
1432
1433
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1431

def date
  @date
end