Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1383
1384
1385
1386
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1383

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1379
1380
1381
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1379

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1381
1382
1383
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1381

def date
  @date
end