Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1247
1248
1249
1250
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1247

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1243
1244
1245
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1243

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1245
1246
1247
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1245

def date
  @date
end