Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1284
1285
1286
1287
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1284

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1280
1281
1282
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1280

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1282
1283
1284
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1282

def date
  @date
end