Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Konbini
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Konbini
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#expires_after_days ⇒ Object
The number of calendar days (between 1 and 60) after which Konbini payment instructions will expire.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(expires_after_days: nil, setup_future_usage: nil) ⇒ Konbini
constructor
A new instance of Konbini.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expires_after_days: nil, setup_future_usage: nil) ⇒ Konbini
Returns a new instance of Konbini.
1794 1795 1796 1797 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1794 def initialize(expires_after_days: nil, setup_future_usage: nil) @expires_after_days = expires_after_days @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#expires_after_days ⇒ Object
The number of calendar days (between 1 and 60) after which Konbini payment instructions will expire. For example, if a PaymentIntent is confirmed with Konbini and expires_after_days set to 2 on Monday JST, the instructions will expire on Wednesday 23:59:59 JST. Defaults to 3 days.
1784 1785 1786 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1784 def expires_after_days @expires_after_days end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1792 1793 1794 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1792 def setup_future_usage @setup_future_usage end |