Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
2032
2033
2034
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2018

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when amount_type is fixed.



2004
2005
2006
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2004

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.



2006
2007
2008
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2006

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



2008
2009
2010
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2008

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected. Defaults to adhoc.



2010
2011
2012
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2010

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.



2012
2013
2014
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2012

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Has a default value based on your merchant category code.



2014
2015
2016
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2014

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



2016
2017
2018
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2016

def start_date
  @start_date
end