Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1635

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when amount_type is fixed.



1621
1622
1623
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1621

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of amount param for fixed or maximum type respectively. Defaults to maximum.



1623
1624
1625
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1623

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



1625
1626
1627
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1625

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected. Defaults to adhoc.



1627
1628
1629
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1627

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when payment_schedule is adhoc. In that case, it defaults to no limit.



1629
1630
1631
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1629

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Has a default value based on your merchant category code.



1631
1632
1633
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1631

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



1633
1634
1635
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1633

def start_date
  @start_date
end