Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1710

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil,
  start_date: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
  @start_date = start_date
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



1696
1697
1698
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1696

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively. Defaults to `maximum`.



1698
1699
1700
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1698

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



1700
1701
1702
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1700

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected. Defaults to ‘adhoc`.



1702
1703
1704
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1702

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



1704
1705
1706
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1704

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Has a default value based on your merchant category code.



1706
1707
1708
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1706

def purpose
  @purpose
end

#start_dateObject

Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.



1708
1709
1710
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1708

def start_date
  @start_date
end