Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Pix

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_includes_iof: nil, expires_after_seconds: nil, mandate_options: nil, setup_future_usage: nil) ⇒ Pix

Returns a new instance of Pix.



1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1644

def initialize(
  amount_includes_iof: nil,
  expires_after_seconds: nil,
  mandate_options: nil,
  setup_future_usage: nil
)
  @amount_includes_iof = amount_includes_iof
  @expires_after_seconds = expires_after_seconds
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#amount_includes_iofObject

Determines if the amount includes the IOF tax. Defaults to never.



1630
1631
1632
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1630

def amount_includes_iof
  @amount_includes_iof
end

#expires_after_secondsObject

The number of seconds (between 10 and 1209600) after which Pix payment will expire. Defaults to 86400 seconds.



1632
1633
1634
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1632

def expires_after_seconds
  @expires_after_seconds
end

#mandate_optionsObject

Additional fields for mandate creation.



1634
1635
1636
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1634

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1642
1643
1644
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1642

def setup_future_usage
  @setup_future_usage
end