Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Pix
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Pix
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#expires_after_seconds ⇒ Object
The number of seconds (between 10 and 1209600) after which Pix payment will expire.
-
#mandate_options ⇒ Object
Additional fields for mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(amount_includes_iof: nil, expires_after_seconds: nil, mandate_options: nil, setup_future_usage: nil) ⇒ Pix
constructor
A new instance of Pix.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_includes_iof: nil, expires_after_seconds: nil, mandate_options: nil, setup_future_usage: nil) ⇒ Pix
Returns a new instance of Pix.
1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1724 def initialize( amount_includes_iof: nil, expires_after_seconds: nil, mandate_options: nil, setup_future_usage: nil ) @amount_includes_iof = amount_includes_iof @expires_after_seconds = expires_after_seconds @mandate_options = @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to never.
1710 1711 1712 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1710 def amount_includes_iof @amount_includes_iof end |
#expires_after_seconds ⇒ Object
The number of seconds (between 10 and 1209600) after which Pix payment will expire. Defaults to 86400 seconds.
1712 1713 1714 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1712 def expires_after_seconds @expires_after_seconds end |
#mandate_options ⇒ Object
Additional fields for mandate creation.
1714 1715 1716 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1714 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1722 1723 1724 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1722 def setup_future_usage @setup_future_usage end |