Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Pix::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Pix::MandateOptions
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
Type of amount.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in
YYYY-MM-DD. -
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
Start date of the mandate, in
YYYY-MM-DD.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1689 def initialize( amount: nil, amount_includes_iof: nil, amount_type: nil, currency: nil, end_date: nil, payment_schedule: nil, reference: nil, start_date: nil ) @amount = amount @amount_includes_iof = amount_includes_iof @amount_type = amount_type @currency = currency @end_date = end_date @payment_schedule = payment_schedule @reference = reference @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments. Required when amount_type=fixed. If not provided for amount_type=maximum, defaults to 40000.
1673 1674 1675 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1673 def amount @amount end |
#amount_includes_iof ⇒ Object
Determines if the amount includes the IOF tax. Defaults to never.
1675 1676 1677 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1675 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object
Type of amount. Defaults to maximum.
1677 1678 1679 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1677 def amount_type @amount_type end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Only brl is supported currently.
1679 1680 1681 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1679 def currency @currency end |
#end_date ⇒ Object
Date when the mandate expires and no further payments will be charged, in YYYY-MM-DD. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
1681 1682 1683 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1681 def end_date @end_date end |
#payment_schedule ⇒ Object
Schedule at which the future payments will be charged. Defaults to monthly.
1683 1684 1685 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1683 def payment_schedule @payment_schedule end |
#reference ⇒ Object
Subscription name displayed to buyers in their bank app. Defaults to the displayable business name.
1685 1686 1687 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1685 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate, in YYYY-MM-DD. Start date should be at least 3 days in the future. Defaults to 3 days after the current date.
1687 1688 1689 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1687 def start_date @start_date end |