Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Satispay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Satispay
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
Instance Method Summary collapse
-
#initialize(capture_method: nil) ⇒ Satispay
constructor
A new instance of Satispay.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil) ⇒ Satispay
Returns a new instance of Satispay.
1769 1770 1771 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1769 def initialize(capture_method: nil) @capture_method = capture_method end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
1767 1768 1769 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1767 def capture_method @capture_method end |