Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::SepaDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::SepaDebit
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: MandateOptions
Instance Attribute Summary collapse
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account.
Instance Method Summary collapse
-
#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil) ⇒ SepaDebit
constructor
A new instance of SepaDebit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil) ⇒ SepaDebit
Returns a new instance of SepaDebit.
1799 1800 1801 1802 1803 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1799 def initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil) @mandate_options = @setup_future_usage = setup_future_usage @target_date = target_date end |
Instance Attribute Details
#mandate_options ⇒ Object
Additional fields for Mandate creation
1787 1788 1789 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1787 def @mandate_options end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1795 1796 1797 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1795 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
1797 1798 1799 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1797 def target_date @target_date end |