Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Sunbit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Sunbit
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, setup_future_usage: nil) ⇒ Sunbit
constructor
A new instance of Sunbit.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, setup_future_usage: nil) ⇒ Sunbit
Returns a new instance of Sunbit.
1847 1848 1849 1850 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1847 def initialize(capture_method: nil, setup_future_usage: nil) @capture_method = capture_method @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer's account.
1837 1838 1839 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1837 def capture_method @capture_method end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
1845 1846 1847 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1845 def setup_future_usage @setup_future_usage end |