Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1874
1875
1876
1877
1878
1879
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1874

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1866
1867
1868
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1866

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1868
1869
1870
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1868

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1870
1871
1872
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1870

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1872
1873
1874
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1872

def end_date
  @end_date
end