Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1927
1928
1929
1930
1931
1932
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1927

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1919
1920
1921
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1919

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1921
1922
1923
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1921

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1923
1924
1925
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1923

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1925
1926
1927
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1925

def end_date
  @end_date
end