Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1847
1848
1849
1850
1851
1852
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1847

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1839
1840
1841
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1839

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1841
1842
1843
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1841

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1843
1844
1845
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1843

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1845
1846
1847
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1845

def end_date
  @end_date
end