Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1767
1768
1769
1770
1771
1772
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1767

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1759
1760
1761
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1759

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1761
1762
1763
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1761

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1763
1764
1765
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1763

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1765
1766
1767
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1765

def end_date
  @end_date
end