Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1902
1903
1904
1905
1906
1907
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1902

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1894
1895
1896
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1894

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1896
1897
1898
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1896

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1898
1899
1900
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1898

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1900
1901
1902
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1900

def end_date
  @end_date
end