Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



1716
1717
1718
1719
1720
1721
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1716

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



1708
1709
1710
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1708

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



1710
1711
1712
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1710

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



1712
1713
1714
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1712

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



1714
1715
1716
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1714

def end_date
  @end_date
end