Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: FinancialConnections

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(financial_connections: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1853

def initialize(
  financial_connections: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



1839
1840
1841
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1839

def financial_connections
  @financial_connections
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



1847
1848
1849
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1847

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer's account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



1849
1850
1851
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1849

def target_date
  @target_date
end

#verification_methodObject

Verification method for the intent



1851
1852
1853
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1851

def verification_method
  @verification_method
end