Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::WechatPay

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(app_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay

Returns a new instance of WechatPay.



2343
2344
2345
2346
2347
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2343

def initialize(app_id: nil, client: nil, setup_future_usage: nil)
  @app_id = app_id
  @client = client
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#app_idObject

The app ID registered with WeChat Pay. Only required when client is ios or android.



2331
2332
2333
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2331

def app_id
  @app_id
end

#clientObject

The client type that the end customer will pay from



2333
2334
2335
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2333

def client
  @client
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



2341
2342
2343
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2341

def setup_future_usage
  @setup_future_usage
end