Class: Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::WechatPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::PaymentMethodOptions::WechatPay
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
The app ID registered with WeChat Pay.
-
#client ⇒ Object
The client type that the end customer will pay from.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(app_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay
constructor
A new instance of WechatPay.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(app_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay
Returns a new instance of WechatPay.
1788 1789 1790 1791 1792 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1788 def initialize(app_id: nil, client: nil, setup_future_usage: nil) @app_id = app_id @client = client @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#app_id ⇒ Object
The app ID registered with WeChat Pay. Only required when client is ios or android.
1776 1777 1778 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1776 def app_id @app_id end |
#client ⇒ Object
The client type that the end customer will pay from
1778 1779 1780 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1778 def client @client end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
1786 1787 1788 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1786 def setup_future_usage @setup_future_usage end |