Class: Stripe::Checkout::SessionCreateParams::Permissions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::Permissions
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: Update
Instance Attribute Summary collapse
-
#update ⇒ Object
Permissions for updating the Checkout Session.
-
#update_discounts ⇒ Object
Determines which entity is allowed to update the discounts (coupons or promotion codes) that apply to this session.
-
#update_line_items ⇒ Object
Determines which entity is allowed to update the line items.
-
#update_shipping_details ⇒ Object
Determines which entity is allowed to update the shipping details.
Instance Method Summary collapse
-
#initialize(update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions
constructor
A new instance of Permissions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions
Returns a new instance of Permissions.
2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2266 def initialize( update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil ) @update = update @update_discounts = update_discounts @update_line_items = update_line_items @update_shipping_details = update_shipping_details end |
Instance Attribute Details
#update ⇒ Object
Permissions for updating the Checkout Session.
2248 2249 2250 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2248 def update @update end |
#update_discounts ⇒ Object
Determines which entity is allowed to update the discounts (coupons or promotion codes) that apply to this session.
Default is ‘client_only`. Stripe Checkout client will automatically handle discount updates. If set to `server_only`, only your server is allowed to update discounts.
2252 2253 2254 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2252 def update_discounts @update_discounts end |
#update_line_items ⇒ Object
Determines which entity is allowed to update the line items.
Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.
When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.
2258 2259 2260 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2258 def update_line_items @update_line_items end |
#update_shipping_details ⇒ Object
Determines which entity is allowed to update the shipping details.
Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.
When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.
2264 2265 2266 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2264 def update_shipping_details @update_shipping_details end |