Class: Stripe::Checkout::SessionCreateParams::Permissions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Update

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(update: nil, update_discounts: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions

Returns a new instance of Permissions.



2162
2163
2164
2165
2166
2167
2168
2169
2170
2171
2172
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2162

def initialize(
  update: nil,
  update_discounts: nil,
  update_line_items: nil,
  update_shipping_details: nil
)
  @update = update
  @update_discounts = update_discounts
  @update_line_items = update_line_items
  @update_shipping_details = update_shipping_details
end

Instance Attribute Details

#updateObject

Permissions for updating the Checkout Session.



2144
2145
2146
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2144

def update
  @update
end

#update_discountsObject

Determines which entity is allowed to update the discounts (coupons or promotion codes) that apply to this session.

Default is ‘client_only`. Stripe Checkout client will automatically handle discount updates. If set to `server_only`, only your server is allowed to update discounts.



2148
2149
2150
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2148

def update_discounts
  @update_discounts
end

#update_line_itemsObject

Determines which entity is allowed to update the line items.

Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.

When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



2154
2155
2156
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2154

def update_line_items
  @update_line_items
end

#update_shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.

When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



2160
2161
2162
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2160

def update_shipping_details
  @update_shipping_details
end