Class: Stripe::Checkout::SessionCreateParams::SavedPaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions

Returns a new instance of SavedPaymentMethodOptions.



2207
2208
2209
2210
2211
2212
2213
2214
2215
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2207

def initialize(
  allow_redisplay_filters: nil,
  payment_method_remove: nil,
  payment_method_save: nil
)
  @allow_redisplay_filters = allow_redisplay_filters
  @payment_method_remove = payment_method_remove
  @payment_method_save = payment_method_save
end

Instance Attribute Details

#allow_redisplay_filtersObject

Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.



2201
2202
2203
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2201

def allow_redisplay_filters
  @allow_redisplay_filters
end

#payment_method_removeObject

Enable customers to choose if they wish to remove their saved payment methods. Disabled by default.



2203
2204
2205
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2203

def payment_method_remove
  @payment_method_remove
end

#payment_method_saveObject

Enable customers to choose if they wish to save their payment method for future use. Disabled by default.



2205
2206
2207
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2205

def payment_method_save
  @payment_method_save
end