Class: Stripe::Checkout::SessionCreateParams::SavedPaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay_filters: nil, payment_method_remove: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions

Returns a new instance of SavedPaymentMethodOptions.



2174
2175
2176
2177
2178
2179
2180
2181
2182
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2174

def initialize(
  allow_redisplay_filters: nil,
  payment_method_remove: nil,
  payment_method_save: nil
)
  @allow_redisplay_filters = allow_redisplay_filters
  @payment_method_remove = payment_method_remove
  @payment_method_save = payment_method_save
end

Instance Attribute Details

#allow_redisplay_filtersObject

Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.



2168
2169
2170
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2168

def allow_redisplay_filters
  @allow_redisplay_filters
end

#payment_method_removeObject

Enable customers to choose if they wish to remove their saved payment methods. Disabled by default.



2170
2171
2172
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2170

def payment_method_remove
  @payment_method_remove
end

#payment_method_saveObject

Enable customers to choose if they wish to save their payment method for future use. Disabled by default.



2172
2173
2174
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2172

def payment_method_save
  @payment_method_save
end