Class: Stripe::Checkout::SessionCreateParams::SetupIntentData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::SetupIntentData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The Stripe account for which the setup is intended.
Instance Method Summary collapse
-
#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData
constructor
A new instance of SetupIntentData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData
Returns a new instance of SetupIntentData.
2317 2318 2319 2320 2321 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2317 def initialize(description: nil, metadata: nil, on_behalf_of: nil) @description = description @metadata = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2311 2312 2313 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2311 def description @description end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2313 2314 2315 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2313 def @metadata end |
#on_behalf_of ⇒ Object
The Stripe account for which the setup is intended.
2315 2316 2317 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2315 def on_behalf_of @on_behalf_of end |