Class: Stripe::Checkout::SessionCreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



2213
2214
2215
2216
2217
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2213

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2207
2208
2209
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2207

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2209
2210
2211
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2209

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



2211
2212
2213
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2211

def on_behalf_of
  @on_behalf_of
end