Class: Stripe::Checkout::SessionCreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



2264
2265
2266
2267
2268
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2264

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2258
2259
2260
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2258

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2260
2261
2262
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2260

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



2262
2263
2264
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2262

def on_behalf_of
  @on_behalf_of
end