Class: Stripe::Checkout::SessionCreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



2193
2194
2195
2196
2197
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2193

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2187
2188
2189
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2187

def description
  @description
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2189
2190
2191
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2189

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



2191
2192
2193
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2191

def on_behalf_of
  @on_behalf_of
end