Class: Stripe::Checkout::SessionCreateParams::SetupIntentData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::SetupIntentData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The Stripe account for which the setup is intended.
Instance Method Summary collapse
-
#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData
constructor
A new instance of SetupIntentData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData
Returns a new instance of SetupIntentData.
2202 2203 2204 2205 2206 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2202 def initialize(description: nil, metadata: nil, on_behalf_of: nil) @description = description @metadata = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2196 2197 2198 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2196 def description @description end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2198 2199 2200 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2198 def @metadata end |
#on_behalf_of ⇒ Object
The Stripe account for which the setup is intended.
2200 2201 2202 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2200 def on_behalf_of @on_behalf_of end |