Class: Stripe::Checkout::SessionCreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



2178
2179
2180
2181
2182
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2178

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2172
2173
2174
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2172

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2174
2175
2176
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2174

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



2176
2177
2178
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2176

def on_behalf_of
  @on_behalf_of
end