Class: Stripe::Checkout::SessionCreateParams::ShippingOption
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::ShippingOption
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: ShippingRateData
Instance Attribute Summary collapse
-
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
-
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
Instance Method Summary collapse
-
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
constructor
A new instance of ShippingOption.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
Returns a new instance of ShippingOption.
2343 2344 2345 2346 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2343 def initialize(shipping_rate: nil, shipping_rate_data: nil) @shipping_rate = shipping_rate @shipping_rate_data = shipping_rate_data end |
Instance Attribute Details
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
2339 2340 2341 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2339 def shipping_rate @shipping_rate end |
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
2341 2342 2343 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2341 def shipping_rate_data @shipping_rate_data end |