Class: Stripe::Checkout::SessionCreateParams::ShippingOption
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::ShippingOption
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: ShippingRateData
Instance Attribute Summary collapse
-
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
-
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
Instance Method Summary collapse
-
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
constructor
A new instance of ShippingOption.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
Returns a new instance of ShippingOption.
2330 2331 2332 2333 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2330 def initialize(shipping_rate: nil, shipping_rate_data: nil) @shipping_rate = shipping_rate @shipping_rate_data = shipping_rate_data end |
Instance Attribute Details
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
2326 2327 2328 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2326 def shipping_rate @shipping_rate end |
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
2328 2329 2330 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2328 def shipping_rate_data @shipping_rate_data end |