Class: Stripe::Checkout::SessionCreateParams::ShippingOption::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



2342
2343
2344
2345
2346
2347
2348
2349
2350
2351
2352
2353
2354
2355
2356
2357
2358
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2342

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



2328
2329
2330
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2328

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



2330
2331
2332
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2330

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



2332
2333
2334
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2332

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2334
2335
2336
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2334

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



2336
2337
2338
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2336

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A [tax code](docs.stripe.com/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.



2338
2339
2340
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2338

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



2340
2341
2342
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2340

def type
  @type
end