Class: Stripe::Checkout::SessionCreateParams::ShippingOption::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2387

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



2373
2374
2375
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2373

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



2375
2376
2377
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2375

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



2377
2378
2379
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2377

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2379
2380
2381
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2379

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



2381
2382
2383
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2381

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A [tax code](docs.stripe.com/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.



2383
2384
2385
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2383

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



2385
2386
2387
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2385

def type
  @type
end