Class: Stripe::Checkout::SessionCreateParams::ShippingOption::ShippingRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::ShippingOption::ShippingRateData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: DeliveryEstimate, FixedAmount
Instance Attribute Summary collapse
-
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer.
-
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer.
-
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
-
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
-
#type ⇒ Object
The type of calculation to use on the shipping rate.
Instance Method Summary collapse
-
#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData
constructor
A new instance of ShippingRateData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData
Returns a new instance of ShippingRateData.
2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2133 def initialize( delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil ) @delivery_estimate = delivery_estimate @display_name = display_name @fixed_amount = fixed_amount @metadata = @tax_behavior = tax_behavior @tax_code = tax_code @type = type end |
Instance Attribute Details
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.
2119 2120 2121 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2119 def delivery_estimate @delivery_estimate end |
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.
2121 2122 2123 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2121 def display_name @display_name end |
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping. Must be present if type is fixed_amount.
2123 2124 2125 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2123 def fixed_amount @fixed_amount end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
2125 2126 2127 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2125 def @metadata end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified.
2127 2128 2129 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2127 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID. The Shipping tax code is txcd_92010001.
2129 2130 2131 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2129 def tax_code @tax_code end |
#type ⇒ Object
The type of calculation to use on the shipping rate.
2131 2132 2133 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2131 def type @type end |