Class: Stripe::Checkout::SessionCreateParams::ShippingOption::ShippingRateData::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



1959
1960
1961
1962
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1959

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



1955
1956
1957
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1955

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



1957
1958
1959
# File 'lib/stripe/params/checkout/session_create_params.rb', line 1957

def tax_behavior
  @tax_behavior
end