Class: Stripe::Checkout::SessionCreateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: BillingCycleAnchorConfig, BillingMode, InvoiceSettings, PendingInvoiceItemInterval, TransferData, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application_fee_percent: nil, billing_cycle_anchor: nil, billing_cycle_anchor_config: nil, billing_mode: nil, default_tax_rates: nil, description: nil, invoice_settings: nil, metadata: nil, on_behalf_of: nil, pending_invoice_item_interval: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



2508
2509
2510
2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2508

def initialize(
  application_fee_percent: nil,
  billing_cycle_anchor: nil,
  billing_cycle_anchor_config: nil,
  billing_mode: nil,
  default_tax_rates: nil,
  description: nil,
  invoice_settings: nil,
  metadata: nil,
  on_behalf_of: nil,
  pending_invoice_item_interval: nil,
  proration_behavior: nil,
  transfer_data: nil,
  trial_end: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @application_fee_percent = application_fee_percent
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_cycle_anchor_config = billing_cycle_anchor_config
  @billing_mode = billing_mode
  @default_tax_rates = default_tax_rates
  @description = description
  @invoice_settings = invoice_settings
  @metadata = 
  @on_behalf_of = on_behalf_of
  @pending_invoice_item_interval = pending_invoice_item_interval
  @proration_behavior = proration_behavior
  @transfer_data = transfer_data
  @trial_end = trial_end
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. To use an application fee percent, the request must be made on behalf of another account, using the ‘Stripe-Account` header or an OAuth key. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



2474
2475
2476
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2474

def application_fee_percent
  @application_fee_percent
end

#billing_cycle_anchorObject

A future timestamp to anchor the subscription’s billing cycle for new subscriptions. You can’t set this parameter if ‘ui_mode` is `elements`.



2476
2477
2478
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2476

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_cycle_anchor_configObject

Configures when the subscription schedule’s billing cycle anchors to a specific day of the week or month.



2478
2479
2480
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2478

def billing_cycle_anchor_config
  @billing_cycle_anchor_config
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



2480
2481
2482
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2480

def billing_mode
  @billing_mode
end

#default_tax_ratesObject

The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.



2484
2485
2486
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2484

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in the [customer portal](docs.stripe.com/customer-management).



2488
2489
2490
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2488

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



2490
2491
2492
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2490

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2492
2493
2494
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2492

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the subscription’s invoices.



2494
2495
2496
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2494

def on_behalf_of
  @on_behalf_of
end

#pending_invoice_item_intervalObject

Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](docs.stripe.com/api#create_invoice) for the given subscription at the specified interval.



2496
2497
2498
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2496

def pending_invoice_item_interval
  @pending_invoice_item_interval
end

#proration_behaviorObject

Determines how to handle prorations resulting from the ‘billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.



2498
2499
2500
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2498

def proration_behavior
  @proration_behavior
end

#transfer_dataObject

If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.



2500
2501
2502
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2500

def transfer_data
  @transfer_data
end

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.



2502
2503
2504
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2502

def trial_end
  @trial_end
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



2504
2505
2506
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2504

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



2506
2507
2508
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2506

def trial_settings
  @trial_settings
end