Class: Stripe::Checkout::SessionCreateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: BillingMode, InvoiceSettings, PendingInvoiceItemInterval, TransferData, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application_fee_percent: nil, billing_cycle_anchor: nil, billing_mode: nil, default_tax_rates: nil, description: nil, invoice_settings: nil, metadata: nil, on_behalf_of: nil, pending_invoice_item_interval: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2450

def initialize(
  application_fee_percent: nil,
  billing_cycle_anchor: nil,
  billing_mode: nil,
  default_tax_rates: nil,
  description: nil,
  invoice_settings: nil,
  metadata: nil,
  on_behalf_of: nil,
  pending_invoice_item_interval: nil,
  proration_behavior: nil,
  transfer_data: nil,
  trial_end: nil,
  trial_period_days: nil,
  trial_settings: nil
)
  @application_fee_percent = application_fee_percent
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_mode = billing_mode
  @default_tax_rates = default_tax_rates
  @description = description
  @invoice_settings = invoice_settings
  @metadata = 
  @on_behalf_of = on_behalf_of
  @pending_invoice_item_interval = pending_invoice_item_interval
  @proration_behavior = proration_behavior
  @transfer_data = transfer_data
  @trial_end = trial_end
  @trial_period_days = trial_period_days
  @trial_settings = trial_settings
end

Instance Attribute Details

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. To use an application fee percent, the request must be made on behalf of another account, using the ‘Stripe-Account` header or an OAuth key. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



2418
2419
2420
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2418

def application_fee_percent
  @application_fee_percent
end

#billing_cycle_anchorObject

A future timestamp to anchor the subscription’s billing cycle for new subscriptions. You can’t set this parameter if ‘ui_mode` is `custom`.



2420
2421
2422
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2420

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



2422
2423
2424
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2422

def billing_mode
  @billing_mode
end

#default_tax_ratesObject

The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.



2426
2427
2428
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2426

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in the [customer portal](docs.stripe.com/customer-management).



2430
2431
2432
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2430

def description
  @description
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



2432
2433
2434
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2432

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2434
2435
2436
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2434

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the subscription’s invoices.



2436
2437
2438
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2436

def on_behalf_of
  @on_behalf_of
end

#pending_invoice_item_intervalObject

Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](docs.stripe.com/api#create_invoice) for the given subscription at the specified interval.



2438
2439
2440
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2438

def pending_invoice_item_interval
  @pending_invoice_item_interval
end

#proration_behaviorObject

Determines how to handle prorations resulting from the ‘billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.



2440
2441
2442
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2440

def proration_behavior
  @proration_behavior
end

#transfer_dataObject

If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.



2442
2443
2444
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2442

def transfer_data
  @transfer_data
end

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.



2444
2445
2446
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2444

def trial_end
  @trial_end
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



2446
2447
2448
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2446

def trial_period_days
  @trial_period_days
end

#trial_settingsObject

Settings related to subscription trials.



2448
2449
2450
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2448

def trial_settings
  @trial_settings
end