Class: Stripe::Checkout::SessionCreateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::SubscriptionData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Defined Under Namespace
Classes: BillingMode, InvoiceSettings, PendingInvoiceItemInterval, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#billing_cycle_anchor ⇒ Object
A future timestamp to anchor the subscription’s billing cycle for new subscriptions.
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set.
-
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
-
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items.
-
#proration_behavior ⇒ Object
Determines how to handle prorations resulting from the ‘billing_cycle_anchor`.
-
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(application_fee_percent: nil, billing_cycle_anchor: nil, billing_mode: nil, default_tax_rates: nil, description: nil, invoice_settings: nil, metadata: nil, on_behalf_of: nil, pending_invoice_item_interval: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(application_fee_percent: nil, billing_cycle_anchor: nil, billing_mode: nil, default_tax_rates: nil, description: nil, invoice_settings: nil, metadata: nil, on_behalf_of: nil, pending_invoice_item_interval: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_period_days: nil, trial_settings: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 2548 2549 2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2530 def initialize( application_fee_percent: nil, billing_cycle_anchor: nil, billing_mode: nil, default_tax_rates: nil, description: nil, invoice_settings: nil, metadata: nil, on_behalf_of: nil, pending_invoice_item_interval: nil, proration_behavior: nil, transfer_data: nil, trial_end: nil, trial_period_days: nil, trial_settings: nil ) @application_fee_percent = application_fee_percent @billing_cycle_anchor = billing_cycle_anchor @billing_mode = billing_mode @default_tax_rates = default_tax_rates @description = description @invoice_settings = invoice_settings @metadata = @on_behalf_of = on_behalf_of @pending_invoice_item_interval = pending_invoice_item_interval @proration_behavior = proration_behavior @transfer_data = transfer_data @trial_end = trial_end @trial_period_days = trial_period_days @trial_settings = trial_settings end |
Instance Attribute Details
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. To use an application fee percent, the request must be made on behalf of another account, using the ‘Stripe-Account` header or an OAuth key. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
2498 2499 2500 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2498 def application_fee_percent @application_fee_percent end |
#billing_cycle_anchor ⇒ Object
A future timestamp to anchor the subscription’s billing cycle for new subscriptions. You can’t set this parameter if ‘ui_mode` is `custom`.
2500 2501 2502 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2500 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
2502 2503 2504 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2502 def billing_mode @billing_mode end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any subscription item that does not have ‘tax_rates` set. Invoices created will have their `default_tax_rates` populated from the subscription.
2506 2507 2508 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2506 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
The subscription’s description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in the [customer portal](docs.stripe.com/customer-management).
2510 2511 2512 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2510 def description @description end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
2512 2513 2514 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2512 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2514 2515 2516 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2514 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the subscription’s invoices.
2516 2517 2518 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2516 def on_behalf_of @on_behalf_of end |
#pending_invoice_item_interval ⇒ Object
Specifies an interval for how often to bill for any pending invoice items. It is analogous to calling [Create an invoice](docs.stripe.com/api#create_invoice) for the given subscription at the specified interval.
2518 2519 2520 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2518 def pending_invoice_item_interval @pending_invoice_item_interval end |
#proration_behavior ⇒ Object
Determines how to handle prorations resulting from the ‘billing_cycle_anchor`. If no value is passed, the default is `create_prorations`.
2520 2521 2522 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2520 def proration_behavior @proration_behavior end |
#transfer_data ⇒ Object
If specified, the funds from the subscription’s invoices will be transferred to the destination and the ID of the resulting transfers will be found on the resulting charges.
2522 2523 2524 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2522 def transfer_data @transfer_data end |
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.
2524 2525 2526 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2524 def trial_end @trial_end end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.
2526 2527 2528 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2526 def trial_period_days @trial_period_days end |
#trial_settings ⇒ Object
Settings related to subscription trials.
2528 2529 2530 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2528 def trial_settings @trial_settings end |