Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
2788 2789 2790 2791 2792 2793 2794 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2788 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
2778 2779 2780 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2778 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
2780 2781 2782 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2780 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
2782 2783 2784 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2782 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
2784 2785 2786 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2784 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
2786 2787 2788 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2786 def second @second end |