Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingCycleAnchorConfig

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig

Returns a new instance of BillingCycleAnchorConfig.



2275
2276
2277
2278
2279
2280
2281
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2275

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



2265
2266
2267
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2265

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



2267
2268
2269
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2267

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



2269
2270
2271
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2269

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



2271
2272
2273
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2271

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



2273
2274
2275
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2273

def second
  @second
end