Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
2398 2399 2400 2401 2402 2403 2404 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2398 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
2388 2389 2390 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2388 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
2390 2391 2392 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2390 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
2392 2393 2394 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2392 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
2394 2395 2396 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2394 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
2396 2397 2398 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2396 def second @second end |