Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingCycleAnchorConfig
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingCycleAnchorConfig
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
constructor
A new instance of BillingCycleAnchorConfig.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ BillingCycleAnchorConfig
Returns a new instance of BillingCycleAnchorConfig.
2384 2385 2386 2387 2388 2389 2390 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2384 def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
2374 2375 2376 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2374 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
2376 2377 2378 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2376 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
2378 2379 2380 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2378 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
2380 2381 2382 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2380 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
2382 2383 2384 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2382 def second @second end |