Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode

Returns a new instance of BillingMode.



2298
2299
2300
2301
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2298

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



2294
2295
2296
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2294

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is flexible.



2296
2297
2298
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2296

def type
  @type
end