Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode

Returns a new instance of BillingMode.



2316
2317
2318
2319
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2316

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



2312
2313
2314
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2312

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is ‘flexible`.



2314
2315
2316
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2314

def type
  @type
end