Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2342
2343
2344
2345
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2342

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



2338
2339
2340
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2338

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2340
2341
2342
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2340

def destination
  @destination
end