Class: Stripe::Checkout::SessionCreateParams::SubscriptionData::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::SubscriptionData::TransferData
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
2273 2274 2275 2276 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2273 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
2269 2270 2271 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2269 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
2271 2272 2273 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2271 def destination @destination end |