Class: Stripe::Checkout::SessionCreateParams::WalletOptions::Link
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionCreateParams::WalletOptions::Link
- Defined in:
- lib/stripe/params/checkout/session_create_params.rb
Instance Attribute Summary collapse
-
#display ⇒ Object
Specifies whether Checkout should display Link as a payment option.
Instance Method Summary collapse
-
#initialize(display: nil) ⇒ Link
constructor
A new instance of Link.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(display: nil) ⇒ Link
Returns a new instance of Link.
2568 2569 2570 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2568 def initialize(display: nil) @display = display end |
Instance Attribute Details
#display ⇒ Object
Specifies whether Checkout should display Link as a payment option. By default, Checkout will display all the supported wallets that the Checkout Session was created with. This is the auto behavior, and it is the default choice.
2566 2567 2568 |
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2566 def display @display end |