Class: Stripe::Checkout::SessionCreateParams::WalletOptions::Link

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(display: nil) ⇒ Link

Returns a new instance of Link.



2451
2452
2453
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2451

def initialize(display: nil)
  @display = display
end

Instance Attribute Details

#displayObject

Specifies whether Checkout should display Link as a payment option. By default, Checkout will display all the supported wallets that the Checkout Session was created with. This is the auto behavior, and it is the default choice.



2449
2450
2451
# File 'lib/stripe/params/checkout/session_create_params.rb', line 2449

def display
  @display
end