Class: Stripe::Checkout::SessionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Checkout::SessionService
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: CreateParams, ExpireParams, ListParams, RetrieveParams, UpdateParams
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Returns the value of attribute line_items.
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a Checkout Session object.
-
#expire(session, params = {}, opts = {}) ⇒ Object
A Checkout Session can be expired when it is in one of these statuses: open.
-
#initialize(requestor) ⇒ SessionService
constructor
A new instance of SessionService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Checkout Sessions.
-
#retrieve(session, params = {}, opts = {}) ⇒ Object
Retrieves a Checkout Session object.
-
#update(session, params = {}, opts = {}) ⇒ Object
Updates a Checkout Session object.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ SessionService
Returns a new instance of SessionService.
9 10 11 12 |
# File 'lib/stripe/services/checkout/session_service.rb', line 9 def initialize(requestor) super @line_items = Stripe::Checkout::SessionLineItemService.new(@requestor) end |
Instance Attribute Details
#line_items ⇒ Object (readonly)
Returns the value of attribute line_items.
7 8 9 |
# File 'lib/stripe/services/checkout/session_service.rb', line 7 def line_items @line_items end |
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a Checkout Session object.
2815 2816 2817 2818 2819 2820 2821 2822 2823 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2815 def create(params = {}, opts = {}) request( method: :post, path: "/v1/checkout/sessions", params: params, opts: opts, base_address: :api ) end |
#expire(session, params = {}, opts = {}) ⇒ Object
A Checkout Session can be expired when it is in one of these statuses: open
After it expires, a customer can’t complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.
2828 2829 2830 2831 2832 2833 2834 2835 2836 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2828 def expire(session, params = {}, opts = {}) request( method: :post, path: format("/v1/checkout/sessions/%<session>s/expire", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Checkout Sessions.
2839 2840 2841 2842 2843 2844 2845 2846 2847 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2839 def list(params = {}, opts = {}) request( method: :get, path: "/v1/checkout/sessions", params: params, opts: opts, base_address: :api ) end |
#retrieve(session, params = {}, opts = {}) ⇒ Object
Retrieves a Checkout Session object.
2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2850 def retrieve(session, params = {}, opts = {}) request( method: :get, path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |
#update(session, params = {}, opts = {}) ⇒ Object
Updates a Checkout Session object.
Related guide: [Dynamically update Checkout](docs.stripe.com/payments/checkout/dynamic-updates)
2863 2864 2865 2866 2867 2868 2869 2870 2871 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2863 def update(session, params = {}, opts = {}) request( method: :post, path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |