Class: Stripe::Checkout::SessionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Checkout::SessionService
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: CreateParams, ExpireParams, ListParams, RetrieveParams, UpdateParams
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Returns the value of attribute line_items.
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a Checkout Session object.
-
#expire(session, params = {}, opts = {}) ⇒ Object
A Checkout Session can be expired when it is in one of these statuses: open.
-
#initialize(requestor) ⇒ SessionService
constructor
A new instance of SessionService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Checkout Sessions.
-
#retrieve(session, params = {}, opts = {}) ⇒ Object
Retrieves a Checkout Session object.
-
#update(session, params = {}, opts = {}) ⇒ Object
Updates a Checkout Session object.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ SessionService
Returns a new instance of SessionService.
9 10 11 12 |
# File 'lib/stripe/services/checkout/session_service.rb', line 9 def initialize(requestor) super @line_items = Stripe::Checkout::SessionLineItemService.new(@requestor) end |
Instance Attribute Details
#line_items ⇒ Object (readonly)
Returns the value of attribute line_items.
7 8 9 |
# File 'lib/stripe/services/checkout/session_service.rb', line 7 def line_items @line_items end |
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a Checkout Session object.
2675 2676 2677 2678 2679 2680 2681 2682 2683 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2675 def create(params = {}, opts = {}) request( method: :post, path: "/v1/checkout/sessions", params: params, opts: opts, base_address: :api ) end |
#expire(session, params = {}, opts = {}) ⇒ Object
A Checkout Session can be expired when it is in one of these statuses: open
After it expires, a customer can’t complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.
2688 2689 2690 2691 2692 2693 2694 2695 2696 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2688 def expire(session, params = {}, opts = {}) request( method: :post, path: format("/v1/checkout/sessions/%<session>s/expire", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Checkout Sessions.
2699 2700 2701 2702 2703 2704 2705 2706 2707 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2699 def list(params = {}, opts = {}) request( method: :get, path: "/v1/checkout/sessions", params: params, opts: opts, base_address: :api ) end |
#retrieve(session, params = {}, opts = {}) ⇒ Object
Retrieves a Checkout Session object.
2710 2711 2712 2713 2714 2715 2716 2717 2718 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2710 def retrieve(session, params = {}, opts = {}) request( method: :get, path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |
#update(session, params = {}, opts = {}) ⇒ Object
Updates a Checkout Session object.
2721 2722 2723 2724 2725 2726 2727 2728 2729 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2721 def update(session, params = {}, opts = {}) request( method: :post, path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |