Class: Stripe::Checkout::SessionService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: CreateParams, ExpireParams, ListParams, RetrieveParams, UpdateParams

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from StripeService

#request, #request_stream

Constructor Details

#initialize(requestor) ⇒ SessionService

Returns a new instance of SessionService.



9
10
11
12
# File 'lib/stripe/services/checkout/session_service.rb', line 9

def initialize(requestor)
  super(requestor)
  @line_items = Stripe::Checkout::SessionLineItemService.new(@requestor)
end

Instance Attribute Details

#line_itemsObject (readonly)

Returns the value of attribute line_items.



7
8
9
# File 'lib/stripe/services/checkout/session_service.rb', line 7

def line_items
  @line_items
end

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

Creates a Checkout Session object.



2600
2601
2602
2603
2604
2605
2606
2607
2608
# File 'lib/stripe/services/checkout/session_service.rb', line 2600

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/checkout/sessions",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#expire(session, params = {}, opts = {}) ⇒ Object

A Checkout Session can be expired when it is in one of these statuses: open

After it expires, a customer can’t complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.



2613
2614
2615
2616
2617
2618
2619
2620
2621
# File 'lib/stripe/services/checkout/session_service.rb', line 2613

def expire(session, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s/expire", { session: CGI.escape(session) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of Checkout Sessions.



2624
2625
2626
2627
2628
2629
2630
2631
2632
# File 'lib/stripe/services/checkout/session_service.rb', line 2624

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/checkout/sessions",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(session, params = {}, opts = {}) ⇒ Object

Retrieves a Checkout Session object.



2635
2636
2637
2638
2639
2640
2641
2642
2643
# File 'lib/stripe/services/checkout/session_service.rb', line 2635

def retrieve(session, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(session, params = {}, opts = {}) ⇒ Object

Updates a Checkout Session object.



2646
2647
2648
2649
2650
2651
2652
2653
2654
# File 'lib/stripe/services/checkout/session_service.rb', line 2646

def update(session, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end