Class: Stripe::Checkout::SessionService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Checkout::SessionService
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: CreateParams, ExpireParams, ListParams, RetrieveParams, UpdateParams
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Returns the value of attribute line_items.
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a Checkout Session object.
-
#expire(session, params = {}, opts = {}) ⇒ Object
A Checkout Session can be expired when it is in one of these statuses: open.
-
#initialize(requestor) ⇒ SessionService
constructor
A new instance of SessionService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Checkout Sessions.
-
#retrieve(session, params = {}, opts = {}) ⇒ Object
Retrieves a Checkout Session object.
-
#update(session, params = {}, opts = {}) ⇒ Object
Updates a Checkout Session object.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ SessionService
Returns a new instance of SessionService.
9 10 11 12 |
# File 'lib/stripe/services/checkout/session_service.rb', line 9 def initialize(requestor) super(requestor) @line_items = Stripe::Checkout::SessionLineItemService.new(@requestor) end |
Instance Attribute Details
#line_items ⇒ Object (readonly)
Returns the value of attribute line_items.
7 8 9 |
# File 'lib/stripe/services/checkout/session_service.rb', line 7 def line_items @line_items end |
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a Checkout Session object.
2579 2580 2581 2582 2583 2584 2585 2586 2587 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2579 def create(params = {}, opts = {}) request( method: :post, path: "/v1/checkout/sessions", params: params, opts: opts, base_address: :api ) end |
#expire(session, params = {}, opts = {}) ⇒ Object
A Checkout Session can be expired when it is in one of these statuses: open
After it expires, a customer can’t complete a Checkout Session and customers loading the Checkout Session see a message saying the Checkout Session is expired.
2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2592 def expire(session, params = {}, opts = {}) request( method: :post, path: format("/v1/checkout/sessions/%<session>s/expire", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Checkout Sessions.
2603 2604 2605 2606 2607 2608 2609 2610 2611 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2603 def list(params = {}, opts = {}) request( method: :get, path: "/v1/checkout/sessions", params: params, opts: opts, base_address: :api ) end |
#retrieve(session, params = {}, opts = {}) ⇒ Object
Retrieves a Checkout Session object.
2614 2615 2616 2617 2618 2619 2620 2621 2622 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2614 def retrieve(session, params = {}, opts = {}) request( method: :get, path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |
#update(session, params = {}, opts = {}) ⇒ Object
Updates a Checkout Session object.
2625 2626 2627 2628 2629 2630 2631 2632 2633 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2625 def update(session, params = {}, opts = {}) request( method: :post, path: format("/v1/checkout/sessions/%<session>s", { session: CGI.escape(session) }), params: params, opts: opts, base_address: :api ) end |