Class: Stripe::Checkout::SessionService::CreateParams::CustomField

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: Dropdown, Label, Numeric, Text

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(dropdown: nil, key: nil, label: nil, numeric: nil, optional: nil, text: nil, type: nil) ⇒ CustomField

Returns a new instance of CustomField.



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/stripe/services/checkout/session_service.rb', line 290

def initialize(
  dropdown: nil,
  key: nil,
  label: nil,
  numeric: nil,
  optional: nil,
  text: nil,
  type: nil
)
  @dropdown = dropdown
  @key = key
  @label = label
  @numeric = numeric
  @optional = optional
  @text = text
  @type = type
end

Instance Attribute Details

Configuration for ‘type=dropdown` fields.



270
271
272
# File 'lib/stripe/services/checkout/session_service.rb', line 270

def dropdown
  @dropdown
end

#keyObject

String of your choice that your integration can use to reconcile this field. Must be unique to this field, alphanumeric, and up to 200 characters.



273
274
275
# File 'lib/stripe/services/checkout/session_service.rb', line 273

def key
  @key
end

#labelObject

The label for the field, displayed to the customer.



276
277
278
# File 'lib/stripe/services/checkout/session_service.rb', line 276

def label
  @label
end

#numericObject

Configuration for ‘type=numeric` fields.



279
280
281
# File 'lib/stripe/services/checkout/session_service.rb', line 279

def numeric
  @numeric
end

#optionalObject

Whether the customer is required to complete the field before completing the Checkout Session. Defaults to ‘false`.



282
283
284
# File 'lib/stripe/services/checkout/session_service.rb', line 282

def optional
  @optional
end

#textObject

Configuration for ‘type=text` fields.



285
286
287
# File 'lib/stripe/services/checkout/session_service.rb', line 285

def text
  @text
end

#typeObject

The type of the field.



288
289
290
# File 'lib/stripe/services/checkout/session_service.rb', line 288

def type
  @type
end