Class: Stripe::Checkout::SessionService::CreateParams::CustomField::Dropdown::Option
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::CustomField::Dropdown::Option
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#label ⇒ Object
The label for the option, displayed to the customer.
-
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer.
Instance Method Summary collapse
-
#initialize(label: nil, value: nil) ⇒ Option
constructor
A new instance of Option.
Methods inherited from RequestParams
Constructor Details
#initialize(label: nil, value: nil) ⇒ Option
Returns a new instance of Option.
191 192 193 194 |
# File 'lib/stripe/services/checkout/session_service.rb', line 191 def initialize(label: nil, value: nil) @label = label @value = value end |
Instance Attribute Details
#label ⇒ Object
The label for the option, displayed to the customer. Up to 100 characters.
187 188 189 |
# File 'lib/stripe/services/checkout/session_service.rb', line 187 def label @label end |
#value ⇒ Object
The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.
189 190 191 |
# File 'lib/stripe/services/checkout/session_service.rb', line 189 def value @value end |