Class: Stripe::Checkout::SessionService::CreateParams::CustomField::Dropdown::Option

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(label: nil, value: nil) ⇒ Option

Returns a new instance of Option.



206
207
208
209
# File 'lib/stripe/services/checkout/session_service.rb', line 206

def initialize(label: nil, value: nil)
  @label = label
  @value = value
end

Instance Attribute Details

#labelObject

The label for the option, displayed to the customer. Up to 100 characters.



201
202
203
# File 'lib/stripe/services/checkout/session_service.rb', line 201

def label
  @label
end

#valueObject

The value for this option, not displayed to the customer, used by your integration to reconcile the option selected by the customer. Must be unique to this option, alphanumeric, and up to 100 characters.



204
205
206
# File 'lib/stripe/services/checkout/session_service.rb', line 204

def value
  @value
end