Class: Stripe::Checkout::SessionService::CreateParams::CustomText
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::CustomText
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: AfterSubmit, ShippingAddress, Submit, TermsOfServiceAcceptance
Instance Attribute Summary collapse
-
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
-
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
-
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
-
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
Instance Method Summary collapse
-
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
constructor
A new instance of CustomText.
Methods inherited from RequestParams
Constructor Details
#initialize(after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil) ⇒ CustomText
Returns a new instance of CustomText.
357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/stripe/services/checkout/session_service.rb', line 357 def initialize( after_submit: nil, shipping_address: nil, submit: nil, terms_of_service_acceptance: nil ) @after_submit = after_submit @shipping_address = shipping_address @submit = submit @terms_of_service_acceptance = terms_of_service_acceptance end |
Instance Attribute Details
#after_submit ⇒ Object
Custom text that should be displayed after the payment confirmation button.
346 347 348 |
# File 'lib/stripe/services/checkout/session_service.rb', line 346 def after_submit @after_submit end |
#shipping_address ⇒ Object
Custom text that should be displayed alongside shipping address collection.
349 350 351 |
# File 'lib/stripe/services/checkout/session_service.rb', line 349 def shipping_address @shipping_address end |
#submit ⇒ Object
Custom text that should be displayed alongside the payment confirmation button.
352 353 354 |
# File 'lib/stripe/services/checkout/session_service.rb', line 352 def submit @submit end |
#terms_of_service_acceptance ⇒ Object
Custom text that should be displayed in place of the default terms of service agreement text.
355 356 357 |
# File 'lib/stripe/services/checkout/session_service.rb', line 355 def terms_of_service_acceptance @terms_of_service_acceptance end |