Class: Stripe::Checkout::SessionService::CreateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



524
525
526
527
528
529
530
# File 'lib/stripe/services/checkout/session_service.rb', line 524

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



510
511
512
# File 'lib/stripe/services/checkout/session_service.rb', line 510

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



513
514
515
# File 'lib/stripe/services/checkout/session_service.rb', line 513

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



516
517
518
# File 'lib/stripe/services/checkout/session_service.rb', line 516

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



519
520
521
# File 'lib/stripe/services/checkout/session_service.rb', line 519

def name
  @name
end

#tax_codeObject



522
523
524
# File 'lib/stripe/services/checkout/session_service.rb', line 522

def tax_code
  @tax_code
end