Class: Stripe::Checkout::SessionService::CreateParams::OptionalItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::OptionalItem::AdjustableQuantity
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
-
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase.
-
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
575 576 577 578 579 |
# File 'lib/stripe/services/checkout/session_service.rb', line 575 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any non-negative integer.
569 570 571 |
# File 'lib/stripe/services/checkout/session_service.rb', line 569 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity of this item the customer can purchase. By default this value is 99. You can specify a value up to 999999.
571 572 573 |
# File 'lib/stripe/services/checkout/session_service.rb', line 571 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity of this item the customer must purchase, if they choose to purchase it. Because this item is optional, the customer will always be able to remove it from their order, even if the ‘minimum` configured here is greater than 0. By default this value is 0.
573 574 575 |
# File 'lib/stripe/services/checkout/session_service.rb', line 573 def minimum @minimum end |