Class: Stripe::Checkout::SessionService::CreateParams::PaymentIntentData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::PaymentIntentData
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: Shipping, TransferData
Instance Attribute Summary collapse
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The Stripe account ID for which these funds are intended.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to [make future payments](stripe.com/docs/payments/payment-intents#future-usage) with the payment method collected by this Checkout Session.
-
#shipping ⇒ Object
Shipping information for this payment.
-
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge.
-
#transfer_data ⇒ Object
The parameters used to automatically create a Transfer when the payment succeeds.
-
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group.
Instance Method Summary collapse
-
#initialize(application_fee_amount: nil, capture_method: nil, description: nil, metadata: nil, on_behalf_of: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentData
constructor
A new instance of PaymentIntentData.
Methods inherited from RequestParams
Constructor Details
#initialize(application_fee_amount: nil, capture_method: nil, description: nil, metadata: nil, on_behalf_of: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil) ⇒ PaymentIntentData
Returns a new instance of PaymentIntentData.
674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/stripe/services/checkout/session_service.rb', line 674 def initialize( application_fee_amount: nil, capture_method: nil, description: nil, metadata: nil, on_behalf_of: nil, receipt_email: nil, setup_future_usage: nil, shipping: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil, transfer_group: nil ) @application_fee_amount = application_fee_amount @capture_method = capture_method @description = description @metadata = @on_behalf_of = on_behalf_of @receipt_email = receipt_email @setup_future_usage = setup_future_usage @shipping = shipping @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data @transfer_group = transfer_group end |
Instance Attribute Details
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
626 627 628 |
# File 'lib/stripe/services/checkout/session_service.rb', line 626 def application_fee_amount @application_fee_amount end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
628 629 630 |
# File 'lib/stripe/services/checkout/session_service.rb', line 628 def capture_method @capture_method end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
630 631 632 |
# File 'lib/stripe/services/checkout/session_service.rb', line 630 def description @description end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
632 633 634 |
# File 'lib/stripe/services/checkout/session_service.rb', line 632 def @metadata end |
#on_behalf_of ⇒ Object
The Stripe account ID for which these funds are intended. For details, see the PaymentIntents [use case for connected accounts](/docs/payments/connected-accounts).
636 637 638 |
# File 'lib/stripe/services/checkout/session_service.rb', line 636 def on_behalf_of @on_behalf_of end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
638 639 640 |
# File 'lib/stripe/services/checkout/session_service.rb', line 638 def receipt_email @receipt_email end |
#setup_future_usage ⇒ Object
Indicates that you intend to [make future payments](stripe.com/docs/payments/payment-intents#future-usage) with the payment method collected by this Checkout Session.
When setting this to ‘on_session`, Checkout will show a notice to the customer that their payment details will be saved.
When setting this to ‘off_session`, Checkout will show a notice to the customer that their payment details will be saved and used for future payments.
If a Customer has been provided or Checkout creates a new Customer, Checkout will attach the payment method to the Customer.
If Checkout does not create a Customer, the payment method is not attached to a Customer. To reuse the payment method, you can retrieve it from the Checkout Session’s PaymentIntent.
When processing card payments, Checkout also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as SCA.
659 660 661 |
# File 'lib/stripe/services/checkout/session_service.rb', line 659 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this payment.
661 662 663 |
# File 'lib/stripe/services/checkout/session_service.rb', line 661 def shipping @shipping end |
#statement_descriptor ⇒ Object
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
665 666 667 |
# File 'lib/stripe/services/checkout/session_service.rb', line 665 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
667 668 669 |
# File 'lib/stripe/services/checkout/session_service.rb', line 667 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
The parameters used to automatically create a Transfer when the payment succeeds. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
670 671 672 |
# File 'lib/stripe/services/checkout/session_service.rb', line 670 def transfer_data @transfer_data end |
#transfer_group ⇒ Object
A string that identifies the resulting payment as part of a group. See the PaymentIntents [use case for connected accounts](stripe.com/docs/connect/separate-charges-and-transfers) for details.
672 673 674 |
# File 'lib/stripe/services/checkout/session_service.rb', line 672 def transfer_group @transfer_group end |