Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Card

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: Installments, Restrictions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(installments: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_three_d_secure: nil, restrictions: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil) ⇒ Card

Returns a new instance of Card.



988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
# File 'lib/stripe/services/checkout/session_service.rb', line 988

def initialize(
  installments: nil,
  request_extended_authorization: nil,
  request_incremental_authorization: nil,
  request_multicapture: nil,
  request_overcapture: nil,
  request_three_d_secure: nil,
  restrictions: nil,
  setup_future_usage: nil,
  statement_descriptor_suffix_kana: nil,
  statement_descriptor_suffix_kanji: nil
)
  @installments = installments
  @request_extended_authorization = request_extended_authorization
  @request_incremental_authorization = request_incremental_authorization
  @request_multicapture = request_multicapture
  @request_overcapture = request_overcapture
  @request_three_d_secure = request_three_d_secure
  @restrictions = restrictions
  @setup_future_usage = setup_future_usage
  @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji
end

Instance Attribute Details

#installmentsObject

Installment options for card payments



962
963
964
# File 'lib/stripe/services/checkout/session_service.rb', line 962

def installments
  @installments
end

#request_extended_authorizationObject

Request ability to [capture beyond the standard authorization validity window](/payments/extended-authorization) for this CheckoutSession.



964
965
966
# File 'lib/stripe/services/checkout/session_service.rb', line 964

def request_extended_authorization
  @request_extended_authorization
end

#request_incremental_authorizationObject

Request ability to [increment the authorization](/payments/incremental-authorization) for this CheckoutSession.



966
967
968
# File 'lib/stripe/services/checkout/session_service.rb', line 966

def request_incremental_authorization
  @request_incremental_authorization
end

#request_multicaptureObject

Request ability to make [multiple captures](/payments/multicapture) for this CheckoutSession.



968
969
970
# File 'lib/stripe/services/checkout/session_service.rb', line 968

def request_multicapture
  @request_multicapture
end

#request_overcaptureObject

Request ability to [overcapture](/payments/overcapture) for this CheckoutSession.



970
971
972
# File 'lib/stripe/services/checkout/session_service.rb', line 970

def request_overcapture
  @request_overcapture
end

#request_three_d_secureObject

We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.



972
973
974
# File 'lib/stripe/services/checkout/session_service.rb', line 972

def request_three_d_secure
  @request_three_d_secure
end

#restrictionsObject

Restrictions to apply to the card payment method. For example, you can block specific card brands.



974
975
976
# File 'lib/stripe/services/checkout/session_service.rb', line 974

def restrictions
  @restrictions
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



982
983
984
# File 'lib/stripe/services/checkout/session_service.rb', line 982

def setup_future_usage
  @setup_future_usage
end

#statement_descriptor_suffix_kanaObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.



984
985
986
# File 'lib/stripe/services/checkout/session_service.rb', line 984

def statement_descriptor_suffix_kana
  @statement_descriptor_suffix_kana
end

#statement_descriptor_suffix_kanjiObject

Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.



986
987
988
# File 'lib/stripe/services/checkout/session_service.rb', line 986

def statement_descriptor_suffix_kanji
  @statement_descriptor_suffix_kanji
end