Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



1174
1175
1176
1177
# File 'lib/stripe/services/checkout/session_service.rb', line 1174

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



1170
1171
1172
# File 'lib/stripe/services/checkout/session_service.rb', line 1170

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



1172
1173
1174
# File 'lib/stripe/services/checkout/session_service.rb', line 1172

def date
  @date
end