Class: Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
-
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1353 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil, start_date: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose @start_date = start_date end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when ‘amount_type` is `fixed`.
1339 1340 1341 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1339 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.
1341 1342 1343 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1341 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
1343 1344 1345 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1343 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
1345 1346 1347 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1345 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.
1347 1348 1349 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1347 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Defaults to retail.
1349 1350 1351 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1349 def purpose @purpose end |
#start_date ⇒ Object
Date, in YYYY-MM-DD format, from which payments will be collected. Defaults to confirmation time.
1351 1352 1353 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1351 def start_date @start_date end |