Class: Stripe::Checkout::SessionService::CreateParams::Permissions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(update_shipping_details: nil) ⇒ Permissions

Returns a new instance of Permissions.



1749
1750
1751
# File 'lib/stripe/services/checkout/session_service.rb', line 1749

def initialize(update_shipping_details: nil)
  @update_shipping_details = update_shipping_details
end

Instance Attribute Details

#update_shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.

When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



1747
1748
1749
# File 'lib/stripe/services/checkout/session_service.rb', line 1747

def update_shipping_details
  @update_shipping_details
end