Class: Stripe::Checkout::SessionService::CreateParams::Permissions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: Update

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(update: nil, update_line_items: nil, update_shipping_details: nil) ⇒ Permissions

Returns a new instance of Permissions.



1833
1834
1835
1836
1837
# File 'lib/stripe/services/checkout/session_service.rb', line 1833

def initialize(update: nil, update_line_items: nil, update_shipping_details: nil)
  @update = update
  @update_line_items = update_line_items
  @update_shipping_details = update_shipping_details
end

Instance Attribute Details

#updateObject

Permissions for updating the Checkout Session.



1819
1820
1821
# File 'lib/stripe/services/checkout/session_service.rb', line 1819

def update
  @update
end

#update_line_itemsObject

Determines which entity is allowed to update the line items.

Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.

When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



1825
1826
1827
# File 'lib/stripe/services/checkout/session_service.rb', line 1825

def update_line_items
  @update_line_items
end

#update_shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.

When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



1831
1832
1833
# File 'lib/stripe/services/checkout/session_service.rb', line 1831

def update_shipping_details
  @update_shipping_details
end