Class: Stripe::Checkout::SessionService::CreateParams::Permissions::Update

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(line_items: nil, shipping_details: nil) ⇒ Update

Returns a new instance of Update.



1704
1705
1706
1707
# File 'lib/stripe/services/checkout/session_service.rb', line 1704

def initialize(line_items: nil, shipping_details: nil)
  @line_items = line_items
  @shipping_details = shipping_details
end

Instance Attribute Details

#line_itemsObject

Determines which entity is allowed to update the line items.

Default is ‘client_only`. Stripe Checkout client will automatically update the line items. If set to `server_only`, only your server is allowed to update the line items.

When set to ‘server_only`, you must add the onLineItemsChange event handler when initializing the Stripe Checkout client and manually update the line items from your server using the Stripe API.



1696
1697
1698
# File 'lib/stripe/services/checkout/session_service.rb', line 1696

def line_items
  @line_items
end

#shipping_detailsObject

Determines which entity is allowed to update the shipping details.

Default is ‘client_only`. Stripe Checkout client will automatically update the shipping details. If set to `server_only`, only your server is allowed to update the shipping details.

When set to ‘server_only`, you must add the onShippingDetailsChange event handler when initializing the Stripe Checkout client and manually update the shipping details from your server using the Stripe API.



1702
1703
1704
# File 'lib/stripe/services/checkout/session_service.rb', line 1702

def shipping_details
  @shipping_details
end