Class: Stripe::Checkout::SessionService::CreateParams::SavedPaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay_filters: nil, payment_method_save: nil) ⇒ SavedPaymentMethodOptions

Returns a new instance of SavedPaymentMethodOptions.



1771
1772
1773
1774
# File 'lib/stripe/services/checkout/session_service.rb', line 1771

def initialize(allow_redisplay_filters: nil, payment_method_save: nil)
  @allow_redisplay_filters = allow_redisplay_filters
  @payment_method_save = payment_method_save
end

Instance Attribute Details

#allow_redisplay_filtersObject

Uses the ‘allow_redisplay` value of each saved payment method to filter the set presented to a returning customer. By default, only saved payment methods with ’allow_redisplay: ‘always’ are shown in Checkout.



1767
1768
1769
# File 'lib/stripe/services/checkout/session_service.rb', line 1767

def allow_redisplay_filters
  @allow_redisplay_filters
end

#payment_method_saveObject

Enable customers to choose if they wish to save their payment method for future use. Disabled by default.



1769
1770
1771
# File 'lib/stripe/services/checkout/session_service.rb', line 1769

def payment_method_save
  @payment_method_save
end