Class: Stripe::Checkout::SessionService::CreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



1785
1786
1787
1788
1789
# File 'lib/stripe/services/checkout/session_service.rb', line 1785

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1779
1780
1781
# File 'lib/stripe/services/checkout/session_service.rb', line 1779

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1781
1782
1783
# File 'lib/stripe/services/checkout/session_service.rb', line 1781

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



1783
1784
1785
# File 'lib/stripe/services/checkout/session_service.rb', line 1783

def on_behalf_of
  @on_behalf_of
end