Class: Stripe::Checkout::SessionService::CreateParams::SetupIntentData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::SetupIntentData
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#on_behalf_of ⇒ Object
The Stripe account for which the setup is intended.
Instance Method Summary collapse
-
#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData
constructor
A new instance of SetupIntentData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData
Returns a new instance of SetupIntentData.
1878 1879 1880 1881 1882 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1878 def initialize(description: nil, metadata: nil, on_behalf_of: nil) @description = description @metadata = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1872 1873 1874 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1872 def description @description end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1874 1875 1876 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1874 def @metadata end |
#on_behalf_of ⇒ Object
The Stripe account for which the setup is intended.
1876 1877 1878 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1876 def on_behalf_of @on_behalf_of end |