Class: Stripe::Checkout::SessionService::CreateParams::SetupIntentData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, metadata: nil, on_behalf_of: nil) ⇒ SetupIntentData

Returns a new instance of SetupIntentData.



1832
1833
1834
1835
1836
# File 'lib/stripe/services/checkout/session_service.rb', line 1832

def initialize(description: nil, metadata: nil, on_behalf_of: nil)
  @description = description
  @metadata = 
  @on_behalf_of = on_behalf_of
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1826
1827
1828
# File 'lib/stripe/services/checkout/session_service.rb', line 1826

def description
  @description
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1828
1829
1830
# File 'lib/stripe/services/checkout/session_service.rb', line 1828

def 
  @metadata
end

#on_behalf_ofObject

The Stripe account for which the setup is intended.



1830
1831
1832
# File 'lib/stripe/services/checkout/session_service.rb', line 1830

def on_behalf_of
  @on_behalf_of
end