Class: Stripe::Checkout::SessionService::CreateParams::ShippingOption::ShippingRateData::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



1809
1810
1811
1812
# File 'lib/stripe/services/checkout/session_service.rb', line 1809

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



1805
1806
1807
# File 'lib/stripe/services/checkout/session_service.rb', line 1805

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



1807
1808
1809
# File 'lib/stripe/services/checkout/session_service.rb', line 1807

def tax_behavior
  @tax_behavior
end