Class: Stripe::Checkout::SessionService::CreateParams::ShippingOption::ShippingRateData::FixedAmount::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::ShippingOption::ShippingRateData::FixedAmount::CurrencyOptions
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
Instance Method Summary collapse
-
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
1816 1817 1818 1819 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1816 def initialize(amount: nil, tax_behavior: nil) @amount = amount @tax_behavior = tax_behavior end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
1812 1813 1814 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1812 def amount @amount end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
1814 1815 1816 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1814 def tax_behavior @tax_behavior end |