Class: Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2059
2060
2061
2062
# File 'lib/stripe/services/checkout/session_service.rb', line 2059

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



2055
2056
2057
# File 'lib/stripe/services/checkout/session_service.rb', line 2055

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2057
2058
2059
# File 'lib/stripe/services/checkout/session_service.rb', line 2057

def destination
  @destination
end