Class: Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TransferData
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1988 1989 1990 1991 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1988 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
1984 1985 1986 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1984 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1986 1987 1988 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1986 def destination @destination end |