Class: Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TransferData
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1883 1884 1885 1886 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1883 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
1879 1880 1881 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1879 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1881 1882 1883 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1881 def destination @destination end |