Class: Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1905
1906
1907
1908
# File 'lib/stripe/services/checkout/session_service.rb', line 1905

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1901
1902
1903
# File 'lib/stripe/services/checkout/session_service.rb', line 1901

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1903
1904
1905
# File 'lib/stripe/services/checkout/session_service.rb', line 1903

def destination
  @destination
end