Class: Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TrialSettings::EndBehavior
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::SubscriptionData::TrialSettings::EndBehavior
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#missing_payment_method ⇒ Object
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
Instance Method Summary collapse
-
#initialize(missing_payment_method: nil) ⇒ EndBehavior
constructor
A new instance of EndBehavior.
Methods inherited from RequestParams
Constructor Details
#initialize(missing_payment_method: nil) ⇒ EndBehavior
Returns a new instance of EndBehavior.
2097 2098 2099 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2097 def initialize(missing_payment_method: nil) @missing_payment_method = missing_payment_method end |
Instance Attribute Details
#missing_payment_method ⇒ Object
Indicates how the subscription should change when the trial ends if the user did not provide a payment method.
2095 2096 2097 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2095 def missing_payment_method @missing_payment_method end |