Class: Stripe::Checkout::SessionService::CreateParams::WalletOptions::Link
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::CreateParams::WalletOptions::Link
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#display ⇒ Object
Specifies whether Checkout should display Link as a payment option.
Instance Method Summary collapse
-
#initialize(display: nil) ⇒ Link
constructor
A new instance of Link.
Methods inherited from RequestParams
Constructor Details
#initialize(display: nil) ⇒ Link
Returns a new instance of Link.
1983 1984 1985 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1983 def initialize(display: nil) @display = display end |
Instance Attribute Details
#display ⇒ Object
Specifies whether Checkout should display Link as a payment option. By default, Checkout will display all the supported wallets that the Checkout Session was created with. This is the ‘auto` behavior, and it is the default choice.
1981 1982 1983 |
# File 'lib/stripe/services/checkout/session_service.rb', line 1981 def display @display end |