Class: Stripe::Checkout::SessionService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: CollectedInformation, ShippingOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
# File 'lib/stripe/services/checkout/session_service.rb', line 2479

def initialize(
  collected_information: nil,
  expand: nil,
  metadata: nil,
  shipping_options: nil
)
  @collected_information = collected_information
  @expand = expand
  @metadata = 
  @shipping_options = shipping_options
end

Instance Attribute Details

#collected_informationObject

Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.



2471
2472
2473
# File 'lib/stripe/services/checkout/session_service.rb', line 2471

def collected_information
  @collected_information
end

#expandObject

Specifies which fields in the response should be expanded.



2473
2474
2475
# File 'lib/stripe/services/checkout/session_service.rb', line 2473

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2475
2476
2477
# File 'lib/stripe/services/checkout/session_service.rb', line 2475

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



2477
2478
2479
# File 'lib/stripe/services/checkout/session_service.rb', line 2477

def shipping_options
  @shipping_options
end