Class: Stripe::Checkout::SessionService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: CollectedInformation, ShippingOption
Instance Attribute Summary collapse
-
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
Instance Method Summary collapse
-
#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2463 2464 2465 2466 2467 2468 2469 2470 2471 2472 2473 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2463 def initialize( collected_information: nil, expand: nil, metadata: nil, shipping_options: nil ) @collected_information = collected_information @expand = @metadata = @shipping_options = end |
Instance Attribute Details
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.
2455 2456 2457 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2455 def collected_information @collected_information end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2457 2458 2459 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2457 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2459 2460 2461 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2459 def @metadata end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
2461 2462 2463 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2461 def @shipping_options end |