Class: Stripe::Checkout::SessionService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: CollectedInformation, ShippingOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
# File 'lib/stripe/services/checkout/session_service.rb', line 2407

def initialize(
  collected_information: nil,
  expand: nil,
  metadata: nil,
  shipping_options: nil
)
  @collected_information = collected_information
  @expand = expand
  @metadata = 
  @shipping_options = shipping_options
end

Instance Attribute Details

#collected_informationObject

Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.



2399
2400
2401
# File 'lib/stripe/services/checkout/session_service.rb', line 2399

def collected_information
  @collected_information
end

#expandObject

Specifies which fields in the response should be expanded.



2401
2402
2403
# File 'lib/stripe/services/checkout/session_service.rb', line 2401

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2403
2404
2405
# File 'lib/stripe/services/checkout/session_service.rb', line 2403

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



2405
2406
2407
# File 'lib/stripe/services/checkout/session_service.rb', line 2405

def shipping_options
  @shipping_options
end