Class: Stripe::Checkout::SessionService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: CollectedInformation, ShippingOption
Instance Attribute Summary collapse
-
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
Instance Method Summary collapse
-
#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collected_information: nil, expand: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2386 2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2386 def initialize( collected_information: nil, expand: nil, metadata: nil, shipping_options: nil ) @collected_information = collected_information @expand = @metadata = @shipping_options = end |
Instance Attribute Details
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
2378 2379 2380 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2378 def collected_information @collected_information end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2380 2381 2382 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2380 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2382 2383 2384 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2382 def @metadata end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
2384 2385 2386 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2384 def @shipping_options end |