Class: Stripe::Checkout::SessionService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: CollectedInformation, LineItem, ShippingOption
Instance Attribute Summary collapse
-
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
Instance Method Summary collapse
-
#initialize(collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2554 def initialize( collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil ) @collected_information = collected_information @expand = @line_items = line_items @metadata = @shipping_options = end |
Instance Attribute Details
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
2532 2533 2534 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2532 def collected_information @collected_information end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2534 2535 2536 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2534 def @expand end |
#line_items ⇒ Object
A list of items the customer is purchasing.
When updating line items, you must retransmit the entire array of line items.
To retain an existing line item, specify its ‘id`.
To update an existing line item, specify its ‘id` along with the new values of the fields to update.
To add a new line item, specify a ‘price` and `quantity`.
To remove an existing line item, omit the line item’s ID from the retransmitted array.
To reorder a line item, specify it at the desired position in the retransmitted array.
2548 2549 2550 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2548 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2550 2551 2552 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2550 def @metadata end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
2552 2553 2554 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2552 def @shipping_options end |