Class: Stripe::Checkout::SessionService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: CollectedInformation, LineItem, ShippingOption

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collected_information: nil, expand: nil, line_items: nil, metadata: nil, shipping_options: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
# File 'lib/stripe/services/checkout/session_service.rb', line 2455

def initialize(
  collected_information: nil,
  expand: nil,
  line_items: nil,
  metadata: nil,
  shipping_options: nil
)
  @collected_information = collected_information
  @expand = expand
  @line_items = line_items
  @metadata = 
  @shipping_options = shipping_options
end

Instance Attribute Details

#collected_informationObject

Information about the customer collected within the Checkout Session.



2433
2434
2435
# File 'lib/stripe/services/checkout/session_service.rb', line 2433

def collected_information
  @collected_information
end

#expandObject

Specifies which fields in the response should be expanded.



2435
2436
2437
# File 'lib/stripe/services/checkout/session_service.rb', line 2435

def expand
  @expand
end

#line_itemsObject

A list of items the customer is purchasing.

When updating line items, you must retransmit the entire array of line items.

To retain an existing line item, specify its ‘id`.

To update an existing line item, specify its ‘id` along with the new values of the fields to update.

To add a new line item, specify a ‘price` and `quantity`. We don’t currently support recurring prices.

To remove an existing line item, omit the line item’s ID from the retransmitted array.

To reorder a line item, specify it at the desired position in the retransmitted array.



2449
2450
2451
# File 'lib/stripe/services/checkout/session_service.rb', line 2449

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2451
2452
2453
# File 'lib/stripe/services/checkout/session_service.rb', line 2451

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



2453
2454
2455
# File 'lib/stripe/services/checkout/session_service.rb', line 2453

def shipping_options
  @shipping_options
end