Class: Stripe::Checkout::SessionService::UpdateParams::Discount::CouponData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_off: nil, currency: nil, duration: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CouponData

Returns a new instance of CouponData.



2499
2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
# File 'lib/stripe/services/checkout/session_service.rb', line 2499

def initialize(
  amount_off: nil,
  currency: nil,
  duration: nil,
  metadata: nil,
  name: nil,
  percent_off: nil
)
  @amount_off = amount_off
  @currency = currency
  @duration = duration
  @metadata = 
  @name = name
  @percent_off = percent_off
end

Instance Attribute Details

#amount_offObject

A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).



2487
2488
2489
# File 'lib/stripe/services/checkout/session_service.rb', line 2487

def amount_off
  @amount_off
end

#currencyObject

Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).



2489
2490
2491
# File 'lib/stripe/services/checkout/session_service.rb', line 2489

def currency
  @currency
end

#durationObject

Specifies how long the discount will be in effect if used on a subscription. Defaults to ‘once`.



2491
2492
2493
# File 'lib/stripe/services/checkout/session_service.rb', line 2491

def duration
  @duration
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2493
2494
2495
# File 'lib/stripe/services/checkout/session_service.rb', line 2493

def 
  @metadata
end

#nameObject

Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the ‘id` is shown if `name` is not set.



2495
2496
2497
# File 'lib/stripe/services/checkout/session_service.rb', line 2495

def name
  @name
end

#percent_offObject

A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).



2497
2498
2499
# File 'lib/stripe/services/checkout/session_service.rb', line 2497

def percent_off
  @percent_off
end