Class: Stripe::Checkout::SessionService::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams::LineItem
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
-
#id ⇒ Object
ID of an existing line item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices).
-
#quantity ⇒ Object
The quantity of the line item being purchased.
-
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 2444 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2430 def initialize( adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil ) @adjustable_quantity = adjustable_quantity @id = id @metadata = @price = price @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
2418 2419 2420 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2418 def adjustable_quantity @adjustable_quantity end |
#id ⇒ Object
ID of an existing line item.
2420 2421 2422 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2420 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2422 2423 2424 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2422 def @metadata end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices).
2424 2425 2426 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2424 def price @price end |
#quantity ⇒ Object
The quantity of the line item being purchased.
2426 2427 2428 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2426 def quantity @quantity end |
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
2428 2429 2430 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2428 def tax_rates @tax_rates end |