Class: Stripe::Checkout::SessionService::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
2420
2421
2422
2423
# File 'lib/stripe/services/checkout/session_service.rb', line 2409

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



2397
2398
2399
# File 'lib/stripe/services/checkout/session_service.rb', line 2397

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



2399
2400
2401
# File 'lib/stripe/services/checkout/session_service.rb', line 2399

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2401
2402
2403
# File 'lib/stripe/services/checkout/session_service.rb', line 2401

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices).



2403
2404
2405
# File 'lib/stripe/services/checkout/session_service.rb', line 2403

def price
  @price
end

#quantityObject

The quantity of the line item being purchased.



2405
2406
2407
# File 'lib/stripe/services/checkout/session_service.rb', line 2405

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



2407
2408
2409
# File 'lib/stripe/services/checkout/session_service.rb', line 2407

def tax_rates
  @tax_rates
end