Class: Stripe::Checkout::SessionService::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



2310
2311
2312
2313
2314
2315
2316
2317
2318
2319
2320
2321
2322
2323
2324
# File 'lib/stripe/services/checkout/session_service.rb', line 2310

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



2298
2299
2300
# File 'lib/stripe/services/checkout/session_service.rb', line 2298

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



2300
2301
2302
# File 'lib/stripe/services/checkout/session_service.rb', line 2300

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2302
2303
2304
# File 'lib/stripe/services/checkout/session_service.rb', line 2302

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices).



2304
2305
2306
# File 'lib/stripe/services/checkout/session_service.rb', line 2304

def price
  @price
end

#quantityObject

The quantity of the line item being purchased.



2306
2307
2308
# File 'lib/stripe/services/checkout/session_service.rb', line 2306

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



2308
2309
2310
# File 'lib/stripe/services/checkout/session_service.rb', line 2308

def tax_rates
  @tax_rates
end