Class: Stripe::Checkout::SessionService::UpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: AdjustableQuantity

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



2564
2565
2566
2567
2568
2569
2570
2571
2572
2573
2574
2575
2576
2577
2578
# File 'lib/stripe/services/checkout/session_service.rb', line 2564

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



2547
2548
2549
# File 'lib/stripe/services/checkout/session_service.rb', line 2547

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



2550
2551
2552
# File 'lib/stripe/services/checkout/session_service.rb', line 2550

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2553
2554
2555
# File 'lib/stripe/services/checkout/session_service.rb', line 2553

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices).



2556
2557
2558
# File 'lib/stripe/services/checkout/session_service.rb', line 2556

def price
  @price
end

#quantityObject

The quantity of the line item being purchased.



2559
2560
2561
# File 'lib/stripe/services/checkout/session_service.rb', line 2559

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



2562
2563
2564
# File 'lib/stripe/services/checkout/session_service.rb', line 2562

def tax_rates
  @tax_rates
end