Class: Stripe::Checkout::SessionService::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams::LineItem
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: AdjustableQuantity
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
-
#id ⇒ Object
ID of an existing line item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices).
-
#quantity ⇒ Object
The quantity of the line item being purchased.
-
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2317 def initialize( adjustable_quantity: nil, id: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil ) @adjustable_quantity = adjustable_quantity @id = id @metadata = @price = price @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
2305 2306 2307 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2305 def adjustable_quantity @adjustable_quantity end |
#id ⇒ Object
ID of an existing line item.
2307 2308 2309 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2307 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2309 2310 2311 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2309 def @metadata end |
#price ⇒ Object
The ID of the [Price](stripe.com/docs/api/prices).
2311 2312 2313 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2311 def price @price end |
#quantity ⇒ Object
The quantity of the line item being purchased.
2313 2314 2315 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2313 def quantity @quantity end |
#tax_rates ⇒ Object
The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.
2315 2316 2317 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2315 def tax_rates @tax_rates end |