Class: Stripe::Checkout::SessionService::UpdateParams::LineItem::AdjustableQuantity

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity

Returns a new instance of AdjustableQuantity.



2540
2541
2542
2543
2544
# File 'lib/stripe/services/checkout/session_service.rb', line 2540

def initialize(enabled: nil, maximum: nil, minimum: nil)
  @enabled = enabled
  @maximum = maximum
  @minimum = minimum
end

Instance Attribute Details

#enabledObject

Set to true if the quantity can be adjusted to any positive integer. Setting to false will remove any previously specified constraints on quantity.



2532
2533
2534
# File 'lib/stripe/services/checkout/session_service.rb', line 2532

def enabled
  @enabled
end

#maximumObject

The maximum quantity the customer can purchase for the Checkout Session. By default this value is 99. You can specify a value up to 999999.



2535
2536
2537
# File 'lib/stripe/services/checkout/session_service.rb', line 2535

def maximum
  @maximum
end

#minimumObject

The minimum quantity the customer must purchase for the Checkout Session. By default this value is 0.



2538
2539
2540
# File 'lib/stripe/services/checkout/session_service.rb', line 2538

def minimum
  @minimum
end