Class: Stripe::Checkout::SessionService::UpdateParams::LineItem::AdjustableQuantity
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams::LineItem::AdjustableQuantity
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any positive integer.
-
#maximum ⇒ Object
The maximum quantity the customer can purchase for the Checkout Session.
-
#minimum ⇒ Object
The minimum quantity the customer must purchase for the Checkout Session.
Instance Method Summary collapse
-
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
constructor
A new instance of AdjustableQuantity.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, maximum: nil, minimum: nil) ⇒ AdjustableQuantity
Returns a new instance of AdjustableQuantity.
2291 2292 2293 2294 2295 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2291 def initialize(enabled: nil, maximum: nil, minimum: nil) @enabled = enabled @maximum = maximum @minimum = minimum end |
Instance Attribute Details
#enabled ⇒ Object
Set to true if the quantity can be adjusted to any positive integer. Setting to false will remove any previously specified constraints on quantity.
2285 2286 2287 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2285 def enabled @enabled end |
#maximum ⇒ Object
The maximum quantity the customer can purchase for the Checkout Session. By default this value is 99. You can specify a value up to 999999.
2287 2288 2289 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2287 def maximum @maximum end |
#minimum ⇒ Object
The minimum quantity the customer must purchase for the Checkout Session. By default this value is 0.
2289 2290 2291 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2289 def minimum @minimum end |