Class: Stripe::Checkout::SessionService::UpdateParams::LineItem::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams::LineItem::PriceData::ProductData
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
2555 2556 2557 2558 2559 2560 2561 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2555 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
2545 2546 2547 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2545 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
2547 2548 2549 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2547 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2549 2550 2551 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2549 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
2551 2552 2553 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2551 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
2553 2554 2555 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2553 def tax_code @tax_code end |