Class: Stripe::Checkout::SessionService::UpdateParams::LineItem::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



2435
2436
2437
2438
2439
2440
2441
# File 'lib/stripe/services/checkout/session_service.rb', line 2435

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



2425
2426
2427
# File 'lib/stripe/services/checkout/session_service.rb', line 2425

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



2427
2428
2429
# File 'lib/stripe/services/checkout/session_service.rb', line 2427

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2429
2430
2431
# File 'lib/stripe/services/checkout/session_service.rb', line 2429

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



2431
2432
2433
# File 'lib/stripe/services/checkout/session_service.rb', line 2431

def name
  @name
end

#tax_codeObject



2433
2434
2435
# File 'lib/stripe/services/checkout/session_service.rb', line 2433

def tax_code
  @tax_code
end