Class: Stripe::Checkout::SessionService::UpdateParams::ShippingOption
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams::ShippingOption
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: ShippingRateData
Instance Attribute Summary collapse
-
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
-
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
Instance Method Summary collapse
-
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
constructor
A new instance of ShippingOption.
Methods inherited from RequestParams
Constructor Details
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
Returns a new instance of ShippingOption.
2674 2675 2676 2677 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2674 def initialize(shipping_rate: nil, shipping_rate_data: nil) @shipping_rate = shipping_rate @shipping_rate_data = shipping_rate_data end |
Instance Attribute Details
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
2670 2671 2672 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2670 def shipping_rate @shipping_rate end |
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
2672 2673 2674 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2672 def shipping_rate_data @shipping_rate_data end |