Class: Stripe::Checkout::SessionService::UpdateParams::ShippingOption

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: ShippingRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption

Returns a new instance of ShippingOption.



2622
2623
2624
2625
# File 'lib/stripe/services/checkout/session_service.rb', line 2622

def initialize(shipping_rate: nil, shipping_rate_data: nil)
  @shipping_rate = shipping_rate
  @shipping_rate_data = shipping_rate_data
end

Instance Attribute Details

#shipping_rateObject

The ID of the Shipping Rate to use for this shipping option.



2618
2619
2620
# File 'lib/stripe/services/checkout/session_service.rb', line 2618

def shipping_rate
  @shipping_rate
end

#shipping_rate_dataObject

Parameters to be passed to Shipping Rate creation for this shipping option.



2620
2621
2622
# File 'lib/stripe/services/checkout/session_service.rb', line 2620

def shipping_rate_data
  @shipping_rate_data
end