Class: Stripe::Checkout::SessionService::UpdateParams::ShippingOption

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Defined Under Namespace

Classes: ShippingRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption

Returns a new instance of ShippingOption.



2447
2448
2449
2450
# File 'lib/stripe/services/checkout/session_service.rb', line 2447

def initialize(shipping_rate: nil, shipping_rate_data: nil)
  @shipping_rate = shipping_rate
  @shipping_rate_data = shipping_rate_data
end

Instance Attribute Details

#shipping_rateObject

The ID of the Shipping Rate to use for this shipping option.



2443
2444
2445
# File 'lib/stripe/services/checkout/session_service.rb', line 2443

def shipping_rate
  @shipping_rate
end

#shipping_rate_dataObject

Parameters to be passed to Shipping Rate creation for this shipping option.



2445
2446
2447
# File 'lib/stripe/services/checkout/session_service.rb', line 2445

def shipping_rate_data
  @shipping_rate_data
end