Class: Stripe::Checkout::SessionService::UpdateParams::ShippingOption
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams::ShippingOption
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Defined Under Namespace
Classes: ShippingRateData
Instance Attribute Summary collapse
-
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
-
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
Instance Method Summary collapse
-
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
constructor
A new instance of ShippingOption.
Methods inherited from RequestParams
Constructor Details
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
Returns a new instance of ShippingOption.
2434 2435 2436 2437 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2434 def initialize(shipping_rate: nil, shipping_rate_data: nil) @shipping_rate = shipping_rate @shipping_rate_data = shipping_rate_data end |
Instance Attribute Details
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
2430 2431 2432 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2430 def shipping_rate @shipping_rate end |
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
2432 2433 2434 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2432 def shipping_rate_data @shipping_rate_data end |