Class: Stripe::Checkout::SessionService::UpdateParams::SubscriptionData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionService::UpdateParams::SubscriptionData
- Defined in:
- lib/stripe/services/checkout/session_service.rb
Instance Attribute Summary collapse
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time.
-
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time.
Instance Method Summary collapse
-
#initialize(trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData
constructor
A new instance of SubscriptionData.
Methods inherited from RequestParams
Constructor Details
#initialize(trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData
Returns a new instance of SubscriptionData.
2915 2916 2917 2918 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2915 def initialize(trial_end: nil, trial_period_days: nil) @trial_end = trial_end @trial_period_days = trial_period_days end |
Instance Attribute Details
#trial_end ⇒ Object
Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.
2911 2912 2913 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2911 def trial_end @trial_end end |
#trial_period_days ⇒ Object
Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.
2913 2914 2915 |
# File 'lib/stripe/services/checkout/session_service.rb', line 2913 def trial_period_days @trial_period_days end |