Class: Stripe::Checkout::SessionService::UpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/checkout/session_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



2754
2755
2756
2757
# File 'lib/stripe/services/checkout/session_service.rb', line 2754

def initialize(trial_end: nil, trial_period_days: nil)
  @trial_end = trial_end
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.



2750
2751
2752
# File 'lib/stripe/services/checkout/session_service.rb', line 2750

def trial_end
  @trial_end
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



2752
2753
2754
# File 'lib/stripe/services/checkout/session_service.rb', line 2752

def trial_period_days
  @trial_period_days
end