Class: Stripe::Checkout::SessionUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/checkout/session_update_params.rb

Defined Under Namespace

Classes: AutomaticTax, CollectedInformation, Discount, InvoiceCreation, LineItem, ShippingOption, SubscriptionData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(automatic_tax: nil, collected_information: nil, discounts: nil, expand: nil, invoice_creation: nil, line_items: nil, metadata: nil, shipping_options: nil, subscription_data: nil) ⇒ SessionUpdateParams

Returns a new instance of SessionUpdateParams.



488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/stripe/params/checkout/session_update_params.rb', line 488

def initialize(
  automatic_tax: nil,
  collected_information: nil,
  discounts: nil,
  expand: nil,
  invoice_creation: nil,
  line_items: nil,
  metadata: nil,
  shipping_options: nil,
  subscription_data: nil
)
  @automatic_tax = automatic_tax
  @collected_information = collected_information
  @discounts = discounts
  @expand = expand
  @invoice_creation = invoice_creation
  @line_items = line_items
  @metadata = 
  @shipping_options = shipping_options
  @subscription_data = subscription_data
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.



458
459
460
# File 'lib/stripe/params/checkout/session_update_params.rb', line 458

def automatic_tax
  @automatic_tax
end

#collected_informationObject

Information about the customer collected within the Checkout Session. Can only be set when updating embedded or custom sessions.



460
461
462
# File 'lib/stripe/params/checkout/session_update_params.rb', line 460

def collected_information
  @collected_information
end

#discountsObject

List of coupons and promotion codes attached to the Checkout Session.



462
463
464
# File 'lib/stripe/params/checkout/session_update_params.rb', line 462

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



464
465
466
# File 'lib/stripe/params/checkout/session_update_params.rb', line 464

def expand
  @expand
end

#invoice_creationObject

Generate a post-purchase Invoice for one-time payments.



466
467
468
# File 'lib/stripe/params/checkout/session_update_params.rb', line 466

def invoice_creation
  @invoice_creation
end

#line_itemsObject

A list of items the customer is purchasing.

When updating line items, you must retransmit the entire array of line items.

To retain an existing line item, specify its id.

To update an existing line item, specify its id along with the new values of the fields to update.

To add a new line item, specify one of price or price_data and quantity.

To remove an existing line item, omit the line item's ID from the retransmitted array.

To reorder a line item, specify it at the desired position in the retransmitted array.



480
481
482
# File 'lib/stripe/params/checkout/session_update_params.rb', line 480

def line_items
  @line_items
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.



482
483
484
# File 'lib/stripe/params/checkout/session_update_params.rb', line 482

def 
  @metadata
end

#shipping_optionsObject

The shipping rate options to apply to this Session. Up to a maximum of 5.



484
485
486
# File 'lib/stripe/params/checkout/session_update_params.rb', line 484

def shipping_options
  @shipping_options
end

#subscription_dataObject

A subset of parameters to be passed to subscription creation for Checkout Sessions in subscription mode.



486
487
488
# File 'lib/stripe/params/checkout/session_update_params.rb', line 486

def subscription_data
  @subscription_data
end

Class Method Details

.field_encodingsObject



510
511
512
513
514
515
516
517
518
519
520
# File 'lib/stripe/params/checkout/session_update_params.rb', line 510

def self.field_encodings
  @field_encodings = {
    line_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
  }
end