Class: Stripe::Checkout::SessionUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionUpdateParams
- Defined in:
- lib/stripe/params/checkout/session_update_params.rb
Defined Under Namespace
Classes: AutomaticTax, CollectedInformation, Discount, InvoiceCreation, LineItem, ShippingOption, SubscriptionData
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
-
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session.
-
#discounts ⇒ Object
List of coupons and promotion codes attached to the Checkout Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
-
#line_items ⇒ Object
A list of items the customer is purchasing.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#shipping_options ⇒ Object
The shipping rate options to apply to this Session.
-
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, collected_information: nil, discounts: nil, expand: nil, invoice_creation: nil, line_items: nil, metadata: nil, shipping_options: nil, subscription_data: nil) ⇒ SessionUpdateParams
constructor
A new instance of SessionUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, collected_information: nil, discounts: nil, expand: nil, invoice_creation: nil, line_items: nil, metadata: nil, shipping_options: nil, subscription_data: nil) ⇒ SessionUpdateParams
Returns a new instance of SessionUpdateParams.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 458 def initialize( automatic_tax: nil, collected_information: nil, discounts: nil, expand: nil, invoice_creation: nil, line_items: nil, metadata: nil, shipping_options: nil, subscription_data: nil ) @automatic_tax = automatic_tax @collected_information = collected_information @discounts = discounts @expand = @invoice_creation = invoice_creation @line_items = line_items @metadata = @shipping_options = @subscription_data = subscription_data end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this session and resulting payments, invoices, and subscriptions.
428 429 430 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 428 def automatic_tax @automatic_tax end |
#collected_information ⇒ Object
Information about the customer collected within the Checkout Session. Can only be set when updating ‘embedded` or `custom` sessions.
430 431 432 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 430 def collected_information @collected_information end |
#discounts ⇒ Object
List of coupons and promotion codes attached to the Checkout Session.
432 433 434 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 432 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
434 435 436 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 434 def @expand end |
#invoice_creation ⇒ Object
Generate a post-purchase Invoice for one-time payments.
436 437 438 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 436 def invoice_creation @invoice_creation end |
#line_items ⇒ Object
A list of items the customer is purchasing.
When updating line items, you must retransmit the entire array of line items.
To retain an existing line item, specify its ‘id`.
To update an existing line item, specify its ‘id` along with the new values of the fields to update.
To add a new line item, specify one of ‘price` or `price_data` and `quantity`.
To remove an existing line item, omit the line item’s ID from the retransmitted array.
To reorder a line item, specify it at the desired position in the retransmitted array.
450 451 452 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 450 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
452 453 454 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 452 def @metadata end |
#shipping_options ⇒ Object
The shipping rate options to apply to this Session. Up to a maximum of 5.
454 455 456 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 454 def @shipping_options end |
#subscription_data ⇒ Object
A subset of parameters to be passed to subscription creation for Checkout Sessions in ‘subscription` mode.
456 457 458 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 456 def subscription_data @subscription_data end |