Class: Stripe::Checkout::SessionUpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionUpdateParams::LineItem
- Defined in:
- lib/stripe/params/checkout/session_update_params.rb
Defined Under Namespace
Classes: AdjustableQuantity, PriceData
Instance Attribute Summary collapse
-
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
-
#id ⇒ Object
ID of an existing line item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the [Price](docs.stripe.com/api/prices).
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
The quantity of the line item being purchased.
-
#tax_rates ⇒ Object
The [tax rates](docs.stripe.com/api/tax_rates) which apply to this line item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 273 def initialize( adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @adjustable_quantity = adjustable_quantity @id = id @metadata = @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#adjustable_quantity ⇒ Object
When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.
259 260 261 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 259 def adjustable_quantity @adjustable_quantity end |
#id ⇒ Object
ID of an existing line item.
261 262 263 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 261 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
263 264 265 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 263 def @metadata end |
#price ⇒ Object
The ID of the [Price](docs.stripe.com/api/prices). One of ‘price` or `price_data` is required when creating a new line item.
265 266 267 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 265 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required when creating a new line item.
267 268 269 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 267 def price_data @price_data end |
#quantity ⇒ Object
The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.
269 270 271 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 269 def quantity @quantity end |
#tax_rates ⇒ Object
The [tax rates](docs.stripe.com/api/tax_rates) which apply to this line item.
271 272 273 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 271 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
291 292 293 294 295 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 291 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |