Class: Stripe::Checkout::SessionUpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_update_params.rb

Defined Under Namespace

Classes: AdjustableQuantity, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/stripe/params/checkout/session_update_params.rb', line 168

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



154
155
156
# File 'lib/stripe/params/checkout/session_update_params.rb', line 154

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



156
157
158
# File 'lib/stripe/params/checkout/session_update_params.rb', line 156

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



158
159
160
# File 'lib/stripe/params/checkout/session_update_params.rb', line 158

def 
  @metadata
end

#priceObject

The ID of the [Price](docs.stripe.com/api/prices). One of ‘price` or `price_data` is required when creating a new line item.



160
161
162
# File 'lib/stripe/params/checkout/session_update_params.rb', line 160

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required when creating a new line item.



162
163
164
# File 'lib/stripe/params/checkout/session_update_params.rb', line 162

def price_data
  @price_data
end

#quantityObject

The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.



164
165
166
# File 'lib/stripe/params/checkout/session_update_params.rb', line 164

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](docs.stripe.com/api/tax_rates) which apply to this line item.



166
167
168
# File 'lib/stripe/params/checkout/session_update_params.rb', line 166

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



186
187
188
189
190
# File 'lib/stripe/params/checkout/session_update_params.rb', line 186

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end