Class: Stripe::Checkout::SessionUpdateParams::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_update_params.rb

Defined Under Namespace

Classes: AdjustableQuantity, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(adjustable_quantity: nil, id: nil, metadata: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/stripe/params/checkout/session_update_params.rb', line 254

def initialize(
  adjustable_quantity: nil,
  id: nil,
  metadata: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @adjustable_quantity = adjustable_quantity
  @id = id
  @metadata = 
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#adjustable_quantityObject

When set, provides configuration for this item’s quantity to be adjusted by the customer during Checkout.



240
241
242
# File 'lib/stripe/params/checkout/session_update_params.rb', line 240

def adjustable_quantity
  @adjustable_quantity
end

#idObject

ID of an existing line item.



242
243
244
# File 'lib/stripe/params/checkout/session_update_params.rb', line 242

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



244
245
246
# File 'lib/stripe/params/checkout/session_update_params.rb', line 244

def 
  @metadata
end

#priceObject

The ID of the [Price](stripe.com/docs/api/prices). One of ‘price` or `price_data` is required when creating a new line item.



246
247
248
# File 'lib/stripe/params/checkout/session_update_params.rb', line 246

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required when creating a new line item.



248
249
250
# File 'lib/stripe/params/checkout/session_update_params.rb', line 248

def price_data
  @price_data
end

#quantityObject

The quantity of the line item being purchased. Quantity should not be defined when ‘recurring.usage_type=metered`.



250
251
252
# File 'lib/stripe/params/checkout/session_update_params.rb', line 250

def quantity
  @quantity
end

#tax_ratesObject

The [tax rates](stripe.com/docs/api/tax_rates) which apply to this line item.



252
253
254
# File 'lib/stripe/params/checkout/session_update_params.rb', line 252

def tax_rates
  @tax_rates
end