Class: Stripe::Checkout::SessionUpdateParams::LineItem::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionUpdateParams::LineItem::PriceData::ProductData
- Defined in:
- lib/stripe/params/checkout/session_update_params.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#unit_label ⇒ Object
A label that represents units of this product.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil) ⇒ ProductData
Returns a new instance of ProductData.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 178 def initialize( description: nil, images: nil, metadata: nil, name: nil, tax_code: nil, unit_label: nil ) @description = description @images = images @metadata = @name = name @tax_code = tax_code @unit_label = unit_label end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
166 167 168 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 166 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
168 169 170 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 168 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
170 171 172 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 170 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
172 173 174 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 172 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
174 175 176 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 174 def tax_code @tax_code end |
#unit_label ⇒ Object
A label that represents units of this product. When set, this will be included in customers’ receipts, invoices, Checkout, and the customer portal.
176 177 178 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 176 def unit_label @unit_label end |