Class: Stripe::Checkout::SessionUpdateParams::ShippingOption
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Checkout::SessionUpdateParams::ShippingOption
- Defined in:
- lib/stripe/params/checkout/session_update_params.rb
Defined Under Namespace
Classes: ShippingRateData
Instance Attribute Summary collapse
-
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
-
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
Instance Method Summary collapse
-
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
constructor
A new instance of ShippingOption.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(shipping_rate: nil, shipping_rate_data: nil) ⇒ ShippingOption
Returns a new instance of ShippingOption.
398 399 400 401 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 398 def initialize(shipping_rate: nil, shipping_rate_data: nil) @shipping_rate = shipping_rate @shipping_rate_data = shipping_rate_data end |
Instance Attribute Details
#shipping_rate ⇒ Object
The ID of the Shipping Rate to use for this shipping option.
394 395 396 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 394 def shipping_rate @shipping_rate end |
#shipping_rate_data ⇒ Object
Parameters to be passed to Shipping Rate creation for this shipping option.
396 397 398 |
# File 'lib/stripe/params/checkout/session_update_params.rb', line 396 def shipping_rate_data @shipping_rate_data end |