Class: Stripe::Checkout::SessionUpdateParams::SubscriptionData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/checkout/session_update_params.rb

Defined Under Namespace

Classes: InvoiceSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(invoice_settings: nil, trial_end: nil, trial_period_days: nil) ⇒ SubscriptionData

Returns a new instance of SubscriptionData.



406
407
408
409
410
# File 'lib/stripe/params/checkout/session_update_params.rb', line 406

def initialize(invoice_settings: nil, trial_end: nil, trial_period_days: nil)
  @invoice_settings = invoice_settings
  @trial_end = trial_end
  @trial_period_days = trial_period_days
end

Instance Attribute Details

#invoice_settingsObject

All invoices will be billed using the specified settings.



400
401
402
# File 'lib/stripe/params/checkout/session_update_params.rb', line 400

def invoice_settings
  @invoice_settings
end

#trial_endObject

Unix timestamp representing the end of the trial period the customer will get before being charged for the first time. Has to be at least 48 hours in the future.



402
403
404
# File 'lib/stripe/params/checkout/session_update_params.rb', line 402

def trial_end
  @trial_end
end

#trial_period_daysObject

Integer representing the number of trial period days before the customer is charged for the first time. Has to be at least 1.



404
405
406
# File 'lib/stripe/params/checkout/session_update_params.rb', line 404

def trial_period_days
  @trial_period_days
end