Class: Stripe::Climate::Order
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Climate::Order
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/climate/order.rb
Overview
Orders represent your intent to purchase a particular Climate product. When you create an order, the payment is deducted from your merchant balance.
Defined Under Namespace
Classes: Beneficiary, CancelParams, CreateParams, DeliveryDetail, ListParams, RetrieveParams, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"climate.order"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_fees ⇒ Object
readonly
Total amount of [Frontier](frontierclimate.com/)‘s service fees in the currency’s smallest unit.
-
#amount_subtotal ⇒ Object
readonly
Total amount of the carbon removal in the currency’s smallest unit.
-
#amount_total ⇒ Object
readonly
Total amount of the order including fees in the currency’s smallest unit.
-
#beneficiary ⇒ Object
readonly
Attribute for field beneficiary.
-
#canceled_at ⇒ Object
readonly
Time at which the order was canceled.
-
#cancellation_reason ⇒ Object
readonly
Reason for the cancellation of this order.
-
#certificate ⇒ Object
readonly
For delivered orders, a URL to a delivery certificate for the order.
-
#confirmed_at ⇒ Object
readonly
Time at which the order was confirmed.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase, representing the currency for this order.
-
#delayed_at ⇒ Object
readonly
Time at which the order’s expected_delivery_year was delayed.
-
#delivered_at ⇒ Object
readonly
Time at which the order was delivered.
-
#delivery_details ⇒ Object
readonly
Details about the delivery of carbon removal for this order.
-
#expected_delivery_year ⇒ Object
readonly
The year this order is expected to be delivered.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#metric_tons ⇒ Object
readonly
Quantity of carbon removal that is included in this order.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#product ⇒ Object
readonly
Unique ID for the Climate ‘Product` this order is purchasing.
-
#product_substituted_at ⇒ Object
readonly
Time at which the order’s product was substituted for a different product.
-
#status ⇒ Object
readonly
The current status of this order.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel(order, params = {}, opts = {}) ⇒ Object
Cancels a Climate order.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a Climate order object for a given Climate product.
-
.list(params = {}, opts = {}) ⇒ Object
Lists all Climate order objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified order by setting the values of the parameters passed.
Instance Method Summary collapse
-
#cancel(params = {}, opts = {}) ⇒ Object
Cancels a Climate order.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_fees ⇒ Object (readonly)
Total amount of [Frontier](frontierclimate.com/)‘s service fees in the currency’s smallest unit.
150 151 152 |
# File 'lib/stripe/resources/climate/order.rb', line 150 def amount_fees @amount_fees end |
#amount_subtotal ⇒ Object (readonly)
Total amount of the carbon removal in the currency’s smallest unit.
152 153 154 |
# File 'lib/stripe/resources/climate/order.rb', line 152 def amount_subtotal @amount_subtotal end |
#amount_total ⇒ Object (readonly)
Total amount of the order including fees in the currency’s smallest unit.
154 155 156 |
# File 'lib/stripe/resources/climate/order.rb', line 154 def amount_total @amount_total end |
#beneficiary ⇒ Object (readonly)
Attribute for field beneficiary
156 157 158 |
# File 'lib/stripe/resources/climate/order.rb', line 156 def beneficiary @beneficiary end |
#canceled_at ⇒ Object (readonly)
Time at which the order was canceled. Measured in seconds since the Unix epoch.
158 159 160 |
# File 'lib/stripe/resources/climate/order.rb', line 158 def canceled_at @canceled_at end |
#cancellation_reason ⇒ Object (readonly)
Reason for the cancellation of this order.
160 161 162 |
# File 'lib/stripe/resources/climate/order.rb', line 160 def cancellation_reason @cancellation_reason end |
#certificate ⇒ Object (readonly)
For delivered orders, a URL to a delivery certificate for the order.
162 163 164 |
# File 'lib/stripe/resources/climate/order.rb', line 162 def certificate @certificate end |
#confirmed_at ⇒ Object (readonly)
Time at which the order was confirmed. Measured in seconds since the Unix epoch.
164 165 166 |
# File 'lib/stripe/resources/climate/order.rb', line 164 def confirmed_at @confirmed_at end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
166 167 168 |
# File 'lib/stripe/resources/climate/order.rb', line 166 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase, representing the currency for this order.
168 169 170 |
# File 'lib/stripe/resources/climate/order.rb', line 168 def currency @currency end |
#delayed_at ⇒ Object (readonly)
Time at which the order’s expected_delivery_year was delayed. Measured in seconds since the Unix epoch.
170 171 172 |
# File 'lib/stripe/resources/climate/order.rb', line 170 def delayed_at @delayed_at end |
#delivered_at ⇒ Object (readonly)
Time at which the order was delivered. Measured in seconds since the Unix epoch.
172 173 174 |
# File 'lib/stripe/resources/climate/order.rb', line 172 def delivered_at @delivered_at end |
#delivery_details ⇒ Object (readonly)
Details about the delivery of carbon removal for this order.
174 175 176 |
# File 'lib/stripe/resources/climate/order.rb', line 174 def delivery_details @delivery_details end |
#expected_delivery_year ⇒ Object (readonly)
The year this order is expected to be delivered.
176 177 178 |
# File 'lib/stripe/resources/climate/order.rb', line 176 def expected_delivery_year @expected_delivery_year end |
#id ⇒ Object (readonly)
Unique identifier for the object.
178 179 180 |
# File 'lib/stripe/resources/climate/order.rb', line 178 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
180 181 182 |
# File 'lib/stripe/resources/climate/order.rb', line 180 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
182 183 184 |
# File 'lib/stripe/resources/climate/order.rb', line 182 def @metadata end |
#metric_tons ⇒ Object (readonly)
Quantity of carbon removal that is included in this order.
184 185 186 |
# File 'lib/stripe/resources/climate/order.rb', line 184 def metric_tons @metric_tons end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
186 187 188 |
# File 'lib/stripe/resources/climate/order.rb', line 186 def object @object end |
#product ⇒ Object (readonly)
Unique ID for the Climate ‘Product` this order is purchasing.
188 189 190 |
# File 'lib/stripe/resources/climate/order.rb', line 188 def product @product end |
#product_substituted_at ⇒ Object (readonly)
Time at which the order’s product was substituted for a different product. Measured in seconds since the Unix epoch.
190 191 192 |
# File 'lib/stripe/resources/climate/order.rb', line 190 def product_substituted_at @product_substituted_at end |
#status ⇒ Object (readonly)
The current status of this order.
192 193 194 |
# File 'lib/stripe/resources/climate/order.rb', line 192 def status @status end |
Class Method Details
.cancel(order, params = {}, opts = {}) ⇒ Object
Cancels a Climate order. You can cancel an order within 24 hours of creation. Stripe refunds the reservation amount_subtotal, but not the amount_fees for user-triggered cancellations. Frontier might cancel reservations if suppliers fail to deliver. If Frontier cancels the reservation, Stripe provides 90 days advance notice and refunds the amount_total.
211 212 213 214 215 216 217 218 |
# File 'lib/stripe/resources/climate/order.rb', line 211 def self.cancel(order, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/climate/orders/%<order>s/cancel", { order: CGI.escape(order) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a Climate order object for a given Climate product. The order will be processed immediately after creation and payment will be deducted your Stripe balance.
222 223 224 |
# File 'lib/stripe/resources/climate/order.rb', line 222 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/climate/orders", params: params, opts: opts) end |
.list(params = {}, opts = {}) ⇒ Object
Lists all Climate order objects. The orders are returned sorted by creation date, with the most recently created orders appearing first.
228 229 230 |
# File 'lib/stripe/resources/climate/order.rb', line 228 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/climate/orders", params: params, opts: opts) end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/climate/order.rb', line 14 def self.object_name "climate.order" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified order by setting the values of the parameters passed.
233 234 235 236 237 238 239 240 |
# File 'lib/stripe/resources/climate/order.rb', line 233 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/climate/orders/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#cancel(params = {}, opts = {}) ⇒ Object
Cancels a Climate order. You can cancel an order within 24 hours of creation. Stripe refunds the reservation amount_subtotal, but not the amount_fees for user-triggered cancellations. Frontier might cancel reservations if suppliers fail to deliver. If Frontier cancels the reservation, Stripe provides 90 days advance notice and refunds the amount_total.
198 199 200 201 202 203 204 205 |
# File 'lib/stripe/resources/climate/order.rb', line 198 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/climate/orders/%<order>s/cancel", { order: CGI.escape(self["id"]) }), params: params, opts: opts ) end |