Class: Stripe::Climate::Order::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Climate::Order::CreateParams
- Defined in:
- lib/stripe/resources/climate/order.rb
Defined Under Namespace
Classes: Beneficiary
Instance Attribute Summary collapse
-
#amount ⇒ Object
Requested amount of carbon removal units.
-
#beneficiary ⇒ Object
Publicly sharable reference for the end beneficiary of carbon removal.
-
#currency ⇒ Object
Request currency for the order as a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#metric_tons ⇒ Object
Requested number of tons for the order.
-
#product ⇒ Object
Unique identifier of the Climate product.
Instance Method Summary collapse
-
#initialize(amount: nil, beneficiary: nil, currency: nil, expand: nil, metadata: nil, metric_tons: nil, product: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, beneficiary: nil, currency: nil, expand: nil, metadata: nil, metric_tons: nil, product: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/stripe/resources/climate/order.rb', line 107 def initialize( amount: nil, beneficiary: nil, currency: nil, expand: nil, metadata: nil, metric_tons: nil, product: nil ) @amount = amount @beneficiary = beneficiary @currency = currency @expand = @metadata = @metric_tons = metric_tons @product = product end |
Instance Attribute Details
#amount ⇒ Object
Requested amount of carbon removal units. Either this or ‘metric_tons` must be specified.
87 88 89 |
# File 'lib/stripe/resources/climate/order.rb', line 87 def amount @amount end |
#beneficiary ⇒ Object
Publicly sharable reference for the end beneficiary of carbon removal. Assumed to be the Stripe account if not set.
90 91 92 |
# File 'lib/stripe/resources/climate/order.rb', line 90 def beneficiary @beneficiary end |
#currency ⇒ Object
Request currency for the order as a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a supported [settlement currency for your account](stripe.com/docs/currencies). If omitted, the account’s default currency will be used.
93 94 95 |
# File 'lib/stripe/resources/climate/order.rb', line 93 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
96 97 98 |
# File 'lib/stripe/resources/climate/order.rb', line 96 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
99 100 101 |
# File 'lib/stripe/resources/climate/order.rb', line 99 def @metadata end |
#metric_tons ⇒ Object
Requested number of tons for the order. Either this or ‘amount` must be specified.
102 103 104 |
# File 'lib/stripe/resources/climate/order.rb', line 102 def metric_tons @metric_tons end |
#product ⇒ Object
Unique identifier of the Climate product.
105 106 107 |
# File 'lib/stripe/resources/climate/order.rb', line 105 def product @product end |