Class: Stripe::Climate::Product
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Climate::Product
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/climate/product.rb
Overview
A Climate product represents a type of carbon removal unit available for reservation. You can retrieve it to see the current price and availability.
Defined Under Namespace
Classes: CurrentPricesPerMetricTon
Constant Summary collapse
- OBJECT_NAME =
"climate.product"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#current_prices_per_metric_ton ⇒ Object
readonly
Current prices for a metric ton of carbon removal in a currency's smallest unit.
-
#delivery_year ⇒ Object
readonly
The year in which the carbon removal is expected to be delivered.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value
trueif the object exists in live mode or the valuefalseif the object exists in test mode. -
#metric_tons_available ⇒ Object
readonly
The quantity of metric tons available for reservation.
-
#name ⇒ Object
readonly
The Climate product's name.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#suppliers ⇒ Object
readonly
The carbon removal suppliers that fulfill orders for this Climate product.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Lists all available Climate product objects.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
33 34 35 |
# File 'lib/stripe/resources/climate/product.rb', line 33 def created @created end |
#current_prices_per_metric_ton ⇒ Object (readonly)
Current prices for a metric ton of carbon removal in a currency's smallest unit.
35 36 37 |
# File 'lib/stripe/resources/climate/product.rb', line 35 def current_prices_per_metric_ton @current_prices_per_metric_ton end |
#delivery_year ⇒ Object (readonly)
The year in which the carbon removal is expected to be delivered. If the year is in the past, this represents spot inventory with guaranteed delivery.
37 38 39 |
# File 'lib/stripe/resources/climate/product.rb', line 37 def delivery_year @delivery_year end |
#id ⇒ Object (readonly)
Unique identifier for the object. For convenience, Climate product IDs are human-readable strings
that start with climsku_. See carbon removal inventory
for a list of available carbon removal products.
41 42 43 |
# File 'lib/stripe/resources/climate/product.rb', line 41 def id @id end |
#livemode ⇒ Object (readonly)
Has the value true if the object exists in live mode or the value false if the object exists in test mode.
43 44 45 |
# File 'lib/stripe/resources/climate/product.rb', line 43 def livemode @livemode end |
#metric_tons_available ⇒ Object (readonly)
The quantity of metric tons available for reservation.
45 46 47 |
# File 'lib/stripe/resources/climate/product.rb', line 45 def metric_tons_available @metric_tons_available end |
#name ⇒ Object (readonly)
The Climate product's name.
47 48 49 |
# File 'lib/stripe/resources/climate/product.rb', line 47 def name @name end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
49 50 51 |
# File 'lib/stripe/resources/climate/product.rb', line 49 def object @object end |
#suppliers ⇒ Object (readonly)
The carbon removal suppliers that fulfill orders for this Climate product.
51 52 53 |
# File 'lib/stripe/resources/climate/product.rb', line 51 def suppliers @suppliers end |
Class Method Details
.field_encodings ⇒ Object
71 72 73 |
# File 'lib/stripe/resources/climate/product.rb', line 71 def self.field_encodings @field_encodings = { metric_tons_available: :decimal_string } end |
.field_remappings ⇒ Object
67 68 69 |
# File 'lib/stripe/resources/climate/product.rb', line 67 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
63 64 65 |
# File 'lib/stripe/resources/climate/product.rb', line 63 def self.inner_class_types @inner_class_types = { current_prices_per_metric_ton: CurrentPricesPerMetricTon } end |
.list(params = {}, opts = {}) ⇒ Object
Lists all available Climate product objects.
54 55 56 57 58 59 60 61 |
# File 'lib/stripe/resources/climate/product.rb', line 54 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/climate/products", params: params, opts: opts ) end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/climate/product.rb', line 12 def self.object_name "climate.product" end |