Class: Stripe::Climate::Product

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/climate/product.rb

Overview

A Climate product represents a type of carbon removal unit available for reservation. You can retrieve it to see the current price and availability.

Defined Under Namespace

Classes: CurrentPricesPerMetricTon, ListParams, RetrieveParams

Constant Summary collapse

OBJECT_NAME =
"climate.product"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



52
53
54
# File 'lib/stripe/resources/climate/product.rb', line 52

def created
  @created
end

#current_prices_per_metric_tonObject (readonly)

Current prices for a metric ton of carbon removal in a currency’s smallest unit.



54
55
56
# File 'lib/stripe/resources/climate/product.rb', line 54

def current_prices_per_metric_ton
  @current_prices_per_metric_ton
end

#delivery_yearObject (readonly)

The year in which the carbon removal is expected to be delivered.



56
57
58
# File 'lib/stripe/resources/climate/product.rb', line 56

def delivery_year
  @delivery_year
end

#idObject (readonly)

Unique identifier for the object. For convenience, Climate product IDs are human-readable strings that start with ‘climsku_`. See [carbon removal inventory](stripe.com/docs/climate/orders/carbon-removal-inventory) for a list of available carbon removal products.



60
61
62
# File 'lib/stripe/resources/climate/product.rb', line 60

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



62
63
64
# File 'lib/stripe/resources/climate/product.rb', line 62

def livemode
  @livemode
end

#metric_tons_availableObject (readonly)

The quantity of metric tons available for reservation.



64
65
66
# File 'lib/stripe/resources/climate/product.rb', line 64

def metric_tons_available
  @metric_tons_available
end

#nameObject (readonly)

The Climate product’s name.



66
67
68
# File 'lib/stripe/resources/climate/product.rb', line 66

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



68
69
70
# File 'lib/stripe/resources/climate/product.rb', line 68

def object
  @object
end

#suppliersObject (readonly)

The carbon removal suppliers that fulfill orders for this Climate product.



70
71
72
# File 'lib/stripe/resources/climate/product.rb', line 70

def suppliers
  @suppliers
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

Lists all available Climate product objects.



73
74
75
76
77
78
79
80
# File 'lib/stripe/resources/climate/product.rb', line 73

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/climate/products",
    params: params,
    opts: opts
  )
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/climate/product.rb', line 12

def self.object_name
  "climate.product"
end