Class: Stripe::Climate::Product
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Climate::Product
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/climate/product.rb
Overview
A Climate product represents a type of carbon removal unit available for reservation. You can retrieve it to see the current price and availability.
Defined Under Namespace
Classes: CurrentPricesPerMetricTon
Constant Summary collapse
- OBJECT_NAME =
"climate.product"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#current_prices_per_metric_ton ⇒ Object
readonly
Current prices for a metric ton of carbon removal in a currency’s smallest unit.
-
#delivery_year ⇒ Object
readonly
The year in which the carbon removal is expected to be delivered.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metric_tons_available ⇒ Object
readonly
The quantity of metric tons available for reservation.
-
#name ⇒ Object
readonly
The Climate product’s name.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#suppliers ⇒ Object
readonly
The carbon removal suppliers that fulfill orders for this Climate product.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(filters = {}, opts = {}) ⇒ Object
Lists all available Climate product objects.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
20 21 22 |
# File 'lib/stripe/resources/climate/product.rb', line 20 def created @created end |
#current_prices_per_metric_ton ⇒ Object (readonly)
Current prices for a metric ton of carbon removal in a currency’s smallest unit.
22 23 24 |
# File 'lib/stripe/resources/climate/product.rb', line 22 def current_prices_per_metric_ton @current_prices_per_metric_ton end |
#delivery_year ⇒ Object (readonly)
The year in which the carbon removal is expected to be delivered.
24 25 26 |
# File 'lib/stripe/resources/climate/product.rb', line 24 def delivery_year @delivery_year end |
#id ⇒ Object (readonly)
Unique identifier for the object. For convenience, Climate product IDs are human-readable strings that start with ‘climsku_`. See [carbon removal inventory](stripe.com/docs/climate/orders/carbon-removal-inventory) for a list of available carbon removal products.
28 29 30 |
# File 'lib/stripe/resources/climate/product.rb', line 28 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
30 31 32 |
# File 'lib/stripe/resources/climate/product.rb', line 30 def livemode @livemode end |
#metric_tons_available ⇒ Object (readonly)
The quantity of metric tons available for reservation.
32 33 34 |
# File 'lib/stripe/resources/climate/product.rb', line 32 def metric_tons_available @metric_tons_available end |
#name ⇒ Object (readonly)
The Climate product’s name.
34 35 36 |
# File 'lib/stripe/resources/climate/product.rb', line 34 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
36 37 38 |
# File 'lib/stripe/resources/climate/product.rb', line 36 def object @object end |
#suppliers ⇒ Object (readonly)
The carbon removal suppliers that fulfill orders for this Climate product.
38 39 40 |
# File 'lib/stripe/resources/climate/product.rb', line 38 def suppliers @suppliers end |
Class Method Details
.list(filters = {}, opts = {}) ⇒ Object
Lists all available Climate product objects.
41 42 43 44 45 46 47 48 |
# File 'lib/stripe/resources/climate/product.rb', line 41 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/climate/products", params: filters, opts: opts ) end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/climate/product.rb', line 12 def self.object_name "climate.product" end |