Class: Stripe::Climate::Supplier

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/climate/supplier.rb

Overview

A supplier of carbon removal.

Defined Under Namespace

Classes: ListParams, Location, RetrieveParams

Constant Summary collapse

OBJECT_NAME =
"climate.supplier"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#idObject (readonly)

Unique identifier for the object.



55
56
57
# File 'lib/stripe/resources/climate/supplier.rb', line 55

def id
  @id
end

#info_urlObject (readonly)

Link to a webpage to learn more about the supplier.



57
58
59
# File 'lib/stripe/resources/climate/supplier.rb', line 57

def info_url
  @info_url
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



59
60
61
# File 'lib/stripe/resources/climate/supplier.rb', line 59

def livemode
  @livemode
end

#locationsObject (readonly)

The locations in which this supplier operates.



61
62
63
# File 'lib/stripe/resources/climate/supplier.rb', line 61

def locations
  @locations
end

#nameObject (readonly)

Name of this carbon removal supplier.



63
64
65
# File 'lib/stripe/resources/climate/supplier.rb', line 63

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



65
66
67
# File 'lib/stripe/resources/climate/supplier.rb', line 65

def object
  @object
end

#removal_pathwayObject (readonly)

The scientific pathway used for carbon removal.



67
68
69
# File 'lib/stripe/resources/climate/supplier.rb', line 67

def removal_pathway
  @removal_pathway
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

Lists all available Climate supplier objects.



70
71
72
73
74
75
76
77
# File 'lib/stripe/resources/climate/supplier.rb', line 70

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/climate/suppliers",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/climate/supplier.rb', line 11

def self.object_name
  "climate.supplier"
end