Class: Stripe::Climate::Supplier

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/climate/supplier.rb

Overview

A supplier of carbon removal.

Defined Under Namespace

Classes: Location

Constant Summary collapse

OBJECT_NAME =
"climate.supplier"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#idObject (readonly)

Unique identifier for the object.



19
20
21
# File 'lib/stripe/resources/climate/supplier.rb', line 19

def id
  @id
end

#info_urlObject (readonly)

Link to a webpage to learn more about the supplier.



21
22
23
# File 'lib/stripe/resources/climate/supplier.rb', line 21

def info_url
  @info_url
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



23
24
25
# File 'lib/stripe/resources/climate/supplier.rb', line 23

def livemode
  @livemode
end

#locationsObject (readonly)

The locations in which this supplier operates.



25
26
27
# File 'lib/stripe/resources/climate/supplier.rb', line 25

def locations
  @locations
end

#nameObject (readonly)

Name of this carbon removal supplier.



27
28
29
# File 'lib/stripe/resources/climate/supplier.rb', line 27

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



29
30
31
# File 'lib/stripe/resources/climate/supplier.rb', line 29

def object
  @object
end

#removal_pathwayObject (readonly)

The scientific pathway used for carbon removal.



31
32
33
# File 'lib/stripe/resources/climate/supplier.rb', line 31

def removal_pathway
  @removal_pathway
end

Class Method Details

.list(filters = {}, opts = {}) ⇒ Object

Lists all available Climate supplier objects.



34
35
36
37
38
39
40
41
# File 'lib/stripe/resources/climate/supplier.rb', line 34

def self.list(filters = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/climate/suppliers",
    params: filters,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/climate/supplier.rb', line 11

def self.object_name
  "climate.supplier"
end