Class: Stripe::ConfirmationToken
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::ConfirmationToken
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Overview
ConfirmationTokens help transport client side data collected by Stripe JS over to your server for confirming a PaymentIntent or SetupIntent. If the confirmation is successful, values present on the ConfirmationToken are written onto the Intent.
To learn more about how to use ConfirmationToken, visit the related guides:
Defined Under Namespace
Classes: MandateData, PaymentMethodOptions, PaymentMethodPreview, Shipping, TestHelpers
Constant Summary collapse
- OBJECT_NAME =
"confirmation_token"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#expires_at ⇒ Object
readonly
Time at which this ConfirmationToken expires and can no longer be used to confirm a PaymentIntent or SetupIntent.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#mandate_data ⇒ Object
readonly
Data used for generating a Mandate.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.
-
#payment_method_options ⇒ Object
readonly
Payment-method-specific configuration for this ConfirmationToken.
-
#payment_method_preview ⇒ Object
readonly
Payment details collected by the Payment Element, used to create a PaymentMethod when a PaymentIntent or SetupIntent is confirmed with this ConfirmationToken.
-
#return_url ⇒ Object
readonly
Return URL used to confirm the Intent.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this ConfirmationToken's payment method.
-
#setup_intent ⇒ Object
readonly
ID of the SetupIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.
-
#shipping ⇒ Object
readonly
Shipping information collected on this ConfirmationToken.
-
#use_stripe_sdk ⇒ Object
readonly
Indicates whether the Stripe SDK is used to handle confirmation flow.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
1744 1745 1746 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1744 def created @created end |
#expires_at ⇒ Object (readonly)
Time at which this ConfirmationToken expires and can no longer be used to confirm a PaymentIntent or SetupIntent.
1746 1747 1748 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1746 def expires_at @expires_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1748 1749 1750 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1748 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
1750 1751 1752 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1750 def livemode @livemode end |
#mandate_data ⇒ Object (readonly)
Data used for generating a Mandate.
1752 1753 1754 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1752 def mandate_data @mandate_data end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
1754 1755 1756 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1754 def object @object end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.
1756 1757 1758 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1756 def payment_intent @payment_intent end |
#payment_method_options ⇒ Object (readonly)
Payment-method-specific configuration for this ConfirmationToken.
1758 1759 1760 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1758 def @payment_method_options end |
#payment_method_preview ⇒ Object (readonly)
Payment details collected by the Payment Element, used to create a PaymentMethod when a PaymentIntent or SetupIntent is confirmed with this ConfirmationToken.
1760 1761 1762 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1760 def payment_method_preview @payment_method_preview end |
#return_url ⇒ Object (readonly)
Return URL used to confirm the Intent.
1762 1763 1764 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1762 def return_url @return_url end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this ConfirmationToken's payment method.
The presence of this property will attach the payment method to the PaymentIntent's Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.
1766 1767 1768 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1766 def setup_future_usage @setup_future_usage end |
#setup_intent ⇒ Object (readonly)
ID of the SetupIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.
1768 1769 1770 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1768 def setup_intent @setup_intent end |
#shipping ⇒ Object (readonly)
Shipping information collected on this ConfirmationToken.
1770 1771 1772 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1770 def shipping @shipping end |
#use_stripe_sdk ⇒ Object (readonly)
Indicates whether the Stripe SDK is used to handle confirmation flow. Defaults to true on ConfirmationToken.
1772 1773 1774 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1772 def use_stripe_sdk @use_stripe_sdk end |
Class Method Details
.field_remappings ⇒ Object
1804 1805 1806 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1804 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1795 1796 1797 1798 1799 1800 1801 1802 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1795 def self.inner_class_types @inner_class_types = { mandate_data: MandateData, payment_method_options: PaymentMethodOptions, payment_method_preview: PaymentMethodPreview, shipping: Shipping, } end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/confirmation_token.rb', line 14 def self.object_name "confirmation_token" end |
Instance Method Details
#test_helpers ⇒ Object
1774 1775 1776 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1774 def test_helpers TestHelpers.new(self) end |