Class: Stripe::ConfirmationToken
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::ConfirmationToken
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Overview
ConfirmationTokens help transport client side data collected by Stripe JS over to your server for confirming a PaymentIntent or SetupIntent. If the confirmation is successful, values present on the ConfirmationToken are written onto the Intent.
To learn more about how to use ConfirmationToken, visit the related guides:
-
[Finalize payments on the server](stripe.com/docs/payments/finalize-payments-on-the-server)
-
[Build two-step confirmation](stripe.com/docs/payments/build-a-two-step-confirmation).
Defined Under Namespace
Classes: CreateParams, MandateData, PaymentMethodOptions, PaymentMethodPreview, Shipping, TestHelpers
Constant Summary collapse
- OBJECT_NAME =
"confirmation_token"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#expires_at ⇒ Object
readonly
Time at which this ConfirmationToken expires and can no longer be used to confirm a PaymentIntent or SetupIntent.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#mandate_data ⇒ Object
readonly
Data used for generating a Mandate.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_intent ⇒ Object
readonly
ID of the PaymentIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.
-
#payment_method_options ⇒ Object
readonly
Payment-method-specific configuration for this ConfirmationToken.
-
#payment_method_preview ⇒ Object
readonly
Payment details collected by the Payment Element, used to create a PaymentMethod when a PaymentIntent or SetupIntent is confirmed with this ConfirmationToken.
-
#return_url ⇒ Object
readonly
Return URL used to confirm the Intent.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this ConfirmationToken’s payment method.
-
#setup_intent ⇒ Object
readonly
ID of the SetupIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.
-
#shipping ⇒ Object
readonly
Shipping information collected on this ConfirmationToken.
-
#use_stripe_sdk ⇒ Object
readonly
Indicates whether the Stripe SDK is used to handle confirmation flow.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
1447 1448 1449 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1447 def created @created end |
#expires_at ⇒ Object (readonly)
Time at which this ConfirmationToken expires and can no longer be used to confirm a PaymentIntent or SetupIntent.
1449 1450 1451 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1449 def expires_at @expires_at end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1451 1452 1453 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1451 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
1453 1454 1455 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1453 def livemode @livemode end |
#mandate_data ⇒ Object (readonly)
Data used for generating a Mandate.
1455 1456 1457 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1455 def mandate_data @mandate_data end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1457 1458 1459 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1457 def object @object end |
#payment_intent ⇒ Object (readonly)
ID of the PaymentIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.
1459 1460 1461 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1459 def payment_intent @payment_intent end |
#payment_method_options ⇒ Object (readonly)
Payment-method-specific configuration for this ConfirmationToken.
1461 1462 1463 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1461 def @payment_method_options end |
#payment_method_preview ⇒ Object (readonly)
Payment details collected by the Payment Element, used to create a PaymentMethod when a PaymentIntent or SetupIntent is confirmed with this ConfirmationToken.
1463 1464 1465 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1463 def payment_method_preview @payment_method_preview end |
#return_url ⇒ Object (readonly)
Return URL used to confirm the Intent.
1465 1466 1467 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1465 def return_url @return_url end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this ConfirmationToken’s payment method.
The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.
1469 1470 1471 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1469 def setup_future_usage @setup_future_usage end |
#setup_intent ⇒ Object (readonly)
ID of the SetupIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.
1471 1472 1473 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1471 def setup_intent @setup_intent end |
#shipping ⇒ Object (readonly)
Shipping information collected on this ConfirmationToken.
1473 1474 1475 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1473 def shipping @shipping end |
#use_stripe_sdk ⇒ Object (readonly)
Indicates whether the Stripe SDK is used to handle confirmation flow. Defaults to ‘true` on ConfirmationToken.
1475 1476 1477 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1475 def use_stripe_sdk @use_stripe_sdk end |
Class Method Details
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/confirmation_token.rb', line 14 def self.object_name "confirmation_token" end |
Instance Method Details
#test_helpers ⇒ Object
1477 1478 1479 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1477 def test_helpers TestHelpers.new(self) end |