Class: Stripe::ConfirmationToken

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Overview

ConfirmationTokens help transport client side data collected by Stripe JS over to your server for confirming a PaymentIntent or SetupIntent. If the confirmation is successful, values present on the ConfirmationToken are written onto the Intent.

To learn more about how to use ConfirmationToken, visit the related guides:

Defined Under Namespace

Classes: CreateParams, MandateData, PaymentMethodOptions, PaymentMethodPreview, Shipping, TestHelpers

Constant Summary collapse

OBJECT_NAME =
"confirmation_token"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1675
1676
1677
# File 'lib/stripe/resources/confirmation_token.rb', line 1675

def created
  @created
end

#expires_atObject (readonly)

Time at which this ConfirmationToken expires and can no longer be used to confirm a PaymentIntent or SetupIntent.



1677
1678
1679
# File 'lib/stripe/resources/confirmation_token.rb', line 1677

def expires_at
  @expires_at
end

#idObject (readonly)

Unique identifier for the object.



1679
1680
1681
# File 'lib/stripe/resources/confirmation_token.rb', line 1679

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1681
1682
1683
# File 'lib/stripe/resources/confirmation_token.rb', line 1681

def livemode
  @livemode
end

#mandate_dataObject (readonly)

Data used for generating a Mandate.



1683
1684
1685
# File 'lib/stripe/resources/confirmation_token.rb', line 1683

def mandate_data
  @mandate_data
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1685
1686
1687
# File 'lib/stripe/resources/confirmation_token.rb', line 1685

def object
  @object
end

#payment_intentObject (readonly)

ID of the PaymentIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.



1687
1688
1689
# File 'lib/stripe/resources/confirmation_token.rb', line 1687

def payment_intent
  @payment_intent
end

#payment_method_optionsObject (readonly)

Payment-method-specific configuration for this ConfirmationToken.



1689
1690
1691
# File 'lib/stripe/resources/confirmation_token.rb', line 1689

def payment_method_options
  @payment_method_options
end

#payment_method_previewObject (readonly)

Payment details collected by the Payment Element, used to create a PaymentMethod when a PaymentIntent or SetupIntent is confirmed with this ConfirmationToken.



1691
1692
1693
# File 'lib/stripe/resources/confirmation_token.rb', line 1691

def payment_method_preview
  @payment_method_preview
end

#return_urlObject (readonly)

Return URL used to confirm the Intent.



1693
1694
1695
# File 'lib/stripe/resources/confirmation_token.rb', line 1693

def return_url
  @return_url
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



1697
1698
1699
# File 'lib/stripe/resources/confirmation_token.rb', line 1697

def setup_future_usage
  @setup_future_usage
end

#setup_intentObject (readonly)

ID of the SetupIntent that this ConfirmationToken was used to confirm, or null if this ConfirmationToken has not yet been used.



1699
1700
1701
# File 'lib/stripe/resources/confirmation_token.rb', line 1699

def setup_intent
  @setup_intent
end

#shippingObject (readonly)

Shipping information collected on this ConfirmationToken.



1701
1702
1703
# File 'lib/stripe/resources/confirmation_token.rb', line 1701

def shipping
  @shipping
end

#use_stripe_sdkObject (readonly)

Indicates whether the Stripe SDK is used to handle confirmation flow. Defaults to ‘true` on ConfirmationToken.



1703
1704
1705
# File 'lib/stripe/resources/confirmation_token.rb', line 1703

def use_stripe_sdk
  @use_stripe_sdk
end

Class Method Details

.object_nameObject



14
15
16
# File 'lib/stripe/resources/confirmation_token.rb', line 14

def self.object_name
  "confirmation_token"
end

Instance Method Details

#test_helpersObject



1705
1706
1707
# File 'lib/stripe/resources/confirmation_token.rb', line 1705

def test_helpers
  TestHelpers.new(self)
end