Class: Stripe::ConfirmationToken::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
# File 'lib/stripe/resources/confirmation_token.rb', line 1606

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1590
1591
1592
# File 'lib/stripe/resources/confirmation_token.rb', line 1590

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



1592
1593
1594
# File 'lib/stripe/resources/confirmation_token.rb', line 1592

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



1594
1595
1596
# File 'lib/stripe/resources/confirmation_token.rb', line 1594

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



1596
1597
1598
# File 'lib/stripe/resources/confirmation_token.rb', line 1596

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



1598
1599
1600
# File 'lib/stripe/resources/confirmation_token.rb', line 1598

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



1602
1603
1604
# File 'lib/stripe/resources/confirmation_token.rb', line 1602

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



1604
1605
1606
# File 'lib/stripe/resources/confirmation_token.rb', line 1604

def shipping
  @shipping
end