Class: Stripe::ConfirmationToken::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/stripe/resources/confirmation_token.rb', line 1428

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1412
1413
1414
# File 'lib/stripe/resources/confirmation_token.rb', line 1412

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



1414
1415
1416
# File 'lib/stripe/resources/confirmation_token.rb', line 1414

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



1416
1417
1418
# File 'lib/stripe/resources/confirmation_token.rb', line 1416

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



1418
1419
1420
# File 'lib/stripe/resources/confirmation_token.rb', line 1418

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



1420
1421
1422
# File 'lib/stripe/resources/confirmation_token.rb', line 1420

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



1424
1425
1426
# File 'lib/stripe/resources/confirmation_token.rb', line 1424

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



1426
1427
1428
# File 'lib/stripe/resources/confirmation_token.rb', line 1426

def shipping
  @shipping
end