Class: Stripe::ConfirmationToken::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: PaymentMethodData, PaymentMethodOptions, Shipping
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
ID of an existing PaymentMethod.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration for this ConfirmationToken.
-
#return_url ⇒ Object
Return URL used to confirm the Intent.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this ConfirmationToken’s payment method.
-
#shipping ⇒ Object
Shipping information for this ConfirmationToken.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1482 def initialize( expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil ) @expand = @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1466 1467 1468 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1466 def @expand end |
#payment_method ⇒ Object
ID of an existing PaymentMethod.
1468 1469 1470 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1468 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
1470 1471 1472 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1470 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment-method-specific configuration for this ConfirmationToken.
1472 1473 1474 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1472 def @payment_method_options end |
#return_url ⇒ Object
Return URL used to confirm the Intent.
1474 1475 1476 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1474 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this ConfirmationToken’s payment method.
The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.
1478 1479 1480 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1478 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this ConfirmationToken.
1480 1481 1482 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1480 def shipping @shipping end |