Class: Stripe::ConfirmationToken::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: PaymentMethodData, PaymentMethodOptions, Shipping
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
ID of an existing PaymentMethod.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Attribute for param field payment_method_options.
-
#return_url ⇒ Object
Return URL used to confirm the Intent.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this ConfirmationToken’s payment method.
-
#shipping ⇒ Object
Shipping information for this ConfirmationToken.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1651 def initialize( expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil ) @expand = @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1635 1636 1637 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1635 def @expand end |
#payment_method ⇒ Object
ID of an existing PaymentMethod.
1637 1638 1639 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1637 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
1639 1640 1641 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1639 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Attribute for param field payment_method_options
1641 1642 1643 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1641 def @payment_method_options end |
#return_url ⇒ Object
Return URL used to confirm the Intent.
1643 1644 1645 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1643 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this ConfirmationToken’s payment method.
The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.
1647 1648 1649 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1647 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this ConfirmationToken.
1649 1650 1651 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1649 def shipping @shipping end |