Class: Stripe::ConfirmationToken::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: PaymentMethodData, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
# File 'lib/stripe/resources/confirmation_token.rb', line 1491

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1477
1478
1479
# File 'lib/stripe/resources/confirmation_token.rb', line 1477

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



1479
1480
1481
# File 'lib/stripe/resources/confirmation_token.rb', line 1479

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



1481
1482
1483
# File 'lib/stripe/resources/confirmation_token.rb', line 1481

def payment_method_data
  @payment_method_data
end

#return_urlObject

Return URL used to confirm the Intent.



1483
1484
1485
# File 'lib/stripe/resources/confirmation_token.rb', line 1483

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



1487
1488
1489
# File 'lib/stripe/resources/confirmation_token.rb', line 1487

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



1489
1490
1491
# File 'lib/stripe/resources/confirmation_token.rb', line 1489

def shipping
  @shipping
end