Class: Stripe::ConfirmationToken::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: PaymentMethodData, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
# File 'lib/stripe/resources/confirmation_token.rb', line 1813

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1794
1795
1796
# File 'lib/stripe/resources/confirmation_token.rb', line 1794

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



1797
1798
1799
# File 'lib/stripe/resources/confirmation_token.rb', line 1797

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



1800
1801
1802
# File 'lib/stripe/resources/confirmation_token.rb', line 1800

def payment_method_data
  @payment_method_data
end

#return_urlObject

Return URL used to confirm the Intent.



1803
1804
1805
# File 'lib/stripe/resources/confirmation_token.rb', line 1803

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



1808
1809
1810
# File 'lib/stripe/resources/confirmation_token.rb', line 1808

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



1811
1812
1813
# File 'lib/stripe/resources/confirmation_token.rb', line 1811

def shipping
  @shipping
end