Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1102 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1090 1091 1092 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1090 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1092 1093 1094 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1092 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1094 1095 1096 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1094 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1096 1097 1098 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1096 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1098 1099 1100 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1098 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1100 1101 1102 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1100 def suffix @suffix end |