Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
# File 'lib/stripe/resources/confirmation_token.rb', line 1018

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1006
1007
1008
# File 'lib/stripe/resources/confirmation_token.rb', line 1006

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1008
1009
1010
# File 'lib/stripe/resources/confirmation_token.rb', line 1008

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1010
1011
1012
# File 'lib/stripe/resources/confirmation_token.rb', line 1010

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1012
1013
1014
# File 'lib/stripe/resources/confirmation_token.rb', line 1012

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1014
1015
1016
# File 'lib/stripe/resources/confirmation_token.rb', line 1014

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1016
1017
1018
# File 'lib/stripe/resources/confirmation_token.rb', line 1016

def suffix
  @suffix
end