Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
# File 'lib/stripe/resources/confirmation_token.rb', line 1098

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1086
1087
1088
# File 'lib/stripe/resources/confirmation_token.rb', line 1086

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1088
1089
1090
# File 'lib/stripe/resources/confirmation_token.rb', line 1088

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1090
1091
1092
# File 'lib/stripe/resources/confirmation_token.rb', line 1090

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1092
1093
1094
# File 'lib/stripe/resources/confirmation_token.rb', line 1092

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1094
1095
1096
# File 'lib/stripe/resources/confirmation_token.rb', line 1094

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1096
1097
1098
# File 'lib/stripe/resources/confirmation_token.rb', line 1096

def suffix
  @suffix
end