Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1014 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1002 1003 1004 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1002 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1004 1005 1006 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1004 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1006 1007 1008 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1006 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1008 1009 1010 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1008 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1010 1011 1012 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1010 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1012 1013 1014 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1012 def suffix @suffix end |