Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1045 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1033 1034 1035 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1033 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
1035 1036 1037 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1035 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
1037 1038 1039 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1037 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
1039 1040 1041 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1039 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
1041 1042 1043 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1041 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
1043 1044 1045 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1043 def suffix @suffix end |