Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
# File 'lib/stripe/resources/confirmation_token.rb', line 1131

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1119
1120
1121
# File 'lib/stripe/resources/confirmation_token.rb', line 1119

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



1121
1122
1123
# File 'lib/stripe/resources/confirmation_token.rb', line 1121

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



1123
1124
1125
# File 'lib/stripe/resources/confirmation_token.rb', line 1123

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



1125
1126
1127
# File 'lib/stripe/resources/confirmation_token.rb', line 1125

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



1127
1128
1129
# File 'lib/stripe/resources/confirmation_token.rb', line 1127

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



1129
1130
1131
# File 'lib/stripe/resources/confirmation_token.rb', line 1129

def suffix
  @suffix
end