Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::RadarOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodData::RadarOptions
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
Instance Method Summary collapse
-
#initialize(session: nil) ⇒ RadarOptions
constructor
A new instance of RadarOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(session: nil) ⇒ RadarOptions
Returns a new instance of RadarOptions.
1202 1203 1204 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1202 def initialize(session: nil) @session = session end |
Instance Attribute Details
#session ⇒ Object
A [Radar Session](stripe.com/docs/radar/radar-session) is a snapshot of the browser metadata and device details that help Radar make more accurate predictions on your payments.
1200 1201 1202 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1200 def session @session end |