Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::Sofort
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodData::Sofort
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
Instance Method Summary collapse
-
#initialize(country: nil) ⇒ Sofort
constructor
A new instance of Sofort.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil) ⇒ Sofort
Returns a new instance of Sofort.
1103 1104 1105 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1103 def initialize(country: nil) @country = country end |
Instance Attribute Details
#country ⇒ Object
Two-letter ISO code representing the country the bank account is located in.
1101 1102 1103 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1101 def country @country end |