Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1186 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
1176 1177 1178 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1176 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
1178 1179 1180 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1178 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
1180 1181 1182 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1180 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
1182 1183 1184 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1182 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
1184 1185 1186 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1184 def routing_number @routing_number end |