Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#plan ⇒ Object
The selected installment plan to use for this payment attempt.
Instance Method Summary collapse
-
#initialize(plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(plan: nil) ⇒ Installments
Returns a new instance of Installments.
1402 1403 1404 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1402 def initialize(plan: nil) @plan = plan end |
Instance Attribute Details
#plan ⇒ Object
The selected installment plan to use for this payment attempt. This parameter can only be provided during confirmation.
1400 1401 1402 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1400 def plan @plan end |