Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
1508 1509 1510 1511 1512 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1508 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
1501 1502 1503 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1501 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
1504 1505 1506 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1504 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
1506 1507 1508 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1506 def type @type end |