Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1338
1339
1340
1341
1342
# File 'lib/stripe/resources/confirmation_token.rb', line 1338

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1331
1332
1333
# File 'lib/stripe/resources/confirmation_token.rb', line 1331

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1334
1335
1336
# File 'lib/stripe/resources/confirmation_token.rb', line 1334

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



1336
1337
1338
# File 'lib/stripe/resources/confirmation_token.rb', line 1336

def type
  @type
end