Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1392
1393
1394
1395
1396
# File 'lib/stripe/resources/confirmation_token.rb', line 1392

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1385
1386
1387
# File 'lib/stripe/resources/confirmation_token.rb', line 1385

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1388
1389
1390
# File 'lib/stripe/resources/confirmation_token.rb', line 1388

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



1390
1391
1392
# File 'lib/stripe/resources/confirmation_token.rb', line 1390

def type
  @type
end