Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1561
1562
1563
1564
1565
# File 'lib/stripe/resources/confirmation_token.rb', line 1561

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1554
1555
1556
# File 'lib/stripe/resources/confirmation_token.rb', line 1554

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1557
1558
1559
# File 'lib/stripe/resources/confirmation_token.rb', line 1557

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



1559
1560
1561
# File 'lib/stripe/resources/confirmation_token.rb', line 1559

def type
  @type
end