Class: Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationToken::CreateParams::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
1566 1567 1568 1569 1570 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1566 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
1559 1560 1561 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1559 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
1562 1563 1564 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1562 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
1564 1565 1566 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1564 def type @type end |