Class: Stripe::ConfirmationToken::PaymentMethodPreview

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Sofort, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1516
1517
1518
# File 'lib/stripe/resources/confirmation_token.rb', line 1516

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1518
1519
1520
# File 'lib/stripe/resources/confirmation_token.rb', line 1518

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1520
1521
1522
# File 'lib/stripe/resources/confirmation_token.rb', line 1520

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1522
1523
1524
# File 'lib/stripe/resources/confirmation_token.rb', line 1522

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



1524
1525
1526
# File 'lib/stripe/resources/confirmation_token.rb', line 1524

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



1526
1527
1528
# File 'lib/stripe/resources/confirmation_token.rb', line 1526

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1528
1529
1530
# File 'lib/stripe/resources/confirmation_token.rb', line 1528

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1530
1531
1532
# File 'lib/stripe/resources/confirmation_token.rb', line 1530

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1532
1533
1534
# File 'lib/stripe/resources/confirmation_token.rb', line 1532

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1534
1535
1536
# File 'lib/stripe/resources/confirmation_token.rb', line 1534

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1536
1537
1538
# File 'lib/stripe/resources/confirmation_token.rb', line 1536

def billie
  @billie
end

#billing_detailsObject (readonly)

Attribute for field billing_details



1538
1539
1540
# File 'lib/stripe/resources/confirmation_token.rb', line 1538

def billing_details
  @billing_details
end

#bizumObject (readonly)

Attribute for field bizum



1540
1541
1542
# File 'lib/stripe/resources/confirmation_token.rb', line 1540

def bizum
  @bizum
end

#blikObject (readonly)

Attribute for field blik



1542
1543
1544
# File 'lib/stripe/resources/confirmation_token.rb', line 1542

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1544
1545
1546
# File 'lib/stripe/resources/confirmation_token.rb', line 1544

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1546
1547
1548
# File 'lib/stripe/resources/confirmation_token.rb', line 1546

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1548
1549
1550
# File 'lib/stripe/resources/confirmation_token.rb', line 1548

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1550
1551
1552
# File 'lib/stripe/resources/confirmation_token.rb', line 1550

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1552
1553
1554
# File 'lib/stripe/resources/confirmation_token.rb', line 1552

def crypto
  @crypto
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



1554
1555
1556
# File 'lib/stripe/resources/confirmation_token.rb', line 1554

def customer
  @customer
end

#customer_accountObject (readonly)

Attribute for field customer_account



1556
1557
1558
# File 'lib/stripe/resources/confirmation_token.rb', line 1556

def 
  @customer_account
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1558
1559
1560
# File 'lib/stripe/resources/confirmation_token.rb', line 1558

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1560
1561
1562
# File 'lib/stripe/resources/confirmation_token.rb', line 1560

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1562
1563
1564
# File 'lib/stripe/resources/confirmation_token.rb', line 1562

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1564
1565
1566
# File 'lib/stripe/resources/confirmation_token.rb', line 1564

def giropay
  @giropay
end

#grabpayObject (readonly)

Attribute for field grabpay



1566
1567
1568
# File 'lib/stripe/resources/confirmation_token.rb', line 1566

def grabpay
  @grabpay
end

#idealObject (readonly)

Attribute for field ideal



1568
1569
1570
# File 'lib/stripe/resources/confirmation_token.rb', line 1568

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1570
1571
1572
# File 'lib/stripe/resources/confirmation_token.rb', line 1570

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1572
1573
1574
# File 'lib/stripe/resources/confirmation_token.rb', line 1572

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1574
1575
1576
# File 'lib/stripe/resources/confirmation_token.rb', line 1574

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1576
1577
1578
# File 'lib/stripe/resources/confirmation_token.rb', line 1576

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1578
1579
1580
# File 'lib/stripe/resources/confirmation_token.rb', line 1578

def kr_card
  @kr_card
end

Attribute for field link



1580
1581
1582
# File 'lib/stripe/resources/confirmation_token.rb', line 1580

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1582
1583
1584
# File 'lib/stripe/resources/confirmation_token.rb', line 1582

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1584
1585
1586
# File 'lib/stripe/resources/confirmation_token.rb', line 1584

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1586
1587
1588
# File 'lib/stripe/resources/confirmation_token.rb', line 1586

def multibanco
  @multibanco
end

Attribute for field naver_pay



1588
1589
1590
# File 'lib/stripe/resources/confirmation_token.rb', line 1588

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1590
1591
1592
# File 'lib/stripe/resources/confirmation_token.rb', line 1590

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1592
1593
1594
# File 'lib/stripe/resources/confirmation_token.rb', line 1592

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1594
1595
1596
# File 'lib/stripe/resources/confirmation_token.rb', line 1594

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1596
1597
1598
# File 'lib/stripe/resources/confirmation_token.rb', line 1596

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1598
1599
1600
# File 'lib/stripe/resources/confirmation_token.rb', line 1598

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1600
1601
1602
# File 'lib/stripe/resources/confirmation_token.rb', line 1600

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1602
1603
1604
# File 'lib/stripe/resources/confirmation_token.rb', line 1602

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



1604
1605
1606
# File 'lib/stripe/resources/confirmation_token.rb', line 1604

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1606
1607
1608
# File 'lib/stripe/resources/confirmation_token.rb', line 1606

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1608
1609
1610
# File 'lib/stripe/resources/confirmation_token.rb', line 1608

def promptpay
  @promptpay
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1610
1611
1612
# File 'lib/stripe/resources/confirmation_token.rb', line 1610

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1612
1613
1614
# File 'lib/stripe/resources/confirmation_token.rb', line 1612

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1614
1615
1616
# File 'lib/stripe/resources/confirmation_token.rb', line 1614

def satispay
  @satispay
end

#scalapayObject (readonly)

Attribute for field scalapay



1616
1617
1618
# File 'lib/stripe/resources/confirmation_token.rb', line 1616

def scalapay
  @scalapay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1618
1619
1620
# File 'lib/stripe/resources/confirmation_token.rb', line 1618

def sepa_debit
  @sepa_debit
end

#sofortObject (readonly)

Attribute for field sofort



1620
1621
1622
# File 'lib/stripe/resources/confirmation_token.rb', line 1620

def sofort
  @sofort
end

#sunbitObject (readonly)

Attribute for field sunbit



1622
1623
1624
# File 'lib/stripe/resources/confirmation_token.rb', line 1622

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



1624
1625
1626
# File 'lib/stripe/resources/confirmation_token.rb', line 1624

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1626
1627
1628
# File 'lib/stripe/resources/confirmation_token.rb', line 1626

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



1628
1629
1630
# File 'lib/stripe/resources/confirmation_token.rb', line 1628

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



1630
1631
1632
# File 'lib/stripe/resources/confirmation_token.rb', line 1630

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1632
1633
1634
# File 'lib/stripe/resources/confirmation_token.rb', line 1632

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1634
1635
1636
# File 'lib/stripe/resources/confirmation_token.rb', line 1634

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1636
1637
1638
# File 'lib/stripe/resources/confirmation_token.rb', line 1636

def zip
  @zip
end

Class Method Details

.field_remappingsObject



1700
1701
1702
# File 'lib/stripe/resources/confirmation_token.rb', line 1700

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
# File 'lib/stripe/resources/confirmation_token.rb', line 1638

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    grabpay: Grabpay,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_debit: SepaDebit,
    sofort: Sofort,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end