Class: Stripe::ConfirmationToken::PaymentMethodPreview

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Bizum, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, Scalapay, SepaDebit, Shopeepay, Sofort, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1617
1618
1619
# File 'lib/stripe/resources/confirmation_token.rb', line 1617

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1619
1620
1621
# File 'lib/stripe/resources/confirmation_token.rb', line 1619

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1621
1622
1623
# File 'lib/stripe/resources/confirmation_token.rb', line 1621

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1623
1624
1625
# File 'lib/stripe/resources/confirmation_token.rb', line 1623

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



1625
1626
1627
# File 'lib/stripe/resources/confirmation_token.rb', line 1625

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



1627
1628
1629
# File 'lib/stripe/resources/confirmation_token.rb', line 1627

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1629
1630
1631
# File 'lib/stripe/resources/confirmation_token.rb', line 1629

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1631
1632
1633
# File 'lib/stripe/resources/confirmation_token.rb', line 1631

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1633
1634
1635
# File 'lib/stripe/resources/confirmation_token.rb', line 1633

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1635
1636
1637
# File 'lib/stripe/resources/confirmation_token.rb', line 1635

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1637
1638
1639
# File 'lib/stripe/resources/confirmation_token.rb', line 1637

def billie
  @billie
end

#billing_detailsObject (readonly)

Attribute for field billing_details



1639
1640
1641
# File 'lib/stripe/resources/confirmation_token.rb', line 1639

def billing_details
  @billing_details
end

#bizumObject (readonly)

Attribute for field bizum



1641
1642
1643
# File 'lib/stripe/resources/confirmation_token.rb', line 1641

def bizum
  @bizum
end

#blikObject (readonly)

Attribute for field blik



1643
1644
1645
# File 'lib/stripe/resources/confirmation_token.rb', line 1643

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1645
1646
1647
# File 'lib/stripe/resources/confirmation_token.rb', line 1645

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1647
1648
1649
# File 'lib/stripe/resources/confirmation_token.rb', line 1647

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1649
1650
1651
# File 'lib/stripe/resources/confirmation_token.rb', line 1649

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1651
1652
1653
# File 'lib/stripe/resources/confirmation_token.rb', line 1651

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1653
1654
1655
# File 'lib/stripe/resources/confirmation_token.rb', line 1653

def crypto
  @crypto
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



1655
1656
1657
# File 'lib/stripe/resources/confirmation_token.rb', line 1655

def customer
  @customer
end

#customer_accountObject (readonly)

Attribute for field customer_account



1657
1658
1659
# File 'lib/stripe/resources/confirmation_token.rb', line 1657

def 
  @customer_account
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1659
1660
1661
# File 'lib/stripe/resources/confirmation_token.rb', line 1659

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1661
1662
1663
# File 'lib/stripe/resources/confirmation_token.rb', line 1661

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1663
1664
1665
# File 'lib/stripe/resources/confirmation_token.rb', line 1663

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1665
1666
1667
# File 'lib/stripe/resources/confirmation_token.rb', line 1665

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1667
1668
1669
# File 'lib/stripe/resources/confirmation_token.rb', line 1667

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1669
1670
1671
# File 'lib/stripe/resources/confirmation_token.rb', line 1669

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1671
1672
1673
# File 'lib/stripe/resources/confirmation_token.rb', line 1671

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1673
1674
1675
# File 'lib/stripe/resources/confirmation_token.rb', line 1673

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1675
1676
1677
# File 'lib/stripe/resources/confirmation_token.rb', line 1675

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1677
1678
1679
# File 'lib/stripe/resources/confirmation_token.rb', line 1677

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1679
1680
1681
# File 'lib/stripe/resources/confirmation_token.rb', line 1679

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1681
1682
1683
# File 'lib/stripe/resources/confirmation_token.rb', line 1681

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1683
1684
1685
# File 'lib/stripe/resources/confirmation_token.rb', line 1683

def kr_card
  @kr_card
end

Attribute for field link



1685
1686
1687
# File 'lib/stripe/resources/confirmation_token.rb', line 1685

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1687
1688
1689
# File 'lib/stripe/resources/confirmation_token.rb', line 1687

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1689
1690
1691
# File 'lib/stripe/resources/confirmation_token.rb', line 1689

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1691
1692
1693
# File 'lib/stripe/resources/confirmation_token.rb', line 1691

def multibanco
  @multibanco
end

Attribute for field naver_pay



1693
1694
1695
# File 'lib/stripe/resources/confirmation_token.rb', line 1693

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1695
1696
1697
# File 'lib/stripe/resources/confirmation_token.rb', line 1695

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1697
1698
1699
# File 'lib/stripe/resources/confirmation_token.rb', line 1697

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1699
1700
1701
# File 'lib/stripe/resources/confirmation_token.rb', line 1699

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1701
1702
1703
# File 'lib/stripe/resources/confirmation_token.rb', line 1701

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1703
1704
1705
# File 'lib/stripe/resources/confirmation_token.rb', line 1703

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1705
1706
1707
# File 'lib/stripe/resources/confirmation_token.rb', line 1705

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1707
1708
1709
# File 'lib/stripe/resources/confirmation_token.rb', line 1707

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



1709
1710
1711
# File 'lib/stripe/resources/confirmation_token.rb', line 1709

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



1711
1712
1713
# File 'lib/stripe/resources/confirmation_token.rb', line 1711

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1713
1714
1715
# File 'lib/stripe/resources/confirmation_token.rb', line 1713

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1715
1716
1717
# File 'lib/stripe/resources/confirmation_token.rb', line 1715

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1717
1718
1719
# File 'lib/stripe/resources/confirmation_token.rb', line 1717

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1719
1720
1721
# File 'lib/stripe/resources/confirmation_token.rb', line 1719

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1721
1722
1723
# File 'lib/stripe/resources/confirmation_token.rb', line 1721

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1723
1724
1725
# File 'lib/stripe/resources/confirmation_token.rb', line 1723

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1725
1726
1727
# File 'lib/stripe/resources/confirmation_token.rb', line 1725

def satispay
  @satispay
end

#scalapayObject (readonly)

Attribute for field scalapay



1727
1728
1729
# File 'lib/stripe/resources/confirmation_token.rb', line 1727

def scalapay
  @scalapay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1729
1730
1731
# File 'lib/stripe/resources/confirmation_token.rb', line 1729

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1731
1732
1733
# File 'lib/stripe/resources/confirmation_token.rb', line 1731

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1733
1734
1735
# File 'lib/stripe/resources/confirmation_token.rb', line 1733

def sofort
  @sofort
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



1735
1736
1737
# File 'lib/stripe/resources/confirmation_token.rb', line 1735

def stripe_balance
  @stripe_balance
end

#sunbitObject (readonly)

Attribute for field sunbit



1737
1738
1739
# File 'lib/stripe/resources/confirmation_token.rb', line 1737

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



1739
1740
1741
# File 'lib/stripe/resources/confirmation_token.rb', line 1739

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1741
1742
1743
# File 'lib/stripe/resources/confirmation_token.rb', line 1741

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



1743
1744
1745
# File 'lib/stripe/resources/confirmation_token.rb', line 1743

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



1745
1746
1747
# File 'lib/stripe/resources/confirmation_token.rb', line 1745

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1747
1748
1749
# File 'lib/stripe/resources/confirmation_token.rb', line 1747

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1749
1750
1751
# File 'lib/stripe/resources/confirmation_token.rb', line 1749

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1751
1752
1753
# File 'lib/stripe/resources/confirmation_token.rb', line 1751

def zip
  @zip
end

Class Method Details

.field_remappingsObject



1822
1823
1824
# File 'lib/stripe/resources/confirmation_token.rb', line 1822

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
# File 'lib/stripe/resources/confirmation_token.rb', line 1753

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    bizum: Bizum,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    scalapay: Scalapay,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_balance: StripeBalance,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end