Class: Stripe::ConfirmationToken::PaymentMethodPreview
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, Upi, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#allow_redisplay ⇒ Object
readonly
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer ⇒ Object
readonly
The ID of the Customer to which this PaymentMethod is saved.
-
#customer_account ⇒ Object
readonly
Attribute for field customer_account.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1477 1478 1479 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1477 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1479 1480 1481 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1479 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1481 1482 1483 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1481 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1483 1484 1485 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1483 def alipay @alipay end |
#allow_redisplay ⇒ Object (readonly)
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
1485 1486 1487 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1485 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1487 1488 1489 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1487 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1489 1490 1491 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1489 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1491 1492 1493 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1491 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1493 1494 1495 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1493 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1495 1496 1497 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1495 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1497 1498 1499 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1497 def billie @billie end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
1499 1500 1501 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1499 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
1501 1502 1503 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1501 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1503 1504 1505 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1503 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1505 1506 1507 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1505 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1507 1508 1509 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1507 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1509 1510 1511 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1509 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1511 1512 1513 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1511 def crypto @crypto end |
#customer ⇒ Object (readonly)
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
1513 1514 1515 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1513 def customer @customer end |
#customer_account ⇒ Object (readonly)
Attribute for field customer_account
1515 1516 1517 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1515 def customer_account @customer_account end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1517 1518 1519 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1517 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1519 1520 1521 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1519 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1521 1522 1523 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1521 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1523 1524 1525 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1523 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1525 1526 1527 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1525 def grabpay @grabpay end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1527 1528 1529 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1527 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1529 1530 1531 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1529 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1531 1532 1533 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1531 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1533 1534 1535 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1533 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1535 1536 1537 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1535 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1537 1538 1539 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1537 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1539 1540 1541 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1539 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1541 1542 1543 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1541 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1543 1544 1545 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1543 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1545 1546 1547 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1545 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1547 1548 1549 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1547 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1549 1550 1551 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1549 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1551 1552 1553 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1551 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1553 1554 1555 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1553 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1555 1556 1557 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1555 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1557 1558 1559 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1557 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1559 1560 1561 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1559 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1561 1562 1563 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1561 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1563 1564 1565 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1563 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1565 1566 1567 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1565 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1567 1568 1569 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1567 def promptpay @promptpay end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1569 1570 1571 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1569 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1571 1572 1573 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1571 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1573 1574 1575 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1573 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1575 1576 1577 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1575 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1577 1578 1579 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1577 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
1579 1580 1581 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1579 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1581 1582 1583 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1581 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
1583 1584 1585 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1583 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
1585 1586 1587 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1585 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1587 1588 1589 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1587 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1589 1590 1591 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1589 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1591 1592 1593 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1591 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
1652 1653 1654 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1652 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1593 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, billing_details: BillingDetails, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, grabpay: Grabpay, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, payto: Payto, pix: Pix, promptpay: Promptpay, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_debit: SepaDebit, sofort: Sofort, swish: Swish, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, wechat_pay: WechatPay, zip: Zip, } end |