Class: Stripe::ConfirmationToken::PaymentMethodPreview

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



1590
1591
1592
# File 'lib/stripe/resources/confirmation_token.rb', line 1590

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1592
1593
1594
# File 'lib/stripe/resources/confirmation_token.rb', line 1592

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1594
1595
1596
# File 'lib/stripe/resources/confirmation_token.rb', line 1594

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1596
1597
1598
# File 'lib/stripe/resources/confirmation_token.rb', line 1596

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



1598
1599
1600
# File 'lib/stripe/resources/confirmation_token.rb', line 1598

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



1600
1601
1602
# File 'lib/stripe/resources/confirmation_token.rb', line 1600

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1602
1603
1604
# File 'lib/stripe/resources/confirmation_token.rb', line 1602

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1604
1605
1606
# File 'lib/stripe/resources/confirmation_token.rb', line 1604

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1606
1607
1608
# File 'lib/stripe/resources/confirmation_token.rb', line 1606

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1608
1609
1610
# File 'lib/stripe/resources/confirmation_token.rb', line 1608

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1610
1611
1612
# File 'lib/stripe/resources/confirmation_token.rb', line 1610

def billie
  @billie
end

#billing_detailsObject (readonly)

Attribute for field billing_details



1612
1613
1614
# File 'lib/stripe/resources/confirmation_token.rb', line 1612

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



1614
1615
1616
# File 'lib/stripe/resources/confirmation_token.rb', line 1614

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1616
1617
1618
# File 'lib/stripe/resources/confirmation_token.rb', line 1616

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



1618
1619
1620
# File 'lib/stripe/resources/confirmation_token.rb', line 1618

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1620
1621
1622
# File 'lib/stripe/resources/confirmation_token.rb', line 1620

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1622
1623
1624
# File 'lib/stripe/resources/confirmation_token.rb', line 1622

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1624
1625
1626
# File 'lib/stripe/resources/confirmation_token.rb', line 1624

def crypto
  @crypto
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



1626
1627
1628
# File 'lib/stripe/resources/confirmation_token.rb', line 1626

def customer
  @customer
end

#customer_accountObject (readonly)

Attribute for field customer_account



1628
1629
1630
# File 'lib/stripe/resources/confirmation_token.rb', line 1628

def 
  @customer_account
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1630
1631
1632
# File 'lib/stripe/resources/confirmation_token.rb', line 1630

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1632
1633
1634
# File 'lib/stripe/resources/confirmation_token.rb', line 1632

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1634
1635
1636
# File 'lib/stripe/resources/confirmation_token.rb', line 1634

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1636
1637
1638
# File 'lib/stripe/resources/confirmation_token.rb', line 1636

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1638
1639
1640
# File 'lib/stripe/resources/confirmation_token.rb', line 1638

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1640
1641
1642
# File 'lib/stripe/resources/confirmation_token.rb', line 1640

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1642
1643
1644
# File 'lib/stripe/resources/confirmation_token.rb', line 1642

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1644
1645
1646
# File 'lib/stripe/resources/confirmation_token.rb', line 1644

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1646
1647
1648
# File 'lib/stripe/resources/confirmation_token.rb', line 1646

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1648
1649
1650
# File 'lib/stripe/resources/confirmation_token.rb', line 1648

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1650
1651
1652
# File 'lib/stripe/resources/confirmation_token.rb', line 1650

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1652
1653
1654
# File 'lib/stripe/resources/confirmation_token.rb', line 1652

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1654
1655
1656
# File 'lib/stripe/resources/confirmation_token.rb', line 1654

def kr_card
  @kr_card
end

Attribute for field link



1656
1657
1658
# File 'lib/stripe/resources/confirmation_token.rb', line 1656

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1658
1659
1660
# File 'lib/stripe/resources/confirmation_token.rb', line 1658

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1660
1661
1662
# File 'lib/stripe/resources/confirmation_token.rb', line 1660

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1662
1663
1664
# File 'lib/stripe/resources/confirmation_token.rb', line 1662

def multibanco
  @multibanco
end

Attribute for field naver_pay



1664
1665
1666
# File 'lib/stripe/resources/confirmation_token.rb', line 1664

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1666
1667
1668
# File 'lib/stripe/resources/confirmation_token.rb', line 1666

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1668
1669
1670
# File 'lib/stripe/resources/confirmation_token.rb', line 1668

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1670
1671
1672
# File 'lib/stripe/resources/confirmation_token.rb', line 1670

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1672
1673
1674
# File 'lib/stripe/resources/confirmation_token.rb', line 1672

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1674
1675
1676
# File 'lib/stripe/resources/confirmation_token.rb', line 1674

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



1676
1677
1678
# File 'lib/stripe/resources/confirmation_token.rb', line 1676

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1678
1679
1680
# File 'lib/stripe/resources/confirmation_token.rb', line 1678

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



1680
1681
1682
# File 'lib/stripe/resources/confirmation_token.rb', line 1680

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



1682
1683
1684
# File 'lib/stripe/resources/confirmation_token.rb', line 1682

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1684
1685
1686
# File 'lib/stripe/resources/confirmation_token.rb', line 1684

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1686
1687
1688
# File 'lib/stripe/resources/confirmation_token.rb', line 1686

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1688
1689
1690
# File 'lib/stripe/resources/confirmation_token.rb', line 1688

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1690
1691
1692
# File 'lib/stripe/resources/confirmation_token.rb', line 1690

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1692
1693
1694
# File 'lib/stripe/resources/confirmation_token.rb', line 1692

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1694
1695
1696
# File 'lib/stripe/resources/confirmation_token.rb', line 1694

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1696
1697
1698
# File 'lib/stripe/resources/confirmation_token.rb', line 1696

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1698
1699
1700
# File 'lib/stripe/resources/confirmation_token.rb', line 1698

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1700
1701
1702
# File 'lib/stripe/resources/confirmation_token.rb', line 1700

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1702
1703
1704
# File 'lib/stripe/resources/confirmation_token.rb', line 1702

def sofort
  @sofort
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



1704
1705
1706
# File 'lib/stripe/resources/confirmation_token.rb', line 1704

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



1706
1707
1708
# File 'lib/stripe/resources/confirmation_token.rb', line 1706

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1708
1709
1710
# File 'lib/stripe/resources/confirmation_token.rb', line 1708

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



1710
1711
1712
# File 'lib/stripe/resources/confirmation_token.rb', line 1710

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1712
1713
1714
# File 'lib/stripe/resources/confirmation_token.rb', line 1712

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1714
1715
1716
# File 'lib/stripe/resources/confirmation_token.rb', line 1714

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1716
1717
1718
# File 'lib/stripe/resources/confirmation_token.rb', line 1716

def zip
  @zip
end

Class Method Details

.field_remappingsObject



1783
1784
1785
# File 'lib/stripe/resources/confirmation_token.rb', line 1783

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
# File 'lib/stripe/resources/confirmation_token.rb', line 1718

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_balance: StripeBalance,
    swish: Swish,
    twint: Twint,
    us_bank_account: UsBankAccount,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end