Class: Stripe::ConfirmationToken::PaymentMethodPreview
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#allow_redisplay ⇒ Object
readonly
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer ⇒ Object
readonly
The ID of the Customer to which this PaymentMethod is saved.
-
#customer_account ⇒ Object
readonly
Attribute for field customer_account.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1562 1563 1564 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1562 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1564 1565 1566 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1564 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1566 1567 1568 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1566 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1568 1569 1570 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1568 def alipay @alipay end |
#allow_redisplay ⇒ Object (readonly)
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
1570 1571 1572 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1570 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1572 1573 1574 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1572 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1574 1575 1576 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1574 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1576 1577 1578 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1576 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1578 1579 1580 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1578 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1580 1581 1582 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1580 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1582 1583 1584 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1582 def billie @billie end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
1584 1585 1586 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1584 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
1586 1587 1588 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1586 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1588 1589 1590 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1588 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
1590 1591 1592 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1590 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1592 1593 1594 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1592 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1594 1595 1596 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1594 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1596 1597 1598 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1596 def crypto @crypto end |
#customer ⇒ Object (readonly)
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
1598 1599 1600 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1598 def customer @customer end |
#customer_account ⇒ Object (readonly)
Attribute for field customer_account
1600 1601 1602 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1600 def customer_account @customer_account end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1602 1603 1604 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1602 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1604 1605 1606 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1604 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1606 1607 1608 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1606 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1608 1609 1610 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1608 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1610 1611 1612 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1610 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1612 1613 1614 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1612 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1614 1615 1616 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1614 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1616 1617 1618 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1616 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1618 1619 1620 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1618 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1620 1621 1622 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1620 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1622 1623 1624 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1622 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1624 1625 1626 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1624 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1626 1627 1628 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1626 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1628 1629 1630 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1628 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1630 1631 1632 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1630 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1632 1633 1634 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1632 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1634 1635 1636 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1634 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1636 1637 1638 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1636 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1638 1639 1640 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1638 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1640 1641 1642 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1640 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1642 1643 1644 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1642 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1644 1645 1646 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1644 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1646 1647 1648 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1646 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1648 1649 1650 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1648 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1650 1651 1652 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1650 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1652 1653 1654 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1652 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1654 1655 1656 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1654 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1656 1657 1658 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1656 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1658 1659 1660 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1658 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1660 1661 1662 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1660 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1662 1663 1664 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1662 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1664 1665 1666 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1664 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1666 1667 1668 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1666 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1668 1669 1670 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1668 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1670 1671 1672 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1670 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1672 1673 1674 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1672 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
1674 1675 1676 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1674 def stripe_balance @stripe_balance end |
#swish ⇒ Object (readonly)
Attribute for field swish
1676 1677 1678 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1676 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1678 1679 1680 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1678 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
1680 1681 1682 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1680 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1682 1683 1684 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1682 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1684 1685 1686 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1684 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1686 1687 1688 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1686 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
1752 1753 1754 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1752 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1688 1689 1690 1691 1692 1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 1750 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1688 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, billing_details: BillingDetails, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, rechnung: Rechnung, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, stripe_balance: StripeBalance, swish: Swish, twint: Twint, us_bank_account: UsBankAccount, wechat_pay: WechatPay, zip: Zip, } end |