Class: Stripe::ConfirmationToken::PaymentMethodPreview

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



737
738
739
# File 'lib/stripe/resources/confirmation_token.rb', line 737

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



739
740
741
# File 'lib/stripe/resources/confirmation_token.rb', line 739

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



741
742
743
# File 'lib/stripe/resources/confirmation_token.rb', line 741

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



743
744
745
# File 'lib/stripe/resources/confirmation_token.rb', line 743

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



745
746
747
# File 'lib/stripe/resources/confirmation_token.rb', line 745

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



747
748
749
# File 'lib/stripe/resources/confirmation_token.rb', line 747

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



749
750
751
# File 'lib/stripe/resources/confirmation_token.rb', line 749

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



751
752
753
# File 'lib/stripe/resources/confirmation_token.rb', line 751

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



753
754
755
# File 'lib/stripe/resources/confirmation_token.rb', line 753

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



755
756
757
# File 'lib/stripe/resources/confirmation_token.rb', line 755

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



757
758
759
# File 'lib/stripe/resources/confirmation_token.rb', line 757

def billie
  @billie
end

#billing_detailsObject (readonly)

Attribute for field billing_details



759
760
761
# File 'lib/stripe/resources/confirmation_token.rb', line 759

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



761
762
763
# File 'lib/stripe/resources/confirmation_token.rb', line 761

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



763
764
765
# File 'lib/stripe/resources/confirmation_token.rb', line 763

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



765
766
767
# File 'lib/stripe/resources/confirmation_token.rb', line 765

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



767
768
769
# File 'lib/stripe/resources/confirmation_token.rb', line 767

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



769
770
771
# File 'lib/stripe/resources/confirmation_token.rb', line 769

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



771
772
773
# File 'lib/stripe/resources/confirmation_token.rb', line 771

def crypto
  @crypto
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



773
774
775
# File 'lib/stripe/resources/confirmation_token.rb', line 773

def customer
  @customer
end

#customer_accountObject (readonly)

Attribute for field customer_account



775
776
777
# File 'lib/stripe/resources/confirmation_token.rb', line 775

def 
  @customer_account
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



777
778
779
# File 'lib/stripe/resources/confirmation_token.rb', line 777

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



779
780
781
# File 'lib/stripe/resources/confirmation_token.rb', line 779

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



781
782
783
# File 'lib/stripe/resources/confirmation_token.rb', line 781

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



783
784
785
# File 'lib/stripe/resources/confirmation_token.rb', line 783

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



785
786
787
# File 'lib/stripe/resources/confirmation_token.rb', line 785

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



787
788
789
# File 'lib/stripe/resources/confirmation_token.rb', line 787

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



789
790
791
# File 'lib/stripe/resources/confirmation_token.rb', line 789

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



791
792
793
# File 'lib/stripe/resources/confirmation_token.rb', line 791

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



793
794
795
# File 'lib/stripe/resources/confirmation_token.rb', line 793

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



795
796
797
# File 'lib/stripe/resources/confirmation_token.rb', line 795

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



797
798
799
# File 'lib/stripe/resources/confirmation_token.rb', line 797

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



799
800
801
# File 'lib/stripe/resources/confirmation_token.rb', line 799

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



801
802
803
# File 'lib/stripe/resources/confirmation_token.rb', line 801

def kr_card
  @kr_card
end

Attribute for field link



803
804
805
# File 'lib/stripe/resources/confirmation_token.rb', line 803

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



805
806
807
# File 'lib/stripe/resources/confirmation_token.rb', line 805

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



807
808
809
# File 'lib/stripe/resources/confirmation_token.rb', line 807

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



809
810
811
# File 'lib/stripe/resources/confirmation_token.rb', line 809

def multibanco
  @multibanco
end

Attribute for field naver_pay



811
812
813
# File 'lib/stripe/resources/confirmation_token.rb', line 811

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



813
814
815
# File 'lib/stripe/resources/confirmation_token.rb', line 813

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



815
816
817
# File 'lib/stripe/resources/confirmation_token.rb', line 815

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



817
818
819
# File 'lib/stripe/resources/confirmation_token.rb', line 817

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



819
820
821
# File 'lib/stripe/resources/confirmation_token.rb', line 819

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



821
822
823
# File 'lib/stripe/resources/confirmation_token.rb', line 821

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



823
824
825
# File 'lib/stripe/resources/confirmation_token.rb', line 823

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



825
826
827
# File 'lib/stripe/resources/confirmation_token.rb', line 825

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



827
828
829
# File 'lib/stripe/resources/confirmation_token.rb', line 827

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



829
830
831
# File 'lib/stripe/resources/confirmation_token.rb', line 829

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



831
832
833
# File 'lib/stripe/resources/confirmation_token.rb', line 831

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



833
834
835
# File 'lib/stripe/resources/confirmation_token.rb', line 833

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



835
836
837
# File 'lib/stripe/resources/confirmation_token.rb', line 835

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



837
838
839
# File 'lib/stripe/resources/confirmation_token.rb', line 837

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



839
840
841
# File 'lib/stripe/resources/confirmation_token.rb', line 839

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



841
842
843
# File 'lib/stripe/resources/confirmation_token.rb', line 841

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



843
844
845
# File 'lib/stripe/resources/confirmation_token.rb', line 843

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



845
846
847
# File 'lib/stripe/resources/confirmation_token.rb', line 845

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



847
848
849
# File 'lib/stripe/resources/confirmation_token.rb', line 847

def sofort
  @sofort
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



849
850
851
# File 'lib/stripe/resources/confirmation_token.rb', line 849

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



851
852
853
# File 'lib/stripe/resources/confirmation_token.rb', line 851

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



853
854
855
# File 'lib/stripe/resources/confirmation_token.rb', line 853

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



855
856
857
# File 'lib/stripe/resources/confirmation_token.rb', line 855

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



857
858
859
# File 'lib/stripe/resources/confirmation_token.rb', line 857

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



859
860
861
# File 'lib/stripe/resources/confirmation_token.rb', line 859

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



861
862
863
# File 'lib/stripe/resources/confirmation_token.rb', line 861

def zip
  @zip
end