Class: Stripe::ConfirmationToken::PaymentMethodPreview
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#allow_redisplay ⇒ Object
readonly
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer ⇒ Object
readonly
The ID of the Customer to which this PaymentMethod is saved.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
682 683 684 |
# File 'lib/stripe/resources/confirmation_token.rb', line 682 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
684 685 686 |
# File 'lib/stripe/resources/confirmation_token.rb', line 684 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
686 687 688 |
# File 'lib/stripe/resources/confirmation_token.rb', line 686 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
688 689 690 |
# File 'lib/stripe/resources/confirmation_token.rb', line 688 def alipay @alipay end |
#allow_redisplay ⇒ Object (readonly)
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
690 691 692 |
# File 'lib/stripe/resources/confirmation_token.rb', line 690 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object (readonly)
Attribute for field alma
692 693 694 |
# File 'lib/stripe/resources/confirmation_token.rb', line 692 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
694 695 696 |
# File 'lib/stripe/resources/confirmation_token.rb', line 694 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
696 697 698 |
# File 'lib/stripe/resources/confirmation_token.rb', line 696 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
698 699 700 |
# File 'lib/stripe/resources/confirmation_token.rb', line 698 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
700 701 702 |
# File 'lib/stripe/resources/confirmation_token.rb', line 700 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
702 703 704 |
# File 'lib/stripe/resources/confirmation_token.rb', line 702 def billie @billie end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
704 705 706 |
# File 'lib/stripe/resources/confirmation_token.rb', line 704 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
706 707 708 |
# File 'lib/stripe/resources/confirmation_token.rb', line 706 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
708 709 710 |
# File 'lib/stripe/resources/confirmation_token.rb', line 708 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
710 711 712 |
# File 'lib/stripe/resources/confirmation_token.rb', line 710 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
712 713 714 |
# File 'lib/stripe/resources/confirmation_token.rb', line 712 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
714 715 716 |
# File 'lib/stripe/resources/confirmation_token.rb', line 714 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
716 717 718 |
# File 'lib/stripe/resources/confirmation_token.rb', line 716 def crypto @crypto end |
#customer ⇒ Object (readonly)
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
718 719 720 |
# File 'lib/stripe/resources/confirmation_token.rb', line 718 def customer @customer end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
720 721 722 |
# File 'lib/stripe/resources/confirmation_token.rb', line 720 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
722 723 724 |
# File 'lib/stripe/resources/confirmation_token.rb', line 722 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
724 725 726 |
# File 'lib/stripe/resources/confirmation_token.rb', line 724 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
726 727 728 |
# File 'lib/stripe/resources/confirmation_token.rb', line 726 def giropay @giropay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
728 729 730 |
# File 'lib/stripe/resources/confirmation_token.rb', line 728 def grabpay @grabpay end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
730 731 732 |
# File 'lib/stripe/resources/confirmation_token.rb', line 730 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
732 733 734 |
# File 'lib/stripe/resources/confirmation_token.rb', line 732 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
734 735 736 |
# File 'lib/stripe/resources/confirmation_token.rb', line 734 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
736 737 738 |
# File 'lib/stripe/resources/confirmation_token.rb', line 736 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
738 739 740 |
# File 'lib/stripe/resources/confirmation_token.rb', line 738 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
740 741 742 |
# File 'lib/stripe/resources/confirmation_token.rb', line 740 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
742 743 744 |
# File 'lib/stripe/resources/confirmation_token.rb', line 742 def link @link end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
744 745 746 |
# File 'lib/stripe/resources/confirmation_token.rb', line 744 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
746 747 748 |
# File 'lib/stripe/resources/confirmation_token.rb', line 746 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
748 749 750 |
# File 'lib/stripe/resources/confirmation_token.rb', line 748 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
750 751 752 |
# File 'lib/stripe/resources/confirmation_token.rb', line 750 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
752 753 754 |
# File 'lib/stripe/resources/confirmation_token.rb', line 752 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
754 755 756 |
# File 'lib/stripe/resources/confirmation_token.rb', line 754 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
756 757 758 |
# File 'lib/stripe/resources/confirmation_token.rb', line 756 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
758 759 760 |
# File 'lib/stripe/resources/confirmation_token.rb', line 758 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
760 761 762 |
# File 'lib/stripe/resources/confirmation_token.rb', line 760 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
762 763 764 |
# File 'lib/stripe/resources/confirmation_token.rb', line 762 def paypal @paypal end |
#pix ⇒ Object (readonly)
Attribute for field pix
764 765 766 |
# File 'lib/stripe/resources/confirmation_token.rb', line 764 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
766 767 768 |
# File 'lib/stripe/resources/confirmation_token.rb', line 766 def promptpay @promptpay end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
768 769 770 |
# File 'lib/stripe/resources/confirmation_token.rb', line 768 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
770 771 772 |
# File 'lib/stripe/resources/confirmation_token.rb', line 770 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
772 773 774 |
# File 'lib/stripe/resources/confirmation_token.rb', line 772 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
774 775 776 |
# File 'lib/stripe/resources/confirmation_token.rb', line 774 def sepa_debit @sepa_debit end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
776 777 778 |
# File 'lib/stripe/resources/confirmation_token.rb', line 776 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
778 779 780 |
# File 'lib/stripe/resources/confirmation_token.rb', line 778 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
780 781 782 |
# File 'lib/stripe/resources/confirmation_token.rb', line 780 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
782 783 784 |
# File 'lib/stripe/resources/confirmation_token.rb', line 782 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
784 785 786 |
# File 'lib/stripe/resources/confirmation_token.rb', line 784 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
786 787 788 |
# File 'lib/stripe/resources/confirmation_token.rb', line 786 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
788 789 790 |
# File 'lib/stripe/resources/confirmation_token.rb', line 788 def zip @zip end |