Class: Stripe::ConfirmationToken::PaymentMethodPreview
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#allow_redisplay ⇒ Object
readonly
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#customer ⇒ Object
readonly
The ID of the Customer to which this PaymentMethod is saved.
-
#customer_account ⇒ Object
readonly
Attribute for field customer_account.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
737 738 739 |
# File 'lib/stripe/resources/confirmation_token.rb', line 737 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
739 740 741 |
# File 'lib/stripe/resources/confirmation_token.rb', line 739 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
741 742 743 |
# File 'lib/stripe/resources/confirmation_token.rb', line 741 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
743 744 745 |
# File 'lib/stripe/resources/confirmation_token.rb', line 743 def alipay @alipay end |
#allow_redisplay ⇒ Object (readonly)
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
745 746 747 |
# File 'lib/stripe/resources/confirmation_token.rb', line 745 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object (readonly)
Attribute for field alma
747 748 749 |
# File 'lib/stripe/resources/confirmation_token.rb', line 747 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
749 750 751 |
# File 'lib/stripe/resources/confirmation_token.rb', line 749 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
751 752 753 |
# File 'lib/stripe/resources/confirmation_token.rb', line 751 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
753 754 755 |
# File 'lib/stripe/resources/confirmation_token.rb', line 753 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
755 756 757 |
# File 'lib/stripe/resources/confirmation_token.rb', line 755 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
757 758 759 |
# File 'lib/stripe/resources/confirmation_token.rb', line 757 def billie @billie end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
759 760 761 |
# File 'lib/stripe/resources/confirmation_token.rb', line 759 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
761 762 763 |
# File 'lib/stripe/resources/confirmation_token.rb', line 761 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
763 764 765 |
# File 'lib/stripe/resources/confirmation_token.rb', line 763 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
765 766 767 |
# File 'lib/stripe/resources/confirmation_token.rb', line 765 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
767 768 769 |
# File 'lib/stripe/resources/confirmation_token.rb', line 767 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
769 770 771 |
# File 'lib/stripe/resources/confirmation_token.rb', line 769 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
771 772 773 |
# File 'lib/stripe/resources/confirmation_token.rb', line 771 def crypto @crypto end |
#customer ⇒ Object (readonly)
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
773 774 775 |
# File 'lib/stripe/resources/confirmation_token.rb', line 773 def customer @customer end |
#customer_account ⇒ Object (readonly)
Attribute for field customer_account
775 776 777 |
# File 'lib/stripe/resources/confirmation_token.rb', line 775 def customer_account @customer_account end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
777 778 779 |
# File 'lib/stripe/resources/confirmation_token.rb', line 777 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
779 780 781 |
# File 'lib/stripe/resources/confirmation_token.rb', line 779 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
781 782 783 |
# File 'lib/stripe/resources/confirmation_token.rb', line 781 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
783 784 785 |
# File 'lib/stripe/resources/confirmation_token.rb', line 783 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
785 786 787 |
# File 'lib/stripe/resources/confirmation_token.rb', line 785 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
787 788 789 |
# File 'lib/stripe/resources/confirmation_token.rb', line 787 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
789 790 791 |
# File 'lib/stripe/resources/confirmation_token.rb', line 789 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
791 792 793 |
# File 'lib/stripe/resources/confirmation_token.rb', line 791 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
793 794 795 |
# File 'lib/stripe/resources/confirmation_token.rb', line 793 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
795 796 797 |
# File 'lib/stripe/resources/confirmation_token.rb', line 795 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
797 798 799 |
# File 'lib/stripe/resources/confirmation_token.rb', line 797 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
799 800 801 |
# File 'lib/stripe/resources/confirmation_token.rb', line 799 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
801 802 803 |
# File 'lib/stripe/resources/confirmation_token.rb', line 801 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
803 804 805 |
# File 'lib/stripe/resources/confirmation_token.rb', line 803 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
805 806 807 |
# File 'lib/stripe/resources/confirmation_token.rb', line 805 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
807 808 809 |
# File 'lib/stripe/resources/confirmation_token.rb', line 807 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
809 810 811 |
# File 'lib/stripe/resources/confirmation_token.rb', line 809 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
811 812 813 |
# File 'lib/stripe/resources/confirmation_token.rb', line 811 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
813 814 815 |
# File 'lib/stripe/resources/confirmation_token.rb', line 813 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
815 816 817 |
# File 'lib/stripe/resources/confirmation_token.rb', line 815 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
817 818 819 |
# File 'lib/stripe/resources/confirmation_token.rb', line 817 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
819 820 821 |
# File 'lib/stripe/resources/confirmation_token.rb', line 819 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
821 822 823 |
# File 'lib/stripe/resources/confirmation_token.rb', line 821 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
823 824 825 |
# File 'lib/stripe/resources/confirmation_token.rb', line 823 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
825 826 827 |
# File 'lib/stripe/resources/confirmation_token.rb', line 825 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
827 828 829 |
# File 'lib/stripe/resources/confirmation_token.rb', line 827 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
829 830 831 |
# File 'lib/stripe/resources/confirmation_token.rb', line 829 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
831 832 833 |
# File 'lib/stripe/resources/confirmation_token.rb', line 831 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
833 834 835 |
# File 'lib/stripe/resources/confirmation_token.rb', line 833 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
835 836 837 |
# File 'lib/stripe/resources/confirmation_token.rb', line 835 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
837 838 839 |
# File 'lib/stripe/resources/confirmation_token.rb', line 837 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
839 840 841 |
# File 'lib/stripe/resources/confirmation_token.rb', line 839 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
841 842 843 |
# File 'lib/stripe/resources/confirmation_token.rb', line 841 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
843 844 845 |
# File 'lib/stripe/resources/confirmation_token.rb', line 843 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
845 846 847 |
# File 'lib/stripe/resources/confirmation_token.rb', line 845 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
847 848 849 |
# File 'lib/stripe/resources/confirmation_token.rb', line 847 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
849 850 851 |
# File 'lib/stripe/resources/confirmation_token.rb', line 849 def stripe_balance @stripe_balance end |
#swish ⇒ Object (readonly)
Attribute for field swish
851 852 853 |
# File 'lib/stripe/resources/confirmation_token.rb', line 851 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
853 854 855 |
# File 'lib/stripe/resources/confirmation_token.rb', line 853 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
855 856 857 |
# File 'lib/stripe/resources/confirmation_token.rb', line 855 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
857 858 859 |
# File 'lib/stripe/resources/confirmation_token.rb', line 857 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
859 860 861 |
# File 'lib/stripe/resources/confirmation_token.rb', line 859 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
861 862 863 |
# File 'lib/stripe/resources/confirmation_token.rb', line 861 def zip @zip end |