Class: Stripe::ConfirmationToken::PaymentMethodPreview

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, Promptpay, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



681
682
683
# File 'lib/stripe/resources/confirmation_token.rb', line 681

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



683
684
685
# File 'lib/stripe/resources/confirmation_token.rb', line 683

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



685
686
687
# File 'lib/stripe/resources/confirmation_token.rb', line 685

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



687
688
689
# File 'lib/stripe/resources/confirmation_token.rb', line 687

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



689
690
691
# File 'lib/stripe/resources/confirmation_token.rb', line 689

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



691
692
693
# File 'lib/stripe/resources/confirmation_token.rb', line 691

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



693
694
695
# File 'lib/stripe/resources/confirmation_token.rb', line 693

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



695
696
697
# File 'lib/stripe/resources/confirmation_token.rb', line 695

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



697
698
699
# File 'lib/stripe/resources/confirmation_token.rb', line 697

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



699
700
701
# File 'lib/stripe/resources/confirmation_token.rb', line 699

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



701
702
703
# File 'lib/stripe/resources/confirmation_token.rb', line 701

def billie
  @billie
end

#billing_detailsObject (readonly)

Attribute for field billing_details



703
704
705
# File 'lib/stripe/resources/confirmation_token.rb', line 703

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



705
706
707
# File 'lib/stripe/resources/confirmation_token.rb', line 705

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



707
708
709
# File 'lib/stripe/resources/confirmation_token.rb', line 707

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



709
710
711
# File 'lib/stripe/resources/confirmation_token.rb', line 709

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



711
712
713
# File 'lib/stripe/resources/confirmation_token.rb', line 711

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



713
714
715
# File 'lib/stripe/resources/confirmation_token.rb', line 713

def cashapp
  @cashapp
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



715
716
717
# File 'lib/stripe/resources/confirmation_token.rb', line 715

def customer
  @customer
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



717
718
719
# File 'lib/stripe/resources/confirmation_token.rb', line 717

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



719
720
721
# File 'lib/stripe/resources/confirmation_token.rb', line 719

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



721
722
723
# File 'lib/stripe/resources/confirmation_token.rb', line 721

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



723
724
725
# File 'lib/stripe/resources/confirmation_token.rb', line 723

def giropay
  @giropay
end

#grabpayObject (readonly)

Attribute for field grabpay



725
726
727
# File 'lib/stripe/resources/confirmation_token.rb', line 725

def grabpay
  @grabpay
end

#idealObject (readonly)

Attribute for field ideal



727
728
729
# File 'lib/stripe/resources/confirmation_token.rb', line 727

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



729
730
731
# File 'lib/stripe/resources/confirmation_token.rb', line 729

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



731
732
733
# File 'lib/stripe/resources/confirmation_token.rb', line 731

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



733
734
735
# File 'lib/stripe/resources/confirmation_token.rb', line 733

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



735
736
737
# File 'lib/stripe/resources/confirmation_token.rb', line 735

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



737
738
739
# File 'lib/stripe/resources/confirmation_token.rb', line 737

def kr_card
  @kr_card
end

Attribute for field link



739
740
741
# File 'lib/stripe/resources/confirmation_token.rb', line 739

def link
  @link
end

#mobilepayObject (readonly)

Attribute for field mobilepay



741
742
743
# File 'lib/stripe/resources/confirmation_token.rb', line 741

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



743
744
745
# File 'lib/stripe/resources/confirmation_token.rb', line 743

def multibanco
  @multibanco
end

Attribute for field naver_pay



745
746
747
# File 'lib/stripe/resources/confirmation_token.rb', line 745

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



747
748
749
# File 'lib/stripe/resources/confirmation_token.rb', line 747

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



749
750
751
# File 'lib/stripe/resources/confirmation_token.rb', line 749

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



751
752
753
# File 'lib/stripe/resources/confirmation_token.rb', line 751

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



753
754
755
# File 'lib/stripe/resources/confirmation_token.rb', line 753

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



755
756
757
# File 'lib/stripe/resources/confirmation_token.rb', line 755

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



757
758
759
# File 'lib/stripe/resources/confirmation_token.rb', line 757

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



759
760
761
# File 'lib/stripe/resources/confirmation_token.rb', line 759

def paypal
  @paypal
end

#pixObject (readonly)

Attribute for field pix



761
762
763
# File 'lib/stripe/resources/confirmation_token.rb', line 761

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



763
764
765
# File 'lib/stripe/resources/confirmation_token.rb', line 763

def promptpay
  @promptpay
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



765
766
767
# File 'lib/stripe/resources/confirmation_token.rb', line 765

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



767
768
769
# File 'lib/stripe/resources/confirmation_token.rb', line 767

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



769
770
771
# File 'lib/stripe/resources/confirmation_token.rb', line 769

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



771
772
773
# File 'lib/stripe/resources/confirmation_token.rb', line 771

def sepa_debit
  @sepa_debit
end

#sofortObject (readonly)

Attribute for field sofort



773
774
775
# File 'lib/stripe/resources/confirmation_token.rb', line 773

def sofort
  @sofort
end

#swishObject (readonly)

Attribute for field swish



775
776
777
# File 'lib/stripe/resources/confirmation_token.rb', line 775

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



777
778
779
# File 'lib/stripe/resources/confirmation_token.rb', line 777

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



779
780
781
# File 'lib/stripe/resources/confirmation_token.rb', line 779

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



781
782
783
# File 'lib/stripe/resources/confirmation_token.rb', line 781

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



783
784
785
# File 'lib/stripe/resources/confirmation_token.rb', line 783

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



785
786
787
# File 'lib/stripe/resources/confirmation_token.rb', line 785

def zip
  @zip
end