Class: Stripe::ConfirmationToken::PaymentMethodPreview

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



732
733
734
# File 'lib/stripe/resources/confirmation_token.rb', line 732

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



734
735
736
# File 'lib/stripe/resources/confirmation_token.rb', line 734

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



736
737
738
# File 'lib/stripe/resources/confirmation_token.rb', line 736

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



738
739
740
# File 'lib/stripe/resources/confirmation_token.rb', line 738

def alipay
  @alipay
end

#allow_redisplayObject (readonly)

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.



740
741
742
# File 'lib/stripe/resources/confirmation_token.rb', line 740

def allow_redisplay
  @allow_redisplay
end

#almaObject (readonly)

Attribute for field alma



742
743
744
# File 'lib/stripe/resources/confirmation_token.rb', line 742

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



744
745
746
# File 'lib/stripe/resources/confirmation_token.rb', line 744

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



746
747
748
# File 'lib/stripe/resources/confirmation_token.rb', line 746

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



748
749
750
# File 'lib/stripe/resources/confirmation_token.rb', line 748

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



750
751
752
# File 'lib/stripe/resources/confirmation_token.rb', line 750

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



752
753
754
# File 'lib/stripe/resources/confirmation_token.rb', line 752

def billie
  @billie
end

#billing_detailsObject (readonly)

Attribute for field billing_details



754
755
756
# File 'lib/stripe/resources/confirmation_token.rb', line 754

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



756
757
758
# File 'lib/stripe/resources/confirmation_token.rb', line 756

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



758
759
760
# File 'lib/stripe/resources/confirmation_token.rb', line 758

def boleto
  @boleto
end

#cardObject (readonly)

Attribute for field card



760
761
762
# File 'lib/stripe/resources/confirmation_token.rb', line 760

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



762
763
764
# File 'lib/stripe/resources/confirmation_token.rb', line 762

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



764
765
766
# File 'lib/stripe/resources/confirmation_token.rb', line 764

def cashapp
  @cashapp
end

#customerObject (readonly)

The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.



766
767
768
# File 'lib/stripe/resources/confirmation_token.rb', line 766

def customer
  @customer
end

#customer_accountObject (readonly)

Attribute for field customer_account



768
769
770
# File 'lib/stripe/resources/confirmation_token.rb', line 768

def 
  @customer_account
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



770
771
772
# File 'lib/stripe/resources/confirmation_token.rb', line 770

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



772
773
774
# File 'lib/stripe/resources/confirmation_token.rb', line 772

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



774
775
776
# File 'lib/stripe/resources/confirmation_token.rb', line 774

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



776
777
778
# File 'lib/stripe/resources/confirmation_token.rb', line 776

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



778
779
780
# File 'lib/stripe/resources/confirmation_token.rb', line 778

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



780
781
782
# File 'lib/stripe/resources/confirmation_token.rb', line 780

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



782
783
784
# File 'lib/stripe/resources/confirmation_token.rb', line 782

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



784
785
786
# File 'lib/stripe/resources/confirmation_token.rb', line 784

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



786
787
788
# File 'lib/stripe/resources/confirmation_token.rb', line 786

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



788
789
790
# File 'lib/stripe/resources/confirmation_token.rb', line 788

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



790
791
792
# File 'lib/stripe/resources/confirmation_token.rb', line 790

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



792
793
794
# File 'lib/stripe/resources/confirmation_token.rb', line 792

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



794
795
796
# File 'lib/stripe/resources/confirmation_token.rb', line 794

def kr_card
  @kr_card
end

Attribute for field link



796
797
798
# File 'lib/stripe/resources/confirmation_token.rb', line 796

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



798
799
800
# File 'lib/stripe/resources/confirmation_token.rb', line 798

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



800
801
802
# File 'lib/stripe/resources/confirmation_token.rb', line 800

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



802
803
804
# File 'lib/stripe/resources/confirmation_token.rb', line 802

def multibanco
  @multibanco
end

Attribute for field naver_pay



804
805
806
# File 'lib/stripe/resources/confirmation_token.rb', line 804

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



806
807
808
# File 'lib/stripe/resources/confirmation_token.rb', line 806

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



808
809
810
# File 'lib/stripe/resources/confirmation_token.rb', line 808

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



810
811
812
# File 'lib/stripe/resources/confirmation_token.rb', line 810

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



812
813
814
# File 'lib/stripe/resources/confirmation_token.rb', line 812

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



814
815
816
# File 'lib/stripe/resources/confirmation_token.rb', line 814

def payco
  @payco
end

#paynowObject (readonly)

Attribute for field paynow



816
817
818
# File 'lib/stripe/resources/confirmation_token.rb', line 816

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



818
819
820
# File 'lib/stripe/resources/confirmation_token.rb', line 818

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



820
821
822
# File 'lib/stripe/resources/confirmation_token.rb', line 820

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



822
823
824
# File 'lib/stripe/resources/confirmation_token.rb', line 822

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



824
825
826
# File 'lib/stripe/resources/confirmation_token.rb', line 824

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



826
827
828
# File 'lib/stripe/resources/confirmation_token.rb', line 826

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



828
829
830
# File 'lib/stripe/resources/confirmation_token.rb', line 828

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



830
831
832
# File 'lib/stripe/resources/confirmation_token.rb', line 830

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



832
833
834
# File 'lib/stripe/resources/confirmation_token.rb', line 832

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



834
835
836
# File 'lib/stripe/resources/confirmation_token.rb', line 834

def satispay
  @satispay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



836
837
838
# File 'lib/stripe/resources/confirmation_token.rb', line 836

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



838
839
840
# File 'lib/stripe/resources/confirmation_token.rb', line 838

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



840
841
842
# File 'lib/stripe/resources/confirmation_token.rb', line 840

def sofort
  @sofort
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



842
843
844
# File 'lib/stripe/resources/confirmation_token.rb', line 842

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



844
845
846
# File 'lib/stripe/resources/confirmation_token.rb', line 844

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



846
847
848
# File 'lib/stripe/resources/confirmation_token.rb', line 846

def twint
  @twint
end

#typeObject (readonly)

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



848
849
850
# File 'lib/stripe/resources/confirmation_token.rb', line 848

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



850
851
852
# File 'lib/stripe/resources/confirmation_token.rb', line 850

def 
  @us_bank_account
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



852
853
854
# File 'lib/stripe/resources/confirmation_token.rb', line 852

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



854
855
856
# File 'lib/stripe/resources/confirmation_token.rb', line 854

def zip
  @zip
end