Class: Stripe::ConfirmationToken::PaymentMethodPreview
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaDebit, Shopeepay, Sofort, StripeBalance, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#allow_redisplay ⇒ Object
readonly
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer ⇒ Object
readonly
The ID of the Customer to which this PaymentMethod is saved.
-
#customer_account ⇒ Object
readonly
Attribute for field customer_account.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
732 733 734 |
# File 'lib/stripe/resources/confirmation_token.rb', line 732 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
734 735 736 |
# File 'lib/stripe/resources/confirmation_token.rb', line 734 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
736 737 738 |
# File 'lib/stripe/resources/confirmation_token.rb', line 736 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
738 739 740 |
# File 'lib/stripe/resources/confirmation_token.rb', line 738 def alipay @alipay end |
#allow_redisplay ⇒ Object (readonly)
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
740 741 742 |
# File 'lib/stripe/resources/confirmation_token.rb', line 740 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object (readonly)
Attribute for field alma
742 743 744 |
# File 'lib/stripe/resources/confirmation_token.rb', line 742 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
744 745 746 |
# File 'lib/stripe/resources/confirmation_token.rb', line 744 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
746 747 748 |
# File 'lib/stripe/resources/confirmation_token.rb', line 746 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
748 749 750 |
# File 'lib/stripe/resources/confirmation_token.rb', line 748 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
750 751 752 |
# File 'lib/stripe/resources/confirmation_token.rb', line 750 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
752 753 754 |
# File 'lib/stripe/resources/confirmation_token.rb', line 752 def billie @billie end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
754 755 756 |
# File 'lib/stripe/resources/confirmation_token.rb', line 754 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
756 757 758 |
# File 'lib/stripe/resources/confirmation_token.rb', line 756 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
758 759 760 |
# File 'lib/stripe/resources/confirmation_token.rb', line 758 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
760 761 762 |
# File 'lib/stripe/resources/confirmation_token.rb', line 760 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
762 763 764 |
# File 'lib/stripe/resources/confirmation_token.rb', line 762 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
764 765 766 |
# File 'lib/stripe/resources/confirmation_token.rb', line 764 def cashapp @cashapp end |
#customer ⇒ Object (readonly)
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
766 767 768 |
# File 'lib/stripe/resources/confirmation_token.rb', line 766 def customer @customer end |
#customer_account ⇒ Object (readonly)
Attribute for field customer_account
768 769 770 |
# File 'lib/stripe/resources/confirmation_token.rb', line 768 def customer_account @customer_account end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
770 771 772 |
# File 'lib/stripe/resources/confirmation_token.rb', line 770 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
772 773 774 |
# File 'lib/stripe/resources/confirmation_token.rb', line 772 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
774 775 776 |
# File 'lib/stripe/resources/confirmation_token.rb', line 774 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
776 777 778 |
# File 'lib/stripe/resources/confirmation_token.rb', line 776 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
778 779 780 |
# File 'lib/stripe/resources/confirmation_token.rb', line 778 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
780 781 782 |
# File 'lib/stripe/resources/confirmation_token.rb', line 780 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
782 783 784 |
# File 'lib/stripe/resources/confirmation_token.rb', line 782 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
784 785 786 |
# File 'lib/stripe/resources/confirmation_token.rb', line 784 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
786 787 788 |
# File 'lib/stripe/resources/confirmation_token.rb', line 786 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
788 789 790 |
# File 'lib/stripe/resources/confirmation_token.rb', line 788 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
790 791 792 |
# File 'lib/stripe/resources/confirmation_token.rb', line 790 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
792 793 794 |
# File 'lib/stripe/resources/confirmation_token.rb', line 792 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
794 795 796 |
# File 'lib/stripe/resources/confirmation_token.rb', line 794 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
796 797 798 |
# File 'lib/stripe/resources/confirmation_token.rb', line 796 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
798 799 800 |
# File 'lib/stripe/resources/confirmation_token.rb', line 798 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
800 801 802 |
# File 'lib/stripe/resources/confirmation_token.rb', line 800 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
802 803 804 |
# File 'lib/stripe/resources/confirmation_token.rb', line 802 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
804 805 806 |
# File 'lib/stripe/resources/confirmation_token.rb', line 804 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
806 807 808 |
# File 'lib/stripe/resources/confirmation_token.rb', line 806 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
808 809 810 |
# File 'lib/stripe/resources/confirmation_token.rb', line 808 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
810 811 812 |
# File 'lib/stripe/resources/confirmation_token.rb', line 810 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
812 813 814 |
# File 'lib/stripe/resources/confirmation_token.rb', line 812 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
814 815 816 |
# File 'lib/stripe/resources/confirmation_token.rb', line 814 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
816 817 818 |
# File 'lib/stripe/resources/confirmation_token.rb', line 816 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
818 819 820 |
# File 'lib/stripe/resources/confirmation_token.rb', line 818 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
820 821 822 |
# File 'lib/stripe/resources/confirmation_token.rb', line 820 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
822 823 824 |
# File 'lib/stripe/resources/confirmation_token.rb', line 822 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
824 825 826 |
# File 'lib/stripe/resources/confirmation_token.rb', line 824 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
826 827 828 |
# File 'lib/stripe/resources/confirmation_token.rb', line 826 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
828 829 830 |
# File 'lib/stripe/resources/confirmation_token.rb', line 828 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
830 831 832 |
# File 'lib/stripe/resources/confirmation_token.rb', line 830 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
832 833 834 |
# File 'lib/stripe/resources/confirmation_token.rb', line 832 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
834 835 836 |
# File 'lib/stripe/resources/confirmation_token.rb', line 834 def satispay @satispay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
836 837 838 |
# File 'lib/stripe/resources/confirmation_token.rb', line 836 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
838 839 840 |
# File 'lib/stripe/resources/confirmation_token.rb', line 838 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
840 841 842 |
# File 'lib/stripe/resources/confirmation_token.rb', line 840 def sofort @sofort end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
842 843 844 |
# File 'lib/stripe/resources/confirmation_token.rb', line 842 def stripe_balance @stripe_balance end |
#swish ⇒ Object (readonly)
Attribute for field swish
844 845 846 |
# File 'lib/stripe/resources/confirmation_token.rb', line 844 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
846 847 848 |
# File 'lib/stripe/resources/confirmation_token.rb', line 846 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
848 849 850 |
# File 'lib/stripe/resources/confirmation_token.rb', line 848 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
850 851 852 |
# File 'lib/stripe/resources/confirmation_token.rb', line 850 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
852 853 854 |
# File 'lib/stripe/resources/confirmation_token.rb', line 852 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
854 855 856 |
# File 'lib/stripe/resources/confirmation_token.rb', line 854 def zip @zip end |