Class: Stripe::ConfirmationToken::PaymentMethodPreview
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#allow_redisplay ⇒ Object
readonly
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer ⇒ Object
readonly
The ID of the Customer to which this PaymentMethod is saved.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
861 862 863 |
# File 'lib/stripe/resources/confirmation_token.rb', line 861 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
864 865 866 |
# File 'lib/stripe/resources/confirmation_token.rb', line 864 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
867 868 869 |
# File 'lib/stripe/resources/confirmation_token.rb', line 867 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
870 871 872 |
# File 'lib/stripe/resources/confirmation_token.rb', line 870 def alipay @alipay end |
#allow_redisplay ⇒ Object (readonly)
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
873 874 875 |
# File 'lib/stripe/resources/confirmation_token.rb', line 873 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object (readonly)
Attribute for field alma
876 877 878 |
# File 'lib/stripe/resources/confirmation_token.rb', line 876 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
879 880 881 |
# File 'lib/stripe/resources/confirmation_token.rb', line 879 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
882 883 884 |
# File 'lib/stripe/resources/confirmation_token.rb', line 882 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
885 886 887 |
# File 'lib/stripe/resources/confirmation_token.rb', line 885 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
888 889 890 |
# File 'lib/stripe/resources/confirmation_token.rb', line 888 def bancontact @bancontact end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
891 892 893 |
# File 'lib/stripe/resources/confirmation_token.rb', line 891 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
894 895 896 |
# File 'lib/stripe/resources/confirmation_token.rb', line 894 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
897 898 899 |
# File 'lib/stripe/resources/confirmation_token.rb', line 897 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
900 901 902 |
# File 'lib/stripe/resources/confirmation_token.rb', line 900 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
903 904 905 |
# File 'lib/stripe/resources/confirmation_token.rb', line 903 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
906 907 908 |
# File 'lib/stripe/resources/confirmation_token.rb', line 906 def cashapp @cashapp end |
#customer ⇒ Object (readonly)
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
909 910 911 |
# File 'lib/stripe/resources/confirmation_token.rb', line 909 def customer @customer end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
912 913 914 |
# File 'lib/stripe/resources/confirmation_token.rb', line 912 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
915 916 917 |
# File 'lib/stripe/resources/confirmation_token.rb', line 915 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
918 919 920 |
# File 'lib/stripe/resources/confirmation_token.rb', line 918 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
921 922 923 |
# File 'lib/stripe/resources/confirmation_token.rb', line 921 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
924 925 926 |
# File 'lib/stripe/resources/confirmation_token.rb', line 924 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
927 928 929 |
# File 'lib/stripe/resources/confirmation_token.rb', line 927 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
930 931 932 |
# File 'lib/stripe/resources/confirmation_token.rb', line 930 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
933 934 935 |
# File 'lib/stripe/resources/confirmation_token.rb', line 933 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
936 937 938 |
# File 'lib/stripe/resources/confirmation_token.rb', line 936 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
939 940 941 |
# File 'lib/stripe/resources/confirmation_token.rb', line 939 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
942 943 944 |
# File 'lib/stripe/resources/confirmation_token.rb', line 942 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
945 946 947 |
# File 'lib/stripe/resources/confirmation_token.rb', line 945 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
948 949 950 |
# File 'lib/stripe/resources/confirmation_token.rb', line 948 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
951 952 953 |
# File 'lib/stripe/resources/confirmation_token.rb', line 951 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
954 955 956 |
# File 'lib/stripe/resources/confirmation_token.rb', line 954 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
957 958 959 |
# File 'lib/stripe/resources/confirmation_token.rb', line 957 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
960 961 962 |
# File 'lib/stripe/resources/confirmation_token.rb', line 960 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
963 964 965 |
# File 'lib/stripe/resources/confirmation_token.rb', line 963 def naver_pay @naver_pay end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
966 967 968 |
# File 'lib/stripe/resources/confirmation_token.rb', line 966 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
969 970 971 |
# File 'lib/stripe/resources/confirmation_token.rb', line 969 def p24 @p24 end |
#payco ⇒ Object (readonly)
Attribute for field payco
972 973 974 |
# File 'lib/stripe/resources/confirmation_token.rb', line 972 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
975 976 977 |
# File 'lib/stripe/resources/confirmation_token.rb', line 975 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
978 979 980 |
# File 'lib/stripe/resources/confirmation_token.rb', line 978 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
981 982 983 |
# File 'lib/stripe/resources/confirmation_token.rb', line 981 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
984 985 986 |
# File 'lib/stripe/resources/confirmation_token.rb', line 984 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
987 988 989 |
# File 'lib/stripe/resources/confirmation_token.rb', line 987 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
990 991 992 |
# File 'lib/stripe/resources/confirmation_token.rb', line 990 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
993 994 995 |
# File 'lib/stripe/resources/confirmation_token.rb', line 993 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
996 997 998 |
# File 'lib/stripe/resources/confirmation_token.rb', line 996 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
999 1000 1001 |
# File 'lib/stripe/resources/confirmation_token.rb', line 999 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1002 1003 1004 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1002 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1005 1006 1007 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1005 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1008 1009 1010 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1008 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
1011 1012 1013 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1011 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1014 1015 1016 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1014 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
1017 1018 1019 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1017 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
1020 1021 1022 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1020 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1023 1024 1025 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1023 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1026 1027 1028 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1026 def zip @zip end |