Class: Stripe::ConfirmationToken::PaymentMethodPreview
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#allow_redisplay ⇒ Object
readonly
This field indicates whether this payment method can be shown again to its customer in a checkout flow.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billing_details ⇒ Object
readonly
Attribute for field billing_details.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#customer ⇒ Object
readonly
The ID of the Customer to which this PaymentMethod is saved.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of the PaymentMethod.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
691 692 693 |
# File 'lib/stripe/resources/confirmation_token.rb', line 691 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
693 694 695 |
# File 'lib/stripe/resources/confirmation_token.rb', line 693 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
695 696 697 |
# File 'lib/stripe/resources/confirmation_token.rb', line 695 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
697 698 699 |
# File 'lib/stripe/resources/confirmation_token.rb', line 697 def alipay @alipay end |
#allow_redisplay ⇒ Object (readonly)
This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to “unspecified”.
699 700 701 |
# File 'lib/stripe/resources/confirmation_token.rb', line 699 def allow_redisplay @allow_redisplay end |
#alma ⇒ Object (readonly)
Attribute for field alma
701 702 703 |
# File 'lib/stripe/resources/confirmation_token.rb', line 701 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
703 704 705 |
# File 'lib/stripe/resources/confirmation_token.rb', line 703 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
705 706 707 |
# File 'lib/stripe/resources/confirmation_token.rb', line 705 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
707 708 709 |
# File 'lib/stripe/resources/confirmation_token.rb', line 707 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
709 710 711 |
# File 'lib/stripe/resources/confirmation_token.rb', line 709 def bancontact @bancontact end |
#billing_details ⇒ Object (readonly)
Attribute for field billing_details
711 712 713 |
# File 'lib/stripe/resources/confirmation_token.rb', line 711 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
713 714 715 |
# File 'lib/stripe/resources/confirmation_token.rb', line 713 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
715 716 717 |
# File 'lib/stripe/resources/confirmation_token.rb', line 715 def boleto @boleto end |
#card ⇒ Object (readonly)
Attribute for field card
717 718 719 |
# File 'lib/stripe/resources/confirmation_token.rb', line 717 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
719 720 721 |
# File 'lib/stripe/resources/confirmation_token.rb', line 719 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
721 722 723 |
# File 'lib/stripe/resources/confirmation_token.rb', line 721 def cashapp @cashapp end |
#customer ⇒ Object (readonly)
The ID of the Customer to which this PaymentMethod is saved. This will not be set when the PaymentMethod has not been saved to a Customer.
723 724 725 |
# File 'lib/stripe/resources/confirmation_token.rb', line 723 def customer @customer end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
725 726 727 |
# File 'lib/stripe/resources/confirmation_token.rb', line 725 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
727 728 729 |
# File 'lib/stripe/resources/confirmation_token.rb', line 727 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
729 730 731 |
# File 'lib/stripe/resources/confirmation_token.rb', line 729 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
731 732 733 |
# File 'lib/stripe/resources/confirmation_token.rb', line 731 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
733 734 735 |
# File 'lib/stripe/resources/confirmation_token.rb', line 733 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
735 736 737 |
# File 'lib/stripe/resources/confirmation_token.rb', line 735 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
737 738 739 |
# File 'lib/stripe/resources/confirmation_token.rb', line 737 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
739 740 741 |
# File 'lib/stripe/resources/confirmation_token.rb', line 739 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
741 742 743 |
# File 'lib/stripe/resources/confirmation_token.rb', line 741 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
743 744 745 |
# File 'lib/stripe/resources/confirmation_token.rb', line 743 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
745 746 747 |
# File 'lib/stripe/resources/confirmation_token.rb', line 745 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
747 748 749 |
# File 'lib/stripe/resources/confirmation_token.rb', line 747 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
749 750 751 |
# File 'lib/stripe/resources/confirmation_token.rb', line 749 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
751 752 753 |
# File 'lib/stripe/resources/confirmation_token.rb', line 751 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
753 754 755 |
# File 'lib/stripe/resources/confirmation_token.rb', line 753 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
755 756 757 |
# File 'lib/stripe/resources/confirmation_token.rb', line 755 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
757 758 759 |
# File 'lib/stripe/resources/confirmation_token.rb', line 757 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
759 760 761 |
# File 'lib/stripe/resources/confirmation_token.rb', line 759 def naver_pay @naver_pay end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
761 762 763 |
# File 'lib/stripe/resources/confirmation_token.rb', line 761 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
763 764 765 |
# File 'lib/stripe/resources/confirmation_token.rb', line 763 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
765 766 767 |
# File 'lib/stripe/resources/confirmation_token.rb', line 765 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
767 768 769 |
# File 'lib/stripe/resources/confirmation_token.rb', line 767 def payco @payco end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
769 770 771 |
# File 'lib/stripe/resources/confirmation_token.rb', line 769 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
771 772 773 |
# File 'lib/stripe/resources/confirmation_token.rb', line 771 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
773 774 775 |
# File 'lib/stripe/resources/confirmation_token.rb', line 773 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
775 776 777 |
# File 'lib/stripe/resources/confirmation_token.rb', line 775 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
777 778 779 |
# File 'lib/stripe/resources/confirmation_token.rb', line 777 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
779 780 781 |
# File 'lib/stripe/resources/confirmation_token.rb', line 779 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
781 782 783 |
# File 'lib/stripe/resources/confirmation_token.rb', line 781 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
783 784 785 |
# File 'lib/stripe/resources/confirmation_token.rb', line 783 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
785 786 787 |
# File 'lib/stripe/resources/confirmation_token.rb', line 785 def samsung_pay @samsung_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
787 788 789 |
# File 'lib/stripe/resources/confirmation_token.rb', line 787 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
789 790 791 |
# File 'lib/stripe/resources/confirmation_token.rb', line 789 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
791 792 793 |
# File 'lib/stripe/resources/confirmation_token.rb', line 791 def sofort @sofort end |
#swish ⇒ Object (readonly)
Attribute for field swish
793 794 795 |
# File 'lib/stripe/resources/confirmation_token.rb', line 793 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
795 796 797 |
# File 'lib/stripe/resources/confirmation_token.rb', line 795 def twint @twint end |
#type ⇒ Object (readonly)
The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.
797 798 799 |
# File 'lib/stripe/resources/confirmation_token.rb', line 797 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
799 800 801 |
# File 'lib/stripe/resources/confirmation_token.rb', line 799 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
801 802 803 |
# File 'lib/stripe/resources/confirmation_token.rb', line 801 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
803 804 805 |
# File 'lib/stripe/resources/confirmation_token.rb', line 803 def zip @zip end |