Class: Stripe::ConfirmationToken::PaymentMethodPreview::AcssDebit
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::AcssDebit
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number of the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#institution_number ⇒ Object
readonly
Institution number of the bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#transit_number ⇒ Object
readonly
Transit number of the bank account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number of the bank account.
62 63 64 |
# File 'lib/stripe/resources/confirmation_token.rb', line 62 def account_number @account_number end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
64 65 66 |
# File 'lib/stripe/resources/confirmation_token.rb', line 64 def bank_name @bank_name end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
66 67 68 |
# File 'lib/stripe/resources/confirmation_token.rb', line 66 def fingerprint @fingerprint end |
#institution_number ⇒ Object (readonly)
Institution number of the bank account.
68 69 70 |
# File 'lib/stripe/resources/confirmation_token.rb', line 68 def institution_number @institution_number end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
70 71 72 |
# File 'lib/stripe/resources/confirmation_token.rb', line 70 def last4 @last4 end |
#transit_number ⇒ Object (readonly)
Transit number of the bank account.
72 73 74 |
# File 'lib/stripe/resources/confirmation_token.rb', line 72 def transit_number @transit_number end |