Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Benefits, Checks, GeneratedFrom, Networks, ThreeDSecureUsage, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitsObject (readonly)

Attribute for field benefits



775
776
777
# File 'lib/stripe/resources/confirmation_token.rb', line 775

def benefits
  @benefits
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



777
778
779
# File 'lib/stripe/resources/confirmation_token.rb', line 777

def brand
  @brand
end

#checksObject (readonly)

Checks on Card address and CVC if provided.



779
780
781
# File 'lib/stripe/resources/confirmation_token.rb', line 779

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



781
782
783
# File 'lib/stripe/resources/confirmation_token.rb', line 781

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



783
784
785
# File 'lib/stripe/resources/confirmation_token.rb', line 783

def description
  @description
end

#display_brandObject (readonly)

The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.



785
786
787
# File 'lib/stripe/resources/confirmation_token.rb', line 785

def display_brand
  @display_brand
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



787
788
789
# File 'lib/stripe/resources/confirmation_token.rb', line 787

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



789
790
791
# File 'lib/stripe/resources/confirmation_token.rb', line 789

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



793
794
795
# File 'lib/stripe/resources/confirmation_token.rb', line 793

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



795
796
797
# File 'lib/stripe/resources/confirmation_token.rb', line 795

def funding
  @funding
end

#generated_fromObject (readonly)

Details of the original PaymentMethod that created this object.



797
798
799
# File 'lib/stripe/resources/confirmation_token.rb', line 797

def generated_from
  @generated_from
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



799
800
801
# File 'lib/stripe/resources/confirmation_token.rb', line 799

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



801
802
803
# File 'lib/stripe/resources/confirmation_token.rb', line 801

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



803
804
805
# File 'lib/stripe/resources/confirmation_token.rb', line 803

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



805
806
807
# File 'lib/stripe/resources/confirmation_token.rb', line 805

def networks
  @networks
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



807
808
809
# File 'lib/stripe/resources/confirmation_token.rb', line 807

def regulated_status
  @regulated_status
end

#three_d_secure_usageObject (readonly)

Contains details on how this Card may be used for 3D Secure authentication.



809
810
811
# File 'lib/stripe/resources/confirmation_token.rb', line 809

def three_d_secure_usage
  @three_d_secure_usage
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



811
812
813
# File 'lib/stripe/resources/confirmation_token.rb', line 811

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



824
825
826
# File 'lib/stripe/resources/confirmation_token.rb', line 824

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



813
814
815
816
817
818
819
820
821
822
# File 'lib/stripe/resources/confirmation_token.rb', line 813

def self.inner_class_types
  @inner_class_types = {
    benefits: Benefits,
    checks: Checks,
    generated_from: GeneratedFrom,
    networks: Networks,
    three_d_secure_usage: ThreeDSecureUsage,
    wallet: Wallet,
  }
end