Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Checks, GeneratedFrom, Networks, ThreeDSecureUsage, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



738
739
740
# File 'lib/stripe/resources/confirmation_token.rb', line 738

def brand
  @brand
end

#checksObject (readonly)

Checks on Card address and CVC if provided.



740
741
742
# File 'lib/stripe/resources/confirmation_token.rb', line 740

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



742
743
744
# File 'lib/stripe/resources/confirmation_token.rb', line 742

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



744
745
746
# File 'lib/stripe/resources/confirmation_token.rb', line 744

def description
  @description
end

#display_brandObject (readonly)

The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.



746
747
748
# File 'lib/stripe/resources/confirmation_token.rb', line 746

def display_brand
  @display_brand
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



748
749
750
# File 'lib/stripe/resources/confirmation_token.rb', line 748

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



750
751
752
# File 'lib/stripe/resources/confirmation_token.rb', line 750

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



754
755
756
# File 'lib/stripe/resources/confirmation_token.rb', line 754

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



756
757
758
# File 'lib/stripe/resources/confirmation_token.rb', line 756

def funding
  @funding
end

#generated_fromObject (readonly)

Details of the original PaymentMethod that created this object.



758
759
760
# File 'lib/stripe/resources/confirmation_token.rb', line 758

def generated_from
  @generated_from
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



760
761
762
# File 'lib/stripe/resources/confirmation_token.rb', line 760

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



762
763
764
# File 'lib/stripe/resources/confirmation_token.rb', line 762

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



764
765
766
# File 'lib/stripe/resources/confirmation_token.rb', line 764

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



766
767
768
# File 'lib/stripe/resources/confirmation_token.rb', line 766

def networks
  @networks
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



768
769
770
# File 'lib/stripe/resources/confirmation_token.rb', line 768

def regulated_status
  @regulated_status
end

#three_d_secure_usageObject (readonly)

Contains details on how this Card may be used for 3D Secure authentication.



770
771
772
# File 'lib/stripe/resources/confirmation_token.rb', line 770

def three_d_secure_usage
  @three_d_secure_usage
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



772
773
774
# File 'lib/stripe/resources/confirmation_token.rb', line 772

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



784
785
786
# File 'lib/stripe/resources/confirmation_token.rb', line 784

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



774
775
776
777
778
779
780
781
782
# File 'lib/stripe/resources/confirmation_token.rb', line 774

def self.inner_class_types
  @inner_class_types = {
    checks: Checks,
    generated_from: GeneratedFrom,
    networks: Networks,
    three_d_secure_usage: ThreeDSecureUsage,
    wallet: Wallet,
  }
end