Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Benefits, Checks, GeneratedFrom, Networks, ThreeDSecureUsage, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#benefitsObject (readonly)

Attribute for field benefits



775
776
777
# File 'lib/stripe/resources/confirmation_token.rb', line 775

def benefits
  @benefits
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



739
740
741
# File 'lib/stripe/resources/confirmation_token.rb', line 739

def brand
  @brand
end

#checksObject (readonly)

Checks on Card address and CVC if provided.



741
742
743
# File 'lib/stripe/resources/confirmation_token.rb', line 741

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



743
744
745
# File 'lib/stripe/resources/confirmation_token.rb', line 743

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



745
746
747
# File 'lib/stripe/resources/confirmation_token.rb', line 745

def description
  @description
end

#display_brandObject (readonly)

The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.



747
748
749
# File 'lib/stripe/resources/confirmation_token.rb', line 747

def display_brand
  @display_brand
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



749
750
751
# File 'lib/stripe/resources/confirmation_token.rb', line 749

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



751
752
753
# File 'lib/stripe/resources/confirmation_token.rb', line 751

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



755
756
757
# File 'lib/stripe/resources/confirmation_token.rb', line 755

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



757
758
759
# File 'lib/stripe/resources/confirmation_token.rb', line 757

def funding
  @funding
end

#generated_fromObject (readonly)

Details of the original PaymentMethod that created this object.



759
760
761
# File 'lib/stripe/resources/confirmation_token.rb', line 759

def generated_from
  @generated_from
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



761
762
763
# File 'lib/stripe/resources/confirmation_token.rb', line 761

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



763
764
765
# File 'lib/stripe/resources/confirmation_token.rb', line 763

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



765
766
767
# File 'lib/stripe/resources/confirmation_token.rb', line 765

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



767
768
769
# File 'lib/stripe/resources/confirmation_token.rb', line 767

def networks
  @networks
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



769
770
771
# File 'lib/stripe/resources/confirmation_token.rb', line 769

def regulated_status
  @regulated_status
end

#three_d_secure_usageObject (readonly)

Contains details on how this Card may be used for 3D Secure authentication.



771
772
773
# File 'lib/stripe/resources/confirmation_token.rb', line 771

def three_d_secure_usage
  @three_d_secure_usage
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



773
774
775
# File 'lib/stripe/resources/confirmation_token.rb', line 773

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



788
789
790
# File 'lib/stripe/resources/confirmation_token.rb', line 788

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



777
778
779
780
781
782
783
784
785
786
# File 'lib/stripe/resources/confirmation_token.rb', line 777

def self.inner_class_types
  @inner_class_types = {
    checks: Checks,
    generated_from: GeneratedFrom,
    networks: Networks,
    three_d_secure_usage: ThreeDSecureUsage,
    wallet: Wallet,
    benefits: Benefits,
  }
end