Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Checks, GeneratedFrom, Networks, ThreeDSecureUsage, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



366
367
368
# File 'lib/stripe/resources/confirmation_token.rb', line 366

def brand
  @brand
end

#checksObject (readonly)

Checks on Card address and CVC if provided.



368
369
370
# File 'lib/stripe/resources/confirmation_token.rb', line 368

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



370
371
372
# File 'lib/stripe/resources/confirmation_token.rb', line 370

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



372
373
374
# File 'lib/stripe/resources/confirmation_token.rb', line 372

def description
  @description
end

#display_brandObject (readonly)

The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.



374
375
376
# File 'lib/stripe/resources/confirmation_token.rb', line 374

def display_brand
  @display_brand
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



376
377
378
# File 'lib/stripe/resources/confirmation_token.rb', line 376

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



378
379
380
# File 'lib/stripe/resources/confirmation_token.rb', line 378

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



382
383
384
# File 'lib/stripe/resources/confirmation_token.rb', line 382

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



384
385
386
# File 'lib/stripe/resources/confirmation_token.rb', line 384

def funding
  @funding
end

#generated_fromObject (readonly)

Details of the original PaymentMethod that created this object.



386
387
388
# File 'lib/stripe/resources/confirmation_token.rb', line 386

def generated_from
  @generated_from
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



388
389
390
# File 'lib/stripe/resources/confirmation_token.rb', line 388

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



390
391
392
# File 'lib/stripe/resources/confirmation_token.rb', line 390

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



392
393
394
# File 'lib/stripe/resources/confirmation_token.rb', line 392

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



394
395
396
# File 'lib/stripe/resources/confirmation_token.rb', line 394

def networks
  @networks
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



396
397
398
# File 'lib/stripe/resources/confirmation_token.rb', line 396

def regulated_status
  @regulated_status
end

#three_d_secure_usageObject (readonly)

Contains details on how this Card may be used for 3D Secure authentication.



398
399
400
# File 'lib/stripe/resources/confirmation_token.rb', line 398

def three_d_secure_usage
  @three_d_secure_usage
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



400
401
402
# File 'lib/stripe/resources/confirmation_token.rb', line 400

def wallet
  @wallet
end