Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Checks, GeneratedFrom, Networks, ThreeDSecureUsage, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



437
438
439
# File 'lib/stripe/resources/confirmation_token.rb', line 437

def brand
  @brand
end

#checksObject (readonly)

Checks on Card address and CVC if provided.



440
441
442
# File 'lib/stripe/resources/confirmation_token.rb', line 440

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



443
444
445
# File 'lib/stripe/resources/confirmation_token.rb', line 443

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



446
447
448
# File 'lib/stripe/resources/confirmation_token.rb', line 446

def description
  @description
end

#display_brandObject (readonly)

The brand to use when displaying the card, this accounts for customer’s brand choice on dual-branded cards. Can be ‘american_express`, `cartes_bancaires`, `diners_club`, `discover`, `eftpos_australia`, `interac`, `jcb`, `mastercard`, `union_pay`, `visa`, or `other` and may contain more values in the future.



449
450
451
# File 'lib/stripe/resources/confirmation_token.rb', line 449

def display_brand
  @display_brand
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



452
453
454
# File 'lib/stripe/resources/confirmation_token.rb', line 452

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



455
456
457
# File 'lib/stripe/resources/confirmation_token.rb', line 455

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



460
461
462
# File 'lib/stripe/resources/confirmation_token.rb', line 460

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



463
464
465
# File 'lib/stripe/resources/confirmation_token.rb', line 463

def funding
  @funding
end

#generated_fromObject (readonly)

Details of the original PaymentMethod that created this object.



466
467
468
# File 'lib/stripe/resources/confirmation_token.rb', line 466

def generated_from
  @generated_from
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



469
470
471
# File 'lib/stripe/resources/confirmation_token.rb', line 469

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



472
473
474
# File 'lib/stripe/resources/confirmation_token.rb', line 472

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



475
476
477
# File 'lib/stripe/resources/confirmation_token.rb', line 475

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



478
479
480
# File 'lib/stripe/resources/confirmation_token.rb', line 478

def networks
  @networks
end

#regulated_statusObject (readonly)

Status of a card based on the card issuer.



481
482
483
# File 'lib/stripe/resources/confirmation_token.rb', line 481

def regulated_status
  @regulated_status
end

#three_d_secure_usageObject (readonly)

Contains details on how this Card may be used for 3D Secure authentication.



484
485
486
# File 'lib/stripe/resources/confirmation_token.rb', line 484

def three_d_secure_usage
  @three_d_secure_usage
end

#walletObject (readonly)

If this Card is part of a card wallet, this contains the details of the card wallet.



487
488
489
# File 'lib/stripe/resources/confirmation_token.rb', line 487

def wallet
  @wallet
end