Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::GeneratedFrom::PaymentMethodDetails::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Offline, Receipt, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount



401
402
403
# File 'lib/stripe/resources/confirmation_token.rb', line 401

def amount_authorized
  @amount_authorized
end

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



403
404
405
# File 'lib/stripe/resources/confirmation_token.rb', line 403

def brand
  @brand
end

#brand_productObject (readonly)

The product code that identifies the specific program or product associated with a card.



405
406
407
# File 'lib/stripe/resources/confirmation_token.rb', line 405

def brand_product
  @brand_product
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.



407
408
409
# File 'lib/stripe/resources/confirmation_token.rb', line 407

def capture_before
  @capture_before
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



409
410
411
# File 'lib/stripe/resources/confirmation_token.rb', line 409

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



411
412
413
# File 'lib/stripe/resources/confirmation_token.rb', line 411

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



413
414
415
# File 'lib/stripe/resources/confirmation_token.rb', line 413

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



415
416
417
# File 'lib/stripe/resources/confirmation_token.rb', line 415

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



417
418
419
# File 'lib/stripe/resources/confirmation_token.rb', line 417

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



419
420
421
# File 'lib/stripe/resources/confirmation_token.rb', line 419

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.



423
424
425
# File 'lib/stripe/resources/confirmation_token.rb', line 423

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



425
426
427
# File 'lib/stripe/resources/confirmation_token.rb', line 425

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



427
428
429
# File 'lib/stripe/resources/confirmation_token.rb', line 427

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



429
430
431
# File 'lib/stripe/resources/confirmation_token.rb', line 429

def iin
  @iin
end

#incremental_authorization_supportedObject (readonly)

Whether this PaymentIntent is eligible for incremental authorizations. Request support using request_incremental_authorization_support.



431
432
433
# File 'lib/stripe/resources/confirmation_token.rb', line 431

def incremental_authorization_supported
  @incremental_authorization_supported
end

#issuerObject (readonly)

The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)



433
434
435
# File 'lib/stripe/resources/confirmation_token.rb', line 433

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



435
436
437
# File 'lib/stripe/resources/confirmation_token.rb', line 435

def last4
  @last4
end

#locationObject (readonly)

ID of the location that this transaction's reader is assigned to.



437
438
439
# File 'lib/stripe/resources/confirmation_token.rb', line 437

def location
  @location
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.



439
440
441
# File 'lib/stripe/resources/confirmation_token.rb', line 439

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



441
442
443
# File 'lib/stripe/resources/confirmation_token.rb', line 441

def network_transaction_id
  @network_transaction_id
end

#offlineObject (readonly)

Details about payments collected offline.



443
444
445
# File 'lib/stripe/resources/confirmation_token.rb', line 443

def offline
  @offline
end

#overcapture_supportedObject (readonly)

Defines whether the authorized amount can be over-captured or not



445
446
447
# File 'lib/stripe/resources/confirmation_token.rb', line 445

def overcapture_supported
  @overcapture_supported
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.



447
448
449
# File 'lib/stripe/resources/confirmation_token.rb', line 447

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



449
450
451
# File 'lib/stripe/resources/confirmation_token.rb', line 449

def read_method
  @read_method
end

#readerObject (readonly)

ID of the reader this transaction was made on.



451
452
453
# File 'lib/stripe/resources/confirmation_token.rb', line 451

def reader
  @reader
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



453
454
455
# File 'lib/stripe/resources/confirmation_token.rb', line 453

def receipt
  @receipt
end

#walletObject (readonly)

Attribute for field wallet



455
456
457
# File 'lib/stripe/resources/confirmation_token.rb', line 455

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



461
462
463
# File 'lib/stripe/resources/confirmation_token.rb', line 461

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



457
458
459
# File 'lib/stripe/resources/confirmation_token.rb', line 457

def self.inner_class_types
  @inner_class_types = { offline: Offline, receipt: Receipt, wallet: Wallet }
end