Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::GeneratedFrom::PaymentMethodDetails::CardPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::Card::GeneratedFrom::PaymentMethodDetails::CardPresent
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: Offline, Receipt, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_authorized ⇒ Object
readonly
The authorized amount.
-
#brand ⇒ Object
readonly
Card brand.
-
#brand_product ⇒ Object
readonly
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#emv_auth_data ⇒ Object
readonly
Authorization response cryptogram.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#generated_card ⇒ Object
readonly
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#incremental_authorization_supported ⇒ Object
readonly
Whether this [PaymentIntent](stripe.com/docs/api/payment_intents) is eligible for incremental authorizations.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#offline ⇒ Object
readonly
Details about payments collected offline.
-
#overcapture_supported ⇒ Object
readonly
Defines whether the authorized amount can be over-captured or not.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
-
#receipt ⇒ Object
readonly
A collection of fields required to be displayed on receipts.
-
#wallet ⇒ Object
readonly
Attribute for field wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_authorized ⇒ Object (readonly)
The authorized amount
402 403 404 |
# File 'lib/stripe/resources/confirmation_token.rb', line 402 def @amount_authorized end |
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.
404 405 406 |
# File 'lib/stripe/resources/confirmation_token.rb', line 404 def brand @brand end |
#brand_product ⇒ Object (readonly)
The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.
406 407 408 |
# File 'lib/stripe/resources/confirmation_token.rb', line 406 def brand_product @brand_product end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.
408 409 410 |
# File 'lib/stripe/resources/confirmation_token.rb', line 408 def capture_before @capture_before end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
410 411 412 |
# File 'lib/stripe/resources/confirmation_token.rb', line 410 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
412 413 414 |
# File 'lib/stripe/resources/confirmation_token.rb', line 412 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
414 415 416 |
# File 'lib/stripe/resources/confirmation_token.rb', line 414 def description @description end |
#emv_auth_data ⇒ Object (readonly)
Authorization response cryptogram.
416 417 418 |
# File 'lib/stripe/resources/confirmation_token.rb', line 416 def emv_auth_data @emv_auth_data end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
418 419 420 |
# File 'lib/stripe/resources/confirmation_token.rb', line 418 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
420 421 422 |
# File 'lib/stripe/resources/confirmation_token.rb', line 420 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
424 425 426 |
# File 'lib/stripe/resources/confirmation_token.rb', line 424 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
426 427 428 |
# File 'lib/stripe/resources/confirmation_token.rb', line 426 def funding @funding end |
#generated_card ⇒ Object (readonly)
ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.
428 429 430 |
# File 'lib/stripe/resources/confirmation_token.rb', line 428 def generated_card @generated_card end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
430 431 432 |
# File 'lib/stripe/resources/confirmation_token.rb', line 430 def iin @iin end |
#incremental_authorization_supported ⇒ Object (readonly)
Whether this [PaymentIntent](stripe.com/docs/api/payment_intents) is eligible for incremental authorizations. Request support using [request_incremental_authorization_support](stripe.com/docs/api/payment_intents/create#create_payment_intent-payment_method_options-card_present-request_incremental_authorization_support).
432 433 434 |
# File 'lib/stripe/resources/confirmation_token.rb', line 432 def @incremental_authorization_supported end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
434 435 436 |
# File 'lib/stripe/resources/confirmation_token.rb', line 434 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
436 437 438 |
# File 'lib/stripe/resources/confirmation_token.rb', line 436 def last4 @last4 end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
438 439 440 |
# File 'lib/stripe/resources/confirmation_token.rb', line 438 def network @network end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
440 441 442 |
# File 'lib/stripe/resources/confirmation_token.rb', line 440 def network_transaction_id @network_transaction_id end |
#offline ⇒ Object (readonly)
Details about payments collected offline.
442 443 444 |
# File 'lib/stripe/resources/confirmation_token.rb', line 442 def offline @offline end |
#overcapture_supported ⇒ Object (readonly)
Defines whether the authorized amount can be over-captured or not
444 445 446 |
# File 'lib/stripe/resources/confirmation_token.rb', line 444 def overcapture_supported @overcapture_supported end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.
446 447 448 |
# File 'lib/stripe/resources/confirmation_token.rb', line 446 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
448 449 450 |
# File 'lib/stripe/resources/confirmation_token.rb', line 448 def read_method @read_method end |
#receipt ⇒ Object (readonly)
A collection of fields required to be displayed on receipts. Only required for EMV transactions.
450 451 452 |
# File 'lib/stripe/resources/confirmation_token.rb', line 450 def receipt @receipt end |
#wallet ⇒ Object (readonly)
Attribute for field wallet
452 453 454 |
# File 'lib/stripe/resources/confirmation_token.rb', line 452 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
458 459 460 |
# File 'lib/stripe/resources/confirmation_token.rb', line 458 def self.field_remappings @field_remappings = {} end |