Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::GeneratedFrom::PaymentMethodDetails::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Offline, Receipt, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount



182
183
184
# File 'lib/stripe/resources/confirmation_token.rb', line 182

def amount_authorized
  @amount_authorized
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



184
185
186
# File 'lib/stripe/resources/confirmation_token.rb', line 184

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.



186
187
188
# File 'lib/stripe/resources/confirmation_token.rb', line 186

def brand_product
  @brand_product
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.



188
189
190
# File 'lib/stripe/resources/confirmation_token.rb', line 188

def capture_before
  @capture_before
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



190
191
192
# File 'lib/stripe/resources/confirmation_token.rb', line 190

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



192
193
194
# File 'lib/stripe/resources/confirmation_token.rb', line 192

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



194
195
196
# File 'lib/stripe/resources/confirmation_token.rb', line 194

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



196
197
198
# File 'lib/stripe/resources/confirmation_token.rb', line 196

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



198
199
200
# File 'lib/stripe/resources/confirmation_token.rb', line 198

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



200
201
202
# File 'lib/stripe/resources/confirmation_token.rb', line 200

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



204
205
206
# File 'lib/stripe/resources/confirmation_token.rb', line 204

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



206
207
208
# File 'lib/stripe/resources/confirmation_token.rb', line 206

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



208
209
210
# File 'lib/stripe/resources/confirmation_token.rb', line 208

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



210
211
212
# File 'lib/stripe/resources/confirmation_token.rb', line 210

def iin
  @iin
end

#incremental_authorization_supportedObject (readonly)

Whether this [PaymentIntent](stripe.com/docs/api/payment_intents) is eligible for incremental authorizations. Request support using [request_incremental_authorization_support](stripe.com/docs/api/payment_intents/create#create_payment_intent-payment_method_options-card_present-request_incremental_authorization_support).



212
213
214
# File 'lib/stripe/resources/confirmation_token.rb', line 212

def incremental_authorization_supported
  @incremental_authorization_supported
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



214
215
216
# File 'lib/stripe/resources/confirmation_token.rb', line 214

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



216
217
218
# File 'lib/stripe/resources/confirmation_token.rb', line 216

def last4
  @last4
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



218
219
220
# File 'lib/stripe/resources/confirmation_token.rb', line 218

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



220
221
222
# File 'lib/stripe/resources/confirmation_token.rb', line 220

def network_transaction_id
  @network_transaction_id
end

#offlineObject (readonly)

Details about payments collected offline.



222
223
224
# File 'lib/stripe/resources/confirmation_token.rb', line 222

def offline
  @offline
end

#overcapture_supportedObject (readonly)

Defines whether the authorized amount can be over-captured or not



224
225
226
# File 'lib/stripe/resources/confirmation_token.rb', line 224

def overcapture_supported
  @overcapture_supported
end

#preferred_localesObject (readonly)

EMV tag 5F2D. Preferred languages specified by the integrated circuit chip.



226
227
228
# File 'lib/stripe/resources/confirmation_token.rb', line 226

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



228
229
230
# File 'lib/stripe/resources/confirmation_token.rb', line 228

def read_method
  @read_method
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



230
231
232
# File 'lib/stripe/resources/confirmation_token.rb', line 230

def receipt
  @receipt
end

#walletObject (readonly)

Attribute for field wallet



232
233
234
# File 'lib/stripe/resources/confirmation_token.rb', line 232

def wallet
  @wallet
end