Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::GeneratedFrom::PaymentMethodDetails::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Offline, Receipt, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount



191
192
193
# File 'lib/stripe/resources/confirmation_token.rb', line 191

def amount_authorized
  @amount_authorized
end

#brandObject (readonly)

Card brand. Can be ‘amex`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



194
195
196
# File 'lib/stripe/resources/confirmation_token.rb', line 194

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.



197
198
199
# File 'lib/stripe/resources/confirmation_token.rb', line 197

def brand_product
  @brand_product
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.



200
201
202
# File 'lib/stripe/resources/confirmation_token.rb', line 200

def capture_before
  @capture_before
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



203
204
205
# File 'lib/stripe/resources/confirmation_token.rb', line 203

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



206
207
208
# File 'lib/stripe/resources/confirmation_token.rb', line 206

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



209
210
211
# File 'lib/stripe/resources/confirmation_token.rb', line 209

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



212
213
214
# File 'lib/stripe/resources/confirmation_token.rb', line 212

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



215
216
217
# File 'lib/stripe/resources/confirmation_token.rb', line 215

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



218
219
220
# File 'lib/stripe/resources/confirmation_token.rb', line 218

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



223
224
225
# File 'lib/stripe/resources/confirmation_token.rb', line 223

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



226
227
228
# File 'lib/stripe/resources/confirmation_token.rb', line 226

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



229
230
231
# File 'lib/stripe/resources/confirmation_token.rb', line 229

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



232
233
234
# File 'lib/stripe/resources/confirmation_token.rb', line 232

def iin
  @iin
end

#incremental_authorization_supportedObject (readonly)

Whether this [PaymentIntent](stripe.com/docs/api/payment_intents) is eligible for incremental authorizations. Request support using [request_incremental_authorization_support](stripe.com/docs/api/payment_intents/create#create_payment_intent-payment_method_options-card_present-request_incremental_authorization_support).



235
236
237
# File 'lib/stripe/resources/confirmation_token.rb', line 235

def incremental_authorization_supported
  @incremental_authorization_supported
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



238
239
240
# File 'lib/stripe/resources/confirmation_token.rb', line 238

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



241
242
243
# File 'lib/stripe/resources/confirmation_token.rb', line 241

def last4
  @last4
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



244
245
246
# File 'lib/stripe/resources/confirmation_token.rb', line 244

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. The first three digits of the Trace ID is the Financial Network Code, the next 6 digits is the Banknet Reference Number, and the last 4 digits represent the date (MM/DD). This field will be available for successful Visa, Mastercard, or American Express transactions and always null for other card brands.



247
248
249
# File 'lib/stripe/resources/confirmation_token.rb', line 247

def network_transaction_id
  @network_transaction_id
end

#offlineObject (readonly)

Details about payments collected offline.



250
251
252
# File 'lib/stripe/resources/confirmation_token.rb', line 250

def offline
  @offline
end

#overcapture_supportedObject (readonly)

Defines whether the authorized amount can be over-captured or not



253
254
255
# File 'lib/stripe/resources/confirmation_token.rb', line 253

def overcapture_supported
  @overcapture_supported
end

#preferred_localesObject (readonly)

EMV tag 5F2D. Preferred languages specified by the integrated circuit chip.



256
257
258
# File 'lib/stripe/resources/confirmation_token.rb', line 256

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



259
260
261
# File 'lib/stripe/resources/confirmation_token.rb', line 259

def read_method
  @read_method
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



262
263
264
# File 'lib/stripe/resources/confirmation_token.rb', line 262

def receipt
  @receipt
end

#walletObject (readonly)

Attribute for field wallet



265
266
267
# File 'lib/stripe/resources/confirmation_token.rb', line 265

def wallet
  @wallet
end