Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::GeneratedFrom::PaymentMethodDetails::CardPresent::Receipt
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::Card::GeneratedFrom::PaymentMethodDetails::CardPresent::Receipt
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_type ⇒ Object
readonly
The type of account being debited or credited.
-
#application_cryptogram ⇒ Object
readonly
EMV tag 9F26, cryptogram generated by the integrated circuit chip.
-
#application_preferred_name ⇒ Object
readonly
Mnenomic of the Application Identifier.
-
#authorization_code ⇒ Object
readonly
Identifier for this transaction.
-
#authorization_response_code ⇒ Object
readonly
EMV tag 8A.
-
#cardholder_verification_method ⇒ Object
readonly
Describes the method used by the cardholder to verify ownership of the card.
-
#dedicated_file_name ⇒ Object
readonly
EMV tag 84.
-
#terminal_verification_results ⇒ Object
readonly
The outcome of a series of EMV functions performed by the card reader.
-
#transaction_status_information ⇒ Object
readonly
An indication of various EMV functions performed during the transaction.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_type ⇒ Object (readonly)
The type of account being debited or credited
158 159 160 |
# File 'lib/stripe/resources/confirmation_token.rb', line 158 def account_type @account_type end |
#application_cryptogram ⇒ Object (readonly)
EMV tag 9F26, cryptogram generated by the integrated circuit chip.
160 161 162 |
# File 'lib/stripe/resources/confirmation_token.rb', line 160 def application_cryptogram @application_cryptogram end |
#application_preferred_name ⇒ Object (readonly)
Mnenomic of the Application Identifier.
162 163 164 |
# File 'lib/stripe/resources/confirmation_token.rb', line 162 def application_preferred_name @application_preferred_name end |
#authorization_code ⇒ Object (readonly)
Identifier for this transaction.
164 165 166 |
# File 'lib/stripe/resources/confirmation_token.rb', line 164 def @authorization_code end |
#authorization_response_code ⇒ Object (readonly)
EMV tag 8A. A code returned by the card issuer.
166 167 168 |
# File 'lib/stripe/resources/confirmation_token.rb', line 166 def @authorization_response_code end |
#cardholder_verification_method ⇒ Object (readonly)
Describes the method used by the cardholder to verify ownership of the card. One of the following: ‘approval`, `failure`, `none`, `offline_pin`, `offline_pin_and_signature`, `online_pin`, or `signature`.
168 169 170 |
# File 'lib/stripe/resources/confirmation_token.rb', line 168 def cardholder_verification_method @cardholder_verification_method end |
#dedicated_file_name ⇒ Object (readonly)
EMV tag 84. Similar to the application identifier stored on the integrated circuit chip.
170 171 172 |
# File 'lib/stripe/resources/confirmation_token.rb', line 170 def dedicated_file_name @dedicated_file_name end |
#terminal_verification_results ⇒ Object (readonly)
The outcome of a series of EMV functions performed by the card reader.
172 173 174 |
# File 'lib/stripe/resources/confirmation_token.rb', line 172 def terminal_verification_results @terminal_verification_results end |
#transaction_status_information ⇒ Object (readonly)
An indication of various EMV functions performed during the transaction.
174 175 176 |
# File 'lib/stripe/resources/confirmation_token.rb', line 174 def transaction_status_information @transaction_status_information end |