Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::Wallet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amex_express_checkoutObject (readonly)

Attribute for field amex_express_checkout



730
731
732
# File 'lib/stripe/resources/confirmation_token.rb', line 730

def amex_express_checkout
  @amex_express_checkout
end

#apple_payObject (readonly)

Attribute for field apple_pay



732
733
734
# File 'lib/stripe/resources/confirmation_token.rb', line 732

def apple_pay
  @apple_pay
end

#dynamic_last4Object (readonly)

(For tokenized numbers only.) The last four digits of the device account number.



734
735
736
# File 'lib/stripe/resources/confirmation_token.rb', line 734

def dynamic_last4
  @dynamic_last4
end

#google_payObject (readonly)

Attribute for field google_pay



736
737
738
# File 'lib/stripe/resources/confirmation_token.rb', line 736

def google_pay
  @google_pay
end

Attribute for field link



738
739
740
# File 'lib/stripe/resources/confirmation_token.rb', line 738

def link
  @link
end

#masterpassObject (readonly)

Attribute for field masterpass



740
741
742
# File 'lib/stripe/resources/confirmation_token.rb', line 740

def masterpass
  @masterpass
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



742
743
744
# File 'lib/stripe/resources/confirmation_token.rb', line 742

def samsung_pay
  @samsung_pay
end

#typeObject (readonly)

The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.



744
745
746
# File 'lib/stripe/resources/confirmation_token.rb', line 744

def type
  @type
end

#visa_checkoutObject (readonly)

Attribute for field visa_checkout



746
747
748
# File 'lib/stripe/resources/confirmation_token.rb', line 746

def visa_checkout
  @visa_checkout
end

Class Method Details

.field_remappingsObject



760
761
762
# File 'lib/stripe/resources/confirmation_token.rb', line 760

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



748
749
750
751
752
753
754
755
756
757
758
# File 'lib/stripe/resources/confirmation_token.rb', line 748

def self.inner_class_types
  @inner_class_types = {
    amex_express_checkout: AmexExpressCheckout,
    apple_pay: ApplePay,
    google_pay: GooglePay,
    link: Link,
    masterpass: Masterpass,
    samsung_pay: SamsungPay,
    visa_checkout: VisaCheckout,
  }
end