Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::Wallet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: AmexExpressCheckout, ApplePay, GooglePay, Link, Masterpass, SamsungPay, VisaCheckout

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amex_express_checkoutObject (readonly)

Attribute for field amex_express_checkout



327
328
329
# File 'lib/stripe/resources/confirmation_token.rb', line 327

def amex_express_checkout
  @amex_express_checkout
end

#apple_payObject (readonly)

Attribute for field apple_pay



329
330
331
# File 'lib/stripe/resources/confirmation_token.rb', line 329

def apple_pay
  @apple_pay
end

#dynamic_last4Object (readonly)

(For tokenized numbers only.) The last four digits of the device account number.



331
332
333
# File 'lib/stripe/resources/confirmation_token.rb', line 331

def dynamic_last4
  @dynamic_last4
end

#google_payObject (readonly)

Attribute for field google_pay



333
334
335
# File 'lib/stripe/resources/confirmation_token.rb', line 333

def google_pay
  @google_pay
end

Attribute for field link



335
336
337
# File 'lib/stripe/resources/confirmation_token.rb', line 335

def link
  @link
end

#masterpassObject (readonly)

Attribute for field masterpass



337
338
339
# File 'lib/stripe/resources/confirmation_token.rb', line 337

def masterpass
  @masterpass
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



339
340
341
# File 'lib/stripe/resources/confirmation_token.rb', line 339

def samsung_pay
  @samsung_pay
end

#typeObject (readonly)

The type of the card wallet, one of ‘amex_express_checkout`, `apple_pay`, `google_pay`, `masterpass`, `samsung_pay`, `visa_checkout`, or `link`. An additional hash is included on the Wallet subhash with a name matching this value. It contains additional information specific to the card wallet type.



341
342
343
# File 'lib/stripe/resources/confirmation_token.rb', line 341

def type
  @type
end

#visa_checkoutObject (readonly)

Attribute for field visa_checkout



343
344
345
# File 'lib/stripe/resources/confirmation_token.rb', line 343

def visa_checkout
  @visa_checkout
end