Class: Stripe::ConfirmationToken::PaymentMethodPreview::Card::Wallet::VisaCheckout

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: BillingAddress, ShippingAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_addressObject (readonly)

Owner’s verified billing address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



710
711
712
# File 'lib/stripe/resources/confirmation_token.rb', line 710

def billing_address
  @billing_address
end

#emailObject (readonly)

Owner’s verified email. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



712
713
714
# File 'lib/stripe/resources/confirmation_token.rb', line 712

def email
  @email
end

#nameObject (readonly)

Owner’s verified full name. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



714
715
716
# File 'lib/stripe/resources/confirmation_token.rb', line 714

def name
  @name
end

#shipping_addressObject (readonly)

Owner’s verified shipping address. Values are verified or provided by the wallet directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



716
717
718
# File 'lib/stripe/resources/confirmation_token.rb', line 716

def shipping_address
  @shipping_address
end

Class Method Details

.field_remappingsObject



725
726
727
# File 'lib/stripe/resources/confirmation_token.rb', line 725

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



718
719
720
721
722
723
# File 'lib/stripe/resources/confirmation_token.rb', line 718

def self.inner_class_types
  @inner_class_types = {
    billing_address: BillingAddress,
    shipping_address: ShippingAddress,
  }
end