Class: Stripe::ConfirmationToken::PaymentMethodPreview::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Networks, Offline, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



833
834
835
# File 'lib/stripe/resources/confirmation_token.rb', line 833

def brand
  @brand
end

#brand_productObject (readonly)

The [product code](stripe.com/docs/card-product-codes) that identifies the specific program or product associated with a card.



835
836
837
# File 'lib/stripe/resources/confirmation_token.rb', line 835

def brand_product
  @brand_product
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



837
838
839
# File 'lib/stripe/resources/confirmation_token.rb', line 837

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



839
840
841
# File 'lib/stripe/resources/confirmation_token.rb', line 839

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



841
842
843
# File 'lib/stripe/resources/confirmation_token.rb', line 841

def description
  @description
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



843
844
845
# File 'lib/stripe/resources/confirmation_token.rb', line 843

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



845
846
847
# File 'lib/stripe/resources/confirmation_token.rb', line 845

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



849
850
851
# File 'lib/stripe/resources/confirmation_token.rb', line 849

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



851
852
853
# File 'lib/stripe/resources/confirmation_token.rb', line 851

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



853
854
855
# File 'lib/stripe/resources/confirmation_token.rb', line 853

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



855
856
857
# File 'lib/stripe/resources/confirmation_token.rb', line 855

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



857
858
859
# File 'lib/stripe/resources/confirmation_token.rb', line 857

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



859
860
861
# File 'lib/stripe/resources/confirmation_token.rb', line 859

def networks
  @networks
end

#offlineObject (readonly)

Details about payment methods collected offline.



861
862
863
# File 'lib/stripe/resources/confirmation_token.rb', line 861

def offline
  @offline
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.



863
864
865
# File 'lib/stripe/resources/confirmation_token.rb', line 863

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



865
866
867
# File 'lib/stripe/resources/confirmation_token.rb', line 865

def read_method
  @read_method
end

#walletObject (readonly)

Attribute for field wallet



867
868
869
# File 'lib/stripe/resources/confirmation_token.rb', line 867

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



873
874
875
# File 'lib/stripe/resources/confirmation_token.rb', line 873

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



869
870
871
# File 'lib/stripe/resources/confirmation_token.rb', line 869

def self.inner_class_types
  @inner_class_types = { networks: Networks, offline: Offline, wallet: Wallet }
end