Class: Stripe::ConfirmationToken::PaymentMethodPreview::InteracPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::InteracPresent
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: Networks
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in ISO 7813 format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card's expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card's expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card's issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#networks ⇒ Object
readonly
Contains information about card networks that can be used to process the payment.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be interac, mastercard or visa.
1106 1107 1108 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1106 def brand @brand end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
1108 1109 1110 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1108 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.
1110 1111 1112 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1110 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
1112 1113 1114 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1112 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card's expiration month.
1114 1115 1116 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1114 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card's expiration year.
1116 1117 1118 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1116 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.
1120 1121 1122 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1120 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be credit, debit, prepaid, or unknown.
1122 1123 1124 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1122 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
1124 1125 1126 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1124 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)
1126 1127 1128 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1126 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
1128 1129 1130 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1128 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about card networks that can be used to process the payment.
1130 1131 1132 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1130 def networks @networks end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.
1132 1133 1134 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1132 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
1134 1135 1136 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1134 def read_method @read_method end |
Class Method Details
.field_remappings ⇒ Object
1140 1141 1142 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1140 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1136 1137 1138 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1136 def self.inner_class_types @inner_class_types = { networks: Networks } end |