Class: Stripe::ConfirmationToken::PaymentMethodPreview::InteracPresent
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::InteracPresent
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Defined Under Namespace
Classes: Networks
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
Card brand.
-
#cardholder_name ⇒ Object
readonly
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#networks ⇒ Object
readonly
Contains information about card networks that can be used to process the payment.
-
#preferred_locales ⇒ Object
readonly
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card.
-
#read_method ⇒ Object
readonly
How card details were read in this transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
Card brand. Can be ‘interac`, `mastercard` or `visa`.
1021 1022 1023 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1021 def brand @brand end |
#cardholder_name ⇒ Object (readonly)
The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.
1023 1024 1025 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1023 def cardholder_name @cardholder_name end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
1025 1026 1027 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1025 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)
1027 1028 1029 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1027 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
1029 1030 1031 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1029 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
1031 1032 1033 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1031 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
1035 1036 1037 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1035 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
1037 1038 1039 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1037 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)
1039 1040 1041 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1039 def iin @iin end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)
1041 1042 1043 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1041 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
1043 1044 1045 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1043 def last4 @last4 end |
#networks ⇒ Object (readonly)
Contains information about card networks that can be used to process the payment.
1045 1046 1047 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1045 def networks @networks end |
#preferred_locales ⇒ Object (readonly)
The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.
1047 1048 1049 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1047 def preferred_locales @preferred_locales end |
#read_method ⇒ Object (readonly)
How card details were read in this transaction.
1049 1050 1051 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1049 def read_method @read_method end |
Class Method Details
.field_remappings ⇒ Object
1055 1056 1057 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1055 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1051 1052 1053 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1051 def self.inner_class_types @inner_class_types = { networks: Networks } end |