Class: Stripe::ConfirmationToken::PaymentMethodPreview::InteracPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Networks

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘interac`, `mastercard` or `visa`.



1074
1075
1076
# File 'lib/stripe/resources/confirmation_token.rb', line 1074

def brand
  @brand
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in [ISO 7813](en.wikipedia.org/wiki/ISO/IEC_7813) format. May include alphanumeric characters, special characters and first/last name separator (‘/`). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



1076
1077
1078
# File 'lib/stripe/resources/confirmation_token.rb', line 1076

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



1078
1079
1080
# File 'lib/stripe/resources/confirmation_token.rb', line 1078

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



1080
1081
1082
# File 'lib/stripe/resources/confirmation_token.rb', line 1080

def description
  @description
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



1082
1083
1084
# File 'lib/stripe/resources/confirmation_token.rb', line 1082

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



1084
1085
1086
# File 'lib/stripe/resources/confirmation_token.rb', line 1084

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



1088
1089
1090
# File 'lib/stripe/resources/confirmation_token.rb', line 1088

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



1090
1091
1092
# File 'lib/stripe/resources/confirmation_token.rb', line 1090

def funding
  @funding
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



1092
1093
1094
# File 'lib/stripe/resources/confirmation_token.rb', line 1092

def iin
  @iin
end

#issuerObject (readonly)

The name of the card’s issuing bank. (For internal use only and not typically available in standard API requests.)



1094
1095
1096
# File 'lib/stripe/resources/confirmation_token.rb', line 1094

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



1096
1097
1098
# File 'lib/stripe/resources/confirmation_token.rb', line 1096

def last4
  @last4
end

#networksObject (readonly)

Contains information about card networks that can be used to process the payment.



1098
1099
1100
# File 'lib/stripe/resources/confirmation_token.rb', line 1098

def networks
  @networks
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card’s chip.



1100
1101
1102
# File 'lib/stripe/resources/confirmation_token.rb', line 1100

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



1102
1103
1104
# File 'lib/stripe/resources/confirmation_token.rb', line 1102

def read_method
  @read_method
end

Class Method Details

.field_remappingsObject



1108
1109
1110
# File 'lib/stripe/resources/confirmation_token.rb', line 1108

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1104
1105
1106
# File 'lib/stripe/resources/confirmation_token.rb', line 1104

def self.inner_class_types
  @inner_class_types = { networks: Networks }
end