Class: Stripe::ConfirmationToken::PaymentMethodPreview::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::NzBankAccount
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1186 1187 1188 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1186 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
1188 1189 1190 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1188 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1190 1191 1192 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1190 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
1192 1193 1194 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1192 def branch_code @branch_code end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1194 1195 1196 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1194 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1196 1197 1198 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1196 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1202 1203 1204 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1202 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1198 1199 1200 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1198 def self.inner_class_types @inner_class_types = {} end |