Class: Stripe::ConfirmationToken::PaymentMethodPreview::NzBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_nameObject (readonly)

The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



1216
1217
1218
# File 'lib/stripe/resources/confirmation_token.rb', line 1216

def 
  @account_holder_name
end

#bank_codeObject (readonly)

The numeric code for the bank account’s bank.



1218
1219
1220
# File 'lib/stripe/resources/confirmation_token.rb', line 1218

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

The name of the bank.



1220
1221
1222
# File 'lib/stripe/resources/confirmation_token.rb', line 1220

def bank_name
  @bank_name
end

#branch_codeObject (readonly)

The numeric code for the bank account’s bank branch.



1222
1223
1224
# File 'lib/stripe/resources/confirmation_token.rb', line 1222

def branch_code
  @branch_code
end

#last4Object (readonly)

Last four digits of the bank account number.



1224
1225
1226
# File 'lib/stripe/resources/confirmation_token.rb', line 1224

def last4
  @last4
end

#suffixObject (readonly)

The suffix of the bank account number.



1226
1227
1228
# File 'lib/stripe/resources/confirmation_token.rb', line 1226

def suffix
  @suffix
end

Class Method Details

.field_remappingsObject



1232
1233
1234
# File 'lib/stripe/resources/confirmation_token.rb', line 1232

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1228
1229
1230
# File 'lib/stripe/resources/confirmation_token.rb', line 1228

def self.inner_class_types
  @inner_class_types = {}
end