Class: Stripe::ConfirmationToken::PaymentMethodPreview::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: GeneratedFrom

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



779
780
781
# File 'lib/stripe/resources/confirmation_token.rb', line 779

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



782
783
784
# File 'lib/stripe/resources/confirmation_token.rb', line 782

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



785
786
787
# File 'lib/stripe/resources/confirmation_token.rb', line 785

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



788
789
790
# File 'lib/stripe/resources/confirmation_token.rb', line 788

def fingerprint
  @fingerprint
end

#generated_fromObject (readonly)

Information about the object that generated this PaymentMethod.



791
792
793
# File 'lib/stripe/resources/confirmation_token.rb', line 791

def generated_from
  @generated_from
end

#last4Object (readonly)

Last four characters of the IBAN.



794
795
796
# File 'lib/stripe/resources/confirmation_token.rb', line 794

def last4
  @last4
end