Class: Stripe::ConfirmationToken::PaymentMethodPreview::StripeBalance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::ConfirmationToken::PaymentMethodPreview::StripeBalance
- Defined in:
- lib/stripe/resources/confirmation_token.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The connected account ID whose Stripe balance to use as the source of payment.
-
#source_type ⇒ Object
readonly
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The connected account ID whose Stripe balance to use as the source of payment
1447 1448 1449 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1447 def account @account end |
#source_type ⇒ Object (readonly)
The [source_type](docs.stripe.com/api/balance/balance_object#balance_object-available-source_types) of the balance
1449 1450 1451 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1449 def source_type @source_type end |
Class Method Details
.field_remappings ⇒ Object
1455 1456 1457 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1455 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1451 1452 1453 |
# File 'lib/stripe/resources/confirmation_token.rb', line 1451 def self.inner_class_types @inner_class_types = {} end |