Class: Stripe::ConfirmationToken::PaymentMethodPreview::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1548
1549
1550
# File 'lib/stripe/resources/confirmation_token.rb', line 1548

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



1550
1551
1552
# File 'lib/stripe/resources/confirmation_token.rb', line 1550

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1552
1553
1554
# File 'lib/stripe/resources/confirmation_token.rb', line 1552

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



1554
1555
1556
# File 'lib/stripe/resources/confirmation_token.rb', line 1554

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



1556
1557
1558
# File 'lib/stripe/resources/confirmation_token.rb', line 1556

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1558
1559
1560
# File 'lib/stripe/resources/confirmation_token.rb', line 1558

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1560
1561
1562
# File 'lib/stripe/resources/confirmation_token.rb', line 1560

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



1562
1563
1564
# File 'lib/stripe/resources/confirmation_token.rb', line 1562

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



1564
1565
1566
# File 'lib/stripe/resources/confirmation_token.rb', line 1564

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



1566
1567
1568
# File 'lib/stripe/resources/confirmation_token.rb', line 1566

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



1572
1573
1574
# File 'lib/stripe/resources/confirmation_token.rb', line 1572

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1568
1569
1570
# File 'lib/stripe/resources/confirmation_token.rb', line 1568

def self.inner_class_types
  @inner_class_types = { networks: Networks, status_details: StatusDetails }
end