Class: Stripe::ConfirmationToken::PaymentMethodPreview::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



1523
1524
1525
# File 'lib/stripe/resources/confirmation_token.rb', line 1523

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



1525
1526
1527
# File 'lib/stripe/resources/confirmation_token.rb', line 1525

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



1527
1528
1529
# File 'lib/stripe/resources/confirmation_token.rb', line 1527

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



1529
1530
1531
# File 'lib/stripe/resources/confirmation_token.rb', line 1529

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



1531
1532
1533
# File 'lib/stripe/resources/confirmation_token.rb', line 1531

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1533
1534
1535
# File 'lib/stripe/resources/confirmation_token.rb', line 1533

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1535
1536
1537
# File 'lib/stripe/resources/confirmation_token.rb', line 1535

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



1537
1538
1539
# File 'lib/stripe/resources/confirmation_token.rb', line 1537

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



1539
1540
1541
# File 'lib/stripe/resources/confirmation_token.rb', line 1539

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



1541
1542
1543
# File 'lib/stripe/resources/confirmation_token.rb', line 1541

def status_details
  @status_details
end

Class Method Details

.field_remappingsObject



1547
1548
1549
# File 'lib/stripe/resources/confirmation_token.rb', line 1547

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1543
1544
1545
# File 'lib/stripe/resources/confirmation_token.rb', line 1543

def self.inner_class_types
  @inner_class_types = { networks: Networks, status_details: StatusDetails }
end