Class: Stripe::ConfirmationToken::PaymentMethodPreview::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



713
714
715
# File 'lib/stripe/resources/confirmation_token.rb', line 713

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



715
716
717
# File 'lib/stripe/resources/confirmation_token.rb', line 715

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



717
718
719
# File 'lib/stripe/resources/confirmation_token.rb', line 717

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



719
720
721
# File 'lib/stripe/resources/confirmation_token.rb', line 719

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



721
722
723
# File 'lib/stripe/resources/confirmation_token.rb', line 721

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



723
724
725
# File 'lib/stripe/resources/confirmation_token.rb', line 723

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



725
726
727
# File 'lib/stripe/resources/confirmation_token.rb', line 725

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



727
728
729
# File 'lib/stripe/resources/confirmation_token.rb', line 727

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



729
730
731
# File 'lib/stripe/resources/confirmation_token.rb', line 729

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



731
732
733
# File 'lib/stripe/resources/confirmation_token.rb', line 731

def status_details
  @status_details
end