Class: Stripe::ConfirmationToken::PaymentMethodPreview::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



828
829
830
# File 'lib/stripe/resources/confirmation_token.rb', line 828

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



831
832
833
# File 'lib/stripe/resources/confirmation_token.rb', line 831

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



834
835
836
# File 'lib/stripe/resources/confirmation_token.rb', line 834

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



837
838
839
# File 'lib/stripe/resources/confirmation_token.rb', line 837

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



840
841
842
# File 'lib/stripe/resources/confirmation_token.rb', line 840

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



843
844
845
# File 'lib/stripe/resources/confirmation_token.rb', line 843

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



846
847
848
# File 'lib/stripe/resources/confirmation_token.rb', line 846

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



849
850
851
# File 'lib/stripe/resources/confirmation_token.rb', line 849

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



852
853
854
# File 'lib/stripe/resources/confirmation_token.rb', line 852

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



855
856
857
# File 'lib/stripe/resources/confirmation_token.rb', line 855

def status_details
  @status_details
end