Class: Stripe::ConfirmationToken::PaymentMethodPreview::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/confirmation_token.rb

Defined Under Namespace

Classes: Networks, StatusDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Account holder type: individual or company.



666
667
668
# File 'lib/stripe/resources/confirmation_token.rb', line 666

def 
  @account_holder_type
end

#account_numberObject (readonly)

Account number of the bank account.



668
669
670
# File 'lib/stripe/resources/confirmation_token.rb', line 668

def 
  @account_number
end

#account_typeObject (readonly)

Account type: checkings or savings. Defaults to checking if omitted.



670
671
672
# File 'lib/stripe/resources/confirmation_token.rb', line 670

def 
  @account_type
end

#bank_nameObject (readonly)

The name of the bank.



672
673
674
# File 'lib/stripe/resources/confirmation_token.rb', line 672

def bank_name
  @bank_name
end

#financial_connections_accountObject (readonly)

The ID of the Financial Connections Account used to create the payment method.



674
675
676
# File 'lib/stripe/resources/confirmation_token.rb', line 674

def 
  @financial_connections_account
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



676
677
678
# File 'lib/stripe/resources/confirmation_token.rb', line 676

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



678
679
680
# File 'lib/stripe/resources/confirmation_token.rb', line 678

def last4
  @last4
end

#networksObject (readonly)

Contains information about US bank account networks that can be used.



680
681
682
# File 'lib/stripe/resources/confirmation_token.rb', line 680

def networks
  @networks
end

#routing_numberObject (readonly)

Routing number of the bank account.



682
683
684
# File 'lib/stripe/resources/confirmation_token.rb', line 682

def routing_number
  @routing_number
end

#status_detailsObject (readonly)

Contains information about the future reusability of this PaymentMethod.



684
685
686
# File 'lib/stripe/resources/confirmation_token.rb', line 684

def status_details
  @status_details
end