Class: Stripe::ConfirmationTokenCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams

Returns a new instance of ConfirmationTokenCreateParams.



697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 697

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



681
682
683
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 681

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



683
684
685
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 683

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



685
686
687
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 685

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



687
688
689
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 687

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



689
690
691
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 689

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken's payment method.

The presence of this property will attach the payment method to the PaymentIntent's Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



693
694
695
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 693

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



695
696
697
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 695

def shipping
  @shipping
end