Class: Stripe::ConfirmationTokenCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams

Returns a new instance of ConfirmationTokenCreateParams.



775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 775

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



759
760
761
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 759

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



761
762
763
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 761

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



763
764
765
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 763

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



765
766
767
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 765

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



767
768
769
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 767

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken's payment method.

The presence of this property will attach the payment method to the PaymentIntent's Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



771
772
773
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 771

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



773
774
775
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 773

def shipping
  @shipping
end