Class: Stripe::ConfirmationTokenCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams

Returns a new instance of ConfirmationTokenCreateParams.



788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 788

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



772
773
774
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 772

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



774
775
776
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 774

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



776
777
778
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 776

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



778
779
780
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 778

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



780
781
782
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 780

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](docs.stripe.com/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



784
785
786
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 784

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



786
787
788
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 786

def shipping
  @shipping
end