Class: Stripe::ConfirmationTokenCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/confirmation_token_create_params.rb

Defined Under Namespace

Classes: PaymentMethodData, PaymentMethodOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, return_url: nil, setup_future_usage: nil, shipping: nil) ⇒ ConfirmationTokenCreateParams

Returns a new instance of ConfirmationTokenCreateParams.



729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 729

def initialize(
  expand: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil
)
  @expand = expand
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



713
714
715
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 713

def expand
  @expand
end

#payment_methodObject

ID of an existing PaymentMethod.



715
716
717
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 715

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod.



717
718
719
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 717

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment-method-specific configuration for this ConfirmationToken.



719
720
721
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 719

def payment_method_options
  @payment_method_options
end

#return_urlObject

Return URL used to confirm the Intent.



721
722
723
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 721

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this ConfirmationToken’s payment method.

The presence of this property will [attach the payment method](docs.stripe.com/payments/save-during-payment) to the PaymentIntent’s Customer, if present, after the PaymentIntent is confirmed and any required actions from the user are complete.



725
726
727
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 725

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this ConfirmationToken.



727
728
729
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 727

def shipping
  @shipping
end