Class: Stripe::ConfirmationTokenCreateParams::PaymentMethodData::Upi::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ConfirmationTokenCreateParams::PaymentMethodData::Upi::MandateOptions
- Defined in:
- lib/stripe/params/confirmation_token_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of
fixedormaximum. -
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
365 366 367 368 369 370 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 365 def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) @amount = amount @amount_type = amount_type @description = description @end_date = end_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
357 358 359 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 357 def amount @amount end |
#amount_type ⇒ Object
One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.
359 360 361 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 359 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
361 362 363 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 361 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription.
363 364 365 |
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 363 def end_date @end_date end |