Class: Stripe::ConfirmationTokenCreateParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/confirmation_token_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



708
709
710
711
712
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 708

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For fixed_count installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



701
702
703
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 701

def count
  @count
end

#intervalObject

For fixed_count installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of month.



704
705
706
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 704

def interval
  @interval
end

#typeObject

Type of installment plan, one of fixed_count, bonus, or revolving.



706
707
708
# File 'lib/stripe/params/confirmation_token_create_params.rb', line 706

def type
  @type
end