Class: Stripe::Coupon

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/coupon.rb

Overview

A coupon contains information about a percent-off or amount-off discount you might want to apply to a customer. Coupons may be applied to [subscriptions](stripe.com/docs/api#subscriptions), [invoices](stripe.com/docs/api#invoices), [checkout sessions](stripe.com/docs/api/checkout/sessions), [quotes](stripe.com/docs/api#quotes), and more. Coupons do not work with conventional one-off [charges](stripe.com/docs/api#create_charge) or [payment intents](stripe.com/docs/api/payment_intents).

Defined Under Namespace

Classes: AppliesTo, CreateParams, CurrencyOptions, DeleteParams, ListParams, Script, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"coupon"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_offObject (readonly)

Amount (in the ‘currency` specified) that will be taken off the subtotal of any invoices for this customer.



196
197
198
# File 'lib/stripe/resources/coupon.rb', line 196

def amount_off
  @amount_off
end

#applies_toObject (readonly)

Attribute for field applies_to



198
199
200
# File 'lib/stripe/resources/coupon.rb', line 198

def applies_to
  @applies_to
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



200
201
202
# File 'lib/stripe/resources/coupon.rb', line 200

def created
  @created
end

#currencyObject (readonly)

If ‘amount_off` has been set, the three-letter [ISO code for the currency](stripe.com/docs/currencies) of the amount to take off.



202
203
204
# File 'lib/stripe/resources/coupon.rb', line 202

def currency
  @currency
end

#currency_optionsObject (readonly)

Coupons defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).



204
205
206
# File 'lib/stripe/resources/coupon.rb', line 204

def currency_options
  @currency_options
end

#deletedObject (readonly)

Always true for a deleted object



234
235
236
# File 'lib/stripe/resources/coupon.rb', line 234

def deleted
  @deleted
end

#durationObject (readonly)

One of ‘forever`, `once`, or `repeating`. Describes how long a customer who applies this coupon will get the discount.



206
207
208
# File 'lib/stripe/resources/coupon.rb', line 206

def duration
  @duration
end

#duration_in_monthsObject (readonly)

If ‘duration` is `repeating`, the number of months the coupon applies. Null if coupon `duration` is `forever` or `once`.



208
209
210
# File 'lib/stripe/resources/coupon.rb', line 208

def duration_in_months
  @duration_in_months
end

#idObject (readonly)

Unique identifier for the object.



210
211
212
# File 'lib/stripe/resources/coupon.rb', line 210

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



212
213
214
# File 'lib/stripe/resources/coupon.rb', line 212

def livemode
  @livemode
end

#max_redemptionsObject (readonly)

Maximum number of times this coupon can be redeemed, in total, across all customers, before it is no longer valid.



214
215
216
# File 'lib/stripe/resources/coupon.rb', line 214

def max_redemptions
  @max_redemptions
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



216
217
218
# File 'lib/stripe/resources/coupon.rb', line 216

def 
  @metadata
end

#nameObject (readonly)

Name of the coupon displayed to customers on for instance invoices or receipts.



218
219
220
# File 'lib/stripe/resources/coupon.rb', line 218

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



220
221
222
# File 'lib/stripe/resources/coupon.rb', line 220

def object
  @object
end

#percent_offObject (readonly)

Percent that will be taken off the subtotal of any invoices for this customer for the duration of the coupon. For example, a coupon with percent_off of 50 will make a $ (or local equivalent)100 invoice $ (or local equivalent)50 instead.



222
223
224
# File 'lib/stripe/resources/coupon.rb', line 222

def percent_off
  @percent_off
end

#redeem_byObject (readonly)

Date after which the coupon can no longer be redeemed.



224
225
226
# File 'lib/stripe/resources/coupon.rb', line 224

def redeem_by
  @redeem_by
end

#scriptObject (readonly)

Configuration of the [script](docs.stripe.com/billing/subscriptions/script-coupons) used to calculate the discount.



226
227
228
# File 'lib/stripe/resources/coupon.rb', line 226

def script
  @script
end

#times_redeemedObject (readonly)

Number of times this coupon has been applied to a customer.



228
229
230
# File 'lib/stripe/resources/coupon.rb', line 228

def times_redeemed
  @times_redeemed
end

#typeObject (readonly)

One of ‘amount_off`, `percent_off`, or `script`. Describes the type of coupon logic used to calculate the discount.



230
231
232
# File 'lib/stripe/resources/coupon.rb', line 230

def type
  @type
end

#validObject (readonly)

Taking account of the above properties, whether this coupon can still be applied to a customer.



232
233
234
# File 'lib/stripe/resources/coupon.rb', line 232

def valid
  @valid
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

You can create coupons easily via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. Coupon creation is also accessible via the API if you need to create coupons on the fly.

A coupon has either a percent_off or an amount_off and currency. If you set an amount_off, that amount will be subtracted from any invoice’s subtotal. For example, an invoice with a subtotal of 100 will have a final total of 0 if a coupon with an amount_off of 200 is applied to it and an invoice with a subtotal of 300 will have a final total of 100 if a coupon with an amount_off of 200 is applied to it.



239
240
241
# File 'lib/stripe/resources/coupon.rb', line 239

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/coupons", params: params, opts: opts)
end

.delete(coupon, params = {}, opts = {}) ⇒ Object

You can delete coupons via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. However, deleting a coupon does not affect any customers who have already applied the coupon; it means that new customers can’t redeem the coupon. You can also delete coupons via the API.



244
245
246
247
248
249
250
251
# File 'lib/stripe/resources/coupon.rb', line 244

def self.delete(coupon, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(coupon) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of your coupons.



264
265
266
# File 'lib/stripe/resources/coupon.rb', line 264

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/coupons", params: params, opts: opts)
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/coupon.rb', line 15

def self.object_name
  "coupon"
end

.update(coupon, params = {}, opts = {}) ⇒ Object

Updates the metadata of a coupon. Other coupon details (currency, duration, amount_off) are, by design, not editable.



269
270
271
272
273
274
275
276
# File 'lib/stripe/resources/coupon.rb', line 269

def self.update(coupon, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(coupon) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

You can delete coupons via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. However, deleting a coupon does not affect any customers who have already applied the coupon; it means that new customers can’t redeem the coupon. You can also delete coupons via the API.



254
255
256
257
258
259
260
261
# File 'lib/stripe/resources/coupon.rb', line 254

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end