Class: Stripe::Coupon
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Coupon
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/coupon.rb
Overview
A coupon contains information about a percent-off or amount-off discount you might want to apply to a customer. Coupons may be applied to [subscriptions](stripe.com/docs/api#subscriptions), [invoices](stripe.com/docs/api#invoices), [checkout sessions](stripe.com/docs/api/checkout/sessions), [quotes](stripe.com/docs/api#quotes), and more. Coupons do not work with conventional one-off [charges](stripe.com/docs/api#create_charge) or [payment intents](stripe.com/docs/api/payment_intents).
Defined Under Namespace
Classes: AppliesTo, CreateParams, CurrencyOptions, DeleteParams, ListParams, Script, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"coupon"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_off ⇒ Object
readonly
Amount (in the ‘currency` specified) that will be taken off the subtotal of any invoices for this customer.
-
#applies_to ⇒ Object
readonly
Attribute for field applies_to.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
If ‘amount_off` has been set, the three-letter [ISO code for the currency](stripe.com/docs/currencies) of the amount to take off.
-
#currency_options ⇒ Object
readonly
Coupons defined in each available currency option.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#duration ⇒ Object
readonly
One of ‘forever`, `once`, or `repeating`.
-
#duration_in_months ⇒ Object
readonly
If ‘duration` is `repeating`, the number of months the coupon applies.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#max_redemptions ⇒ Object
readonly
Maximum number of times this coupon can be redeemed, in total, across all customers, before it is no longer valid.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
Name of the coupon displayed to customers on for instance invoices or receipts.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#percent_off ⇒ Object
readonly
Percent that will be taken off the subtotal of any invoices for this customer for the duration of the coupon.
-
#redeem_by ⇒ Object
readonly
Date after which the coupon can no longer be redeemed.
-
#script ⇒ Object
readonly
Configuration of the [script](docs.stripe.com/billing/subscriptions/script-coupons) used to calculate the discount.
-
#times_redeemed ⇒ Object
readonly
Number of times this coupon has been applied to a customer.
-
#type ⇒ Object
readonly
One of ‘amount_off`, `percent_off`, or `script`.
-
#valid ⇒ Object
readonly
Taking account of the above properties, whether this coupon can still be applied to a customer.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
You can create coupons easily via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard.
-
.delete(coupon, params = {}, opts = {}) ⇒ Object
You can delete coupons via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your coupons.
- .object_name ⇒ Object
-
.update(coupon, params = {}, opts = {}) ⇒ Object
Updates the metadata of a coupon.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
You can delete coupons via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_off ⇒ Object (readonly)
Amount (in the ‘currency` specified) that will be taken off the subtotal of any invoices for this customer.
197 198 199 |
# File 'lib/stripe/resources/coupon.rb', line 197 def amount_off @amount_off end |
#applies_to ⇒ Object (readonly)
Attribute for field applies_to
199 200 201 |
# File 'lib/stripe/resources/coupon.rb', line 199 def applies_to @applies_to end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
201 202 203 |
# File 'lib/stripe/resources/coupon.rb', line 201 def created @created end |
#currency ⇒ Object (readonly)
If ‘amount_off` has been set, the three-letter [ISO code for the currency](stripe.com/docs/currencies) of the amount to take off.
203 204 205 |
# File 'lib/stripe/resources/coupon.rb', line 203 def currency @currency end |
#currency_options ⇒ Object (readonly)
Coupons defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
205 206 207 |
# File 'lib/stripe/resources/coupon.rb', line 205 def @currency_options end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
235 236 237 |
# File 'lib/stripe/resources/coupon.rb', line 235 def deleted @deleted end |
#duration ⇒ Object (readonly)
One of ‘forever`, `once`, or `repeating`. Describes how long a customer who applies this coupon will get the discount.
207 208 209 |
# File 'lib/stripe/resources/coupon.rb', line 207 def duration @duration end |
#duration_in_months ⇒ Object (readonly)
If ‘duration` is `repeating`, the number of months the coupon applies. Null if coupon `duration` is `forever` or `once`.
209 210 211 |
# File 'lib/stripe/resources/coupon.rb', line 209 def duration_in_months @duration_in_months end |
#id ⇒ Object (readonly)
Unique identifier for the object.
211 212 213 |
# File 'lib/stripe/resources/coupon.rb', line 211 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
213 214 215 |
# File 'lib/stripe/resources/coupon.rb', line 213 def livemode @livemode end |
#max_redemptions ⇒ Object (readonly)
Maximum number of times this coupon can be redeemed, in total, across all customers, before it is no longer valid.
215 216 217 |
# File 'lib/stripe/resources/coupon.rb', line 215 def max_redemptions @max_redemptions end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
217 218 219 |
# File 'lib/stripe/resources/coupon.rb', line 217 def @metadata end |
#name ⇒ Object (readonly)
Name of the coupon displayed to customers on for instance invoices or receipts.
219 220 221 |
# File 'lib/stripe/resources/coupon.rb', line 219 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
221 222 223 |
# File 'lib/stripe/resources/coupon.rb', line 221 def object @object end |
#percent_off ⇒ Object (readonly)
Percent that will be taken off the subtotal of any invoices for this customer for the duration of the coupon. For example, a coupon with percent_off of 50 will make a $ (or local equivalent)100 invoice $ (or local equivalent)50 instead.
223 224 225 |
# File 'lib/stripe/resources/coupon.rb', line 223 def percent_off @percent_off end |
#redeem_by ⇒ Object (readonly)
Date after which the coupon can no longer be redeemed.
225 226 227 |
# File 'lib/stripe/resources/coupon.rb', line 225 def redeem_by @redeem_by end |
#script ⇒ Object (readonly)
Configuration of the [script](docs.stripe.com/billing/subscriptions/script-coupons) used to calculate the discount.
227 228 229 |
# File 'lib/stripe/resources/coupon.rb', line 227 def script @script end |
#times_redeemed ⇒ Object (readonly)
Number of times this coupon has been applied to a customer.
229 230 231 |
# File 'lib/stripe/resources/coupon.rb', line 229 def times_redeemed @times_redeemed end |
#type ⇒ Object (readonly)
One of ‘amount_off`, `percent_off`, or `script`. Describes the type of coupon logic used to calculate the discount.
231 232 233 |
# File 'lib/stripe/resources/coupon.rb', line 231 def type @type end |
#valid ⇒ Object (readonly)
Taking account of the above properties, whether this coupon can still be applied to a customer.
233 234 235 |
# File 'lib/stripe/resources/coupon.rb', line 233 def valid @valid end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
You can create coupons easily via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. Coupon creation is also accessible via the API if you need to create coupons on the fly.
A coupon has either a percent_off or an amount_off and currency. If you set an amount_off, that amount will be subtracted from any invoice’s subtotal. For example, an invoice with a subtotal of 100 will have a final total of 0 if a coupon with an amount_off of 200 is applied to it and an invoice with a subtotal of 300 will have a final total of 100 if a coupon with an amount_off of 200 is applied to it.
240 241 242 |
# File 'lib/stripe/resources/coupon.rb', line 240 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/coupons", params: params, opts: opts) end |
.delete(coupon, params = {}, opts = {}) ⇒ Object
You can delete coupons via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. However, deleting a coupon does not affect any customers who have already applied the coupon; it means that new customers can’t redeem the coupon. You can also delete coupons via the API.
245 246 247 248 249 250 251 252 |
# File 'lib/stripe/resources/coupon.rb', line 245 def self.delete(coupon, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(coupon) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your coupons.
265 266 267 |
# File 'lib/stripe/resources/coupon.rb', line 265 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/coupons", params: params, opts: opts) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/coupon.rb', line 15 def self.object_name "coupon" end |
.update(coupon, params = {}, opts = {}) ⇒ Object
Updates the metadata of a coupon. Other coupon details (currency, duration, amount_off) are, by design, not editable.
270 271 272 273 274 275 276 277 |
# File 'lib/stripe/resources/coupon.rb', line 270 def self.update(coupon, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(coupon) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
You can delete coupons via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. However, deleting a coupon does not affect any customers who have already applied the coupon; it means that new customers can’t redeem the coupon. You can also delete coupons via the API.
255 256 257 258 259 260 261 262 |
# File 'lib/stripe/resources/coupon.rb', line 255 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(self["id"]) }), params: params, opts: opts ) end |