Class: Stripe::Coupon

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/coupon.rb

Overview

A coupon contains information about a percent-off or amount-off discount you might want to apply to a customer. Coupons may be applied to [subscriptions](stripe.com/docs/api#subscriptions), [invoices](stripe.com/docs/api#invoices), [checkout sessions](stripe.com/docs/api/checkout/sessions), [quotes](stripe.com/docs/api#quotes), and more. Coupons do not work with conventional one-off [charges](stripe.com/docs/api#create_charge) or [payment intents](stripe.com/docs/api/payment_intents).

Defined Under Namespace

Classes: AppliesTo, CreateParams, CurrencyOptions, DeleteParams, ListParams, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"coupon"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_offObject (readonly)

Amount (in the ‘currency` specified) that will be taken off the subtotal of any invoices for this customer.



172
173
174
# File 'lib/stripe/resources/coupon.rb', line 172

def amount_off
  @amount_off
end

#applies_toObject (readonly)

Attribute for field applies_to



174
175
176
# File 'lib/stripe/resources/coupon.rb', line 174

def applies_to
  @applies_to
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



176
177
178
# File 'lib/stripe/resources/coupon.rb', line 176

def created
  @created
end

#currencyObject (readonly)

If ‘amount_off` has been set, the three-letter [ISO code for the currency](stripe.com/docs/currencies) of the amount to take off.



178
179
180
# File 'lib/stripe/resources/coupon.rb', line 178

def currency
  @currency
end

#currency_optionsObject (readonly)

Coupons defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).



180
181
182
# File 'lib/stripe/resources/coupon.rb', line 180

def currency_options
  @currency_options
end

#deletedObject (readonly)

Always true for a deleted object



206
207
208
# File 'lib/stripe/resources/coupon.rb', line 206

def deleted
  @deleted
end

#durationObject (readonly)

One of ‘forever`, `once`, or `repeating`. Describes how long a customer who applies this coupon will get the discount.



182
183
184
# File 'lib/stripe/resources/coupon.rb', line 182

def duration
  @duration
end

#duration_in_monthsObject (readonly)

If ‘duration` is `repeating`, the number of months the coupon applies. Null if coupon `duration` is `forever` or `once`.



184
185
186
# File 'lib/stripe/resources/coupon.rb', line 184

def duration_in_months
  @duration_in_months
end

#idObject (readonly)

Unique identifier for the object.



186
187
188
# File 'lib/stripe/resources/coupon.rb', line 186

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



188
189
190
# File 'lib/stripe/resources/coupon.rb', line 188

def livemode
  @livemode
end

#max_redemptionsObject (readonly)

Maximum number of times this coupon can be redeemed, in total, across all customers, before it is no longer valid.



190
191
192
# File 'lib/stripe/resources/coupon.rb', line 190

def max_redemptions
  @max_redemptions
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



192
193
194
# File 'lib/stripe/resources/coupon.rb', line 192

def 
  @metadata
end

#nameObject (readonly)

Name of the coupon displayed to customers on for instance invoices or receipts.



194
195
196
# File 'lib/stripe/resources/coupon.rb', line 194

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



196
197
198
# File 'lib/stripe/resources/coupon.rb', line 196

def object
  @object
end

#percent_offObject (readonly)

Percent that will be taken off the subtotal of any invoices for this customer for the duration of the coupon. For example, a coupon with percent_off of 50 will make a $ (or local equivalent)100 invoice $ (or local equivalent)50 instead.



198
199
200
# File 'lib/stripe/resources/coupon.rb', line 198

def percent_off
  @percent_off
end

#redeem_byObject (readonly)

Date after which the coupon can no longer be redeemed.



200
201
202
# File 'lib/stripe/resources/coupon.rb', line 200

def redeem_by
  @redeem_by
end

#times_redeemedObject (readonly)

Number of times this coupon has been applied to a customer.



202
203
204
# File 'lib/stripe/resources/coupon.rb', line 202

def times_redeemed
  @times_redeemed
end

#validObject (readonly)

Taking account of the above properties, whether this coupon can still be applied to a customer.



204
205
206
# File 'lib/stripe/resources/coupon.rb', line 204

def valid
  @valid
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

You can create coupons easily via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. Coupon creation is also accessible via the API if you need to create coupons on the fly.

A coupon has either a percent_off or an amount_off and currency. If you set an amount_off, that amount will be subtracted from any invoice’s subtotal. For example, an invoice with a subtotal of 100 will have a final total of 0 if a coupon with an amount_off of 200 is applied to it and an invoice with a subtotal of 300 will have a final total of 100 if a coupon with an amount_off of 200 is applied to it.



211
212
213
# File 'lib/stripe/resources/coupon.rb', line 211

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/coupons", params: params, opts: opts)
end

.delete(coupon, params = {}, opts = {}) ⇒ Object

You can delete coupons via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. However, deleting a coupon does not affect any customers who have already applied the coupon; it means that new customers can’t redeem the coupon. You can also delete coupons via the API.



216
217
218
219
220
221
222
223
# File 'lib/stripe/resources/coupon.rb', line 216

def self.delete(coupon, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(coupon) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of your coupons.



236
237
238
# File 'lib/stripe/resources/coupon.rb', line 236

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/coupons", params: params, opts: opts)
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/coupon.rb', line 15

def self.object_name
  "coupon"
end

.update(coupon, params = {}, opts = {}) ⇒ Object

Updates the metadata of a coupon. Other coupon details (currency, duration, amount_off) are, by design, not editable.



241
242
243
244
245
246
247
248
# File 'lib/stripe/resources/coupon.rb', line 241

def self.update(coupon, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(coupon) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

You can delete coupons via the [coupon management](dashboard.stripe.com/coupons) page of the Stripe dashboard. However, deleting a coupon does not affect any customers who have already applied the coupon; it means that new customers can’t redeem the coupon. You can also delete coupons via the API.



226
227
228
229
230
231
232
233
# File 'lib/stripe/resources/coupon.rb', line 226

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/coupons/%<coupon>s", { coupon: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end