Class: Stripe::Coupon::Script

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/coupon.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#configurationObject (readonly)

The configuration values of the script. The keys and values are specific to the script implementation.



31
32
33
# File 'lib/stripe/resources/coupon.rb', line 31

def configuration
  @configuration
end

#display_nameObject (readonly)

The name of the script used to calculate the discount.



33
34
35
# File 'lib/stripe/resources/coupon.rb', line 33

def display_name
  @display_name
end

#idObject (readonly)

The script implementation ID for this coupon.



35
36
37
# File 'lib/stripe/resources/coupon.rb', line 35

def id
  @id
end