Class: Stripe::CouponCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CouponCreateParams
- Defined in:
- lib/stripe/params/coupon_create_params.rb
Defined Under Namespace
Classes: AppliesTo, CurrencyOptions, Script
Instance Attribute Summary collapse
-
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if
percent_offis not passed). -
#applies_to ⇒ Object
A hash containing directions for what this Coupon will apply discounts to.
-
#currency ⇒ Object
Three-letter ISO code for the currency of the
amount_offparameter (required ifamount_offis passed). -
#currency_options ⇒ Object
Coupons defined in each available currency option (only supported if
amount_offis passed). -
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription.
-
#duration_in_months ⇒ Object
Required only if
durationisrepeating, in which case it must be a positive integer that specifies the number of months the discount will be in effect. -
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#id ⇒ Object
Unique string of your choice that will be used to identify this coupon when applying it to a customer.
-
#max_redemptions ⇒ Object
A positive integer specifying the number of times the coupon can be redeemed before it's no longer valid.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts.
-
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if
amount_offis not passed). -
#redeem_by ⇒ Object
Unix timestamp specifying the last time at which the coupon can be redeemed (cannot be set to more than 5 years in the future).
-
#script ⇒ Object
Configuration of the script used to calculate the discount.
Instance Method Summary collapse
-
#initialize(amount_off: nil, applies_to: nil, currency: nil, currency_options: nil, duration: nil, duration_in_months: nil, expand: nil, id: nil, max_redemptions: nil, metadata: nil, name: nil, percent_off: nil, redeem_by: nil, script: nil) ⇒ CouponCreateParams
constructor
A new instance of CouponCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_off: nil, applies_to: nil, currency: nil, currency_options: nil, duration: nil, duration_in_months: nil, expand: nil, id: nil, max_redemptions: nil, metadata: nil, name: nil, percent_off: nil, redeem_by: nil, script: nil) ⇒ CouponCreateParams
Returns a new instance of CouponCreateParams.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/stripe/params/coupon_create_params.rb', line 64 def initialize( amount_off: nil, applies_to: nil, currency: nil, currency_options: nil, duration: nil, duration_in_months: nil, expand: nil, id: nil, max_redemptions: nil, metadata: nil, name: nil, percent_off: nil, redeem_by: nil, script: nil ) @amount_off = amount_off @applies_to = applies_to @currency = currency @currency_options = @duration = duration @duration_in_months = duration_in_months @expand = @id = id @max_redemptions = max_redemptions @metadata = @name = name @percent_off = percent_off @redeem_by = redeem_by @script = script end |
Instance Attribute Details
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if percent_off is not passed).
36 37 38 |
# File 'lib/stripe/params/coupon_create_params.rb', line 36 def amount_off @amount_off end |
#applies_to ⇒ Object
A hash containing directions for what this Coupon will apply discounts to.
38 39 40 |
# File 'lib/stripe/params/coupon_create_params.rb', line 38 def applies_to @applies_to end |
#currency ⇒ Object
Three-letter ISO code for the currency of the amount_off parameter (required if amount_off is passed).
40 41 42 |
# File 'lib/stripe/params/coupon_create_params.rb', line 40 def currency @currency end |
#currency_options ⇒ Object
Coupons defined in each available currency option (only supported if amount_off is passed). Each key must be a three-letter ISO currency code and a supported currency.
42 43 44 |
# File 'lib/stripe/params/coupon_create_params.rb', line 42 def @currency_options end |
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription. Defaults to once.
44 45 46 |
# File 'lib/stripe/params/coupon_create_params.rb', line 44 def duration @duration end |
#duration_in_months ⇒ Object
Required only if duration is repeating, in which case it must be a positive integer that specifies the number of months the discount will be in effect.
46 47 48 |
# File 'lib/stripe/params/coupon_create_params.rb', line 46 def duration_in_months @duration_in_months end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
48 49 50 |
# File 'lib/stripe/params/coupon_create_params.rb', line 48 def @expand end |
#id ⇒ Object
Unique string of your choice that will be used to identify this coupon when applying it to a customer. If you don't want to specify a particular code, you can leave the ID blank and we'll generate a random code for you.
50 51 52 |
# File 'lib/stripe/params/coupon_create_params.rb', line 50 def id @id end |
#max_redemptions ⇒ Object
A positive integer specifying the number of times the coupon can be redeemed before it's no longer valid. For example, you might have a 50% off coupon that the first 20 readers of your blog can use.
52 53 54 |
# File 'lib/stripe/params/coupon_create_params.rb', line 52 def max_redemptions @max_redemptions end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
54 55 56 |
# File 'lib/stripe/params/coupon_create_params.rb', line 54 def @metadata end |
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the id is shown if name is not set.
56 57 58 |
# File 'lib/stripe/params/coupon_create_params.rb', line 56 def name @name end |
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if amount_off is not passed).
58 59 60 |
# File 'lib/stripe/params/coupon_create_params.rb', line 58 def percent_off @percent_off end |
#redeem_by ⇒ Object
Unix timestamp specifying the last time at which the coupon can be redeemed (cannot be set to more than 5 years in the future). After the redeem_by date, the coupon can no longer be applied to new customers.
60 61 62 |
# File 'lib/stripe/params/coupon_create_params.rb', line 60 def redeem_by @redeem_by end |
#script ⇒ Object
Configuration of the script used to calculate the discount.
62 63 64 |
# File 'lib/stripe/params/coupon_create_params.rb', line 62 def script @script end |