Class: Stripe::CouponService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CouponService::CreateParams
- Defined in:
- lib/stripe/services/coupon_service.rb
Defined Under Namespace
Classes: AppliesTo, CurrencyOptions
Instance Attribute Summary collapse
-
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).
-
#applies_to ⇒ Object
A hash containing directions for what this Coupon will apply discounts to.
-
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).
-
#currency_options ⇒ Object
Coupons defined in each available currency option (only supported if ‘amount_off` is passed).
-
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription.
-
#duration_in_months ⇒ Object
Required only if ‘duration` is `repeating`, in which case it must be a positive integer that specifies the number of months the discount will be in effect.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#id ⇒ Object
Unique string of your choice that will be used to identify this coupon when applying it to a customer.
-
#max_redemptions ⇒ Object
A positive integer specifying the number of times the coupon can be redeemed before it’s no longer valid.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts.
-
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).
-
#redeem_by ⇒ Object
Unix timestamp specifying the last time at which the coupon can be redeemed.
Instance Method Summary collapse
-
#initialize(amount_off: nil, applies_to: nil, currency: nil, currency_options: nil, duration: nil, duration_in_months: nil, expand: nil, id: nil, max_redemptions: nil, metadata: nil, name: nil, percent_off: nil, redeem_by: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_off: nil, applies_to: nil, currency: nil, currency_options: nil, duration: nil, duration_in_months: nil, expand: nil, id: nil, max_redemptions: nil, metadata: nil, name: nil, percent_off: nil, redeem_by: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/stripe/services/coupon_service.rb', line 126 def initialize( amount_off: nil, applies_to: nil, currency: nil, currency_options: nil, duration: nil, duration_in_months: nil, expand: nil, id: nil, max_redemptions: nil, metadata: nil, name: nil, percent_off: nil, redeem_by: nil ) @amount_off = amount_off @applies_to = applies_to @currency = currency @currency_options = @duration = duration @duration_in_months = duration_in_months @expand = @id = id @max_redemptions = max_redemptions @metadata = @name = name @percent_off = percent_off @redeem_by = redeem_by end |
Instance Attribute Details
#amount_off ⇒ Object
A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).
100 101 102 |
# File 'lib/stripe/services/coupon_service.rb', line 100 def amount_off @amount_off end |
#applies_to ⇒ Object
A hash containing directions for what this Coupon will apply discounts to.
102 103 104 |
# File 'lib/stripe/services/coupon_service.rb', line 102 def applies_to @applies_to end |
#currency ⇒ Object
Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).
104 105 106 |
# File 'lib/stripe/services/coupon_service.rb', line 104 def currency @currency end |
#currency_options ⇒ Object
Coupons defined in each available currency option (only supported if ‘amount_off` is passed). Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
106 107 108 |
# File 'lib/stripe/services/coupon_service.rb', line 106 def @currency_options end |
#duration ⇒ Object
Specifies how long the discount will be in effect if used on a subscription. Defaults to ‘once`.
108 109 110 |
# File 'lib/stripe/services/coupon_service.rb', line 108 def duration @duration end |
#duration_in_months ⇒ Object
Required only if ‘duration` is `repeating`, in which case it must be a positive integer that specifies the number of months the discount will be in effect.
110 111 112 |
# File 'lib/stripe/services/coupon_service.rb', line 110 def duration_in_months @duration_in_months end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
112 113 114 |
# File 'lib/stripe/services/coupon_service.rb', line 112 def @expand end |
#id ⇒ Object
Unique string of your choice that will be used to identify this coupon when applying it to a customer. If you don’t want to specify a particular code, you can leave the ID blank and we’ll generate a random code for you.
114 115 116 |
# File 'lib/stripe/services/coupon_service.rb', line 114 def id @id end |
#max_redemptions ⇒ Object
A positive integer specifying the number of times the coupon can be redeemed before it’s no longer valid. For example, you might have a 50% off coupon that the first 20 readers of your blog can use.
116 117 118 |
# File 'lib/stripe/services/coupon_service.rb', line 116 def max_redemptions @max_redemptions end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
118 119 120 |
# File 'lib/stripe/services/coupon_service.rb', line 118 def @metadata end |
#name ⇒ Object
Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the ‘id` is shown if `name` is not set.
120 121 122 |
# File 'lib/stripe/services/coupon_service.rb', line 120 def name @name end |
#percent_off ⇒ Object
A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).
122 123 124 |
# File 'lib/stripe/services/coupon_service.rb', line 122 def percent_off @percent_off end |
#redeem_by ⇒ Object
Unix timestamp specifying the last time at which the coupon can be redeemed. After the redeem_by date, the coupon can no longer be applied to new customers.
124 125 126 |
# File 'lib/stripe/services/coupon_service.rb', line 124 def redeem_by @redeem_by end |