Class: Stripe::CouponService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/coupon_service.rb

Defined Under Namespace

Classes: AppliesTo, CurrencyOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_off: nil, applies_to: nil, currency: nil, currency_options: nil, duration: nil, duration_in_months: nil, expand: nil, id: nil, max_redemptions: nil, metadata: nil, name: nil, percent_off: nil, redeem_by: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/stripe/services/coupon_service.rb', line 149

def initialize(
  amount_off: nil,
  applies_to: nil,
  currency: nil,
  currency_options: nil,
  duration: nil,
  duration_in_months: nil,
  expand: nil,
  id: nil,
  max_redemptions: nil,
  metadata: nil,
  name: nil,
  percent_off: nil,
  redeem_by: nil
)
  @amount_off = amount_off
  @applies_to = applies_to
  @currency = currency
  @currency_options = currency_options
  @duration = duration
  @duration_in_months = duration_in_months
  @expand = expand
  @id = id
  @max_redemptions = max_redemptions
  @metadata = 
  @name = name
  @percent_off = percent_off
  @redeem_by = redeem_by
end

Instance Attribute Details

#amount_offObject

A positive integer representing the amount to subtract from an invoice total (required if ‘percent_off` is not passed).



111
112
113
# File 'lib/stripe/services/coupon_service.rb', line 111

def amount_off
  @amount_off
end

#applies_toObject

A hash containing directions for what this Coupon will apply discounts to.



114
115
116
# File 'lib/stripe/services/coupon_service.rb', line 114

def applies_to
  @applies_to
end

#currencyObject

Three-letter [ISO code for the currency](stripe.com/docs/currencies) of the ‘amount_off` parameter (required if `amount_off` is passed).



117
118
119
# File 'lib/stripe/services/coupon_service.rb', line 117

def currency
  @currency
end

#currency_optionsObject

Coupons defined in each available currency option (only supported if ‘amount_off` is passed). Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).



120
121
122
# File 'lib/stripe/services/coupon_service.rb', line 120

def currency_options
  @currency_options
end

#durationObject

Specifies how long the discount will be in effect if used on a subscription. Defaults to ‘once`.



123
124
125
# File 'lib/stripe/services/coupon_service.rb', line 123

def duration
  @duration
end

#duration_in_monthsObject

Required only if ‘duration` is `repeating`, in which case it must be a positive integer that specifies the number of months the discount will be in effect.



126
127
128
# File 'lib/stripe/services/coupon_service.rb', line 126

def duration_in_months
  @duration_in_months
end

#expandObject

Specifies which fields in the response should be expanded.



129
130
131
# File 'lib/stripe/services/coupon_service.rb', line 129

def expand
  @expand
end

#idObject

Unique string of your choice that will be used to identify this coupon when applying it to a customer. If you don’t want to specify a particular code, you can leave the ID blank and we’ll generate a random code for you.



132
133
134
# File 'lib/stripe/services/coupon_service.rb', line 132

def id
  @id
end

#max_redemptionsObject

A positive integer specifying the number of times the coupon can be redeemed before it’s no longer valid. For example, you might have a 50% off coupon that the first 20 readers of your blog can use.



135
136
137
# File 'lib/stripe/services/coupon_service.rb', line 135

def max_redemptions
  @max_redemptions
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



138
139
140
# File 'lib/stripe/services/coupon_service.rb', line 138

def 
  @metadata
end

#nameObject

Name of the coupon displayed to customers on, for instance invoices, or receipts. By default the ‘id` is shown if `name` is not set.



141
142
143
# File 'lib/stripe/services/coupon_service.rb', line 141

def name
  @name
end

#percent_offObject

A positive float larger than 0, and smaller or equal to 100, that represents the discount the coupon will apply (required if ‘amount_off` is not passed).



144
145
146
# File 'lib/stripe/services/coupon_service.rb', line 144

def percent_off
  @percent_off
end

#redeem_byObject

Unix timestamp specifying the last time at which the coupon can be redeemed. After the redeem_by date, the coupon can no longer be applied to new customers.



147
148
149
# File 'lib/stripe/services/coupon_service.rb', line 147

def redeem_by
  @redeem_by
end