Class: Stripe::CreditNote::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Defined Under Namespace

Classes: Line, Refund, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund: nil, refund_amount: nil, refunds: nil, shipping_cost: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/stripe/resources/credit_note.rb', line 242

def initialize(
  amount: nil,
  credit_amount: nil,
  effective_at: nil,
  email_type: nil,
  expand: nil,
  invoice: nil,
  lines: nil,
  memo: nil,
  metadata: nil,
  out_of_band_amount: nil,
  reason: nil,
  refund: nil,
  refund_amount: nil,
  refunds: nil,
  shipping_cost: nil
)
  @amount = amount
  @credit_amount = credit_amount
  @effective_at = effective_at
  @email_type = email_type
  @expand = expand
  @invoice = invoice
  @lines = lines
  @memo = memo
  @metadata = 
  @out_of_band_amount = out_of_band_amount
  @reason = reason
  @refund = refund
  @refund_amount = refund_amount
  @refunds = refunds
  @shipping_cost = shipping_cost
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) representing the total amount of the credit note.



212
213
214
# File 'lib/stripe/resources/credit_note.rb', line 212

def amount
  @amount
end

#credit_amountObject

The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.



214
215
216
# File 'lib/stripe/resources/credit_note.rb', line 214

def credit_amount
  @credit_amount
end

#effective_atObject

The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.



216
217
218
# File 'lib/stripe/resources/credit_note.rb', line 216

def effective_at
  @effective_at
end

#email_typeObject

Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.



218
219
220
# File 'lib/stripe/resources/credit_note.rb', line 218

def email_type
  @email_type
end

#expandObject

Specifies which fields in the response should be expanded.



220
221
222
# File 'lib/stripe/resources/credit_note.rb', line 220

def expand
  @expand
end

#invoiceObject

ID of the invoice.



222
223
224
# File 'lib/stripe/resources/credit_note.rb', line 222

def invoice
  @invoice
end

#linesObject

Line items that make up the credit note.



224
225
226
# File 'lib/stripe/resources/credit_note.rb', line 224

def lines
  @lines
end

#memoObject

The credit note’s memo appears on the credit note PDF.



226
227
228
# File 'lib/stripe/resources/credit_note.rb', line 226

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



228
229
230
# File 'lib/stripe/resources/credit_note.rb', line 228

def 
  @metadata
end

#out_of_band_amountObject

The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.



230
231
232
# File 'lib/stripe/resources/credit_note.rb', line 230

def out_of_band_amount
  @out_of_band_amount
end

#reasonObject

Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`



232
233
234
# File 'lib/stripe/resources/credit_note.rb', line 232

def reason
  @reason
end

#refundObject

ID of an existing refund to link this credit note to.



234
235
236
# File 'lib/stripe/resources/credit_note.rb', line 234

def refund
  @refund
end

#refund_amountObject

The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.



236
237
238
# File 'lib/stripe/resources/credit_note.rb', line 236

def refund_amount
  @refund_amount
end

#refundsObject

Refunds to link to this credit note.



238
239
240
# File 'lib/stripe/resources/credit_note.rb', line 238

def refunds
  @refunds
end

#shipping_costObject

When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.



240
241
242
# File 'lib/stripe/resources/credit_note.rb', line 240

def shipping_cost
  @shipping_cost
end