Class: Stripe::CreditNote::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Defined Under Namespace

Classes: Line, Refund, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, expand: nil, invoice: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund: nil, refund_amount: nil, refunds: nil, shipping_cost: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/stripe/resources/credit_note.rb', line 292

def initialize(
  amount: nil,
  credit_amount: nil,
  effective_at: nil,
  email_type: nil,
  expand: nil,
  invoice: nil,
  lines: nil,
  memo: nil,
  metadata: nil,
  out_of_band_amount: nil,
  reason: nil,
  refund: nil,
  refund_amount: nil,
  refunds: nil,
  shipping_cost: nil
)
  @amount = amount
  @credit_amount = credit_amount
  @effective_at = effective_at
  @email_type = email_type
  @expand = expand
  @invoice = invoice
  @lines = lines
  @memo = memo
  @metadata = 
  @out_of_band_amount = out_of_band_amount
  @reason = reason
  @refund = refund
  @refund_amount = refund_amount
  @refunds = refunds
  @shipping_cost = shipping_cost
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) representing the total amount of the credit note.



248
249
250
# File 'lib/stripe/resources/credit_note.rb', line 248

def amount
  @amount
end

#credit_amountObject

The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.



251
252
253
# File 'lib/stripe/resources/credit_note.rb', line 251

def credit_amount
  @credit_amount
end

#effective_atObject

The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.



254
255
256
# File 'lib/stripe/resources/credit_note.rb', line 254

def effective_at
  @effective_at
end

#email_typeObject

Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.



257
258
259
# File 'lib/stripe/resources/credit_note.rb', line 257

def email_type
  @email_type
end

#expandObject

Specifies which fields in the response should be expanded.



260
261
262
# File 'lib/stripe/resources/credit_note.rb', line 260

def expand
  @expand
end

#invoiceObject

ID of the invoice.



263
264
265
# File 'lib/stripe/resources/credit_note.rb', line 263

def invoice
  @invoice
end

#linesObject

Line items that make up the credit note.



266
267
268
# File 'lib/stripe/resources/credit_note.rb', line 266

def lines
  @lines
end

#memoObject

The credit note’s memo appears on the credit note PDF.



269
270
271
# File 'lib/stripe/resources/credit_note.rb', line 269

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



272
273
274
# File 'lib/stripe/resources/credit_note.rb', line 272

def 
  @metadata
end

#out_of_band_amountObject

The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.



275
276
277
# File 'lib/stripe/resources/credit_note.rb', line 275

def out_of_band_amount
  @out_of_band_amount
end

#reasonObject

Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`



278
279
280
# File 'lib/stripe/resources/credit_note.rb', line 278

def reason
  @reason
end

#refundObject

ID of an existing refund to link this credit note to.



281
282
283
# File 'lib/stripe/resources/credit_note.rb', line 281

def refund
  @refund
end

#refund_amountObject

The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.



284
285
286
# File 'lib/stripe/resources/credit_note.rb', line 284

def refund_amount
  @refund_amount
end

#refundsObject

Refunds to link to this credit note.



287
288
289
# File 'lib/stripe/resources/credit_note.rb', line 287

def refunds
  @refunds
end

#shipping_costObject

When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.



290
291
292
# File 'lib/stripe/resources/credit_note.rb', line 290

def shipping_cost
  @shipping_cost
end