Class: Stripe::CreditNote::CreateParams::Line::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CreditNote::CreateParams::Line::TaxAmount
- Defined in:
- lib/stripe/resources/credit_note.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate ⇒ Object
The id of the tax rate for this tax amount.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
170 171 172 173 174 |
# File 'lib/stripe/resources/credit_note.rb', line 170 def initialize(amount: nil, tax_rate: nil, taxable_amount: nil) @amount = amount @tax_rate = tax_rate @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
162 163 164 |
# File 'lib/stripe/resources/credit_note.rb', line 162 def amount @amount end |
#tax_rate ⇒ Object
The id of the tax rate for this tax amount. The tax rate must have been automatically created by Stripe.
165 166 167 |
# File 'lib/stripe/resources/credit_note.rb', line 165 def tax_rate @tax_rate end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
168 169 170 |
# File 'lib/stripe/resources/credit_note.rb', line 168 def taxable_amount @taxable_amount end |