Class: Stripe::CreditNote::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CreditNote::ListParams
- Defined in:
- lib/stripe/resources/credit_note.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return credit notes that were created during the given date interval.
-
#customer ⇒ Object
Only return credit notes for the customer specified by this customer ID.
-
#customer_account ⇒ Object
Only return credit notes for the account specified by this account ID.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
Only return credit notes for the invoice specified by this invoice ID.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/stripe/resources/credit_note.rb', line 178 def initialize( created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, starting_after: nil ) @created = created @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @invoice = invoice @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return credit notes that were created during the given date interval.
162 163 164 |
# File 'lib/stripe/resources/credit_note.rb', line 162 def created @created end |
#customer ⇒ Object
Only return credit notes for the customer specified by this customer ID.
164 165 166 |
# File 'lib/stripe/resources/credit_note.rb', line 164 def customer @customer end |
#customer_account ⇒ Object
Only return credit notes for the account specified by this account ID.
166 167 168 |
# File 'lib/stripe/resources/credit_note.rb', line 166 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
168 169 170 |
# File 'lib/stripe/resources/credit_note.rb', line 168 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
170 171 172 |
# File 'lib/stripe/resources/credit_note.rb', line 170 def @expand end |
#invoice ⇒ Object
Only return credit notes for the invoice specified by this invoice ID.
172 173 174 |
# File 'lib/stripe/resources/credit_note.rb', line 172 def invoice @invoice end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
174 175 176 |
# File 'lib/stripe/resources/credit_note.rb', line 174 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
176 177 178 |
# File 'lib/stripe/resources/credit_note.rb', line 176 def starting_after @starting_after end |