Class: Stripe::CreditNote::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/stripe/resources/credit_note.rb', line 139

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return credit notes that were created during the given date interval.



119
120
121
# File 'lib/stripe/resources/credit_note.rb', line 119

def created
  @created
end

#customerObject

Only return credit notes for the customer specified by this customer ID.



122
123
124
# File 'lib/stripe/resources/credit_note.rb', line 122

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



125
126
127
# File 'lib/stripe/resources/credit_note.rb', line 125

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



128
129
130
# File 'lib/stripe/resources/credit_note.rb', line 128

def expand
  @expand
end

#invoiceObject

Only return credit notes for the invoice specified by this invoice ID.



131
132
133
# File 'lib/stripe/resources/credit_note.rb', line 131

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



134
135
136
# File 'lib/stripe/resources/credit_note.rb', line 134

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



137
138
139
# File 'lib/stripe/resources/credit_note.rb', line 137

def starting_after
  @starting_after
end