Class: Stripe::CreditNote::ListPreviewLineItemsParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CreditNote::ListPreviewLineItemsParams
- Defined in:
- lib/stripe/resources/credit_note.rb
Defined Under Namespace
Classes: Line, Refund, ShippingCost
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) representing the total amount of the credit note.
-
#credit_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.
-
#effective_at ⇒ Object
The date when this credit note is in effect.
-
#email_type ⇒ Object
Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
ID of the invoice.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#lines ⇒ Object
Line items that make up the credit note.
-
#memo ⇒ Object
The credit note’s memo appears on the credit note PDF.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#out_of_band_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.
-
#reason ⇒ Object
Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`.
-
#refund_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to refund.
-
#refunds ⇒ Object
Refunds to link to this credit note.
-
#shipping_cost ⇒ Object
When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil, starting_after: nil) ⇒ ListPreviewLineItemsParams
constructor
A new instance of ListPreviewLineItemsParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil, starting_after: nil) ⇒ ListPreviewLineItemsParams
Returns a new instance of ListPreviewLineItemsParams.
551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/stripe/resources/credit_note.rb', line 551 def initialize( amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund_amount: nil, refunds: nil, shipping_cost: nil, starting_after: nil ) @amount = amount @credit_amount = credit_amount @effective_at = effective_at @email_type = email_type @ending_before = ending_before @expand = @invoice = invoice @limit = limit @lines = lines @memo = memo @metadata = @out_of_band_amount = out_of_band_amount @reason = reason @refund_amount = refund_amount @refunds = refunds @shipping_cost = shipping_cost @starting_after = starting_after end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) representing the total amount of the credit note.
517 518 519 |
# File 'lib/stripe/resources/credit_note.rb', line 517 def amount @amount end |
#credit_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.
519 520 521 |
# File 'lib/stripe/resources/credit_note.rb', line 519 def credit_amount @credit_amount end |
#effective_at ⇒ Object
The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.
521 522 523 |
# File 'lib/stripe/resources/credit_note.rb', line 521 def effective_at @effective_at end |
#email_type ⇒ Object
Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.
523 524 525 |
# File 'lib/stripe/resources/credit_note.rb', line 523 def email_type @email_type end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
525 526 527 |
# File 'lib/stripe/resources/credit_note.rb', line 525 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
527 528 529 |
# File 'lib/stripe/resources/credit_note.rb', line 527 def @expand end |
#invoice ⇒ Object
ID of the invoice.
529 530 531 |
# File 'lib/stripe/resources/credit_note.rb', line 529 def invoice @invoice end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
531 532 533 |
# File 'lib/stripe/resources/credit_note.rb', line 531 def limit @limit end |
#lines ⇒ Object
Line items that make up the credit note.
533 534 535 |
# File 'lib/stripe/resources/credit_note.rb', line 533 def lines @lines end |
#memo ⇒ Object
The credit note’s memo appears on the credit note PDF.
535 536 537 |
# File 'lib/stripe/resources/credit_note.rb', line 535 def memo @memo end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
537 538 539 |
# File 'lib/stripe/resources/credit_note.rb', line 537 def @metadata end |
#out_of_band_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.
539 540 541 |
# File 'lib/stripe/resources/credit_note.rb', line 539 def out_of_band_amount @out_of_band_amount end |
#reason ⇒ Object
Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`
541 542 543 |
# File 'lib/stripe/resources/credit_note.rb', line 541 def reason @reason end |
#refund_amount ⇒ Object
The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.
543 544 545 |
# File 'lib/stripe/resources/credit_note.rb', line 543 def refund_amount @refund_amount end |
#refunds ⇒ Object
Refunds to link to this credit note.
545 546 547 |
# File 'lib/stripe/resources/credit_note.rb', line 545 def refunds @refunds end |
#shipping_cost ⇒ Object
When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.
547 548 549 |
# File 'lib/stripe/resources/credit_note.rb', line 547 def shipping_cost @shipping_cost end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
549 550 551 |
# File 'lib/stripe/resources/credit_note.rb', line 549 def starting_after @starting_after end |