Class: Stripe::CreditNote::ListPreviewLineItemsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/credit_note.rb

Defined Under Namespace

Classes: Line, Refund, ShippingCost

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, credit_amount: nil, effective_at: nil, email_type: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, lines: nil, memo: nil, metadata: nil, out_of_band_amount: nil, reason: nil, refund: nil, refund_amount: nil, refunds: nil, shipping_cost: nil, starting_after: nil) ⇒ ListPreviewLineItemsParams

Returns a new instance of ListPreviewLineItemsParams.



665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
# File 'lib/stripe/resources/credit_note.rb', line 665

def initialize(
  amount: nil,
  credit_amount: nil,
  effective_at: nil,
  email_type: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  lines: nil,
  memo: nil,
  metadata: nil,
  out_of_band_amount: nil,
  reason: nil,
  refund: nil,
  refund_amount: nil,
  refunds: nil,
  shipping_cost: nil,
  starting_after: nil
)
  @amount = amount
  @credit_amount = credit_amount
  @effective_at = effective_at
  @email_type = email_type
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @lines = lines
  @memo = memo
  @metadata = 
  @out_of_band_amount = out_of_band_amount
  @reason = reason
  @refund = refund
  @refund_amount = refund_amount
  @refunds = refunds
  @shipping_cost = shipping_cost
  @starting_after = starting_after
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) representing the total amount of the credit note.



612
613
614
# File 'lib/stripe/resources/credit_note.rb', line 612

def amount
  @amount
end

#credit_amountObject

The integer amount in cents (or local equivalent) representing the amount to credit the customer’s balance, which will be automatically applied to their next invoice.



615
616
617
# File 'lib/stripe/resources/credit_note.rb', line 615

def credit_amount
  @credit_amount
end

#effective_atObject

The date when this credit note is in effect. Same as ‘created` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the credit note PDF.



618
619
620
# File 'lib/stripe/resources/credit_note.rb', line 618

def effective_at
  @effective_at
end

#email_typeObject

Type of email to send to the customer, one of ‘credit_note` or `none` and the default is `credit_note`.



621
622
623
# File 'lib/stripe/resources/credit_note.rb', line 621

def email_type
  @email_type
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



624
625
626
# File 'lib/stripe/resources/credit_note.rb', line 624

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



627
628
629
# File 'lib/stripe/resources/credit_note.rb', line 627

def expand
  @expand
end

#invoiceObject

ID of the invoice.



630
631
632
# File 'lib/stripe/resources/credit_note.rb', line 630

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



633
634
635
# File 'lib/stripe/resources/credit_note.rb', line 633

def limit
  @limit
end

#linesObject

Line items that make up the credit note.



636
637
638
# File 'lib/stripe/resources/credit_note.rb', line 636

def lines
  @lines
end

#memoObject

The credit note’s memo appears on the credit note PDF.



639
640
641
# File 'lib/stripe/resources/credit_note.rb', line 639

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



642
643
644
# File 'lib/stripe/resources/credit_note.rb', line 642

def 
  @metadata
end

#out_of_band_amountObject

The integer amount in cents (or local equivalent) representing the amount that is credited outside of Stripe.



645
646
647
# File 'lib/stripe/resources/credit_note.rb', line 645

def out_of_band_amount
  @out_of_band_amount
end

#reasonObject

Reason for issuing this credit note, one of ‘duplicate`, `fraudulent`, `order_change`, or `product_unsatisfactory`



648
649
650
# File 'lib/stripe/resources/credit_note.rb', line 648

def reason
  @reason
end

#refundObject

ID of an existing refund to link this credit note to.



651
652
653
# File 'lib/stripe/resources/credit_note.rb', line 651

def refund
  @refund
end

#refund_amountObject

The integer amount in cents (or local equivalent) representing the amount to refund. If set, a refund will be created for the charge associated with the invoice.



654
655
656
# File 'lib/stripe/resources/credit_note.rb', line 654

def refund_amount
  @refund_amount
end

#refundsObject

Refunds to link to this credit note.



657
658
659
# File 'lib/stripe/resources/credit_note.rb', line 657

def refunds
  @refunds
end

#shipping_costObject

When shipping_cost contains the shipping_rate from the invoice, the shipping_cost is included in the credit note.



660
661
662
# File 'lib/stripe/resources/credit_note.rb', line 660

def shipping_cost
  @shipping_cost
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



663
664
665
# File 'lib/stripe/resources/credit_note.rb', line 663

def starting_after
  @starting_after
end