Class: Stripe::CreditNote::ListPreviewLineItemsParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CreditNote::ListPreviewLineItemsParams::Line
- Defined in:
- lib/stripe/resources/credit_note.rb
Defined Under Namespace
Classes: TaxAmount
Instance Attribute Summary collapse
-
#amount ⇒ Object
The line item amount to credit.
-
#description ⇒ Object
The description of the credit note line item.
-
#invoice_line_item ⇒ Object
The invoice line item to credit.
-
#quantity ⇒ Object
The line item quantity to credit.
-
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for the credit note line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the credit note line item.
-
#type ⇒ Object
Type of the credit note line item, one of ‘invoice_line_item` or `custom_line_item`.
-
#unit_amount ⇒ Object
The integer unit amount in cents (or local equivalent) of the credit note line item.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, invoice_line_item: nil, quantity: nil, tax_amounts: nil, tax_rates: nil, type: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, invoice_line_item: nil, quantity: nil, tax_amounts: nil, tax_rates: nil, type: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ Line
Returns a new instance of Line.
473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/stripe/resources/credit_note.rb', line 473 def initialize( amount: nil, description: nil, invoice_line_item: nil, quantity: nil, tax_amounts: nil, tax_rates: nil, type: nil, unit_amount: nil, unit_amount_decimal: nil ) @amount = amount @description = description @invoice_line_item = invoice_line_item @quantity = quantity @tax_amounts = tax_amounts @tax_rates = tax_rates @type = type @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#amount ⇒ Object
The line item amount to credit. Only valid when ‘type` is `invoice_line_item`. If invoice is set up with `automatic_tax=true`, this amount is tax exclusive
455 456 457 |
# File 'lib/stripe/resources/credit_note.rb', line 455 def amount @amount end |
#description ⇒ Object
The description of the credit note line item. Only valid when the ‘type` is `custom_line_item`.
457 458 459 |
# File 'lib/stripe/resources/credit_note.rb', line 457 def description @description end |
#invoice_line_item ⇒ Object
The invoice line item to credit. Only valid when the ‘type` is `invoice_line_item`.
459 460 461 |
# File 'lib/stripe/resources/credit_note.rb', line 459 def invoice_line_item @invoice_line_item end |
#quantity ⇒ Object
The line item quantity to credit.
461 462 463 |
# File 'lib/stripe/resources/credit_note.rb', line 461 def quantity @quantity end |
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for the credit note line item. Cannot be mixed with ‘tax_rates`.
463 464 465 |
# File 'lib/stripe/resources/credit_note.rb', line 463 def tax_amounts @tax_amounts end |
#tax_rates ⇒ Object
The tax rates which apply to the credit note line item. Only valid when the ‘type` is `custom_line_item` and cannot be mixed with `tax_amounts`.
465 466 467 |
# File 'lib/stripe/resources/credit_note.rb', line 465 def tax_rates @tax_rates end |
#type ⇒ Object
Type of the credit note line item, one of ‘invoice_line_item` or `custom_line_item`
467 468 469 |
# File 'lib/stripe/resources/credit_note.rb', line 467 def type @type end |
#unit_amount ⇒ Object
The integer unit amount in cents (or local equivalent) of the credit note line item. This ‘unit_amount` will be multiplied by the quantity to get the full amount to credit for this line item. Only valid when `type` is `custom_line_item`.
469 470 471 |
# File 'lib/stripe/resources/credit_note.rb', line 469 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
471 472 473 |
# File 'lib/stripe/resources/credit_note.rb', line 471 def unit_amount_decimal @unit_amount_decimal end |