Class: Stripe::CreditNote::ListPreviewLineItemsParams::Line

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/credit_note.rb

Defined Under Namespace

Classes: TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, invoice_line_item: nil, quantity: nil, tax_amounts: nil, tax_rates: nil, type: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ Line

Returns a new instance of Line.



567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/stripe/resources/credit_note.rb', line 567

def initialize(
  amount: nil,
  description: nil,
  invoice_line_item: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil,
  type: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @invoice_line_item = invoice_line_item
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
  @type = type
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The line item amount to credit. Only valid when ‘type` is `invoice_line_item`. If invoice is set up with `automatic_tax=true`, this amount is tax exclusive



541
542
543
# File 'lib/stripe/resources/credit_note.rb', line 541

def amount
  @amount
end

#descriptionObject

The description of the credit note line item. Only valid when the ‘type` is `custom_line_item`.



544
545
546
# File 'lib/stripe/resources/credit_note.rb', line 544

def description
  @description
end

#invoice_line_itemObject

The invoice line item to credit. Only valid when the ‘type` is `invoice_line_item`.



547
548
549
# File 'lib/stripe/resources/credit_note.rb', line 547

def invoice_line_item
  @invoice_line_item
end

#quantityObject

The line item quantity to credit.



550
551
552
# File 'lib/stripe/resources/credit_note.rb', line 550

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for the credit note line item. Cannot be mixed with ‘tax_rates`.



553
554
555
# File 'lib/stripe/resources/credit_note.rb', line 553

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the credit note line item. Only valid when the ‘type` is `custom_line_item` and cannot be mixed with `tax_amounts`.



556
557
558
# File 'lib/stripe/resources/credit_note.rb', line 556

def tax_rates
  @tax_rates
end

#typeObject

Type of the credit note line item, one of ‘invoice_line_item` or `custom_line_item`



559
560
561
# File 'lib/stripe/resources/credit_note.rb', line 559

def type
  @type
end

#unit_amountObject

The integer unit amount in cents (or local equivalent) of the credit note line item. This ‘unit_amount` will be multiplied by the quantity to get the full amount to credit for this line item. Only valid when `type` is `custom_line_item`.



562
563
564
# File 'lib/stripe/resources/credit_note.rb', line 562

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



565
566
567
# File 'lib/stripe/resources/credit_note.rb', line 565

def unit_amount_decimal
  @unit_amount_decimal
end