Class: Stripe::CreditNote::ListPreviewLineItemsParams::Refund

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/credit_note.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_refunded: nil, refund: nil) ⇒ Refund

Returns a new instance of Refund.



597
598
599
600
# File 'lib/stripe/resources/credit_note.rb', line 597

def initialize(amount_refunded: nil, refund: nil)
  @amount_refunded = amount_refunded
  @refund = refund
end

Instance Attribute Details

#amount_refundedObject

Amount of the refund that applies to this credit note, in cents (or local equivalent). Defaults to the entire refund amount.



592
593
594
# File 'lib/stripe/resources/credit_note.rb', line 592

def amount_refunded
  @amount_refunded
end

#refundObject

ID of an existing refund to link this credit note to.



595
596
597
# File 'lib/stripe/resources/credit_note.rb', line 595

def refund
  @refund
end