Class: Stripe::CreditNote::PreviewParams::Line::TaxAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/credit_note.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_rate: nil, taxable_amount: nil) ⇒ TaxAmount

Returns a new instance of TaxAmount.



308
309
310
311
312
# File 'lib/stripe/resources/credit_note.rb', line 308

def initialize(amount: nil, tax_rate: nil, taxable_amount: nil)
  @amount = amount
  @tax_rate = tax_rate
  @taxable_amount = taxable_amount
end

Instance Attribute Details

#amountObject

The amount, in cents (or local equivalent), of the tax.



302
303
304
# File 'lib/stripe/resources/credit_note.rb', line 302

def amount
  @amount
end

#tax_rateObject

The id of the tax rate for this tax amount. The tax rate must have been automatically created by Stripe.



304
305
306
# File 'lib/stripe/resources/credit_note.rb', line 304

def tax_rate
  @tax_rate
end

#taxable_amountObject

The amount on which tax is calculated, in cents (or local equivalent).



306
307
308
# File 'lib/stripe/resources/credit_note.rb', line 306

def taxable_amount
  @taxable_amount
end