Class: Stripe::CreditNote::PreviewParams::Line::TaxAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/credit_note.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_rate: nil, taxable_amount: nil) ⇒ TaxAmount

Returns a new instance of TaxAmount.



365
366
367
368
369
# File 'lib/stripe/resources/credit_note.rb', line 365

def initialize(amount: nil, tax_rate: nil, taxable_amount: nil)
  @amount = amount
  @tax_rate = tax_rate
  @taxable_amount = taxable_amount
end

Instance Attribute Details

#amountObject

The amount, in cents (or local equivalent), of the tax.



357
358
359
# File 'lib/stripe/resources/credit_note.rb', line 357

def amount
  @amount
end

#tax_rateObject

The id of the tax rate for this tax amount. The tax rate must have been automatically created by Stripe.



360
361
362
# File 'lib/stripe/resources/credit_note.rb', line 360

def tax_rate
  @tax_rate
end

#taxable_amountObject

The amount on which tax is calculated, in cents (or local equivalent).



363
364
365
# File 'lib/stripe/resources/credit_note.rb', line 363

def taxable_amount
  @taxable_amount
end