Class: Stripe::CreditNote::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, memo: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



291
292
293
294
295
# File 'lib/stripe/resources/credit_note.rb', line 291

def initialize(expand: nil, memo: nil, metadata: nil)
  @expand = expand
  @memo = memo
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



285
286
287
# File 'lib/stripe/resources/credit_note.rb', line 285

def expand
  @expand
end

#memoObject

Credit note memo.



287
288
289
# File 'lib/stripe/resources/credit_note.rb', line 287

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



289
290
291
# File 'lib/stripe/resources/credit_note.rb', line 289

def 
  @metadata
end