Class: Stripe::CreditNote::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/credit_note.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, memo: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



346
347
348
349
350
# File 'lib/stripe/resources/credit_note.rb', line 346

def initialize(expand: nil, memo: nil, metadata: nil)
  @expand = expand
  @memo = memo
  @metadata = 
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



338
339
340
# File 'lib/stripe/resources/credit_note.rb', line 338

def expand
  @expand
end

#memoObject

Credit note memo.



341
342
343
# File 'lib/stripe/resources/credit_note.rb', line 341

def memo
  @memo
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



344
345
346
# File 'lib/stripe/resources/credit_note.rb', line 344

def 
  @metadata
end