Class: Stripe::CreditNoteLineItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::CreditNoteLineItem
- Defined in:
- lib/stripe/resources/credit_note_line_item.rb
Overview
The credit note line item object
Defined Under Namespace
Classes: DiscountAmount, PretaxCreditAmount, Tax, TaxCalculationReference
Constant Summary collapse
- OBJECT_NAME =
"credit_note_line_item"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The integer amount in cents (or local equivalent) representing the gross amount being credited for this line item, excluding (exclusive) tax and discounts.
-
#description ⇒ Object
readonly
Description of the item being credited.
-
#discount_amount ⇒ Object
readonly
The integer amount in cents (or local equivalent) representing the discount being credited for this line item.
-
#discount_amounts ⇒ Object
readonly
The amount of discount calculated per discount for this line item.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice_line_item ⇒ Object
readonly
ID of the invoice line item being credited.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pretax_credit_amounts ⇒ Object
readonly
The pretax credit amounts (ex: discount, credit grants, etc) for this line item.
-
#quantity ⇒ Object
readonly
The number of units of product being credited.
-
#tax_calculation_reference ⇒ Object
readonly
The tax calculation identifiers of the line item.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to the line item.
-
#taxes ⇒ Object
readonly
The tax information of the line item.
-
#type ⇒ Object
readonly
The type of the credit note line item, one of ‘invoice_line_item` or `custom_line_item`.
-
#unit_amount ⇒ Object
readonly
The cost of each unit of product being credited.
-
#unit_amount_decimal ⇒ Object
readonly
Same as ‘unit_amount`, but contains a decimal value with at most 12 decimal places.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The integer amount in cents (or local equivalent) representing the gross amount being credited for this line item, excluding (exclusive) tax and discounts.
56 57 58 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 56 def amount @amount end |
#description ⇒ Object (readonly)
Description of the item being credited.
58 59 60 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 58 def description @description end |
#discount_amount ⇒ Object (readonly)
The integer amount in cents (or local equivalent) representing the discount being credited for this line item.
60 61 62 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 60 def discount_amount @discount_amount end |
#discount_amounts ⇒ Object (readonly)
The amount of discount calculated per discount for this line item
62 63 64 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 62 def discount_amounts @discount_amounts end |
#id ⇒ Object (readonly)
Unique identifier for the object.
64 65 66 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 64 def id @id end |
#invoice_line_item ⇒ Object (readonly)
ID of the invoice line item being credited
66 67 68 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 66 def invoice_line_item @invoice_line_item end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
68 69 70 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 68 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
70 71 72 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 70 def object @object end |
#pretax_credit_amounts ⇒ Object (readonly)
The pretax credit amounts (ex: discount, credit grants, etc) for this line item.
72 73 74 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 72 def pretax_credit_amounts @pretax_credit_amounts end |
#quantity ⇒ Object (readonly)
The number of units of product being credited.
74 75 76 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 74 def quantity @quantity end |
#tax_calculation_reference ⇒ Object (readonly)
The tax calculation identifiers of the line item.
76 77 78 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 76 def tax_calculation_reference @tax_calculation_reference end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to the line item.
78 79 80 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 78 def tax_rates @tax_rates end |
#taxes ⇒ Object (readonly)
The tax information of the line item.
80 81 82 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 80 def taxes @taxes end |
#type ⇒ Object (readonly)
The type of the credit note line item, one of ‘invoice_line_item` or `custom_line_item`. When the type is `invoice_line_item` there is an additional `invoice_line_item` property on the resource the value of which is the id of the credited line item on the invoice.
82 83 84 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 82 def type @type end |
#unit_amount ⇒ Object (readonly)
The cost of each unit of product being credited.
84 85 86 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 84 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object (readonly)
Same as ‘unit_amount`, but contains a decimal value with at most 12 decimal places.
86 87 88 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 86 def unit_amount_decimal @unit_amount_decimal end |
Class Method Details
.object_name ⇒ Object
8 9 10 |
# File 'lib/stripe/resources/credit_note_line_item.rb', line 8 def self.object_name "credit_note_line_item" end |