Class: Stripe::CreditNotePreviewLinesService::ListParams::Line

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/credit_note_preview_lines_service.rb

Defined Under Namespace

Classes: TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, invoice_line_item: nil, quantity: nil, tax_amounts: nil, tax_rates: nil, type: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ Line

Returns a new instance of Line.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 51

def initialize(
  amount: nil,
  description: nil,
  invoice_line_item: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil,
  type: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @invoice_line_item = invoice_line_item
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
  @type = type
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The line item amount to credit. Only valid when ‘type` is `invoice_line_item`. If invoice is set up with `automatic_tax=true`, this amount is tax exclusive



25
26
27
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 25

def amount
  @amount
end

#descriptionObject

The description of the credit note line item. Only valid when the ‘type` is `custom_line_item`.



28
29
30
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 28

def description
  @description
end

#invoice_line_itemObject

The invoice line item to credit. Only valid when the ‘type` is `invoice_line_item`.



31
32
33
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 31

def invoice_line_item
  @invoice_line_item
end

#quantityObject

The line item quantity to credit.



34
35
36
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 34

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for the credit note line item. Cannot be mixed with ‘tax_rates`.



37
38
39
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 37

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the credit note line item. Only valid when the ‘type` is `custom_line_item` and cannot be mixed with `tax_amounts`.



40
41
42
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 40

def tax_rates
  @tax_rates
end

#typeObject

Type of the credit note line item, one of ‘invoice_line_item` or `custom_line_item`



43
44
45
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 43

def type
  @type
end

#unit_amountObject

The integer unit amount in cents (or local equivalent) of the credit note line item. This ‘unit_amount` will be multiplied by the quantity to get the full amount to credit for this line item. Only valid when `type` is `custom_line_item`.



46
47
48
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 46

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



49
50
51
# File 'lib/stripe/services/credit_note_preview_lines_service.rb', line 49

def unit_amount_decimal
  @unit_amount_decimal
end