Class: Stripe::Crypto::Customer
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Crypto::Customer
- Extended by:
- APIOperations::NestedResource
- Defined in:
- lib/stripe/resources/crypto/customer.rb
Overview
This object represents a crypto onramp customer. Use it to get their kyc status and payment methods.
Defined Under Namespace
Classes: KycTier, Verification
Constant Summary collapse
- OBJECT_NAME =
"crypto.customer"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#kyc_region ⇒ Object
readonly
The KYC region determined by the customer's address country.
-
#kyc_tiers ⇒ Object
readonly
List of KYC tiers and their verification status.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#provided_fields ⇒ Object
readonly
The set of KYC Fields provided for this customers.
-
#verifications ⇒ Object
readonly
List of verifications and their outcome.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods included from APIOperations::NestedResource
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
Unique identifier for the object.
52 53 54 |
# File 'lib/stripe/resources/crypto/customer.rb', line 52 def id @id end |
#kyc_region ⇒ Object (readonly)
The KYC region determined by the customer's address country.
54 55 56 |
# File 'lib/stripe/resources/crypto/customer.rb', line 54 def kyc_region @kyc_region end |
#kyc_tiers ⇒ Object (readonly)
List of KYC tiers and their verification status.
56 57 58 |
# File 'lib/stripe/resources/crypto/customer.rb', line 56 def kyc_tiers @kyc_tiers end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
58 59 60 |
# File 'lib/stripe/resources/crypto/customer.rb', line 58 def object @object end |
#provided_fields ⇒ Object (readonly)
The set of KYC Fields provided for this customers.
60 61 62 |
# File 'lib/stripe/resources/crypto/customer.rb', line 60 def provided_fields @provided_fields end |
#verifications ⇒ Object (readonly)
List of verifications and their outcome.
62 63 64 |
# File 'lib/stripe/resources/crypto/customer.rb', line 62 def verifications @verifications end |
Class Method Details
.field_remappings ⇒ Object
68 69 70 |
# File 'lib/stripe/resources/crypto/customer.rb', line 68 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
64 65 66 |
# File 'lib/stripe/resources/crypto/customer.rb', line 64 def self.inner_class_types @inner_class_types = { kyc_tiers: KycTier, verifications: Verification } end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/crypto/customer.rb', line 11 def self.object_name "crypto.customer" end |