Class: Stripe::Crypto::CustomerPaymentToken
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Crypto::CustomerPaymentToken
- Defined in:
- lib/stripe/resources/crypto/customer_payment_token.rb
Overview
A read-only representation of a user's PaymentMethod for use in Crypto On Ramp transactions.
Defined Under Namespace
Classes: Card, UsBankAccount
Constant Summary collapse
- OBJECT_NAME =
"crypto.payment_token"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card ⇒ Object
readonly
A
cardPaymentToken, this hash contains details of the card PaymentToken. -
#id ⇒ Object
readonly
Unique identifier for the object.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#type ⇒ Object
readonly
Type of the Payment Token.
-
#us_bank_account ⇒ Object
readonly
A
us_bank_accountPaymentToken, this hash contains details of the US bank account PaymentToken.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card ⇒ Object (readonly)
A card PaymentToken, this hash contains details of the card PaymentToken.
65 66 67 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 65 def card @card end |
#id ⇒ Object (readonly)
Unique identifier for the object.
67 68 69 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 67 def id @id end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
69 70 71 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 69 def object @object end |
#type ⇒ Object (readonly)
Type of the Payment Token.
71 72 73 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 71 def type @type end |
#us_bank_account ⇒ Object (readonly)
A us_bank_account PaymentToken, this hash contains details of the US bank account PaymentToken.
73 74 75 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 73 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
79 80 81 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 79 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
75 76 77 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 75 def self.inner_class_types @inner_class_types = { card: Card, us_bank_account: UsBankAccount } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/crypto/customer_payment_token.rb', line 9 def self.object_name "crypto.payment_token" end |