Class: Stripe::Crypto::DepositAddressCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Crypto::DepositAddressCreateParams
- Defined in:
- lib/stripe/params/crypto/deposit_address_create_params.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
If set, this deposit address is scoped to a Customer and can only receive funds from that customer.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#network ⇒ Object
The blockchain network to generate a deposit address for.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil, metadata: nil, network: nil) ⇒ DepositAddressCreateParams
constructor
A new instance of DepositAddressCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(customer: nil, expand: nil, metadata: nil, network: nil) ⇒ DepositAddressCreateParams
Returns a new instance of DepositAddressCreateParams.
16 17 18 19 20 21 |
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 16 def initialize(customer: nil, expand: nil, metadata: nil, network: nil) @customer = customer @expand = @metadata = @network = network end |
Instance Attribute Details
#customer ⇒ Object
If set, this deposit address is scoped to a Customer and can only receive funds from that customer. Otherwise, this deposit address can receive funds from any customer.
8 9 10 |
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 8 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
10 11 12 |
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 10 def @expand end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
12 13 14 |
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 12 def @metadata end |
#network ⇒ Object
The blockchain network to generate a deposit address for.
14 15 16 |
# File 'lib/stripe/params/crypto/deposit_address_create_params.rb', line 14 def network @network end |