Class: Stripe::Crypto::OnrampSessionCheckoutParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Crypto::OnrampSessionCheckoutParams
- Defined in:
- lib/stripe/params/crypto/onramp_session_checkout_params.rb
Defined Under Namespace
Classes: MandateData
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#mandate_data ⇒ Object
This hash contains details about the mandate to create.
Instance Method Summary collapse
-
#initialize(expand: nil, mandate_data: nil) ⇒ OnrampSessionCheckoutParams
constructor
A new instance of OnrampSessionCheckoutParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, mandate_data: nil) ⇒ OnrampSessionCheckoutParams
Returns a new instance of OnrampSessionCheckoutParams.
50 51 52 53 |
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 50 def initialize(expand: nil, mandate_data: nil) @expand = @mandate_data = mandate_data end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
46 47 48 |
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 46 def @expand end |
#mandate_data ⇒ Object
This hash contains details about the mandate to create
48 49 50 |
# File 'lib/stripe/params/crypto/onramp_session_checkout_params.rb', line 48 def mandate_data @mandate_data end |