Class: Stripe::Crypto::OnrampSessionListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Crypto::OnrampSessionListParams
- Defined in:
- lib/stripe/params/crypto/onramp_session_list_params.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return onramp sessions that were created during the given date interval.
-
#destination_currency ⇒ Object
The destination cryptocurrency to filter by.
-
#destination_network ⇒ Object
The destination blockchain network to filter by.
-
#ending_before ⇒ Object
An object ID cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
-
#starting_after ⇒ Object
An object ID cursor for use in pagination.
-
#status ⇒ Object
The status of the Onramp Session.
Instance Method Summary collapse
-
#initialize(created: nil, destination_currency: nil, destination_network: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ OnrampSessionListParams
constructor
A new instance of OnrampSessionListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(created: nil, destination_currency: nil, destination_network: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ OnrampSessionListParams
Returns a new instance of OnrampSessionListParams.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 41 def initialize( created: nil, destination_currency: nil, destination_network: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil ) @created = created @destination_currency = destination_currency @destination_network = destination_network @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status end |
Instance Attribute Details
#created ⇒ Object
Only return onramp sessions that were created during the given date interval.
25 26 27 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 25 def created @created end |
#destination_currency ⇒ Object
The destination cryptocurrency to filter by.
27 28 29 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 27 def destination_currency @destination_currency end |
#destination_network ⇒ Object
The destination blockchain network to filter by.
29 30 31 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 29 def destination_network @destination_network end |
#ending_before ⇒ Object
An object ID cursor for use in pagination.
31 32 33 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 31 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
33 34 35 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 33 def @expand end |
#limit ⇒ Object
A limit ranging from 1 to 100 (defaults to 10).
35 36 37 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 35 def limit @limit end |
#starting_after ⇒ Object
An object ID cursor for use in pagination.
37 38 39 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 37 def starting_after @starting_after end |
#status ⇒ Object
The status of the Onramp Session. One of = {initialized, rejected, requires_payment, fulfillment_processing, fulfillment_complete}
39 40 41 |
# File 'lib/stripe/params/crypto/onramp_session_list_params.rb', line 39 def status @status end |