Class: Stripe::Customer
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Customer
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/customer.rb
Overview
This object represents a customer of your business. Use it to [create recurring charges](stripe.com/docs/invoicing/customer), [save payment](stripe.com/docs/payments/save-during-payment) and contact information, and track payments that belong to the same customer.
Defined Under Namespace
Classes: Address, InvoiceSettings, Shipping, Tax, TestHelpers
Constant Summary collapse
- OBJECT_NAME =
"customer"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The customer’s address.
-
#balance ⇒ Object
readonly
The current balance, if any, that’s stored on the customer in their default currency.
-
#business_name ⇒ Object
readonly
The customer’s business name.
-
#cash_balance ⇒ Object
readonly
The current funds being held by Stripe on behalf of the customer.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO code for the currency](stripe.com/docs/currencies) the customer can be charged in for recurring billing purposes.
-
#default_source ⇒ Object
readonly
ID of the default payment source for the customer.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#delinquent ⇒ Object
readonly
Tracks the most recent state change on any invoice belonging to the customer.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#discount ⇒ Object
readonly
Describes the current discount active on the customer, if there is one.
-
#email ⇒ Object
readonly
The customer’s email address.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#individual_name ⇒ Object
readonly
The customer’s individual name.
-
#invoice_credit_balance ⇒ Object
readonly
The current multi-currency balances, if any, that’s stored on the customer.
-
#invoice_prefix ⇒ Object
readonly
The prefix for the customer used to generate unique invoice numbers.
-
#invoice_settings ⇒ Object
readonly
Attribute for field invoice_settings.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
The customer’s full name or business name.
-
#next_invoice_sequence ⇒ Object
readonly
The suffix of the customer’s next invoice number (for example, 0001).
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The customer’s phone number.
-
#preferred_locales ⇒ Object
readonly
The customer’s preferred locales (languages), ordered by preference.
-
#shipping ⇒ Object
readonly
Mailing and shipping address for the customer.
-
#sources ⇒ Object
readonly
The customer’s payment sources, if any.
-
#subscriptions ⇒ Object
readonly
The customer’s current subscriptions, if any.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#tax_exempt ⇒ Object
readonly
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`.
-
#tax_ids ⇒ Object
readonly
The customer’s tax IDs.
-
#test_clock ⇒ Object
readonly
ID of the test clock that this customer belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new customer object.
-
.create_funding_instructions(customer, params = {}, opts = {}) ⇒ Object
Retrieve funding instructions for a customer cash balance.
-
.delete(customer, params = {}, opts = {}) ⇒ Object
Permanently deletes a customer.
-
.delete_discount(customer, params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a customer.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your customers.
-
.list_payment_methods(customer, params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for a given Customer.
- .object_name ⇒ Object
-
.retrieve_cash_balance(customer, params = {}, opts = {}) ⇒ Object
Retrieves a customer’s cash balance.
-
.retrieve_payment_method(customer, payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object for a given Customer.
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.update(customer, params = {}, opts = {}) ⇒ Object
Updates the specified customer by setting the values of the parameters passed.
-
.update_cash_balance(customer, params = {}, opts = {}) ⇒ Object
Changes the settings on a customer’s cash balance.
Instance Method Summary collapse
-
#create_funding_instructions(params = {}, opts = {}) ⇒ Object
Retrieve funding instructions for a customer cash balance.
-
#delete(params = {}, opts = {}) ⇒ Object
Permanently deletes a customer.
-
#delete_discount(params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a customer.
-
#list_payment_methods(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for a given Customer.
-
#retrieve_payment_method(payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object for a given Customer.
- #test_helpers ⇒ Object
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The customer’s address.
172 173 174 |
# File 'lib/stripe/resources/customer.rb', line 172 def address @address end |
#balance ⇒ Object (readonly)
The current balance, if any, that’s stored on the customer in their default currency. If negative, the customer has credit to apply to their next invoice. If positive, the customer has an amount owed that’s added to their next invoice. The balance only considers amounts that Stripe hasn’t successfully applied to any invoice. It doesn’t reflect unpaid invoices. This balance is only taken into account after invoices finalize. For multi-currency balances, see [invoice_credit_balance](stripe.com/docs/api/customers/object#customer_object-invoice_credit_balance).
174 175 176 |
# File 'lib/stripe/resources/customer.rb', line 174 def balance @balance end |
#business_name ⇒ Object (readonly)
The customer’s business name.
176 177 178 |
# File 'lib/stripe/resources/customer.rb', line 176 def business_name @business_name end |
#cash_balance ⇒ Object (readonly)
The current funds being held by Stripe on behalf of the customer. You can apply these funds towards payment intents when the source is “cash_balance”. The ‘settings` field describes if these funds apply to these payment intents manually or automatically.
178 179 180 |
# File 'lib/stripe/resources/customer.rb', line 178 def cash_balance @cash_balance end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
180 181 182 |
# File 'lib/stripe/resources/customer.rb', line 180 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO code for the currency](stripe.com/docs/currencies) the customer can be charged in for recurring billing purposes.
182 183 184 |
# File 'lib/stripe/resources/customer.rb', line 182 def currency @currency end |
#default_source ⇒ Object (readonly)
ID of the default payment source for the customer.
If you use payment methods created through the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) field instead.
186 187 188 |
# File 'lib/stripe/resources/customer.rb', line 186 def default_source @default_source end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
238 239 240 |
# File 'lib/stripe/resources/customer.rb', line 238 def deleted @deleted end |
#delinquent ⇒ Object (readonly)
Tracks the most recent state change on any invoice belonging to the customer. Paying an invoice or marking it uncollectible via the API will set this field to false. An automatic payment failure or passing the ‘invoice.due_date` will set this field to `true`.
If an invoice becomes uncollectible by [dunning](stripe.com/docs/billing/automatic-collection), ‘delinquent` doesn’t reset to ‘false`.
If you care whether the customer has paid their most recent subscription invoice, use ‘subscription.status` instead. Paying or marking uncollectible any customer invoice regardless of whether it is the latest invoice for a subscription will always set this field to `false`.
192 193 194 |
# File 'lib/stripe/resources/customer.rb', line 192 def delinquent @delinquent end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
194 195 196 |
# File 'lib/stripe/resources/customer.rb', line 194 def description @description end |
#discount ⇒ Object (readonly)
Describes the current discount active on the customer, if there is one.
196 197 198 |
# File 'lib/stripe/resources/customer.rb', line 196 def discount @discount end |
#email ⇒ Object (readonly)
The customer’s email address.
198 199 200 |
# File 'lib/stripe/resources/customer.rb', line 198 def email @email end |
#id ⇒ Object (readonly)
Unique identifier for the object.
200 201 202 |
# File 'lib/stripe/resources/customer.rb', line 200 def id @id end |
#individual_name ⇒ Object (readonly)
The customer’s individual name.
202 203 204 |
# File 'lib/stripe/resources/customer.rb', line 202 def individual_name @individual_name end |
#invoice_credit_balance ⇒ Object (readonly)
The current multi-currency balances, if any, that’s stored on the customer. If positive in a currency, the customer has a credit to apply to their next invoice denominated in that currency. If negative, the customer has an amount owed that’s added to their next invoice denominated in that currency. These balances don’t apply to unpaid invoices. They solely track amounts that Stripe hasn’t successfully applied to any invoice. Stripe only applies a balance in a specific currency to an invoice after that invoice (which is in the same currency) finalizes.
204 205 206 |
# File 'lib/stripe/resources/customer.rb', line 204 def invoice_credit_balance @invoice_credit_balance end |
#invoice_prefix ⇒ Object (readonly)
The prefix for the customer used to generate unique invoice numbers.
206 207 208 |
# File 'lib/stripe/resources/customer.rb', line 206 def invoice_prefix @invoice_prefix end |
#invoice_settings ⇒ Object (readonly)
Attribute for field invoice_settings
208 209 210 |
# File 'lib/stripe/resources/customer.rb', line 208 def invoice_settings @invoice_settings end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
210 211 212 |
# File 'lib/stripe/resources/customer.rb', line 210 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
212 213 214 |
# File 'lib/stripe/resources/customer.rb', line 212 def @metadata end |
#name ⇒ Object (readonly)
The customer’s full name or business name.
214 215 216 |
# File 'lib/stripe/resources/customer.rb', line 214 def name @name end |
#next_invoice_sequence ⇒ Object (readonly)
The suffix of the customer’s next invoice number (for example, 0001). When the account uses account level sequencing, this parameter is ignored in API requests and the field omitted in API responses.
216 217 218 |
# File 'lib/stripe/resources/customer.rb', line 216 def next_invoice_sequence @next_invoice_sequence end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
218 219 220 |
# File 'lib/stripe/resources/customer.rb', line 218 def object @object end |
#phone ⇒ Object (readonly)
The customer’s phone number.
220 221 222 |
# File 'lib/stripe/resources/customer.rb', line 220 def phone @phone end |
#preferred_locales ⇒ Object (readonly)
The customer’s preferred locales (languages), ordered by preference.
222 223 224 |
# File 'lib/stripe/resources/customer.rb', line 222 def preferred_locales @preferred_locales end |
#shipping ⇒ Object (readonly)
Mailing and shipping address for the customer. Appears on invoices emailed to this customer.
224 225 226 |
# File 'lib/stripe/resources/customer.rb', line 224 def shipping @shipping end |
#sources ⇒ Object (readonly)
The customer’s payment sources, if any.
226 227 228 |
# File 'lib/stripe/resources/customer.rb', line 226 def sources @sources end |
#subscriptions ⇒ Object (readonly)
The customer’s current subscriptions, if any.
228 229 230 |
# File 'lib/stripe/resources/customer.rb', line 228 def subscriptions @subscriptions end |
#tax ⇒ Object (readonly)
Attribute for field tax
230 231 232 |
# File 'lib/stripe/resources/customer.rb', line 230 def tax @tax end |
#tax_exempt ⇒ Object (readonly)
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to `reverse`, invoice and receipt PDFs include the following text: **“Reverse charge”**.
232 233 234 |
# File 'lib/stripe/resources/customer.rb', line 232 def tax_exempt @tax_exempt end |
#tax_ids ⇒ Object (readonly)
The customer’s tax IDs.
234 235 236 |
# File 'lib/stripe/resources/customer.rb', line 234 def tax_ids @tax_ids end |
#test_clock ⇒ Object (readonly)
ID of the test clock that this customer belongs to.
236 237 238 |
# File 'lib/stripe/resources/customer.rb', line 236 def test_clock @test_clock end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new customer object.
241 242 243 |
# File 'lib/stripe/resources/customer.rb', line 241 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/customers", params: params, opts: opts) end |
.create_funding_instructions(customer, params = {}, opts = {}) ⇒ Object
Retrieve funding instructions for a customer cash balance. If funding instructions do not yet exist for the customer, new funding instructions will be created. If funding instructions have already been created for a given customer, the same funding instructions will be retrieved. In other words, we will return the same funding instructions each time.
260 261 262 263 264 265 266 267 |
# File 'lib/stripe/resources/customer.rb', line 260 def self.create_funding_instructions(customer, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/customers/%<customer>s/funding_instructions", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.delete(customer, params = {}, opts = {}) ⇒ Object
Permanently deletes a customer. It cannot be undone. Also immediately cancels any active subscriptions on the customer.
270 271 272 273 274 275 276 277 |
# File 'lib/stripe/resources/customer.rb', line 270 def self.delete(customer, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/customers/%<customer>s", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.delete_discount(customer, params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a customer.
300 301 302 303 304 305 306 307 |
# File 'lib/stripe/resources/customer.rb', line 300 def self.delete_discount(customer, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/customers/%<customer>s/discount", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
442 443 444 |
# File 'lib/stripe/resources/customer.rb', line 442 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
433 434 435 436 437 438 439 440 |
# File 'lib/stripe/resources/customer.rb', line 433 def self.inner_class_types @inner_class_types = { address: Address, invoice_settings: InvoiceSettings, shipping: Shipping, tax: Tax, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your customers. The customers are returned sorted by creation date, with the most recent customers appearing first.
310 311 312 |
# File 'lib/stripe/resources/customer.rb', line 310 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/customers", params: params, opts: opts) end |
.list_payment_methods(customer, params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for a given Customer
325 326 327 328 329 330 331 332 |
# File 'lib/stripe/resources/customer.rb', line 325 def self.list_payment_methods(customer, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/payment_methods", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/customer.rb', line 16 def self.object_name "customer" end |
.retrieve_cash_balance(customer, params = {}, opts = {}) ⇒ Object
Retrieves a customer’s cash balance.
335 336 337 338 339 340 341 342 |
# File 'lib/stripe/resources/customer.rb', line 335 def self.retrieve_cash_balance(customer, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/cash_balance", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.retrieve_payment_method(customer, payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object for a given Customer.
355 356 357 358 359 360 361 362 |
# File 'lib/stripe/resources/customer.rb', line 355 def self.retrieve_payment_method(customer, payment_method, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/payment_methods/%<payment_method>s", { customer: CGI.escape(customer), payment_method: CGI.escape(payment_method) }), params: params, opts: opts ) end |
.search(params = {}, opts = {}) ⇒ Object
364 365 366 |
# File 'lib/stripe/resources/customer.rb', line 364 def self.search(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/customers/search", params: params, opts: opts) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
368 369 370 |
# File 'lib/stripe/resources/customer.rb', line 368 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.update(customer, params = {}, opts = {}) ⇒ Object
Updates the specified customer by setting the values of the parameters passed. Any parameters not provided will be left unchanged. For example, if you pass the source parameter, that becomes the customer’s active source (e.g., a card) to be used for all charges in the future. When you update a customer to a new valid card source by passing the source parameter: for each of the customer’s current subscriptions, if the subscription bills automatically and is in the past_due state, then the latest open invoice for the subscription with automatic collection enabled will be retried. This retry will not count as an automatic retry, and will not affect the next regularly scheduled payment for the invoice. Changing the default_source for a customer will not trigger this behavior.
This request accepts mostly the same arguments as the customer creation call.
375 376 377 378 379 380 381 382 |
# File 'lib/stripe/resources/customer.rb', line 375 def self.update(customer, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/customers/%<customer>s", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.update_cash_balance(customer, params = {}, opts = {}) ⇒ Object
Changes the settings on a customer’s cash balance.
385 386 387 388 389 390 391 392 |
# File 'lib/stripe/resources/customer.rb', line 385 def self.update_cash_balance(customer, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/customers/%<customer>s/cash_balance", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
Instance Method Details
#create_funding_instructions(params = {}, opts = {}) ⇒ Object
Retrieve funding instructions for a customer cash balance. If funding instructions do not yet exist for the customer, new funding instructions will be created. If funding instructions have already been created for a given customer, the same funding instructions will be retrieved. In other words, we will return the same funding instructions each time.
248 249 250 251 252 253 254 255 |
# File 'lib/stripe/resources/customer.rb', line 248 def create_funding_instructions(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/customers/%<customer>s/funding_instructions", { customer: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#delete(params = {}, opts = {}) ⇒ Object
Permanently deletes a customer. It cannot be undone. Also immediately cancels any active subscriptions on the customer.
280 281 282 283 284 285 286 287 |
# File 'lib/stripe/resources/customer.rb', line 280 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/customers/%<customer>s", { customer: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#delete_discount(params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a customer.
290 291 292 293 294 295 296 297 |
# File 'lib/stripe/resources/customer.rb', line 290 def delete_discount(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/customers/%<customer>s/discount", { customer: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#list_payment_methods(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for a given Customer
315 316 317 318 319 320 321 322 |
# File 'lib/stripe/resources/customer.rb', line 315 def list_payment_methods(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/payment_methods", { customer: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#retrieve_payment_method(payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object for a given Customer.
345 346 347 348 349 350 351 352 |
# File 'lib/stripe/resources/customer.rb', line 345 def retrieve_payment_method(payment_method, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/payment_methods/%<payment_method>s", { customer: CGI.escape(self["id"]), payment_method: CGI.escape(payment_method) }), params: params, opts: opts ) end |
#test_helpers ⇒ Object
402 403 404 |
# File 'lib/stripe/resources/customer.rb', line 402 def test_helpers TestHelpers.new(self) end |