Class: Stripe::Customer
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Customer
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/customer.rb
Overview
This object represents a customer of your business. Use it to [create recurring charges](stripe.com/docs/invoicing/customer), [save payment](stripe.com/docs/payments/save-during-payment) and contact information, and track payments that belong to the same customer.
Defined Under Namespace
Classes: Address, CreateFundingInstructionsParams, CreateParams, DeleteDiscountParams, DeleteParams, FundCashBalanceParams, InvoiceSettings, ListParams, ListPaymentMethodsParams, RetrieveParams, RetrievePaymentMethodParams, SearchParams, Shipping, Tax, TestHelpers, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"customer"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
The customer’s address.
-
#balance ⇒ Object
readonly
The current balance, if any, that’s stored on the customer.
-
#cash_balance ⇒ Object
readonly
The current funds being held by Stripe on behalf of the customer.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO code for the currency](stripe.com/docs/currencies) the customer can be charged in for recurring billing purposes.
-
#default_source ⇒ Object
readonly
ID of the default payment source for the customer.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#delinquent ⇒ Object
readonly
Tracks the most recent state change on any invoice belonging to the customer.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#discount ⇒ Object
readonly
Describes the current discount active on the customer, if there is one.
-
#email ⇒ Object
readonly
The customer’s email address.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice_credit_balance ⇒ Object
readonly
The current multi-currency balances, if any, that’s stored on the customer.
-
#invoice_prefix ⇒ Object
readonly
The prefix for the customer used to generate unique invoice numbers.
-
#invoice_settings ⇒ Object
readonly
Attribute for field invoice_settings.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
The customer’s full name or business name.
-
#next_invoice_sequence ⇒ Object
readonly
The suffix of the customer’s next invoice number (for example, 0001).
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone ⇒ Object
readonly
The customer’s phone number.
-
#preferred_locales ⇒ Object
readonly
The customer’s preferred locales (languages), ordered by preference.
-
#shipping ⇒ Object
readonly
Mailing and shipping address for the customer.
-
#sources ⇒ Object
readonly
The customer’s payment sources, if any.
-
#subscriptions ⇒ Object
readonly
The customer’s current subscriptions, if any.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#tax_exempt ⇒ Object
readonly
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`.
-
#tax_ids ⇒ Object
readonly
The customer’s tax IDs.
-
#test_clock ⇒ Object
readonly
ID of the test clock that this customer belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new customer object.
-
.create_funding_instructions(customer, params = {}, opts = {}) ⇒ Object
Retrieve funding instructions for a customer cash balance.
-
.delete(customer, params = {}, opts = {}) ⇒ Object
Permanently deletes a customer.
-
.delete_discount(customer, params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a customer.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your customers.
-
.list_payment_methods(customer, params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for a given Customer.
- .object_name ⇒ Object
-
.retrieve_cash_balance(customer, params = {}, opts = {}) ⇒ Object
Retrieves a customer’s cash balance.
-
.retrieve_payment_method(customer, payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object for a given Customer.
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.update(customer, params = {}, opts = {}) ⇒ Object
Updates the specified customer by setting the values of the parameters passed.
-
.update_cash_balance(customer, params = {}, opts = {}) ⇒ Object
Changes the settings on a customer’s cash balance.
Instance Method Summary collapse
-
#create_funding_instructions(params = {}, opts = {}) ⇒ Object
Retrieve funding instructions for a customer cash balance.
-
#delete(params = {}, opts = {}) ⇒ Object
Permanently deletes a customer.
-
#delete_discount(params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a customer.
-
#list_payment_methods(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for a given Customer.
-
#retrieve_payment_method(payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object for a given Customer.
- #test_helpers ⇒ Object
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
The customer’s address.
801 802 803 |
# File 'lib/stripe/resources/customer.rb', line 801 def address @address end |
#balance ⇒ Object (readonly)
The current balance, if any, that’s stored on the customer. If negative, the customer has credit to apply to their next invoice. If positive, the customer has an amount owed that’s added to their next invoice. The balance only considers amounts that Stripe hasn’t successfully applied to any invoice. It doesn’t reflect unpaid invoices. This balance is only taken into account after invoices finalize.
803 804 805 |
# File 'lib/stripe/resources/customer.rb', line 803 def balance @balance end |
#cash_balance ⇒ Object (readonly)
The current funds being held by Stripe on behalf of the customer. You can apply these funds towards payment intents when the source is “cash_balance”. The ‘settings` field describes if these funds apply to these payment intents manually or automatically.
805 806 807 |
# File 'lib/stripe/resources/customer.rb', line 805 def cash_balance @cash_balance end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
807 808 809 |
# File 'lib/stripe/resources/customer.rb', line 807 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO code for the currency](stripe.com/docs/currencies) the customer can be charged in for recurring billing purposes.
809 810 811 |
# File 'lib/stripe/resources/customer.rb', line 809 def currency @currency end |
#default_source ⇒ Object (readonly)
ID of the default payment source for the customer.
If you use payment methods created through the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/object#customer_object-invoice_settings-default_payment_method) field instead.
813 814 815 |
# File 'lib/stripe/resources/customer.rb', line 813 def default_source @default_source end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
863 864 865 |
# File 'lib/stripe/resources/customer.rb', line 863 def deleted @deleted end |
#delinquent ⇒ Object (readonly)
Tracks the most recent state change on any invoice belonging to the customer. Paying an invoice or marking it uncollectible via the API will set this field to false. An automatic payment failure or passing the ‘invoice.due_date` will set this field to `true`.
If an invoice becomes uncollectible by [dunning](stripe.com/docs/billing/automatic-collection), ‘delinquent` doesn’t reset to ‘false`.
If you care whether the customer has paid their most recent subscription invoice, use ‘subscription.status` instead. Paying or marking uncollectible any customer invoice regardless of whether it is the latest invoice for a subscription will always set this field to `false`.
819 820 821 |
# File 'lib/stripe/resources/customer.rb', line 819 def delinquent @delinquent end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
821 822 823 |
# File 'lib/stripe/resources/customer.rb', line 821 def description @description end |
#discount ⇒ Object (readonly)
Describes the current discount active on the customer, if there is one.
823 824 825 |
# File 'lib/stripe/resources/customer.rb', line 823 def discount @discount end |
#email ⇒ Object (readonly)
The customer’s email address.
825 826 827 |
# File 'lib/stripe/resources/customer.rb', line 825 def email @email end |
#id ⇒ Object (readonly)
Unique identifier for the object.
827 828 829 |
# File 'lib/stripe/resources/customer.rb', line 827 def id @id end |
#invoice_credit_balance ⇒ Object (readonly)
The current multi-currency balances, if any, that’s stored on the customer. If positive in a currency, the customer has a credit to apply to their next invoice denominated in that currency. If negative, the customer has an amount owed that’s added to their next invoice denominated in that currency. These balances don’t apply to unpaid invoices. They solely track amounts that Stripe hasn’t successfully applied to any invoice. Stripe only applies a balance in a specific currency to an invoice after that invoice (which is in the same currency) finalizes.
829 830 831 |
# File 'lib/stripe/resources/customer.rb', line 829 def invoice_credit_balance @invoice_credit_balance end |
#invoice_prefix ⇒ Object (readonly)
The prefix for the customer used to generate unique invoice numbers.
831 832 833 |
# File 'lib/stripe/resources/customer.rb', line 831 def invoice_prefix @invoice_prefix end |
#invoice_settings ⇒ Object (readonly)
Attribute for field invoice_settings
833 834 835 |
# File 'lib/stripe/resources/customer.rb', line 833 def invoice_settings @invoice_settings end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
835 836 837 |
# File 'lib/stripe/resources/customer.rb', line 835 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
837 838 839 |
# File 'lib/stripe/resources/customer.rb', line 837 def @metadata end |
#name ⇒ Object (readonly)
The customer’s full name or business name.
839 840 841 |
# File 'lib/stripe/resources/customer.rb', line 839 def name @name end |
#next_invoice_sequence ⇒ Object (readonly)
The suffix of the customer’s next invoice number (for example, 0001). When the account uses account level sequencing, this parameter is ignored in API requests and the field omitted in API responses.
841 842 843 |
# File 'lib/stripe/resources/customer.rb', line 841 def next_invoice_sequence @next_invoice_sequence end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
843 844 845 |
# File 'lib/stripe/resources/customer.rb', line 843 def object @object end |
#phone ⇒ Object (readonly)
The customer’s phone number.
845 846 847 |
# File 'lib/stripe/resources/customer.rb', line 845 def phone @phone end |
#preferred_locales ⇒ Object (readonly)
The customer’s preferred locales (languages), ordered by preference.
847 848 849 |
# File 'lib/stripe/resources/customer.rb', line 847 def preferred_locales @preferred_locales end |
#shipping ⇒ Object (readonly)
Mailing and shipping address for the customer. Appears on invoices emailed to this customer.
849 850 851 |
# File 'lib/stripe/resources/customer.rb', line 849 def shipping @shipping end |
#sources ⇒ Object (readonly)
The customer’s payment sources, if any.
851 852 853 |
# File 'lib/stripe/resources/customer.rb', line 851 def sources @sources end |
#subscriptions ⇒ Object (readonly)
The customer’s current subscriptions, if any.
853 854 855 |
# File 'lib/stripe/resources/customer.rb', line 853 def subscriptions @subscriptions end |
#tax ⇒ Object (readonly)
Attribute for field tax
855 856 857 |
# File 'lib/stripe/resources/customer.rb', line 855 def tax @tax end |
#tax_exempt ⇒ Object (readonly)
Describes the customer’s tax exemption status, which is ‘none`, `exempt`, or `reverse`. When set to `reverse`, invoice and receipt PDFs include the following text: **“Reverse charge”**.
857 858 859 |
# File 'lib/stripe/resources/customer.rb', line 857 def tax_exempt @tax_exempt end |
#tax_ids ⇒ Object (readonly)
The customer’s tax IDs.
859 860 861 |
# File 'lib/stripe/resources/customer.rb', line 859 def tax_ids @tax_ids end |
#test_clock ⇒ Object (readonly)
ID of the test clock that this customer belongs to.
861 862 863 |
# File 'lib/stripe/resources/customer.rb', line 861 def test_clock @test_clock end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new customer object.
866 867 868 |
# File 'lib/stripe/resources/customer.rb', line 866 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/customers", params: params, opts: opts) end |
.create_funding_instructions(customer, params = {}, opts = {}) ⇒ Object
Retrieve funding instructions for a customer cash balance. If funding instructions do not yet exist for the customer, new funding instructions will be created. If funding instructions have already been created for a given customer, the same funding instructions will be retrieved. In other words, we will return the same funding instructions each time.
885 886 887 888 889 890 891 892 |
# File 'lib/stripe/resources/customer.rb', line 885 def self.create_funding_instructions(customer, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/customers/%<customer>s/funding_instructions", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.delete(customer, params = {}, opts = {}) ⇒ Object
Permanently deletes a customer. It cannot be undone. Also immediately cancels any active subscriptions on the customer.
895 896 897 898 899 900 901 902 |
# File 'lib/stripe/resources/customer.rb', line 895 def self.delete(customer, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/customers/%<customer>s", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.delete_discount(customer, params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a customer.
925 926 927 928 929 930 931 932 |
# File 'lib/stripe/resources/customer.rb', line 925 def self.delete_discount(customer, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/customers/%<customer>s/discount", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your customers. The customers are returned sorted by creation date, with the most recent customers appearing first.
935 936 937 |
# File 'lib/stripe/resources/customer.rb', line 935 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/customers", params: params, opts: opts) end |
.list_payment_methods(customer, params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for a given Customer
950 951 952 953 954 955 956 957 |
# File 'lib/stripe/resources/customer.rb', line 950 def self.list_payment_methods(customer, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/payment_methods", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/customer.rb', line 16 def self.object_name "customer" end |
.retrieve_cash_balance(customer, params = {}, opts = {}) ⇒ Object
Retrieves a customer’s cash balance.
960 961 962 963 964 965 966 967 |
# File 'lib/stripe/resources/customer.rb', line 960 def self.retrieve_cash_balance(customer, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/cash_balance", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.retrieve_payment_method(customer, payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object for a given Customer.
980 981 982 983 984 985 986 987 |
# File 'lib/stripe/resources/customer.rb', line 980 def self.retrieve_payment_method(customer, payment_method, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/payment_methods/%<payment_method>s", { customer: CGI.escape(customer), payment_method: CGI.escape(payment_method) }), params: params, opts: opts ) end |
.search(params = {}, opts = {}) ⇒ Object
989 990 991 |
# File 'lib/stripe/resources/customer.rb', line 989 def self.search(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/customers/search", params: params, opts: opts) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
993 994 995 |
# File 'lib/stripe/resources/customer.rb', line 993 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.update(customer, params = {}, opts = {}) ⇒ Object
Updates the specified customer by setting the values of the parameters passed. Any parameters not provided will be left unchanged. For example, if you pass the source parameter, that becomes the customer’s active source (e.g., a card) to be used for all charges in the future. When you update a customer to a new valid card source by passing the source parameter: for each of the customer’s current subscriptions, if the subscription bills automatically and is in the past_due state, then the latest open invoice for the subscription with automatic collection enabled will be retried. This retry will not count as an automatic retry, and will not affect the next regularly scheduled payment for the invoice. Changing the default_source for a customer will not trigger this behavior.
This request accepts mostly the same arguments as the customer creation call.
1000 1001 1002 1003 1004 1005 1006 1007 |
# File 'lib/stripe/resources/customer.rb', line 1000 def self.update(customer, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/customers/%<customer>s", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
.update_cash_balance(customer, params = {}, opts = {}) ⇒ Object
Changes the settings on a customer’s cash balance.
1010 1011 1012 1013 1014 1015 1016 1017 |
# File 'lib/stripe/resources/customer.rb', line 1010 def self.update_cash_balance(customer, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/customers/%<customer>s/cash_balance", { customer: CGI.escape(customer) }), params: params, opts: opts ) end |
Instance Method Details
#create_funding_instructions(params = {}, opts = {}) ⇒ Object
Retrieve funding instructions for a customer cash balance. If funding instructions do not yet exist for the customer, new funding instructions will be created. If funding instructions have already been created for a given customer, the same funding instructions will be retrieved. In other words, we will return the same funding instructions each time.
873 874 875 876 877 878 879 880 |
# File 'lib/stripe/resources/customer.rb', line 873 def create_funding_instructions(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/customers/%<customer>s/funding_instructions", { customer: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#delete(params = {}, opts = {}) ⇒ Object
Permanently deletes a customer. It cannot be undone. Also immediately cancels any active subscriptions on the customer.
905 906 907 908 909 910 911 912 |
# File 'lib/stripe/resources/customer.rb', line 905 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/customers/%<customer>s", { customer: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#delete_discount(params = {}, opts = {}) ⇒ Object
Removes the currently applied discount on a customer.
915 916 917 918 919 920 921 922 |
# File 'lib/stripe/resources/customer.rb', line 915 def delete_discount(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/customers/%<customer>s/discount", { customer: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#list_payment_methods(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentMethods for a given Customer
940 941 942 943 944 945 946 947 |
# File 'lib/stripe/resources/customer.rb', line 940 def list_payment_methods(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/payment_methods", { customer: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#retrieve_payment_method(payment_method, params = {}, opts = {}) ⇒ Object
Retrieves a PaymentMethod object for a given Customer.
970 971 972 973 974 975 976 977 |
# File 'lib/stripe/resources/customer.rb', line 970 def retrieve_payment_method(payment_method, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/customers/%<customer>s/payment_methods/%<payment_method>s", { customer: CGI.escape(self["id"]), payment_method: CGI.escape(payment_method) }), params: params, opts: opts ) end |
#test_helpers ⇒ Object
1027 1028 1029 |
# File 'lib/stripe/resources/customer.rb', line 1027 def test_helpers TestHelpers.new(self) end |