Class: Stripe::Customer::CreateFundingInstructionsParams::BankTransfer
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Customer::CreateFundingInstructionsParams::BankTransfer
- Defined in:
- lib/stripe/resources/customer.rb
Defined Under Namespace
Classes: EuBankTransfer
Instance Attribute Summary collapse
-
#eu_bank_transfer ⇒ Object
Configuration for eu_bank_transfer funding type.
-
#requested_address_types ⇒ Object
List of address types that should be returned in the financial_addresses response.
-
#type ⇒ Object
The type of the ‘bank_transfer`.
Instance Method Summary collapse
-
#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer
constructor
A new instance of BankTransfer.
Methods inherited from RequestParams
Constructor Details
#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer
Returns a new instance of BankTransfer.
797 798 799 800 801 |
# File 'lib/stripe/resources/customer.rb', line 797 def initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) @eu_bank_transfer = eu_bank_transfer @requested_address_types = requested_address_types @type = type end |
Instance Attribute Details
#eu_bank_transfer ⇒ Object
Configuration for eu_bank_transfer funding type.
789 790 791 |
# File 'lib/stripe/resources/customer.rb', line 789 def eu_bank_transfer @eu_bank_transfer end |
#requested_address_types ⇒ Object
List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.
Permitted values include: ‘sort_code`, `zengin`, `iban`, or `spei`.
793 794 795 |
# File 'lib/stripe/resources/customer.rb', line 793 def requested_address_types @requested_address_types end |
#type ⇒ Object
The type of the ‘bank_transfer`
795 796 797 |
# File 'lib/stripe/resources/customer.rb', line 795 def type @type end |