Class: Stripe::Customer::CreateFundingInstructionsParams::BankTransfer

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/customer.rb

Defined Under Namespace

Classes: EuBankTransfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil) ⇒ BankTransfer

Returns a new instance of BankTransfer.



881
882
883
884
885
# File 'lib/stripe/resources/customer.rb', line 881

def initialize(eu_bank_transfer: nil, requested_address_types: nil, type: nil)
  @eu_bank_transfer = eu_bank_transfer
  @requested_address_types = requested_address_types
  @type = type
end

Instance Attribute Details

#eu_bank_transferObject

Configuration for eu_bank_transfer funding type.



871
872
873
# File 'lib/stripe/resources/customer.rb', line 871

def eu_bank_transfer
  @eu_bank_transfer
end

#requested_address_typesObject

List of address types that should be returned in the financial_addresses response. If not specified, all valid types will be returned.

Permitted values include: ‘sort_code`, `zengin`, `iban`, or `spei`.



876
877
878
# File 'lib/stripe/resources/customer.rb', line 876

def requested_address_types
  @requested_address_types
end

#typeObject

The type of the ‘bank_transfer`



879
880
881
# File 'lib/stripe/resources/customer.rb', line 879

def type
  @type
end