Class: Stripe::Customer::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Customer::CreateParams
- Defined in:
- lib/stripe/resources/customer.rb
Defined Under Namespace
Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax, TaxIdDatum
Instance Attribute Summary collapse
-
#address ⇒ Object
The customer’s address.
-
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices.
-
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
-
#description ⇒ Object
An arbitrary string that you can attach to a customer object.
-
#email ⇒ Object
Customer’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers.
-
#invoice_settings ⇒ Object
Default invoice settings for this customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The customer’s full name or business name.
-
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice.
-
#payment_method ⇒ Object
Attribute for param field payment_method.
-
#phone ⇒ Object
The customer’s phone number.
-
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#source ⇒ Object
Attribute for param field source.
-
#tax ⇒ Object
Tax details about the customer.
-
#tax_exempt ⇒ Object
The customer’s tax exemption.
-
#tax_id_data ⇒ Object
The customer’s tax IDs.
-
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
-
#validate ⇒ Object
Attribute for param field validate.
Instance Method Summary collapse
-
#initialize(address: nil, balance: nil, cash_balance: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, balance: nil, cash_balance: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/stripe/resources/customer.rb', line 673 def initialize( address: nil, balance: nil, cash_balance: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil ) @address = address @balance = balance @cash_balance = cash_balance @description = description @email = email @expand = @invoice_prefix = invoice_prefix @invoice_settings = invoice_settings @metadata = @name = name @next_invoice_sequence = next_invoice_sequence @payment_method = payment_method @phone = phone @preferred_locales = preferred_locales @shipping = shipping @source = source @tax = tax @tax_exempt = tax_exempt @tax_id_data = tax_id_data @test_clock = test_clock @validate = validate end |
Instance Attribute Details
#address ⇒ Object
The customer’s address.
631 632 633 |
# File 'lib/stripe/resources/customer.rb', line 631 def address @address end |
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.
633 634 635 |
# File 'lib/stripe/resources/customer.rb', line 633 def balance @balance end |
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
635 636 637 |
# File 'lib/stripe/resources/customer.rb', line 635 def cash_balance @cash_balance end |
#description ⇒ Object
An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.
637 638 639 |
# File 'lib/stripe/resources/customer.rb', line 637 def description @description end |
#email ⇒ Object
Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.
639 640 641 |
# File 'lib/stripe/resources/customer.rb', line 639 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
641 642 643 |
# File 'lib/stripe/resources/customer.rb', line 641 def @expand end |
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.
643 644 645 |
# File 'lib/stripe/resources/customer.rb', line 643 def invoice_prefix @invoice_prefix end |
#invoice_settings ⇒ Object
Default invoice settings for this customer.
645 646 647 |
# File 'lib/stripe/resources/customer.rb', line 645 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
647 648 649 |
# File 'lib/stripe/resources/customer.rb', line 647 def @metadata end |
#name ⇒ Object
The customer’s full name or business name.
649 650 651 |
# File 'lib/stripe/resources/customer.rb', line 649 def name @name end |
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice. Defaults to 1.
651 652 653 |
# File 'lib/stripe/resources/customer.rb', line 651 def next_invoice_sequence @next_invoice_sequence end |
#payment_method ⇒ Object
Attribute for param field payment_method
653 654 655 |
# File 'lib/stripe/resources/customer.rb', line 653 def payment_method @payment_method end |
#phone ⇒ Object
The customer’s phone number.
655 656 657 |
# File 'lib/stripe/resources/customer.rb', line 655 def phone @phone end |
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
657 658 659 |
# File 'lib/stripe/resources/customer.rb', line 657 def preferred_locales @preferred_locales end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
659 660 661 |
# File 'lib/stripe/resources/customer.rb', line 659 def shipping @shipping end |
#source ⇒ Object
Attribute for param field source
661 662 663 |
# File 'lib/stripe/resources/customer.rb', line 661 def source @source end |
#tax ⇒ Object
Tax details about the customer.
663 664 665 |
# File 'lib/stripe/resources/customer.rb', line 663 def tax @tax end |
#tax_exempt ⇒ Object
The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.
665 666 667 |
# File 'lib/stripe/resources/customer.rb', line 665 def tax_exempt @tax_exempt end |
#tax_id_data ⇒ Object
The customer’s tax IDs.
667 668 669 |
# File 'lib/stripe/resources/customer.rb', line 667 def tax_id_data @tax_id_data end |
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
669 670 671 |
# File 'lib/stripe/resources/customer.rb', line 669 def test_clock @test_clock end |
#validate ⇒ Object
Attribute for param field validate
671 672 673 |
# File 'lib/stripe/resources/customer.rb', line 671 def validate @validate end |