Class: Stripe::Customer::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Customer::CreateParams
- Defined in:
- lib/stripe/resources/customer.rb
Defined Under Namespace
Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax, TaxIdDatum
Instance Attribute Summary collapse
-
#address ⇒ Object
The customer’s address.
-
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices.
-
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
-
#coupon ⇒ Object
Attribute for param field coupon.
-
#description ⇒ Object
An arbitrary string that you can attach to a customer object.
-
#email ⇒ Object
Customer’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers.
-
#invoice_settings ⇒ Object
Default invoice settings for this customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The customer’s full name or business name.
-
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice.
-
#payment_method ⇒ Object
Attribute for param field payment_method.
-
#phone ⇒ Object
The customer’s phone number.
-
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
-
#promotion_code ⇒ Object
The ID of a promotion code to apply to the customer.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#source ⇒ Object
Attribute for param field source.
-
#tax ⇒ Object
Tax details about the customer.
-
#tax_exempt ⇒ Object
The customer’s tax exemption.
-
#tax_id_data ⇒ Object
The customer’s tax IDs.
-
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
-
#validate ⇒ Object
Attribute for param field validate.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, balance: nil, cash_balance: nil, coupon: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, promotion_code: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 |
# File 'lib/stripe/resources/customer.rb', line 743 def initialize( address: nil, balance: nil, cash_balance: nil, coupon: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, promotion_code: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil ) @address = address @balance = balance @cash_balance = cash_balance @coupon = coupon @description = description @email = email @expand = @invoice_prefix = invoice_prefix @invoice_settings = invoice_settings @metadata = @name = name @next_invoice_sequence = next_invoice_sequence @payment_method = payment_method @phone = phone @preferred_locales = preferred_locales @promotion_code = promotion_code @shipping = shipping @source = source @tax = tax @tax_exempt = tax_exempt @tax_id_data = tax_id_data @test_clock = test_clock @validate = validate end |
Instance Attribute Details
#address ⇒ Object
The customer’s address.
675 676 677 |
# File 'lib/stripe/resources/customer.rb', line 675 def address @address end |
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.
678 679 680 |
# File 'lib/stripe/resources/customer.rb', line 678 def balance @balance end |
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
681 682 683 |
# File 'lib/stripe/resources/customer.rb', line 681 def cash_balance @cash_balance end |
#coupon ⇒ Object
Attribute for param field coupon
684 685 686 |
# File 'lib/stripe/resources/customer.rb', line 684 def coupon @coupon end |
#description ⇒ Object
An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.
687 688 689 |
# File 'lib/stripe/resources/customer.rb', line 687 def description @description end |
#email ⇒ Object
Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.
690 691 692 |
# File 'lib/stripe/resources/customer.rb', line 690 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
693 694 695 |
# File 'lib/stripe/resources/customer.rb', line 693 def @expand end |
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.
696 697 698 |
# File 'lib/stripe/resources/customer.rb', line 696 def invoice_prefix @invoice_prefix end |
#invoice_settings ⇒ Object
Default invoice settings for this customer.
699 700 701 |
# File 'lib/stripe/resources/customer.rb', line 699 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
702 703 704 |
# File 'lib/stripe/resources/customer.rb', line 702 def @metadata end |
#name ⇒ Object
The customer’s full name or business name.
705 706 707 |
# File 'lib/stripe/resources/customer.rb', line 705 def name @name end |
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice. Defaults to 1.
708 709 710 |
# File 'lib/stripe/resources/customer.rb', line 708 def next_invoice_sequence @next_invoice_sequence end |
#payment_method ⇒ Object
Attribute for param field payment_method
711 712 713 |
# File 'lib/stripe/resources/customer.rb', line 711 def payment_method @payment_method end |
#phone ⇒ Object
The customer’s phone number.
714 715 716 |
# File 'lib/stripe/resources/customer.rb', line 714 def phone @phone end |
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
717 718 719 |
# File 'lib/stripe/resources/customer.rb', line 717 def preferred_locales @preferred_locales end |
#promotion_code ⇒ Object
The ID of a promotion code to apply to the customer. The customer will have a discount applied on all recurring payments. Charges you create through the API will not have the discount.
720 721 722 |
# File 'lib/stripe/resources/customer.rb', line 720 def promotion_code @promotion_code end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
723 724 725 |
# File 'lib/stripe/resources/customer.rb', line 723 def shipping @shipping end |
#source ⇒ Object
Attribute for param field source
726 727 728 |
# File 'lib/stripe/resources/customer.rb', line 726 def source @source end |
#tax ⇒ Object
Tax details about the customer.
729 730 731 |
# File 'lib/stripe/resources/customer.rb', line 729 def tax @tax end |
#tax_exempt ⇒ Object
The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.
732 733 734 |
# File 'lib/stripe/resources/customer.rb', line 732 def tax_exempt @tax_exempt end |
#tax_id_data ⇒ Object
The customer’s tax IDs.
735 736 737 |
# File 'lib/stripe/resources/customer.rb', line 735 def tax_id_data @tax_id_data end |
#test_clock ⇒ Object
ID of the test clock to attach to the customer.
738 739 740 |
# File 'lib/stripe/resources/customer.rb', line 738 def test_clock @test_clock end |
#validate ⇒ Object
Attribute for param field validate
741 742 743 |
# File 'lib/stripe/resources/customer.rb', line 741 def validate @validate end |