Class: Stripe::Customer::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/customer.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, test_clock: nil) ⇒ ListParams

Returns a new instance of ListParams.



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/stripe/resources/customer.rb', line 385

def initialize(
  created: nil,
  email: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  test_clock: nil
)
  @created = created
  @email = email
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @test_clock = test_clock
end

Instance Attribute Details

#createdObject

Only return customers that were created during the given date interval.



371
372
373
# File 'lib/stripe/resources/customer.rb', line 371

def created
  @created
end

#emailObject

A case-sensitive filter on the list based on the customer’s ‘email` field. The value must be a string.



373
374
375
# File 'lib/stripe/resources/customer.rb', line 373

def email
  @email
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



375
376
377
# File 'lib/stripe/resources/customer.rb', line 375

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



377
378
379
# File 'lib/stripe/resources/customer.rb', line 377

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



379
380
381
# File 'lib/stripe/resources/customer.rb', line 379

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



381
382
383
# File 'lib/stripe/resources/customer.rb', line 381

def starting_after
  @starting_after
end

#test_clockObject

Provides a list of customers that are associated with the specified test clock. The response will not include customers with test clocks if this parameter is not set.



383
384
385
# File 'lib/stripe/resources/customer.rb', line 383

def test_clock
  @test_clock
end