Class: Stripe::Customer::ListPaymentMethodsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/customer.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(allow_redisplay: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil) ⇒ ListPaymentMethodsParams

Returns a new instance of ListPaymentMethodsParams.



697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
# File 'lib/stripe/resources/customer.rb', line 697

def initialize(
  allow_redisplay: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil
)
  @allow_redisplay = allow_redisplay
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
end

Instance Attribute Details

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



685
686
687
# File 'lib/stripe/resources/customer.rb', line 685

def allow_redisplay
  @allow_redisplay
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



687
688
689
# File 'lib/stripe/resources/customer.rb', line 687

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



689
690
691
# File 'lib/stripe/resources/customer.rb', line 689

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



691
692
693
# File 'lib/stripe/resources/customer.rb', line 691

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



693
694
695
# File 'lib/stripe/resources/customer.rb', line 693

def starting_after
  @starting_after
end

#typeObject

An optional filter on the list, based on the object ‘type` field. Without the filter, the list includes all current and future payment method types. If your integration expects only one type of payment method in the response, make sure to provide a type value in the request.



695
696
697
# File 'lib/stripe/resources/customer.rb', line 695

def type
  @type
end