Class: Stripe::Customer::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Customer::Tax
- Defined in:
- lib/stripe/resources/customer.rb
Defined Under Namespace
Classes: Location
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
readonly
Surfaces if automatic tax computation is possible given the current customer location information.
-
#ip_address ⇒ Object
readonly
A recent IP address of the customer used for tax reporting and tax location inference.
-
#location ⇒ Object
readonly
The customer’s location as identified by Stripe Tax.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#automatic_tax ⇒ Object (readonly)
Surfaces if automatic tax computation is possible given the current customer location information.
122 123 124 |
# File 'lib/stripe/resources/customer.rb', line 122 def automatic_tax @automatic_tax end |
#ip_address ⇒ Object (readonly)
A recent IP address of the customer used for tax reporting and tax location inference.
125 126 127 |
# File 'lib/stripe/resources/customer.rb', line 125 def ip_address @ip_address end |
#location ⇒ Object (readonly)
The customer’s location as identified by Stripe Tax.
128 129 130 |
# File 'lib/stripe/resources/customer.rb', line 128 def location @location end |