Class: Stripe::Customer::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/customer.rb

Defined Under Namespace

Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, balance: nil, cash_balance: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/stripe/resources/customer.rb', line 305

def initialize(
  address: nil,
  balance: nil,
  cash_balance: nil,
  default_source: nil,
  description: nil,
  email: nil,
  expand: nil,
  invoice_prefix: nil,
  invoice_settings: nil,
  metadata: nil,
  name: nil,
  next_invoice_sequence: nil,
  phone: nil,
  preferred_locales: nil,
  shipping: nil,
  source: nil,
  tax: nil,
  tax_exempt: nil,
  validate: nil
)
  @address = address
  @balance = balance
  @cash_balance = cash_balance
  @default_source = default_source
  @description = description
  @email = email
  @expand = expand
  @invoice_prefix = invoice_prefix
  @invoice_settings = invoice_settings
  @metadata = 
  @name = name
  @next_invoice_sequence = next_invoice_sequence
  @phone = phone
  @preferred_locales = preferred_locales
  @shipping = shipping
  @source = source
  @tax = tax
  @tax_exempt = tax_exempt
  @validate = validate
end

Instance Attribute Details

#addressObject

The customer’s address.



263
264
265
# File 'lib/stripe/resources/customer.rb', line 263

def address
  @address
end

#balanceObject

An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.



265
266
267
# File 'lib/stripe/resources/customer.rb', line 265

def balance
  @balance
end

#cash_balanceObject

Balance information and default balance settings for this customer.



267
268
269
# File 'lib/stripe/resources/customer.rb', line 267

def cash_balance
  @cash_balance
end

#default_sourceObject

If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.

Provide the ID of a payment source already attached to this customer to make it this customer’s default payment source.

If you want to add a new payment source and make it the default, see the [source](stripe.com/docs/api/customers/update#update_customer-source) property.



273
274
275
# File 'lib/stripe/resources/customer.rb', line 273

def default_source
  @default_source
end

#descriptionObject

An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.



275
276
277
# File 'lib/stripe/resources/customer.rb', line 275

def description
  @description
end

#emailObject

Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.



277
278
279
# File 'lib/stripe/resources/customer.rb', line 277

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



279
280
281
# File 'lib/stripe/resources/customer.rb', line 279

def expand
  @expand
end

#invoice_prefixObject

The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.



281
282
283
# File 'lib/stripe/resources/customer.rb', line 281

def invoice_prefix
  @invoice_prefix
end

#invoice_settingsObject

Default invoice settings for this customer.



283
284
285
# File 'lib/stripe/resources/customer.rb', line 283

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



285
286
287
# File 'lib/stripe/resources/customer.rb', line 285

def 
  @metadata
end

#nameObject

The customer’s full name or business name.



287
288
289
# File 'lib/stripe/resources/customer.rb', line 287

def name
  @name
end

#next_invoice_sequenceObject

The sequence to be used on the customer’s next invoice. Defaults to 1.



289
290
291
# File 'lib/stripe/resources/customer.rb', line 289

def next_invoice_sequence
  @next_invoice_sequence
end

#phoneObject

The customer’s phone number.



291
292
293
# File 'lib/stripe/resources/customer.rb', line 291

def phone
  @phone
end

#preferred_localesObject

Customer’s preferred languages, ordered by preference.



293
294
295
# File 'lib/stripe/resources/customer.rb', line 293

def preferred_locales
  @preferred_locales
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



295
296
297
# File 'lib/stripe/resources/customer.rb', line 295

def shipping
  @shipping
end

#sourceObject

Attribute for param field source



297
298
299
# File 'lib/stripe/resources/customer.rb', line 297

def source
  @source
end

#taxObject

Tax details about the customer.



299
300
301
# File 'lib/stripe/resources/customer.rb', line 299

def tax
  @tax
end

#tax_exemptObject

The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.



301
302
303
# File 'lib/stripe/resources/customer.rb', line 301

def tax_exempt
  @tax_exempt
end

#validateObject

Attribute for param field validate



303
304
305
# File 'lib/stripe/resources/customer.rb', line 303

def validate
  @validate
end