Class: Stripe::Customer::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Customer::UpdateParams
- Defined in:
- lib/stripe/resources/customer.rb
Defined Under Namespace
Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax
Instance Attribute Summary collapse
-
#address ⇒ Object
The customer’s address.
-
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices.
-
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
-
#default_source ⇒ Object
If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.
-
#description ⇒ Object
An arbitrary string that you can attach to a customer object.
-
#email ⇒ Object
Customer’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers.
-
#invoice_settings ⇒ Object
Default invoice settings for this customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The customer’s full name or business name.
-
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice.
-
#phone ⇒ Object
The customer’s phone number.
-
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#source ⇒ Object
Attribute for param field source.
-
#tax ⇒ Object
Tax details about the customer.
-
#tax_exempt ⇒ Object
The customer’s tax exemption.
-
#validate ⇒ Object
Attribute for param field validate.
Instance Method Summary collapse
-
#initialize(address: nil, balance: nil, cash_balance: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, balance: nil, cash_balance: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/stripe/resources/customer.rb', line 369 def initialize( address: nil, balance: nil, cash_balance: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil ) @address = address @balance = balance @cash_balance = cash_balance @default_source = default_source @description = description @email = email @expand = @invoice_prefix = invoice_prefix @invoice_settings = invoice_settings @metadata = @name = name @next_invoice_sequence = next_invoice_sequence @phone = phone @preferred_locales = preferred_locales @shipping = shipping @source = source @tax = tax @tax_exempt = tax_exempt @validate = validate end |
Instance Attribute Details
#address ⇒ Object
The customer’s address.
327 328 329 |
# File 'lib/stripe/resources/customer.rb', line 327 def address @address end |
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.
329 330 331 |
# File 'lib/stripe/resources/customer.rb', line 329 def balance @balance end |
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
331 332 333 |
# File 'lib/stripe/resources/customer.rb', line 331 def cash_balance @cash_balance end |
#default_source ⇒ Object
If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.
Provide the ID of a payment source already attached to this customer to make it this customer’s default payment source.
If you want to add a new payment source and make it the default, see the [source](stripe.com/docs/api/customers/update#update_customer-source) property.
337 338 339 |
# File 'lib/stripe/resources/customer.rb', line 337 def default_source @default_source end |
#description ⇒ Object
An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.
339 340 341 |
# File 'lib/stripe/resources/customer.rb', line 339 def description @description end |
#email ⇒ Object
Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.
341 342 343 |
# File 'lib/stripe/resources/customer.rb', line 341 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
343 344 345 |
# File 'lib/stripe/resources/customer.rb', line 343 def @expand end |
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.
345 346 347 |
# File 'lib/stripe/resources/customer.rb', line 345 def invoice_prefix @invoice_prefix end |
#invoice_settings ⇒ Object
Default invoice settings for this customer.
347 348 349 |
# File 'lib/stripe/resources/customer.rb', line 347 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
349 350 351 |
# File 'lib/stripe/resources/customer.rb', line 349 def @metadata end |
#name ⇒ Object
The customer’s full name or business name.
351 352 353 |
# File 'lib/stripe/resources/customer.rb', line 351 def name @name end |
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice. Defaults to 1.
353 354 355 |
# File 'lib/stripe/resources/customer.rb', line 353 def next_invoice_sequence @next_invoice_sequence end |
#phone ⇒ Object
The customer’s phone number.
355 356 357 |
# File 'lib/stripe/resources/customer.rb', line 355 def phone @phone end |
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
357 358 359 |
# File 'lib/stripe/resources/customer.rb', line 357 def preferred_locales @preferred_locales end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
359 360 361 |
# File 'lib/stripe/resources/customer.rb', line 359 def shipping @shipping end |
#source ⇒ Object
Attribute for param field source
361 362 363 |
# File 'lib/stripe/resources/customer.rb', line 361 def source @source end |
#tax ⇒ Object
Tax details about the customer.
363 364 365 |
# File 'lib/stripe/resources/customer.rb', line 363 def tax @tax end |
#tax_exempt ⇒ Object
The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.
365 366 367 |
# File 'lib/stripe/resources/customer.rb', line 365 def tax_exempt @tax_exempt end |
#validate ⇒ Object
Attribute for param field validate
367 368 369 |
# File 'lib/stripe/resources/customer.rb', line 367 def validate @validate end |