Class: Stripe::Customer::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/customer.rb

Defined Under Namespace

Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, balance: nil, cash_balance: nil, coupon: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, promotion_code: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/stripe/resources/customer.rb', line 380

def initialize(
  address: nil,
  balance: nil,
  cash_balance: nil,
  coupon: nil,
  default_source: nil,
  description: nil,
  email: nil,
  expand: nil,
  invoice_prefix: nil,
  invoice_settings: nil,
  metadata: nil,
  name: nil,
  next_invoice_sequence: nil,
  phone: nil,
  preferred_locales: nil,
  promotion_code: nil,
  shipping: nil,
  source: nil,
  tax: nil,
  tax_exempt: nil,
  validate: nil
)
  @address = address
  @balance = balance
  @cash_balance = cash_balance
  @coupon = coupon
  @default_source = default_source
  @description = description
  @email = email
  @expand = expand
  @invoice_prefix = invoice_prefix
  @invoice_settings = invoice_settings
  @metadata = 
  @name = name
  @next_invoice_sequence = next_invoice_sequence
  @phone = phone
  @preferred_locales = preferred_locales
  @promotion_code = promotion_code
  @shipping = shipping
  @source = source
  @tax = tax
  @tax_exempt = tax_exempt
  @validate = validate
end

Instance Attribute Details

#addressObject

The customer’s address.



314
315
316
# File 'lib/stripe/resources/customer.rb', line 314

def address
  @address
end

#balanceObject

An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.



317
318
319
# File 'lib/stripe/resources/customer.rb', line 317

def balance
  @balance
end

#cash_balanceObject

Balance information and default balance settings for this customer.



320
321
322
# File 'lib/stripe/resources/customer.rb', line 320

def cash_balance
  @cash_balance
end

#couponObject

Attribute for param field coupon



323
324
325
# File 'lib/stripe/resources/customer.rb', line 323

def coupon
  @coupon
end

#default_sourceObject

If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.

Provide the ID of a payment source already attached to this customer to make it this customer’s default payment source.

If you want to add a new payment source and make it the default, see the [source](stripe.com/docs/api/customers/update#update_customer-source) property.



330
331
332
# File 'lib/stripe/resources/customer.rb', line 330

def default_source
  @default_source
end

#descriptionObject

An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.



333
334
335
# File 'lib/stripe/resources/customer.rb', line 333

def description
  @description
end

#emailObject

Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.



336
337
338
# File 'lib/stripe/resources/customer.rb', line 336

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



339
340
341
# File 'lib/stripe/resources/customer.rb', line 339

def expand
  @expand
end

#invoice_prefixObject

The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.



342
343
344
# File 'lib/stripe/resources/customer.rb', line 342

def invoice_prefix
  @invoice_prefix
end

#invoice_settingsObject

Default invoice settings for this customer.



345
346
347
# File 'lib/stripe/resources/customer.rb', line 345

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



348
349
350
# File 'lib/stripe/resources/customer.rb', line 348

def 
  @metadata
end

#nameObject

The customer’s full name or business name.



351
352
353
# File 'lib/stripe/resources/customer.rb', line 351

def name
  @name
end

#next_invoice_sequenceObject

The sequence to be used on the customer’s next invoice. Defaults to 1.



354
355
356
# File 'lib/stripe/resources/customer.rb', line 354

def next_invoice_sequence
  @next_invoice_sequence
end

#phoneObject

The customer’s phone number.



357
358
359
# File 'lib/stripe/resources/customer.rb', line 357

def phone
  @phone
end

#preferred_localesObject

Customer’s preferred languages, ordered by preference.



360
361
362
# File 'lib/stripe/resources/customer.rb', line 360

def preferred_locales
  @preferred_locales
end

#promotion_codeObject

The ID of a promotion code to apply to the customer. The customer will have a discount applied on all recurring payments. Charges you create through the API will not have the discount.



363
364
365
# File 'lib/stripe/resources/customer.rb', line 363

def promotion_code
  @promotion_code
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



366
367
368
# File 'lib/stripe/resources/customer.rb', line 366

def shipping
  @shipping
end

#sourceObject

Attribute for param field source



369
370
371
# File 'lib/stripe/resources/customer.rb', line 369

def source
  @source
end

#taxObject

Tax details about the customer.



372
373
374
# File 'lib/stripe/resources/customer.rb', line 372

def tax
  @tax
end

#tax_exemptObject

The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.



375
376
377
# File 'lib/stripe/resources/customer.rb', line 375

def tax_exempt
  @tax_exempt
end

#validateObject

Attribute for param field validate



378
379
380
# File 'lib/stripe/resources/customer.rb', line 378

def validate
  @validate
end