Class: Stripe::Customer::UpdateParams::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Customer::UpdateParams::InvoiceSettings
- Defined in:
- lib/stripe/resources/customer.rb
Defined Under Namespace
Classes: CustomField, RenderingOptions
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.
-
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
-
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/stripe/resources/customer.rb', line 194 def initialize( custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil ) @custom_fields = custom_fields @default_payment_method = default_payment_method @footer = @rendering_options = end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer. When updating, pass an empty string to remove previously-defined fields.
186 187 188 |
# File 'lib/stripe/resources/customer.rb', line 186 def custom_fields @custom_fields end |
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.
188 189 190 |
# File 'lib/stripe/resources/customer.rb', line 188 def default_payment_method @default_payment_method end |
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
190 191 192 |
# File 'lib/stripe/resources/customer.rb', line 190 def @footer end |
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
192 193 194 |
# File 'lib/stripe/resources/customer.rb', line 192 def @rendering_options end |