Class: Stripe::CustomerBalanceTransactionService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerBalanceTransactionService::UpdateParams
- Defined in:
- lib/stripe/services/customer_balance_transaction_service.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
71 72 73 74 75 |
# File 'lib/stripe/services/customer_balance_transaction_service.rb', line 71 def initialize(description: nil, expand: nil, metadata: nil) @description = description @expand = @metadata = end |
Instance Attribute Details
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
63 64 65 |
# File 'lib/stripe/services/customer_balance_transaction_service.rb', line 63 def description @description end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
66 67 68 |
# File 'lib/stripe/services/customer_balance_transaction_service.rb', line 66 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
69 70 71 |
# File 'lib/stripe/services/customer_balance_transaction_service.rb', line 69 def @metadata end |