Class: Stripe::CustomerPaymentSourceService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerPaymentSourceService::CreateParams
- Defined in:
- lib/stripe/services/customer_payment_source_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#source ⇒ Object
Please refer to full [documentation](stripe.com/docs/api) instead.
-
#validate ⇒ Object
Attribute for param field validate.
Instance Method Summary collapse
-
#initialize(expand: nil, metadata: nil, source: nil, validate: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, metadata: nil, source: nil, validate: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
44 45 46 47 48 49 |
# File 'lib/stripe/services/customer_payment_source_service.rb', line 44 def initialize(expand: nil, metadata: nil, source: nil, validate: nil) @expand = @metadata = @source = source @validate = validate end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
33 34 35 |
# File 'lib/stripe/services/customer_payment_source_service.rb', line 33 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
36 37 38 |
# File 'lib/stripe/services/customer_payment_source_service.rb', line 36 def @metadata end |
#source ⇒ Object
Please refer to full [documentation](stripe.com/docs/api) instead.
39 40 41 |
# File 'lib/stripe/services/customer_payment_source_service.rb', line 39 def source @source end |
#validate ⇒ Object
Attribute for param field validate
42 43 44 |
# File 'lib/stripe/services/customer_payment_source_service.rb', line 42 def validate @validate end |