Class: Stripe::CustomerPaymentSourceService::VerifyParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerPaymentSourceService::VerifyParams
- Defined in:
- lib/stripe/services/customer_payment_source_service.rb
Instance Attribute Summary collapse
-
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(amounts: nil, expand: nil) ⇒ VerifyParams
constructor
A new instance of VerifyParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amounts: nil, expand: nil) ⇒ VerifyParams
Returns a new instance of VerifyParams.
208 209 210 211 |
# File 'lib/stripe/services/customer_payment_source_service.rb', line 208 def initialize(amounts: nil, expand: nil) @amounts = amounts @expand = end |
Instance Attribute Details
#amounts ⇒ Object
Two positive integers, in cents, equal to the values of the microdeposits sent to the bank account.
203 204 205 |
# File 'lib/stripe/services/customer_payment_source_service.rb', line 203 def amounts @amounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
206 207 208 |
# File 'lib/stripe/services/customer_payment_source_service.rb', line 206 def @expand end |