Class: Stripe::CustomerService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/customer_service.rb

Defined Under Namespace

Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax, TaxIdDatum

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, balance: nil, cash_balance: nil, coupon: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, payment_method: nil, phone: nil, preferred_locales: nil, promotion_code: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, tax_id_data: nil, test_clock: nil, validate: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/stripe/services/customer_service.rb', line 543

def initialize(
  address: nil,
  balance: nil,
  cash_balance: nil,
  coupon: nil,
  description: nil,
  email: nil,
  expand: nil,
  invoice_prefix: nil,
  invoice_settings: nil,
  metadata: nil,
  name: nil,
  next_invoice_sequence: nil,
  payment_method: nil,
  phone: nil,
  preferred_locales: nil,
  promotion_code: nil,
  shipping: nil,
  source: nil,
  tax: nil,
  tax_exempt: nil,
  tax_id_data: nil,
  test_clock: nil,
  validate: nil
)
  @address = address
  @balance = balance
  @cash_balance = cash_balance
  @coupon = coupon
  @description = description
  @email = email
  @expand = expand
  @invoice_prefix = invoice_prefix
  @invoice_settings = invoice_settings
  @metadata = 
  @name = name
  @next_invoice_sequence = next_invoice_sequence
  @payment_method = payment_method
  @phone = phone
  @preferred_locales = preferred_locales
  @promotion_code = promotion_code
  @shipping = shipping
  @source = source
  @tax = tax
  @tax_exempt = tax_exempt
  @tax_id_data = tax_id_data
  @test_clock = test_clock
  @validate = validate
end

Instance Attribute Details

#addressObject

The customer’s address.



497
498
499
# File 'lib/stripe/services/customer_service.rb', line 497

def address
  @address
end

#balanceObject

An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.



499
500
501
# File 'lib/stripe/services/customer_service.rb', line 499

def balance
  @balance
end

#cash_balanceObject

Balance information and default balance settings for this customer.



501
502
503
# File 'lib/stripe/services/customer_service.rb', line 501

def cash_balance
  @cash_balance
end

#couponObject

Attribute for param field coupon



503
504
505
# File 'lib/stripe/services/customer_service.rb', line 503

def coupon
  @coupon
end

#descriptionObject

An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.



505
506
507
# File 'lib/stripe/services/customer_service.rb', line 505

def description
  @description
end

#emailObject

Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.



507
508
509
# File 'lib/stripe/services/customer_service.rb', line 507

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



509
510
511
# File 'lib/stripe/services/customer_service.rb', line 509

def expand
  @expand
end

#invoice_prefixObject

The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.



511
512
513
# File 'lib/stripe/services/customer_service.rb', line 511

def invoice_prefix
  @invoice_prefix
end

#invoice_settingsObject

Default invoice settings for this customer.



513
514
515
# File 'lib/stripe/services/customer_service.rb', line 513

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



515
516
517
# File 'lib/stripe/services/customer_service.rb', line 515

def 
  @metadata
end

#nameObject

The customer’s full name or business name.



517
518
519
# File 'lib/stripe/services/customer_service.rb', line 517

def name
  @name
end

#next_invoice_sequenceObject

The sequence to be used on the customer’s next invoice. Defaults to 1.



519
520
521
# File 'lib/stripe/services/customer_service.rb', line 519

def next_invoice_sequence
  @next_invoice_sequence
end

#payment_methodObject

Attribute for param field payment_method



521
522
523
# File 'lib/stripe/services/customer_service.rb', line 521

def payment_method
  @payment_method
end

#phoneObject

The customer’s phone number.



523
524
525
# File 'lib/stripe/services/customer_service.rb', line 523

def phone
  @phone
end

#preferred_localesObject

Customer’s preferred languages, ordered by preference.



525
526
527
# File 'lib/stripe/services/customer_service.rb', line 525

def preferred_locales
  @preferred_locales
end

#promotion_codeObject

The ID of a promotion code to apply to the customer. The customer will have a discount applied on all recurring payments. Charges you create through the API will not have the discount.



527
528
529
# File 'lib/stripe/services/customer_service.rb', line 527

def promotion_code
  @promotion_code
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



529
530
531
# File 'lib/stripe/services/customer_service.rb', line 529

def shipping
  @shipping
end

#sourceObject

Attribute for param field source



531
532
533
# File 'lib/stripe/services/customer_service.rb', line 531

def source
  @source
end

#taxObject

Tax details about the customer.



533
534
535
# File 'lib/stripe/services/customer_service.rb', line 533

def tax
  @tax
end

#tax_exemptObject

The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.



535
536
537
# File 'lib/stripe/services/customer_service.rb', line 535

def tax_exempt
  @tax_exempt
end

#tax_id_dataObject

The customer’s tax IDs.



537
538
539
# File 'lib/stripe/services/customer_service.rb', line 537

def tax_id_data
  @tax_id_data
end

#test_clockObject

ID of the test clock to attach to the customer.



539
540
541
# File 'lib/stripe/services/customer_service.rb', line 539

def test_clock
  @test_clock
end

#validateObject

Attribute for param field validate



541
542
543
# File 'lib/stripe/services/customer_service.rb', line 541

def validate
  @validate
end