Class: Stripe::CustomerService::CreateParams::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerService::CreateParams::InvoiceSettings
- Defined in:
- lib/stripe/services/customer_service.rb
Defined Under Namespace
Classes: CustomField, RenderingOptions
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.
-
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
-
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/stripe/services/customer_service.rb', line 415 def initialize( custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil ) @custom_fields = custom_fields @default_payment_method = default_payment_method @footer = @rendering_options = end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer. When updating, pass an empty string to remove previously-defined fields.
407 408 409 |
# File 'lib/stripe/services/customer_service.rb', line 407 def custom_fields @custom_fields end |
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.
409 410 411 |
# File 'lib/stripe/services/customer_service.rb', line 409 def default_payment_method @default_payment_method end |
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
411 412 413 |
# File 'lib/stripe/services/customer_service.rb', line 411 def @footer end |
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
413 414 415 |
# File 'lib/stripe/services/customer_service.rb', line 413 def @rendering_options end |