Class: Stripe::CustomerService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/customer_service.rb

Defined Under Namespace

Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, balance: nil, cash_balance: nil, coupon: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, promotion_code: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/stripe/services/customer_service.rb', line 230

def initialize(
  address: nil,
  balance: nil,
  cash_balance: nil,
  coupon: nil,
  default_source: nil,
  description: nil,
  email: nil,
  expand: nil,
  invoice_prefix: nil,
  invoice_settings: nil,
  metadata: nil,
  name: nil,
  next_invoice_sequence: nil,
  phone: nil,
  preferred_locales: nil,
  promotion_code: nil,
  shipping: nil,
  source: nil,
  tax: nil,
  tax_exempt: nil,
  validate: nil
)
  @address = address
  @balance = balance
  @cash_balance = cash_balance
  @coupon = coupon
  @default_source = default_source
  @description = description
  @email = email
  @expand = expand
  @invoice_prefix = invoice_prefix
  @invoice_settings = invoice_settings
  @metadata = 
  @name = name
  @next_invoice_sequence = next_invoice_sequence
  @phone = phone
  @preferred_locales = preferred_locales
  @promotion_code = promotion_code
  @shipping = shipping
  @source = source
  @tax = tax
  @tax_exempt = tax_exempt
  @validate = validate
end

Instance Attribute Details

#addressObject

The customer’s address.



184
185
186
# File 'lib/stripe/services/customer_service.rb', line 184

def address
  @address
end

#balanceObject

An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.



186
187
188
# File 'lib/stripe/services/customer_service.rb', line 186

def balance
  @balance
end

#cash_balanceObject

Balance information and default balance settings for this customer.



188
189
190
# File 'lib/stripe/services/customer_service.rb', line 188

def cash_balance
  @cash_balance
end

#couponObject

Attribute for param field coupon



190
191
192
# File 'lib/stripe/services/customer_service.rb', line 190

def coupon
  @coupon
end

#default_sourceObject

If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.

Provide the ID of a payment source already attached to this customer to make it this customer’s default payment source.

If you want to add a new payment source and make it the default, see the [source](stripe.com/docs/api/customers/update#update_customer-source) property.



196
197
198
# File 'lib/stripe/services/customer_service.rb', line 196

def default_source
  @default_source
end

#descriptionObject

An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.



198
199
200
# File 'lib/stripe/services/customer_service.rb', line 198

def description
  @description
end

#emailObject

Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.



200
201
202
# File 'lib/stripe/services/customer_service.rb', line 200

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



202
203
204
# File 'lib/stripe/services/customer_service.rb', line 202

def expand
  @expand
end

#invoice_prefixObject

The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.



204
205
206
# File 'lib/stripe/services/customer_service.rb', line 204

def invoice_prefix
  @invoice_prefix
end

#invoice_settingsObject

Default invoice settings for this customer.



206
207
208
# File 'lib/stripe/services/customer_service.rb', line 206

def invoice_settings
  @invoice_settings
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



208
209
210
# File 'lib/stripe/services/customer_service.rb', line 208

def 
  @metadata
end

#nameObject

The customer’s full name or business name.



210
211
212
# File 'lib/stripe/services/customer_service.rb', line 210

def name
  @name
end

#next_invoice_sequenceObject

The sequence to be used on the customer’s next invoice. Defaults to 1.



212
213
214
# File 'lib/stripe/services/customer_service.rb', line 212

def next_invoice_sequence
  @next_invoice_sequence
end

#phoneObject

The customer’s phone number.



214
215
216
# File 'lib/stripe/services/customer_service.rb', line 214

def phone
  @phone
end

#preferred_localesObject

Customer’s preferred languages, ordered by preference.



216
217
218
# File 'lib/stripe/services/customer_service.rb', line 216

def preferred_locales
  @preferred_locales
end

#promotion_codeObject

The ID of a promotion code to apply to the customer. The customer will have a discount applied on all recurring payments. Charges you create through the API will not have the discount.



218
219
220
# File 'lib/stripe/services/customer_service.rb', line 218

def promotion_code
  @promotion_code
end

#shippingObject

The customer’s shipping information. Appears on invoices emailed to this customer.



220
221
222
# File 'lib/stripe/services/customer_service.rb', line 220

def shipping
  @shipping
end

#sourceObject

Attribute for param field source



222
223
224
# File 'lib/stripe/services/customer_service.rb', line 222

def source
  @source
end

#taxObject

Tax details about the customer.



224
225
226
# File 'lib/stripe/services/customer_service.rb', line 224

def tax
  @tax
end

#tax_exemptObject

The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.



226
227
228
# File 'lib/stripe/services/customer_service.rb', line 226

def tax_exempt
  @tax_exempt
end

#validateObject

Attribute for param field validate



228
229
230
# File 'lib/stripe/services/customer_service.rb', line 228

def validate
  @validate
end