Class: Stripe::CustomerService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerService::UpdateParams
- Defined in:
- lib/stripe/services/customer_service.rb
Defined Under Namespace
Classes: Address, CashBalance, InvoiceSettings, Shipping, Tax
Instance Attribute Summary collapse
-
#address ⇒ Object
The customer’s address.
-
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices.
-
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
-
#coupon ⇒ Object
Attribute for param field coupon.
-
#default_source ⇒ Object
If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.
-
#description ⇒ Object
An arbitrary string that you can attach to a customer object.
-
#email ⇒ Object
Customer’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers.
-
#invoice_settings ⇒ Object
Default invoice settings for this customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The customer’s full name or business name.
-
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice.
-
#phone ⇒ Object
The customer’s phone number.
-
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
-
#promotion_code ⇒ Object
The ID of a promotion code to apply to the customer.
-
#shipping ⇒ Object
The customer’s shipping information.
-
#source ⇒ Object
Attribute for param field source.
-
#tax ⇒ Object
Tax details about the customer.
-
#tax_exempt ⇒ Object
The customer’s tax exemption.
-
#validate ⇒ Object
Attribute for param field validate.
Instance Method Summary collapse
-
#initialize(address: nil, balance: nil, cash_balance: nil, coupon: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, promotion_code: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, balance: nil, cash_balance: nil, coupon: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, promotion_code: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/stripe/services/customer_service.rb', line 268 def initialize( address: nil, balance: nil, cash_balance: nil, coupon: nil, default_source: nil, description: nil, email: nil, expand: nil, invoice_prefix: nil, invoice_settings: nil, metadata: nil, name: nil, next_invoice_sequence: nil, phone: nil, preferred_locales: nil, promotion_code: nil, shipping: nil, source: nil, tax: nil, tax_exempt: nil, validate: nil ) @address = address @balance = balance @cash_balance = cash_balance @coupon = coupon @default_source = default_source @description = description @email = email @expand = @invoice_prefix = invoice_prefix @invoice_settings = invoice_settings @metadata = @name = name @next_invoice_sequence = next_invoice_sequence @phone = phone @preferred_locales = preferred_locales @promotion_code = promotion_code @shipping = shipping @source = source @tax = tax @tax_exempt = tax_exempt @validate = validate end |
Instance Attribute Details
#address ⇒ Object
The customer’s address.
202 203 204 |
# File 'lib/stripe/services/customer_service.rb', line 202 def address @address end |
#balance ⇒ Object
An integer amount in cents (or local equivalent) that represents the customer’s current balance, which affect the customer’s future invoices. A negative amount represents a credit that decreases the amount due on an invoice; a positive amount increases the amount due on an invoice.
205 206 207 |
# File 'lib/stripe/services/customer_service.rb', line 205 def balance @balance end |
#cash_balance ⇒ Object
Balance information and default balance settings for this customer.
208 209 210 |
# File 'lib/stripe/services/customer_service.rb', line 208 def cash_balance @cash_balance end |
#coupon ⇒ Object
Attribute for param field coupon
211 212 213 |
# File 'lib/stripe/services/customer_service.rb', line 211 def coupon @coupon end |
#default_source ⇒ Object
If you are using payment methods created via the PaymentMethods API, see the [invoice_settings.default_payment_method](stripe.com/docs/api/customers/update#update_customer-invoice_settings-default_payment_method) parameter.
Provide the ID of a payment source already attached to this customer to make it this customer’s default payment source.
If you want to add a new payment source and make it the default, see the [source](stripe.com/docs/api/customers/update#update_customer-source) property.
218 219 220 |
# File 'lib/stripe/services/customer_service.rb', line 218 def default_source @default_source end |
#description ⇒ Object
An arbitrary string that you can attach to a customer object. It is displayed alongside the customer in the dashboard.
221 222 223 |
# File 'lib/stripe/services/customer_service.rb', line 221 def description @description end |
#email ⇒ Object
Customer’s email address. It’s displayed alongside the customer in your dashboard and can be useful for searching and tracking. This may be up to *512 characters*.
224 225 226 |
# File 'lib/stripe/services/customer_service.rb', line 224 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
227 228 229 |
# File 'lib/stripe/services/customer_service.rb', line 227 def @expand end |
#invoice_prefix ⇒ Object
The prefix for the customer used to generate unique invoice numbers. Must be 3–12 uppercase letters or numbers.
230 231 232 |
# File 'lib/stripe/services/customer_service.rb', line 230 def invoice_prefix @invoice_prefix end |
#invoice_settings ⇒ Object
Default invoice settings for this customer.
233 234 235 |
# File 'lib/stripe/services/customer_service.rb', line 233 def invoice_settings @invoice_settings end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
236 237 238 |
# File 'lib/stripe/services/customer_service.rb', line 236 def @metadata end |
#name ⇒ Object
The customer’s full name or business name.
239 240 241 |
# File 'lib/stripe/services/customer_service.rb', line 239 def name @name end |
#next_invoice_sequence ⇒ Object
The sequence to be used on the customer’s next invoice. Defaults to 1.
242 243 244 |
# File 'lib/stripe/services/customer_service.rb', line 242 def next_invoice_sequence @next_invoice_sequence end |
#phone ⇒ Object
The customer’s phone number.
245 246 247 |
# File 'lib/stripe/services/customer_service.rb', line 245 def phone @phone end |
#preferred_locales ⇒ Object
Customer’s preferred languages, ordered by preference.
248 249 250 |
# File 'lib/stripe/services/customer_service.rb', line 248 def preferred_locales @preferred_locales end |
#promotion_code ⇒ Object
The ID of a promotion code to apply to the customer. The customer will have a discount applied on all recurring payments. Charges you create through the API will not have the discount.
251 252 253 |
# File 'lib/stripe/services/customer_service.rb', line 251 def promotion_code @promotion_code end |
#shipping ⇒ Object
The customer’s shipping information. Appears on invoices emailed to this customer.
254 255 256 |
# File 'lib/stripe/services/customer_service.rb', line 254 def shipping @shipping end |
#source ⇒ Object
Attribute for param field source
257 258 259 |
# File 'lib/stripe/services/customer_service.rb', line 257 def source @source end |
#tax ⇒ Object
Tax details about the customer.
260 261 262 |
# File 'lib/stripe/services/customer_service.rb', line 260 def tax @tax end |
#tax_exempt ⇒ Object
The customer’s tax exemption. One of ‘none`, `exempt`, or `reverse`.
263 264 265 |
# File 'lib/stripe/services/customer_service.rb', line 263 def tax_exempt @tax_exempt end |
#validate ⇒ Object
Attribute for param field validate
266 267 268 |
# File 'lib/stripe/services/customer_service.rb', line 266 def validate @validate end |