Class: Stripe::CustomerService::UpdateParams::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/customer_service.rb

Defined Under Namespace

Classes: CustomField, RenderingOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



114
115
116
117
118
119
120
121
122
123
124
# File 'lib/stripe/services/customer_service.rb', line 114

def initialize(
  custom_fields: nil,
  default_payment_method: nil,
  footer: nil,
  rendering_options: nil
)
  @custom_fields = custom_fields
  @default_payment_method = default_payment_method
  @footer = footer
  @rendering_options = rendering_options
end

Instance Attribute Details

#custom_fieldsObject

The list of up to 4 default custom fields to be displayed on invoices for this customer. When updating, pass an empty string to remove previously-defined fields.



106
107
108
# File 'lib/stripe/services/customer_service.rb', line 106

def custom_fields
  @custom_fields
end

#default_payment_methodObject

ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.



108
109
110
# File 'lib/stripe/services/customer_service.rb', line 108

def default_payment_method
  @default_payment_method
end

Default footer to be displayed on invoices for this customer.



110
111
112
# File 'lib/stripe/services/customer_service.rb', line 110

def footer
  @footer
end

#rendering_optionsObject

Default options for invoice PDF rendering for this customer.



112
113
114
# File 'lib/stripe/services/customer_service.rb', line 112

def rendering_options
  @rendering_options
end