Class: Stripe::CustomerService::UpdateParams::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerService::UpdateParams::InvoiceSettings
- Defined in:
- lib/stripe/services/customer_service.rb
Defined Under Namespace
Classes: CustomField, RenderingOptions
Instance Attribute Summary collapse
-
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer.
-
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.
-
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
-
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
Instance Method Summary collapse
-
#initialize(custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/stripe/services/customer_service.rb', line 124 def initialize( custom_fields: nil, default_payment_method: nil, footer: nil, rendering_options: nil ) @custom_fields = custom_fields @default_payment_method = default_payment_method @footer = @rendering_options = end |
Instance Attribute Details
#custom_fields ⇒ Object
The list of up to 4 default custom fields to be displayed on invoices for this customer. When updating, pass an empty string to remove previously-defined fields.
113 114 115 |
# File 'lib/stripe/services/customer_service.rb', line 113 def custom_fields @custom_fields end |
#default_payment_method ⇒ Object
ID of a payment method that’s attached to the customer, to be used as the customer’s default payment method for subscriptions and invoices.
116 117 118 |
# File 'lib/stripe/services/customer_service.rb', line 116 def default_payment_method @default_payment_method end |
#footer ⇒ Object
Default footer to be displayed on invoices for this customer.
119 120 121 |
# File 'lib/stripe/services/customer_service.rb', line 119 def @footer end |
#rendering_options ⇒ Object
Default options for invoice PDF rendering for this customer.
122 123 124 |
# File 'lib/stripe/services/customer_service.rb', line 122 def @rendering_options end |