Class: Stripe::CustomerSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::CustomerSession
- Extended by:
- APIOperations::Create
- Defined in:
- lib/stripe/resources/customer_session.rb
Overview
A Customer Session allows you to grant Stripe’s frontend SDKs (like Stripe.js) client-side access control over a Customer.
Related guides: [Customer Session with the Payment Element](docs.stripe.com/payments/accept-a-payment-deferred?platform=web&type=payment#save-payment-methods), [Customer Session with the Pricing Table](docs.stripe.com/payments/checkout/pricing-table#customer-session), [Customer Session with the Buy Button](docs.stripe.com/payment-links/buy-button#pass-an-existing-customer).
Defined Under Namespace
Classes: Components, CreateParams
Constant Summary collapse
- OBJECT_NAME =
"customer_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#client_secret ⇒ Object
readonly
The client secret of this Customer Session.
-
#components ⇒ Object
readonly
Configuration for the components supported by this Customer Session.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer ⇒ Object
readonly
The Customer the Customer Session was created for.
-
#customer_account ⇒ Object
readonly
The Account that the Customer Session was created for.
-
#expires_at ⇒ Object
readonly
The timestamp at which this Customer Session will expire.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a Customer Session object that includes a single-use client secret that you can use on your front-end to grant client-side API access for certain customer resources.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
Methods included from APIOperations::Create
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#client_secret ⇒ Object (readonly)
The client secret of this Customer Session. Used on the client to set up secure access to the given ‘customer`.
The client secret can be used to provide access to ‘customer` from your frontend. It should not be stored, logged, or exposed to anyone other than the relevant customer. Make sure that you have TLS enabled on any page that includes the client secret.
211 212 213 |
# File 'lib/stripe/resources/customer_session.rb', line 211 def client_secret @client_secret end |
#components ⇒ Object (readonly)
Configuration for the components supported by this Customer Session.
213 214 215 |
# File 'lib/stripe/resources/customer_session.rb', line 213 def components @components end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
215 216 217 |
# File 'lib/stripe/resources/customer_session.rb', line 215 def created @created end |
#customer ⇒ Object (readonly)
The Customer the Customer Session was created for.
217 218 219 |
# File 'lib/stripe/resources/customer_session.rb', line 217 def customer @customer end |
#customer_account ⇒ Object (readonly)
The Account that the Customer Session was created for.
219 220 221 |
# File 'lib/stripe/resources/customer_session.rb', line 219 def customer_account @customer_account end |
#expires_at ⇒ Object (readonly)
The timestamp at which this Customer Session will expire.
221 222 223 |
# File 'lib/stripe/resources/customer_session.rb', line 221 def expires_at @expires_at end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
223 224 225 |
# File 'lib/stripe/resources/customer_session.rb', line 223 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
225 226 227 |
# File 'lib/stripe/resources/customer_session.rb', line 225 def object @object end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a Customer Session object that includes a single-use client secret that you can use on your front-end to grant client-side API access for certain customer resources.
228 229 230 231 232 233 234 235 |
# File 'lib/stripe/resources/customer_session.rb', line 228 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/customer_sessions", params: params, opts: opts ) end |
.field_remappings ⇒ Object
241 242 243 |
# File 'lib/stripe/resources/customer_session.rb', line 241 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
237 238 239 |
# File 'lib/stripe/resources/customer_session.rb', line 237 def self.inner_class_types @inner_class_types = { components: Components } end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/customer_session.rb', line 15 def self.object_name "customer_session" end |