Class: Stripe::CustomerSession

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/customer_session.rb

Overview

A Customer Session allows you to grant Stripe’s frontend SDKs (like Stripe.js) client-side access control over a Customer.

Related guides: [Customer Session with the Payment Element](stripe.com/payments/accept-a-payment-deferred?platform=web&type=payment#save-payment-methods), [Customer Session with the Pricing Table](stripe.com/payments/checkout/pricing-table#customer-session), [Customer Session with the Buy Button](stripe.com/payment-links/buy-button#pass-an-existing-customer).

Defined Under Namespace

Classes: Components

Constant Summary collapse

OBJECT_NAME =
"customer_session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#client_secretObject (readonly)

The client secret of this Customer Session. Used on the client to set up secure access to the given ‘customer`.

The client secret can be used to provide access to ‘customer` from your frontend. It should not be stored, logged, or exposed to anyone other than the relevant customer. Make sure that you have TLS enabled on any page that includes the client secret.



39
40
41
# File 'lib/stripe/resources/customer_session.rb', line 39

def client_secret
  @client_secret
end

#componentsObject (readonly)

Configuration for the components supported by this Customer Session.



41
42
43
# File 'lib/stripe/resources/customer_session.rb', line 41

def components
  @components
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



43
44
45
# File 'lib/stripe/resources/customer_session.rb', line 43

def created
  @created
end

#customerObject (readonly)

The Customer the Customer Session was created for.



45
46
47
# File 'lib/stripe/resources/customer_session.rb', line 45

def customer
  @customer
end

#expires_atObject (readonly)

The timestamp at which this Customer Session will expire.



47
48
49
# File 'lib/stripe/resources/customer_session.rb', line 47

def expires_at
  @expires_at
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



49
50
51
# File 'lib/stripe/resources/customer_session.rb', line 49

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



51
52
53
# File 'lib/stripe/resources/customer_session.rb', line 51

def object
  @object
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a Customer Session object that includes a single-use client secret that you can use on your front-end to grant client-side API access for certain customer resources.



54
55
56
57
58
59
60
61
# File 'lib/stripe/resources/customer_session.rb', line 54

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/customer_sessions",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/customer_session.rb', line 15

def self.object_name
  "customer_session"
end