Class: Stripe::CustomerSession::Components
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::CustomerSession::Components
- Defined in:
- lib/stripe/resources/customer_session.rb
Defined Under Namespace
Classes: BuyButton, CustomerSheet, MobilePaymentElement, PaymentElement, PricingTable, TaxIdElement
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#buy_button ⇒ Object
readonly
This hash contains whether the buy button is enabled.
-
#customer_sheet ⇒ Object
readonly
This hash contains whether the customer sheet is enabled and the features it supports.
-
#mobile_payment_element ⇒ Object
readonly
This hash contains whether the mobile payment element is enabled and the features it supports.
-
#payment_element ⇒ Object
readonly
This hash contains whether the Payment Element is enabled and the features it supports.
-
#pricing_table ⇒ Object
readonly
This hash contains whether the pricing table is enabled.
-
#tax_id_element ⇒ Object
readonly
This hash contains whether the Tax ID Element is enabled and the features it supports.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#buy_button ⇒ Object (readonly)
This hash contains whether the buy button is enabled.
200 201 202 |
# File 'lib/stripe/resources/customer_session.rb', line 200 def @buy_button end |
#customer_sheet ⇒ Object (readonly)
This hash contains whether the customer sheet is enabled and the features it supports.
202 203 204 |
# File 'lib/stripe/resources/customer_session.rb', line 202 def customer_sheet @customer_sheet end |
#mobile_payment_element ⇒ Object (readonly)
This hash contains whether the mobile payment element is enabled and the features it supports.
204 205 206 |
# File 'lib/stripe/resources/customer_session.rb', line 204 def mobile_payment_element @mobile_payment_element end |
#payment_element ⇒ Object (readonly)
This hash contains whether the Payment Element is enabled and the features it supports.
206 207 208 |
# File 'lib/stripe/resources/customer_session.rb', line 206 def payment_element @payment_element end |
#pricing_table ⇒ Object (readonly)
This hash contains whether the pricing table is enabled.
208 209 210 |
# File 'lib/stripe/resources/customer_session.rb', line 208 def pricing_table @pricing_table end |
#tax_id_element ⇒ Object (readonly)
This hash contains whether the Tax ID Element is enabled and the features it supports.
210 211 212 |
# File 'lib/stripe/resources/customer_session.rb', line 210 def tax_id_element @tax_id_element end |
Class Method Details
.field_remappings ⇒ Object
223 224 225 |
# File 'lib/stripe/resources/customer_session.rb', line 223 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
212 213 214 215 216 217 218 219 220 221 |
# File 'lib/stripe/resources/customer_session.rb', line 212 def self.inner_class_types @inner_class_types = { buy_button: BuyButton, customer_sheet: CustomerSheet, mobile_payment_element: MobilePaymentElement, payment_element: PaymentElement, pricing_table: PricingTable, tax_id_element: TaxIdElement, } end |