Class: Stripe::CustomerSession::Components
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::CustomerSession::Components
- Defined in:
- lib/stripe/resources/customer_session.rb
Defined Under Namespace
Classes: BuyButton, PaymentElement, PricingTable
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#buy_button ⇒ Object
readonly
This hash contains whether the buy button is enabled.
-
#payment_element ⇒ Object
readonly
This hash contains whether the Payment Element is enabled and the features it supports.
-
#pricing_table ⇒ Object
readonly
This hash contains whether the pricing table is enabled.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#buy_button ⇒ Object (readonly)
This hash contains whether the buy button is enabled.
91 92 93 |
# File 'lib/stripe/resources/customer_session.rb', line 91 def @buy_button end |
#payment_element ⇒ Object (readonly)
This hash contains whether the Payment Element is enabled and the features it supports.
93 94 95 |
# File 'lib/stripe/resources/customer_session.rb', line 93 def payment_element @payment_element end |
#pricing_table ⇒ Object (readonly)
This hash contains whether the pricing table is enabled.
95 96 97 |
# File 'lib/stripe/resources/customer_session.rb', line 95 def pricing_table @pricing_table end |
Class Method Details
.field_remappings ⇒ Object
105 106 107 |
# File 'lib/stripe/resources/customer_session.rb', line 105 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
97 98 99 100 101 102 103 |
# File 'lib/stripe/resources/customer_session.rb', line 97 def self.inner_class_types @inner_class_types = { buy_button: BuyButton, payment_element: PaymentElement, pricing_table: PricingTable, } end |