Class: Stripe::CustomerSession::Components::PaymentElement::Features

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/customer_session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#payment_method_allow_redisplay_filtersObject (readonly)

A list of allow_redisplay values that controls which saved payment methods the Payment Element displays by filtering to only show payment methods with an allow_redisplay value that is present in this list.

If not specified, defaults to ["always"]. In order to display all saved payment methods, specify ["always", "limited", "unspecified"].



127
128
129
# File 'lib/stripe/resources/customer_session.rb', line 127

def payment_method_allow_redisplay_filters
  @payment_method_allow_redisplay_filters
end

#payment_method_redisplayObject (readonly)

Controls whether or not the Payment Element shows saved payment methods. This parameter defaults to disabled.



129
130
131
# File 'lib/stripe/resources/customer_session.rb', line 129

def payment_method_redisplay
  @payment_method_redisplay
end

#payment_method_redisplay_limitObject (readonly)

Determines the max number of saved payment methods for the Payment Element to display. This parameter defaults to 3. The maximum redisplay limit is 10.



131
132
133
# File 'lib/stripe/resources/customer_session.rb', line 131

def payment_method_redisplay_limit
  @payment_method_redisplay_limit
end

#payment_method_removeObject (readonly)

Controls whether the Payment Element displays the option to remove a saved payment method. This parameter defaults to disabled.

Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method. Removing the payment method detaches the customer object from that PaymentMethod.



135
136
137
# File 'lib/stripe/resources/customer_session.rb', line 135

def payment_method_remove
  @payment_method_remove
end

#payment_method_saveObject (readonly)

Controls whether the Payment Element displays a checkbox offering to save a new payment method. This parameter defaults to disabled.

If a customer checks the box, the allow_redisplay value on the PaymentMethod is set to 'always' at confirmation time. For PaymentIntents, the setup_future_usage value is also set to the value defined in payment_method_save_usage.



139
140
141
# File 'lib/stripe/resources/customer_session.rb', line 139

def payment_method_save
  @payment_method_save
end

#payment_method_save_usageObject (readonly)

When using PaymentIntents and the customer checks the save checkbox, this field determines the setup_future_usage value used to confirm the PaymentIntent.

When using SetupIntents, directly configure the usage value on SetupIntent creation.



143
144
145
# File 'lib/stripe/resources/customer_session.rb', line 143

def payment_method_save_usage
  @payment_method_save_usage
end

Class Method Details

.field_remappingsObject



149
150
151
# File 'lib/stripe/resources/customer_session.rb', line 149

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



145
146
147
# File 'lib/stripe/resources/customer_session.rb', line 145

def self.inner_class_types
  @inner_class_types = {}
end