Class: Stripe::CustomerSession::Components::TaxIdElement::Features

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/customer_session.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#tax_id_redisplayObject (readonly)

Controls whether the Tax ID Element displays saved tax IDs for the customer. This parameter defaults to ‘disabled`.

When enabled, the Tax ID Element will show existing tax IDs associated with the customer, allowing them to select from previously saved tax identification numbers.



172
173
174
# File 'lib/stripe/resources/customer_session.rb', line 172

def tax_id_redisplay
  @tax_id_redisplay
end

#tax_id_saveObject (readonly)

Controls whether the Tax ID Element allows merchants to save new tax IDs for their customer. This parameter defaults to ‘disabled`.

When enabled, customers can enter and save new tax identification numbers during the payment flow, which will be stored securely and associated with their customer object for future use.



176
177
178
# File 'lib/stripe/resources/customer_session.rb', line 176

def tax_id_save
  @tax_id_save
end

Class Method Details

.field_remappingsObject



182
183
184
# File 'lib/stripe/resources/customer_session.rb', line 182

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



178
179
180
# File 'lib/stripe/resources/customer_session.rb', line 178

def self.inner_class_types
  @inner_class_types = {}
end