Class: Stripe::CustomerSession::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSession::CreateParams
- Defined in:
- lib/stripe/resources/customer_session.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#components ⇒ Object
Configuration for each component.
-
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
-
#customer_account ⇒ Object
The ID of an existing Account for which to create the Customer Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
201 202 203 204 205 206 |
# File 'lib/stripe/resources/customer_session.rb', line 201 def initialize(components: nil, customer: nil, customer_account: nil, expand: nil) @components = components @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#components ⇒ Object
Configuration for each component. Exactly 1 component must be enabled.
193 194 195 |
# File 'lib/stripe/resources/customer_session.rb', line 193 def components @components end |
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
195 196 197 |
# File 'lib/stripe/resources/customer_session.rb', line 195 def customer @customer end |
#customer_account ⇒ Object
The ID of an existing Account for which to create the Customer Session.
197 198 199 |
# File 'lib/stripe/resources/customer_session.rb', line 197 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
199 200 201 |
# File 'lib/stripe/resources/customer_session.rb', line 199 def @expand end |