Class: Stripe::CustomerSession::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSession::CreateParams
- Defined in:
- lib/stripe/resources/customer_session.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#components ⇒ Object
Configuration for each component.
-
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(components: nil, customer: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(components: nil, customer: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
155 156 157 158 159 |
# File 'lib/stripe/resources/customer_session.rb', line 155 def initialize(components: nil, customer: nil, expand: nil) @components = components @customer = customer @expand = end |
Instance Attribute Details
#components ⇒ Object
Configuration for each component. Exactly 1 component must be enabled.
149 150 151 |
# File 'lib/stripe/resources/customer_session.rb', line 149 def components @components end |
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
151 152 153 |
# File 'lib/stripe/resources/customer_session.rb', line 151 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
153 154 155 |
# File 'lib/stripe/resources/customer_session.rb', line 153 def @expand end |