Class: Stripe::CustomerSession::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/customer_session.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(components: nil, customer: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



173
174
175
176
177
# File 'lib/stripe/resources/customer_session.rb', line 173

def initialize(components: nil, customer: nil, expand: nil)
  @components = components
  @customer = customer
  @expand = expand
end

Instance Attribute Details

#componentsObject

Configuration for each component. Exactly 1 component must be enabled.



165
166
167
# File 'lib/stripe/resources/customer_session.rb', line 165

def components
  @components
end

#customerObject

The ID of an existing customer for which to create the Customer Session.



168
169
170
# File 'lib/stripe/resources/customer_session.rb', line 168

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



171
172
173
# File 'lib/stripe/resources/customer_session.rb', line 171

def expand
  @expand
end