Class: Stripe::CustomerSession::CreateParams::Components::PaymentElement::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/customer_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment_method_allow_redisplay_filters: nil, payment_method_redisplay: nil, payment_method_redisplay_limit: nil, payment_method_remove: nil, payment_method_save: nil, payment_method_save_usage: nil) ⇒ Features

Returns a new instance of Features.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/stripe/resources/customer_session.rb', line 100

def initialize(
  payment_method_allow_redisplay_filters: nil,
  payment_method_redisplay: nil,
  payment_method_redisplay_limit: nil,
  payment_method_remove: nil,
  payment_method_save: nil,
  payment_method_save_usage: nil
)
  @payment_method_allow_redisplay_filters = payment_method_allow_redisplay_filters
  @payment_method_redisplay = payment_method_redisplay
  @payment_method_redisplay_limit = payment_method_redisplay_limit
  @payment_method_remove = payment_method_remove
  @payment_method_save = payment_method_save
  @payment_method_save_usage = payment_method_save_usage
end

Instance Attribute Details

#payment_method_allow_redisplay_filtersObject

A list of [‘allow_redisplay`](docs.stripe.com/api/payment_methods/object#payment_method_object-allow_redisplay) values that controls which saved payment methods the Payment Element displays by filtering to only show payment methods with an `allow_redisplay` value that is present in this list.

If not specified, defaults to [“always”]. In order to display all saved payment methods, specify [“always”, “limited”, “unspecified”].



82
83
84
# File 'lib/stripe/resources/customer_session.rb', line 82

def payment_method_allow_redisplay_filters
  @payment_method_allow_redisplay_filters
end

#payment_method_redisplayObject

Controls whether or not the Payment Element shows saved payment methods. This parameter defaults to ‘disabled`.



84
85
86
# File 'lib/stripe/resources/customer_session.rb', line 84

def payment_method_redisplay
  @payment_method_redisplay
end

#payment_method_redisplay_limitObject

Determines the max number of saved payment methods for the Payment Element to display. This parameter defaults to ‘3`. The maximum redisplay limit is `10`.



86
87
88
# File 'lib/stripe/resources/customer_session.rb', line 86

def payment_method_redisplay_limit
  @payment_method_redisplay_limit
end

#payment_method_removeObject

Controls whether the Payment Element displays the option to remove a saved payment method. This parameter defaults to ‘disabled`.

Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method. Removing the payment method detaches the [‘customer` object](docs.stripe.com/api/payment_methods/object#payment_method_object-customer) from that [PaymentMethod](docs.stripe.com/api/payment_methods).



90
91
92
# File 'lib/stripe/resources/customer_session.rb', line 90

def payment_method_remove
  @payment_method_remove
end

#payment_method_saveObject

Controls whether the Payment Element displays a checkbox offering to save a new payment method. This parameter defaults to ‘disabled`.

If a customer checks the box, the [‘allow_redisplay`](docs.stripe.com/api/payment_methods/object#payment_method_object-allow_redisplay) value on the PaymentMethod is set to `’always’‘ at confirmation time. For PaymentIntents, the [`setup_future_usage`](docs.stripe.com/api/payment_intents/object#payment_intent_object-setup_future_usage) value is also set to the value defined in `payment_method_save_usage`.



94
95
96
# File 'lib/stripe/resources/customer_session.rb', line 94

def payment_method_save
  @payment_method_save
end

#payment_method_save_usageObject

When using PaymentIntents and the customer checks the save checkbox, this field determines the [‘setup_future_usage`](docs.stripe.com/api/payment_intents/object#payment_intent_object-setup_future_usage) value used to confirm the PaymentIntent.

When using SetupIntents, directly configure the [‘usage`](docs.stripe.com/api/setup_intents/object#setup_intent_object-usage) value on SetupIntent creation.



98
99
100
# File 'lib/stripe/resources/customer_session.rb', line 98

def payment_method_save_usage
  @payment_method_save_usage
end