Class: Stripe::CustomerSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionCreateParams
- Defined in:
- lib/stripe/params/customer_session_create_params.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#components ⇒ Object
Configuration for each component.
-
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
-
#customer_account ⇒ Object
The ID of an existing Account for which to create the Customer Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CustomerSessionCreateParams
constructor
A new instance of CustomerSessionCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CustomerSessionCreateParams
Returns a new instance of CustomerSessionCreateParams.
238 239 240 241 242 243 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 238 def initialize(components: nil, customer: nil, customer_account: nil, expand: nil) @components = components @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#components ⇒ Object
Configuration for each component. At least 1 component must be enabled.
230 231 232 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 230 def components @components end |
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
232 233 234 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 232 def customer @customer end |
#customer_account ⇒ Object
The ID of an existing Account for which to create the Customer Session.
234 235 236 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 234 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
236 237 238 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 236 def @expand end |