Class: Stripe::CustomerSessionCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/customer_session_create_params.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CustomerSessionCreateParams

Returns a new instance of CustomerSessionCreateParams.



212
213
214
215
216
217
# File 'lib/stripe/params/customer_session_create_params.rb', line 212

def initialize(components: nil, customer: nil, customer_account: nil, expand: nil)
  @components = components
  @customer = customer
  @customer_account = 
  @expand = expand
end

Instance Attribute Details

#componentsObject

Configuration for each component. At least 1 component must be enabled.



204
205
206
# File 'lib/stripe/params/customer_session_create_params.rb', line 204

def components
  @components
end

#customerObject

The ID of an existing customer for which to create the Customer Session.



206
207
208
# File 'lib/stripe/params/customer_session_create_params.rb', line 206

def customer
  @customer
end

#customer_accountObject

The ID of an existing Account for which to create the Customer Session.



208
209
210
# File 'lib/stripe/params/customer_session_create_params.rb', line 208

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



210
211
212
# File 'lib/stripe/params/customer_session_create_params.rb', line 210

def expand
  @expand
end