Class: Stripe::CustomerSessionCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/customer_session_create_params.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CustomerSessionCreateParams

Returns a new instance of CustomerSessionCreateParams.



96
97
98
99
100
101
# File 'lib/stripe/params/customer_session_create_params.rb', line 96

def initialize(components: nil, customer: nil, customer_account: nil, expand: nil)
  @components = components
  @customer = customer
  @customer_account = 
  @expand = expand
end

Instance Attribute Details

#componentsObject

Configuration for each component. Exactly 1 component must be enabled.



88
89
90
# File 'lib/stripe/params/customer_session_create_params.rb', line 88

def components
  @components
end

#customerObject

The ID of an existing customer for which to create the Customer Session.



90
91
92
# File 'lib/stripe/params/customer_session_create_params.rb', line 90

def customer
  @customer
end

#customer_accountObject

The ID of an existing Account for which to create the Customer Session.



92
93
94
# File 'lib/stripe/params/customer_session_create_params.rb', line 92

def 
  @customer_account
end

#expandObject

Specifies which fields in the response should be expanded.



94
95
96
# File 'lib/stripe/params/customer_session_create_params.rb', line 94

def expand
  @expand
end