Class: Stripe::CustomerSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionCreateParams
- Defined in:
- lib/stripe/params/customer_session_create_params.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#components ⇒ Object
Configuration for each component.
-
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
-
#customer_account ⇒ Object
The ID of an existing Account for which to create the Customer Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CustomerSessionCreateParams
constructor
A new instance of CustomerSessionCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CustomerSessionCreateParams
Returns a new instance of CustomerSessionCreateParams.
96 97 98 99 100 101 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 96 def initialize(components: nil, customer: nil, customer_account: nil, expand: nil) @components = components @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#components ⇒ Object
Configuration for each component. Exactly 1 component must be enabled.
88 89 90 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 88 def components @components end |
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
90 91 92 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 90 def customer @customer end |
#customer_account ⇒ Object
The ID of an existing Account for which to create the Customer Session.
92 93 94 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 92 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
94 95 96 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 94 def @expand end |