Class: Stripe::CustomerSessionCreateParams::Components::PaymentElement::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionCreateParams::Components::PaymentElement::Features
- Defined in:
- lib/stripe/params/customer_session_create_params.rb
Instance Attribute Summary collapse
-
#payment_method_allow_redisplay_filters ⇒ Object
A list of
allow_redisplayvalues that controls which saved payment methods the Payment Element displays by filtering to only show payment methods with anallow_redisplayvalue that is present in this list. -
#payment_method_redisplay ⇒ Object
Controls whether or not the Payment Element shows saved payment methods.
-
#payment_method_redisplay_limit ⇒ Object
Determines the max number of saved payment methods for the Payment Element to display.
-
#payment_method_remove ⇒ Object
Controls whether the Payment Element displays the option to remove a saved payment method.
-
#payment_method_save ⇒ Object
Controls whether the Payment Element displays a checkbox offering to save a new payment method.
-
#payment_method_save_usage ⇒ Object
When using PaymentIntents and the customer checks the save checkbox, this field determines the
setup_future_usagevalue used to confirm the PaymentIntent.
Instance Method Summary collapse
-
#initialize(payment_method_allow_redisplay_filters: nil, payment_method_redisplay: nil, payment_method_redisplay_limit: nil, payment_method_remove: nil, payment_method_save: nil, payment_method_save_usage: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(payment_method_allow_redisplay_filters: nil, payment_method_redisplay: nil, payment_method_redisplay_limit: nil, payment_method_remove: nil, payment_method_save: nil, payment_method_save_usage: nil) ⇒ Features
Returns a new instance of Features.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 130 def initialize( payment_method_allow_redisplay_filters: nil, payment_method_redisplay: nil, payment_method_redisplay_limit: nil, payment_method_remove: nil, payment_method_save: nil, payment_method_save_usage: nil ) @payment_method_allow_redisplay_filters = payment_method_allow_redisplay_filters @payment_method_redisplay = payment_method_redisplay @payment_method_redisplay_limit = payment_method_redisplay_limit @payment_method_remove = payment_method_remove @payment_method_save = payment_method_save @payment_method_save_usage = payment_method_save_usage end |
Instance Attribute Details
#payment_method_allow_redisplay_filters ⇒ Object
A list of allow_redisplay values that controls which saved payment methods the Payment Element displays by filtering to only show payment methods with an allow_redisplay value that is present in this list.
If not specified, defaults to ["always"]. In order to display all saved payment methods, specify ["always", "limited", "unspecified"].
112 113 114 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 112 def payment_method_allow_redisplay_filters @payment_method_allow_redisplay_filters end |
#payment_method_redisplay ⇒ Object
Controls whether or not the Payment Element shows saved payment methods. This parameter defaults to disabled.
114 115 116 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 114 def payment_method_redisplay @payment_method_redisplay end |
#payment_method_redisplay_limit ⇒ Object
Determines the max number of saved payment methods for the Payment Element to display. This parameter defaults to 3. The maximum redisplay limit is 10.
116 117 118 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 116 def payment_method_redisplay_limit @payment_method_redisplay_limit end |
#payment_method_remove ⇒ Object
Controls whether the Payment Element displays the option to remove a saved payment method. This parameter defaults to disabled.
Allowing buyers to remove their saved payment methods impacts subscriptions that depend on that payment method. Removing the payment method detaches the customer object from that PaymentMethod.
120 121 122 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 120 def payment_method_remove @payment_method_remove end |
#payment_method_save ⇒ Object
Controls whether the Payment Element displays a checkbox offering to save a new payment method. This parameter defaults to disabled.
If a customer checks the box, the allow_redisplay value on the PaymentMethod is set to 'always' at confirmation time. For PaymentIntents, the setup_future_usage value is also set to the value defined in payment_method_save_usage.
124 125 126 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 124 def payment_method_save @payment_method_save end |
#payment_method_save_usage ⇒ Object
When using PaymentIntents and the customer checks the save checkbox, this field determines the setup_future_usage value used to confirm the PaymentIntent.
When using SetupIntents, directly configure the usage value on SetupIntent creation.
128 129 130 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 128 def payment_method_save_usage @payment_method_save_usage end |