Class: Stripe::CustomerSessionCreateParams::Components::TaxIdElement::Features
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionCreateParams::Components::TaxIdElement::Features
- Defined in:
- lib/stripe/params/customer_session_create_params.rb
Instance Attribute Summary collapse
-
#tax_id_redisplay ⇒ Object
Controls whether the Tax ID Element displays saved tax IDs for the customer.
-
#tax_id_save ⇒ Object
Controls whether the Tax ID Element allows merchants to save new tax IDs for their customer.
Instance Method Summary collapse
-
#initialize(tax_id_redisplay: nil, tax_id_save: nil) ⇒ Features
constructor
A new instance of Features.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, discriminator, discriminator_fields, field_encodings, new, #to_h
Constructor Details
#initialize(tax_id_redisplay: nil, tax_id_save: nil) ⇒ Features
Returns a new instance of Features.
177 178 179 180 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 177 def initialize(tax_id_redisplay: nil, tax_id_save: nil) @tax_id_redisplay = tax_id_redisplay @tax_id_save = tax_id_save end |
Instance Attribute Details
#tax_id_redisplay ⇒ Object
Controls whether the Tax ID Element displays saved tax IDs for the customer. This parameter defaults to disabled.
When enabled, the Tax ID Element will show existing tax IDs associated with the customer, allowing them to select from previously saved tax identification numbers.
171 172 173 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 171 def tax_id_redisplay @tax_id_redisplay end |
#tax_id_save ⇒ Object
Controls whether the Tax ID Element allows merchants to save new tax IDs for their customer. This parameter defaults to disabled.
When enabled, customers can enter and save new tax identification numbers during the payment flow, which will be stored securely and associated with their customer object for future use.
175 176 177 |
# File 'lib/stripe/params/customer_session_create_params.rb', line 175 def tax_id_save @tax_id_save end |