Class: Stripe::CustomerSessionCreateParams::Components::TaxIdElement::Features

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/customer_session_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(tax_id_redisplay: nil, tax_id_save: nil) ⇒ Features

Returns a new instance of Features.



159
160
161
162
# File 'lib/stripe/params/customer_session_create_params.rb', line 159

def initialize(tax_id_redisplay: nil, tax_id_save: nil)
  @tax_id_redisplay = tax_id_redisplay
  @tax_id_save = tax_id_save
end

Instance Attribute Details

#tax_id_redisplayObject

Controls whether the Tax ID Element displays saved tax IDs for the customer. This parameter defaults to ‘disabled`.

When enabled, the Tax ID Element will show existing tax IDs associated with the customer, allowing them to select from previously saved tax identification numbers.



153
154
155
# File 'lib/stripe/params/customer_session_create_params.rb', line 153

def tax_id_redisplay
  @tax_id_redisplay
end

#tax_id_saveObject

Controls whether the Tax ID Element allows merchants to save new tax IDs for their customer. This parameter defaults to ‘disabled`.

When enabled, customers can enter and save new tax identification numbers during the payment flow, which will be stored securely and associated with their customer object for future use.



157
158
159
# File 'lib/stripe/params/customer_session_create_params.rb', line 157

def tax_id_save
  @tax_id_save
end