Class: Stripe::CustomerSessionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionService::CreateParams
- Defined in:
- lib/stripe/services/customer_session_service.rb
Defined Under Namespace
Classes: Components
Instance Attribute Summary collapse
-
#components ⇒ Object
Configuration for each component.
-
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
-
#customer_account ⇒ Object
The ID of an existing Account for which to create the Customer Session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(components: nil, customer: nil, customer_account: nil, expand: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
97 98 99 100 101 102 |
# File 'lib/stripe/services/customer_session_service.rb', line 97 def initialize(components: nil, customer: nil, customer_account: nil, expand: nil) @components = components @customer = customer @customer_account = customer_account @expand = end |
Instance Attribute Details
#components ⇒ Object
Configuration for each component. Exactly 1 component must be enabled.
89 90 91 |
# File 'lib/stripe/services/customer_session_service.rb', line 89 def components @components end |
#customer ⇒ Object
The ID of an existing customer for which to create the Customer Session.
91 92 93 |
# File 'lib/stripe/services/customer_session_service.rb', line 91 def customer @customer end |
#customer_account ⇒ Object
The ID of an existing Account for which to create the Customer Session.
93 94 95 |
# File 'lib/stripe/services/customer_session_service.rb', line 93 def customer_account @customer_account end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
95 96 97 |
# File 'lib/stripe/services/customer_session_service.rb', line 95 def @expand end |