Class: Stripe::CustomerSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/customer_session_service.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(components: nil, customer: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



105
106
107
108
109
# File 'lib/stripe/services/customer_session_service.rb', line 105

def initialize(components: nil, customer: nil, expand: nil)
  @components = components
  @customer = customer
  @expand = expand
end

Instance Attribute Details

#componentsObject

Configuration for each component. Exactly 1 component must be enabled.



97
98
99
# File 'lib/stripe/services/customer_session_service.rb', line 97

def components
  @components
end

#customerObject

The ID of an existing customer for which to create the Customer Session.



100
101
102
# File 'lib/stripe/services/customer_session_service.rb', line 100

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



103
104
105
# File 'lib/stripe/services/customer_session_service.rb', line 103

def expand
  @expand
end