Class: Stripe::CustomerSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/customer_session_service.rb

Defined Under Namespace

Classes: Components

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(components: nil, customer: nil, expand: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



95
96
97
98
99
# File 'lib/stripe/services/customer_session_service.rb', line 95

def initialize(components: nil, customer: nil, expand: nil)
  @components = components
  @customer = customer
  @expand = expand
end

Instance Attribute Details

#componentsObject

Configuration for each component. Exactly 1 component must be enabled.



89
90
91
# File 'lib/stripe/services/customer_session_service.rb', line 89

def components
  @components
end

#customerObject

The ID of an existing customer for which to create the Customer Session.



91
92
93
# File 'lib/stripe/services/customer_session_service.rb', line 91

def customer
  @customer
end

#expandObject

Specifies which fields in the response should be expanded.



93
94
95
# File 'lib/stripe/services/customer_session_service.rb', line 93

def expand
  @expand
end