Class: Stripe::CustomerSessionService::CreateParams::Components::PaymentElement
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::CustomerSessionService::CreateParams::Components::PaymentElement
- Defined in:
- lib/stripe/services/customer_session_service.rb
Defined Under Namespace
Classes: Features
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether the Payment Element is enabled.
-
#features ⇒ Object
This hash defines whether the Payment Element supports certain features.
Instance Method Summary collapse
-
#initialize(enabled: nil, features: nil) ⇒ PaymentElement
constructor
A new instance of PaymentElement.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, features: nil) ⇒ PaymentElement
Returns a new instance of PaymentElement.
67 68 69 70 |
# File 'lib/stripe/services/customer_session_service.rb', line 67 def initialize(enabled: nil, features: nil) @enabled = enabled @features = features end |
Instance Attribute Details
#enabled ⇒ Object
Whether the Payment Element is enabled.
62 63 64 |
# File 'lib/stripe/services/customer_session_service.rb', line 62 def enabled @enabled end |
#features ⇒ Object
This hash defines whether the Payment Element supports certain features.
65 66 67 |
# File 'lib/stripe/services/customer_session_service.rb', line 65 def features @features end |