Class: Stripe::DelegatedCheckout::Order
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::DelegatedCheckout::Order
- Defined in:
- lib/stripe/resources/delegated_checkout/order.rb
Overview
An order represents the post-checkout lifecycle of a delegated checkout purchase.
Defined Under Namespace
Constant Summary collapse
- OBJECT_NAME =
"delegated_checkout.order"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#latest_order_event ⇒ Object
readonly
The latest order event for this order.
-
#line_items ⇒ Object
readonly
The line items in this order.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#permalink_url ⇒ Object
readonly
The permalink URL for this order.
-
#requested_session ⇒ Object
readonly
The requested session associated with this order.
-
#seller_reference ⇒ Object
readonly
The seller reference for this order.
-
#totals ⇒ Object
readonly
The totals for this order.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
111 112 113 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 111 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
113 114 115 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 113 def currency @currency end |
#id ⇒ Object (readonly)
Unique identifier for the object.
115 116 117 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 115 def id @id end |
#latest_order_event ⇒ Object (readonly)
The latest order event for this order.
117 118 119 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 117 def latest_order_event @latest_order_event end |
#line_items ⇒ Object (readonly)
The line items in this order.
119 120 121 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 119 def line_items @line_items end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
121 122 123 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 121 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
123 124 125 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 123 def object @object end |
#permalink_url ⇒ Object (readonly)
The permalink URL for this order.
125 126 127 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 125 def permalink_url @permalink_url end |
#requested_session ⇒ Object (readonly)
The requested session associated with this order.
127 128 129 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 127 def requested_session @requested_session end |
#seller_reference ⇒ Object (readonly)
The seller reference for this order.
129 130 131 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 129 def seller_reference @seller_reference end |
#totals ⇒ Object (readonly)
The totals for this order.
131 132 133 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 131 def totals @totals end |
Class Method Details
.field_remappings ⇒ Object
137 138 139 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 137 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
133 134 135 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 133 def self.inner_class_types @inner_class_types = { line_items: LineItem, totals: Totals } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/delegated_checkout/order.rb', line 9 def self.object_name "delegated_checkout.order" end |