Class: Stripe::DelegatedCheckout::OrderEvent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::DelegatedCheckout::OrderEvent
- Defined in:
- lib/stripe/resources/delegated_checkout/order_event.rb
Overview
An order event represents a change to a delegated checkout order.
Defined Under Namespace
Classes: Adjustment, Fulfillment
Constant Summary collapse
- OBJECT_NAME =
"delegated_checkout.order_event"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#adjustment ⇒ Object
readonly
The adjustment details for this order event.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#fulfillment ⇒ Object
readonly
The fulfillment details for this order event.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#occurred_at ⇒ Object
readonly
Time at which this event occurred.
-
#order ⇒ Object
readonly
The delegated checkout order associated with this order event.
-
#requested_session ⇒ Object
readonly
The requested session associated with this order event.
-
#type ⇒ Object
readonly
The type of order event.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#adjustment ⇒ Object (readonly)
The adjustment details for this order event.
89 90 91 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 89 def adjustment @adjustment end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
91 92 93 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 91 def created @created end |
#fulfillment ⇒ Object (readonly)
The fulfillment details for this order event.
93 94 95 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 93 def fulfillment @fulfillment end |
#id ⇒ Object (readonly)
Unique identifier for the object.
95 96 97 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 95 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
97 98 99 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 97 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
99 100 101 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 99 def object @object end |
#occurred_at ⇒ Object (readonly)
Time at which this event occurred. Measured in seconds since the Unix epoch.
101 102 103 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 101 def occurred_at @occurred_at end |
#order ⇒ Object (readonly)
The delegated checkout order associated with this order event.
103 104 105 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 103 def order @order end |
#requested_session ⇒ Object (readonly)
The requested session associated with this order event.
105 106 107 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 105 def requested_session @requested_session end |
#type ⇒ Object (readonly)
The type of order event.
107 108 109 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 107 def type @type end |
Class Method Details
.field_remappings ⇒ Object
113 114 115 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 113 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
109 110 111 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 109 def self.inner_class_types @inner_class_types = { adjustment: Adjustment, fulfillment: Fulfillment } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/delegated_checkout/order_event.rb', line 9 def self.object_name "delegated_checkout.order_event" end |