Class: Stripe::DelegatedCheckout::RequestedSession

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/delegated_checkout/requested_session.rb

Overview

A requested session is a session that has been requested by a customer.

Defined Under Namespace

Classes: AffiliateAttribution, BuyerConsents, FulfillmentDetails, LineItemDetail, OrderDetails, PaymentMethodOptions, PaymentMethodPreview, RiskDetails, SellerDetails, TotalDetails

Constant Summary collapse

OBJECT_NAME =
"delegated_checkout.requested_session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliate_attributionsObject (readonly)

Affiliate attribution data associated with this requested session.



651
652
653
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 651

def affiliate_attributions
  @affiliate_attributions
end

#amount_subtotalObject (readonly)

The subtotal amount of the requested session.



653
654
655
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 653

def amount_subtotal
  @amount_subtotal
end

#amount_totalObject (readonly)

The total amount of the requested session.



655
656
657
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 655

def amount_total
  @amount_total
end

#buyer_consentsObject (readonly)

The buyer consent options for this requested session, including marketing preferences.



657
658
659
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 657

def buyer_consents
  @buyer_consents
end

#created_atObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



659
660
661
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 659

def created_at
  @created_at
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



661
662
663
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 661

def currency
  @currency
end

#customerObject (readonly)

The customer for this requested session.



663
664
665
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 663

def customer
  @customer
end

#expires_atObject (readonly)

Time at which the requested session expires. Measured in seconds since the Unix epoch.



665
666
667
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 665

def expires_at
  @expires_at
end

#fulfillment_detailsObject (readonly)

The details of the fulfillment.



667
668
669
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 667

def fulfillment_details
  @fulfillment_details
end

#idObject (readonly)

Unique identifier for the object.



669
670
671
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 669

def id
  @id
end

#line_item_detailsObject (readonly)

The line items to be purchased.



671
672
673
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 671

def line_item_details
  @line_item_details
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



673
674
675
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 673

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



675
676
677
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 675

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



677
678
679
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 677

def object
  @object
end

#order_detailsObject (readonly)

The details of the order.



679
680
681
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 679

def order_details
  @order_details
end

#payment_methodObject (readonly)

The payment method used for the requested session.



681
682
683
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 681

def payment_method
  @payment_method
end

#payment_method_optionsObject (readonly)

The payment method options for this requested session.



683
684
685
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 683

def payment_method_options
  @payment_method_options
end

#payment_method_previewObject (readonly)

The preview of the payment method to be created when the requested session is confirmed.



685
686
687
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 685

def payment_method_preview
  @payment_method_preview
end

#risk_detailsObject (readonly)

The risk details of the requested session.



687
688
689
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 687

def risk_details
  @risk_details
end

#seller_detailsObject (readonly)

Attribute for field seller_details



689
690
691
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 689

def seller_details
  @seller_details
end

#setup_future_usageObject (readonly)

Whether or not the payment method should be saved for future use.



691
692
693
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 691

def setup_future_usage
  @setup_future_usage
end

#shared_metadataObject (readonly)

The metadata shared with the seller.



693
694
695
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 693

def 
  @shared_metadata
end

#shared_payment_issued_tokenObject (readonly)

The SPT used for payment.



695
696
697
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 695

def shared_payment_issued_token
  @shared_payment_issued_token
end

#statusObject (readonly)

The status of the requested session.



697
698
699
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 697

def status
  @status
end

#total_detailsObject (readonly)

Attribute for field total_details



699
700
701
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 699

def total_details
  @total_details
end

#updated_atObject (readonly)

Time at which the object was last updated. Measured in seconds since the Unix epoch.



701
702
703
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 701

def updated_at
  @updated_at
end

Class Method Details

.confirm(requested_session, params = {}, opts = {}) ⇒ Object

Confirms a requested session



714
715
716
717
718
719
720
721
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 714

def self.confirm(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a requested session



724
725
726
727
728
729
730
731
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 724

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/delegated_checkout/requested_sessions",
    params: params,
    opts: opts
  )
end

.expire(requested_session, params = {}, opts = {}) ⇒ Object

Expires a requested session



744
745
746
747
748
749
750
751
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 744

def self.expire(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



778
779
780
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 778

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



763
764
765
766
767
768
769
770
771
772
773
774
775
776
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 763

def self.inner_class_types
  @inner_class_types = {
    affiliate_attributions: AffiliateAttribution,
    buyer_consents: BuyerConsents,
    fulfillment_details: FulfillmentDetails,
    line_item_details: LineItemDetail,
    order_details: OrderDetails,
    payment_method_options: PaymentMethodOptions,
    payment_method_preview: PaymentMethodPreview,
    risk_details: RiskDetails,
    seller_details: SellerDetails,
    total_details: TotalDetails,
  }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 12

def self.object_name
  "delegated_checkout.requested_session"
end

.update(requested_session, params = {}, opts = {}) ⇒ Object

Updates a requested session



754
755
756
757
758
759
760
761
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 754

def self.update(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#confirm(params = {}, opts = {}) ⇒ Object

Confirms a requested session



704
705
706
707
708
709
710
711
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 704

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#expire(params = {}, opts = {}) ⇒ Object

Expires a requested session



734
735
736
737
738
739
740
741
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 734

def expire(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end