Class: Stripe::DelegatedCheckout::RequestedSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::DelegatedCheckout::RequestedSession
- Extended by:
- APIOperations::Create
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Overview
A requested session is a session that has been requested by a customer.
Defined Under Namespace
Classes: AffiliateAttribution, BuyerConsents, FulfillmentDetails, LineItemDetail, OrderDetails, PaymentMethodOptions, PaymentMethodPreview, RiskDetails, SellerDetails, TotalDetails
Constant Summary collapse
- OBJECT_NAME =
"delegated_checkout.requested_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate_attributions ⇒ Object
readonly
Affiliate attribution data associated with this requested session.
-
#amount_subtotal ⇒ Object
readonly
The subtotal amount of the requested session.
-
#amount_total ⇒ Object
readonly
The total amount of the requested session.
-
#buyer_consents ⇒ Object
readonly
The buyer consent options for this requested session, including marketing preferences.
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
The customer for this requested session.
-
#expires_at ⇒ Object
readonly
Time at which the requested session expires.
-
#fulfillment_details ⇒ Object
readonly
The details of the fulfillment.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#line_item_details ⇒ Object
readonly
The line items to be purchased.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#order_details ⇒ Object
readonly
The details of the order.
-
#payment_method ⇒ Object
readonly
The payment method used for the requested session.
-
#payment_method_options ⇒ Object
readonly
The payment method options for this requested session.
-
#payment_method_preview ⇒ Object
readonly
The preview of the payment method to be created when the requested session is confirmed.
-
#risk_details ⇒ Object
readonly
The risk details of the requested session.
-
#seller_details ⇒ Object
readonly
Attribute for field seller_details.
-
#setup_future_usage ⇒ Object
readonly
Whether or not the payment method should be saved for future use.
-
#shared_metadata ⇒ Object
readonly
The metadata shared with the seller.
-
#shared_payment_issued_token ⇒ Object
readonly
The SPT used for payment.
-
#status ⇒ Object
readonly
The status of the requested session.
-
#total_details ⇒ Object
readonly
Attribute for field total_details.
-
#updated_at ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session.
-
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
-
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session.
Instance Method Summary collapse
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session.
Methods included from APIOperations::Create
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate_attributions ⇒ Object (readonly)
Affiliate attribution data associated with this requested session.
634 635 636 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 634 def affiliate_attributions @affiliate_attributions end |
#amount_subtotal ⇒ Object (readonly)
The subtotal amount of the requested session.
636 637 638 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 636 def amount_subtotal @amount_subtotal end |
#amount_total ⇒ Object (readonly)
The total amount of the requested session.
638 639 640 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 638 def amount_total @amount_total end |
#buyer_consents ⇒ Object (readonly)
The buyer consent options for this requested session, including marketing preferences.
640 641 642 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 640 def @buyer_consents end |
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
642 643 644 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 642 def created_at @created_at end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
644 645 646 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 644 def currency @currency end |
#customer ⇒ Object (readonly)
The customer for this requested session.
646 647 648 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 646 def customer @customer end |
#expires_at ⇒ Object (readonly)
Time at which the requested session expires. Measured in seconds since the Unix epoch.
648 649 650 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 648 def expires_at @expires_at end |
#fulfillment_details ⇒ Object (readonly)
The details of the fulfillment.
650 651 652 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 650 def fulfillment_details @fulfillment_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
652 653 654 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 652 def id @id end |
#line_item_details ⇒ Object (readonly)
The line items to be purchased.
654 655 656 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 654 def line_item_details @line_item_details end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
656 657 658 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 656 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
658 659 660 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 658 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
660 661 662 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 660 def object @object end |
#order_details ⇒ Object (readonly)
The details of the order.
662 663 664 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 662 def order_details @order_details end |
#payment_method ⇒ Object (readonly)
The payment method used for the requested session.
664 665 666 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 664 def payment_method @payment_method end |
#payment_method_options ⇒ Object (readonly)
The payment method options for this requested session.
666 667 668 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 666 def @payment_method_options end |
#payment_method_preview ⇒ Object (readonly)
The preview of the payment method to be created when the requested session is confirmed.
668 669 670 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 668 def payment_method_preview @payment_method_preview end |
#risk_details ⇒ Object (readonly)
The risk details of the requested session.
670 671 672 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 670 def risk_details @risk_details end |
#seller_details ⇒ Object (readonly)
Attribute for field seller_details
672 673 674 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 672 def seller_details @seller_details end |
#setup_future_usage ⇒ Object (readonly)
Whether or not the payment method should be saved for future use.
674 675 676 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 674 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object (readonly)
The metadata shared with the seller.
676 677 678 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 676 def @shared_metadata end |
#shared_payment_issued_token ⇒ Object (readonly)
The SPT used for payment.
678 679 680 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 678 def shared_payment_issued_token @shared_payment_issued_token end |
#status ⇒ Object (readonly)
The status of the requested session.
680 681 682 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 680 def status @status end |
#total_details ⇒ Object (readonly)
Attribute for field total_details
682 683 684 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 682 def total_details @total_details end |
#updated_at ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
684 685 686 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 684 def updated_at @updated_at end |
Class Method Details
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session
697 698 699 700 701 702 703 704 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 697 def self.confirm(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session
707 708 709 710 711 712 713 714 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 707 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/delegated_checkout/requested_sessions", params: params, opts: opts ) end |
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session
727 728 729 730 731 732 733 734 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 727 def self.expire(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
761 762 763 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 761 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
746 747 748 749 750 751 752 753 754 755 756 757 758 759 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 746 def self.inner_class_types @inner_class_types = { affiliate_attributions: AffiliateAttribution, buyer_consents: BuyerConsents, fulfillment_details: FulfillmentDetails, line_item_details: LineItemDetail, order_details: OrderDetails, payment_method_options: PaymentMethodOptions, payment_method_preview: PaymentMethodPreview, risk_details: RiskDetails, seller_details: SellerDetails, total_details: TotalDetails, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 12 def self.object_name "delegated_checkout.requested_session" end |
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session
737 738 739 740 741 742 743 744 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 737 def self.update(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
Instance Method Details
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session
687 688 689 690 691 692 693 694 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 687 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session
717 718 719 720 721 722 723 724 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 717 def expire(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |