Class: Stripe::DelegatedCheckout::RequestedSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::DelegatedCheckout::RequestedSession
- Extended by:
- APIOperations::Create
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Overview
A requested session is a session that has been requested by a customer.
Defined Under Namespace
Classes: AffiliateAttribution, FulfillmentDetails, LineItemDetail, OrderDetails, PaymentMethodPreview, RiskDetails, SellerDetails, TotalDetails
Constant Summary collapse
- OBJECT_NAME =
"delegated_checkout.requested_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate_attributions ⇒ Object
readonly
Affiliate attribution data associated with this requested session.
-
#amount_subtotal ⇒ Object
readonly
The subtotal amount of the requested session.
-
#amount_total ⇒ Object
readonly
The total amount of the requested session.
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
The customer for this requested session.
-
#expires_at ⇒ Object
readonly
Time at which the requested session expires.
-
#fulfillment_details ⇒ Object
readonly
The details of the fulfillment.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#line_item_details ⇒ Object
readonly
The line items to be purchased.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#order_details ⇒ Object
readonly
The details of the order.
-
#payment_method ⇒ Object
readonly
The payment method used for the requested session.
-
#payment_method_preview ⇒ Object
readonly
The preview of the payment method to be created when the requested session is confirmed.
-
#risk_details ⇒ Object
readonly
The risk details of the requested session.
-
#seller_details ⇒ Object
readonly
Attribute for field seller_details.
-
#setup_future_usage ⇒ Object
readonly
Whether or not the payment method should be saved for future use.
-
#shared_metadata ⇒ Object
readonly
The metadata shared with the seller.
-
#shared_payment_issued_token ⇒ Object
readonly
The SPT used for payment.
-
#status ⇒ Object
readonly
The status of the requested session.
-
#total_details ⇒ Object
readonly
Attribute for field total_details.
-
#updated_at ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session.
-
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
-
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session.
Instance Method Summary collapse
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session.
Methods included from APIOperations::Create
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate_attributions ⇒ Object (readonly)
Affiliate attribution data associated with this requested session.
558 559 560 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 558 def affiliate_attributions @affiliate_attributions end |
#amount_subtotal ⇒ Object (readonly)
The subtotal amount of the requested session.
560 561 562 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 560 def amount_subtotal @amount_subtotal end |
#amount_total ⇒ Object (readonly)
The total amount of the requested session.
562 563 564 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 562 def amount_total @amount_total end |
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
564 565 566 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 564 def created_at @created_at end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
566 567 568 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 566 def currency @currency end |
#customer ⇒ Object (readonly)
The customer for this requested session.
568 569 570 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 568 def customer @customer end |
#expires_at ⇒ Object (readonly)
Time at which the requested session expires. Measured in seconds since the Unix epoch.
570 571 572 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 570 def expires_at @expires_at end |
#fulfillment_details ⇒ Object (readonly)
The details of the fulfillment.
572 573 574 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 572 def fulfillment_details @fulfillment_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
574 575 576 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 574 def id @id end |
#line_item_details ⇒ Object (readonly)
The line items to be purchased.
576 577 578 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 576 def line_item_details @line_item_details end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
578 579 580 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 578 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
580 581 582 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 580 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
582 583 584 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 582 def object @object end |
#order_details ⇒ Object (readonly)
The details of the order.
584 585 586 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 584 def order_details @order_details end |
#payment_method ⇒ Object (readonly)
The payment method used for the requested session.
586 587 588 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 586 def payment_method @payment_method end |
#payment_method_preview ⇒ Object (readonly)
The preview of the payment method to be created when the requested session is confirmed.
588 589 590 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 588 def payment_method_preview @payment_method_preview end |
#risk_details ⇒ Object (readonly)
The risk details of the requested session.
590 591 592 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 590 def risk_details @risk_details end |
#seller_details ⇒ Object (readonly)
Attribute for field seller_details
592 593 594 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 592 def seller_details @seller_details end |
#setup_future_usage ⇒ Object (readonly)
Whether or not the payment method should be saved for future use.
594 595 596 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 594 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object (readonly)
The metadata shared with the seller.
596 597 598 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 596 def @shared_metadata end |
#shared_payment_issued_token ⇒ Object (readonly)
The SPT used for payment.
598 599 600 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 598 def shared_payment_issued_token @shared_payment_issued_token end |
#status ⇒ Object (readonly)
The status of the requested session.
600 601 602 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 600 def status @status end |
#total_details ⇒ Object (readonly)
Attribute for field total_details
602 603 604 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 602 def total_details @total_details end |
#updated_at ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
604 605 606 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 604 def updated_at @updated_at end |
Class Method Details
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session
617 618 619 620 621 622 623 624 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 617 def self.confirm(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session
627 628 629 630 631 632 633 634 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 627 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/delegated_checkout/requested_sessions", params: params, opts: opts ) end |
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session
647 648 649 650 651 652 653 654 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 647 def self.expire(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
679 680 681 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 679 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
666 667 668 669 670 671 672 673 674 675 676 677 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 666 def self.inner_class_types @inner_class_types = { affiliate_attributions: AffiliateAttribution, fulfillment_details: FulfillmentDetails, line_item_details: LineItemDetail, order_details: OrderDetails, payment_method_preview: PaymentMethodPreview, risk_details: RiskDetails, seller_details: SellerDetails, total_details: TotalDetails, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 12 def self.object_name "delegated_checkout.requested_session" end |
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session
657 658 659 660 661 662 663 664 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 657 def self.update(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
Instance Method Details
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session
607 608 609 610 611 612 613 614 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 607 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session
637 638 639 640 641 642 643 644 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 637 def expire(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |