Class: Stripe::DelegatedCheckout::RequestedSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::DelegatedCheckout::RequestedSession
- Extended by:
- APIOperations::Create
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Overview
A requested session is a session that has been requested by a customer.
Defined Under Namespace
Classes: AffiliateAttribution, FulfillmentDetails, LineItemDetail, OrderDetails, PaymentMethodOptions, PaymentMethodPreview, RiskDetails, SellerDetails, TotalDetails
Constant Summary collapse
- OBJECT_NAME =
"delegated_checkout.requested_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#affiliate_attributions ⇒ Object
readonly
Affiliate attribution data associated with this requested session.
-
#amount_subtotal ⇒ Object
readonly
The subtotal amount of the requested session.
-
#amount_total ⇒ Object
readonly
The total amount of the requested session.
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
The customer for this requested session.
-
#expires_at ⇒ Object
readonly
Time at which the requested session expires.
-
#fulfillment_details ⇒ Object
readonly
The details of the fulfillment.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#line_item_details ⇒ Object
readonly
The line items to be purchased.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#order_details ⇒ Object
readonly
The details of the order.
-
#payment_method ⇒ Object
readonly
The payment method used for the requested session.
-
#payment_method_options ⇒ Object
readonly
The payment method options for this requested session.
-
#payment_method_preview ⇒ Object
readonly
The preview of the payment method to be created when the requested session is confirmed.
-
#risk_details ⇒ Object
readonly
The risk details of the requested session.
-
#seller_details ⇒ Object
readonly
Attribute for field seller_details.
-
#setup_future_usage ⇒ Object
readonly
Whether or not the payment method should be saved for future use.
-
#shared_metadata ⇒ Object
readonly
The metadata shared with the seller.
-
#shared_payment_issued_token ⇒ Object
readonly
The SPT used for payment.
-
#status ⇒ Object
readonly
The status of the requested session.
-
#total_details ⇒ Object
readonly
Attribute for field total_details.
-
#updated_at ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session.
-
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
-
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session.
Instance Method Summary collapse
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session.
Methods included from APIOperations::Create
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#affiliate_attributions ⇒ Object (readonly)
Affiliate attribution data associated with this requested session.
593 594 595 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 593 def affiliate_attributions @affiliate_attributions end |
#amount_subtotal ⇒ Object (readonly)
The subtotal amount of the requested session.
595 596 597 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 595 def amount_subtotal @amount_subtotal end |
#amount_total ⇒ Object (readonly)
The total amount of the requested session.
597 598 599 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 597 def amount_total @amount_total end |
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
599 600 601 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 599 def created_at @created_at end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
601 602 603 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 601 def currency @currency end |
#customer ⇒ Object (readonly)
The customer for this requested session.
603 604 605 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 603 def customer @customer end |
#expires_at ⇒ Object (readonly)
Time at which the requested session expires. Measured in seconds since the Unix epoch.
605 606 607 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 605 def expires_at @expires_at end |
#fulfillment_details ⇒ Object (readonly)
The details of the fulfillment.
607 608 609 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 607 def fulfillment_details @fulfillment_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
609 610 611 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 609 def id @id end |
#line_item_details ⇒ Object (readonly)
The line items to be purchased.
611 612 613 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 611 def line_item_details @line_item_details end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
613 614 615 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 613 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
615 616 617 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 615 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
617 618 619 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 617 def object @object end |
#order_details ⇒ Object (readonly)
The details of the order.
619 620 621 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 619 def order_details @order_details end |
#payment_method ⇒ Object (readonly)
The payment method used for the requested session.
621 622 623 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 621 def payment_method @payment_method end |
#payment_method_options ⇒ Object (readonly)
The payment method options for this requested session.
641 642 643 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 641 def @payment_method_options end |
#payment_method_preview ⇒ Object (readonly)
The preview of the payment method to be created when the requested session is confirmed.
623 624 625 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 623 def payment_method_preview @payment_method_preview end |
#risk_details ⇒ Object (readonly)
The risk details of the requested session.
625 626 627 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 625 def risk_details @risk_details end |
#seller_details ⇒ Object (readonly)
Attribute for field seller_details
627 628 629 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 627 def seller_details @seller_details end |
#setup_future_usage ⇒ Object (readonly)
Whether or not the payment method should be saved for future use.
629 630 631 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 629 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object (readonly)
The metadata shared with the seller.
631 632 633 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 631 def @shared_metadata end |
#shared_payment_issued_token ⇒ Object (readonly)
The SPT used for payment.
633 634 635 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 633 def shared_payment_issued_token @shared_payment_issued_token end |
#status ⇒ Object (readonly)
The status of the requested session.
635 636 637 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 635 def status @status end |
#total_details ⇒ Object (readonly)
Attribute for field total_details
637 638 639 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 637 def total_details @total_details end |
#updated_at ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
639 640 641 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 639 def updated_at @updated_at end |
Class Method Details
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session
654 655 656 657 658 659 660 661 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 654 def self.confirm(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session
664 665 666 667 668 669 670 671 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 664 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/delegated_checkout/requested_sessions", params: params, opts: opts ) end |
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session
684 685 686 687 688 689 690 691 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 684 def self.expire(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
717 718 719 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 717 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
703 704 705 706 707 708 709 710 711 712 713 714 715 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 703 def self.inner_class_types @inner_class_types = { affiliate_attributions: AffiliateAttribution, fulfillment_details: FulfillmentDetails, line_item_details: LineItemDetail, order_details: OrderDetails, payment_method_preview: PaymentMethodPreview, risk_details: RiskDetails, seller_details: SellerDetails, total_details: TotalDetails, payment_method_options: PaymentMethodOptions, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 12 def self.object_name "delegated_checkout.requested_session" end |
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session
694 695 696 697 698 699 700 701 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 694 def self.update(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
Instance Method Details
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session
644 645 646 647 648 649 650 651 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 644 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session
674 675 676 677 678 679 680 681 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 674 def expire(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |