Class: Stripe::DelegatedCheckout::RequestedSession

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/delegated_checkout/requested_session.rb

Overview

A requested session is a session that has been requested by a customer.

Defined Under Namespace

Classes: AffiliateAttribution, FulfillmentDetails, LineItemDetail, OrderDetails, PaymentMethodPreview, RiskDetails, SellerDetails, TotalDetails

Constant Summary collapse

OBJECT_NAME =
"delegated_checkout.requested_session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#affiliate_attributionsObject (readonly)

Affiliate attribution data associated with this requested session.



553
554
555
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 553

def affiliate_attributions
  @affiliate_attributions
end

#amount_subtotalObject (readonly)

The subtotal amount of the requested session.



507
508
509
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 507

def amount_subtotal
  @amount_subtotal
end

#amount_totalObject (readonly)

The total amount of the requested session.



509
510
511
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 509

def amount_total
  @amount_total
end

#created_atObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



511
512
513
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 511

def created_at
  @created_at
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



513
514
515
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 513

def currency
  @currency
end

#customerObject (readonly)

The customer for this requested session.



515
516
517
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 515

def customer
  @customer
end

#expires_atObject (readonly)

Time at which the requested session expires. Measured in seconds since the Unix epoch.



517
518
519
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 517

def expires_at
  @expires_at
end

#fulfillment_detailsObject (readonly)

The details of the fulfillment.



519
520
521
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 519

def fulfillment_details
  @fulfillment_details
end

#idObject (readonly)

Unique identifier for the object.



521
522
523
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 521

def id
  @id
end

#line_item_detailsObject (readonly)

The line items to be purchased.



523
524
525
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 523

def line_item_details
  @line_item_details
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



525
526
527
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 525

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



527
528
529
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 527

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



529
530
531
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 529

def object
  @object
end

#order_detailsObject (readonly)

The details of the order.



531
532
533
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 531

def order_details
  @order_details
end

#payment_methodObject (readonly)

The payment method used for the requested session.



533
534
535
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 533

def payment_method
  @payment_method
end

#payment_method_previewObject (readonly)

The preview of the payment method to be created when the requested session is confirmed.



535
536
537
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 535

def payment_method_preview
  @payment_method_preview
end

#risk_detailsObject (readonly)

The risk details of the requested session.



537
538
539
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 537

def risk_details
  @risk_details
end

#seller_detailsObject (readonly)

Attribute for field seller_details



539
540
541
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 539

def seller_details
  @seller_details
end

#setup_future_usageObject (readonly)

Whether or not the payment method should be saved for future use.



541
542
543
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 541

def setup_future_usage
  @setup_future_usage
end

#shared_metadataObject (readonly)

The metadata shared with the seller.



543
544
545
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 543

def 
  @shared_metadata
end

#shared_payment_issued_tokenObject (readonly)

The SPT used for payment.



545
546
547
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 545

def shared_payment_issued_token
  @shared_payment_issued_token
end

#statusObject (readonly)

The status of the requested session.



547
548
549
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 547

def status
  @status
end

#total_detailsObject (readonly)

Attribute for field total_details



549
550
551
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 549

def total_details
  @total_details
end

#updated_atObject (readonly)

Time at which the object was last updated. Measured in seconds since the Unix epoch.



551
552
553
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 551

def updated_at
  @updated_at
end

Class Method Details

.confirm(requested_session, params = {}, opts = {}) ⇒ Object

Confirms a requested session



566
567
568
569
570
571
572
573
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 566

def self.confirm(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a requested session



576
577
578
579
580
581
582
583
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 576

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/delegated_checkout/requested_sessions",
    params: params,
    opts: opts
  )
end

.expire(requested_session, params = {}, opts = {}) ⇒ Object

Expires a requested session



596
597
598
599
600
601
602
603
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 596

def self.expire(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



628
629
630
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 628

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



615
616
617
618
619
620
621
622
623
624
625
626
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 615

def self.inner_class_types
  @inner_class_types = {
    fulfillment_details: FulfillmentDetails,
    line_item_details: LineItemDetail,
    order_details: OrderDetails,
    payment_method_preview: PaymentMethodPreview,
    risk_details: RiskDetails,
    seller_details: SellerDetails,
    total_details: TotalDetails,
    affiliate_attributions: AffiliateAttribution,
  }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 12

def self.object_name
  "delegated_checkout.requested_session"
end

.update(requested_session, params = {}, opts = {}) ⇒ Object

Updates a requested session



606
607
608
609
610
611
612
613
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 606

def self.update(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#confirm(params = {}, opts = {}) ⇒ Object

Confirms a requested session



556
557
558
559
560
561
562
563
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 556

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#expire(params = {}, opts = {}) ⇒ Object

Expires a requested session



586
587
588
589
590
591
592
593
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 586

def expire(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end