Class: Stripe::DelegatedCheckout::RequestedSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::DelegatedCheckout::RequestedSession
- Extended by:
- APIOperations::Create
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Overview
A requested session is a session that has been requested by a customer.
Defined Under Namespace
Classes: FulfillmentDetails, LineItemDetail, OrderDetails, PaymentMethodPreview, SellerDetails, TotalDetails
Constant Summary collapse
- OBJECT_NAME =
"delegated_checkout.requested_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_subtotal ⇒ Object
readonly
The subtotal amount of the requested session.
-
#amount_total ⇒ Object
readonly
The total amount of the requested session.
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
The customer for this requested session.
-
#expires_at ⇒ Object
readonly
Time at which the requested session expires.
-
#fulfillment_details ⇒ Object
readonly
The details of the fulfillment.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#line_item_details ⇒ Object
readonly
The line items to be purchased.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#order_details ⇒ Object
readonly
The details of the order.
-
#payment_method ⇒ Object
readonly
The payment method used for the requested session.
-
#payment_method_preview ⇒ Object
readonly
The preview of the payment method to be created when the requested session is confirmed.
-
#seller_details ⇒ Object
readonly
Attribute for field seller_details.
-
#setup_future_usage ⇒ Object
readonly
Whether or not the payment method should be saved for future use.
-
#shared_metadata ⇒ Object
readonly
The metadata shared with the seller.
-
#shared_payment_issued_token ⇒ Object
readonly
The SPT used for payment.
-
#status ⇒ Object
readonly
The status of the requested session.
-
#total_details ⇒ Object
readonly
Attribute for field total_details.
-
#updated_at ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session.
-
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
-
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session.
Instance Method Summary collapse
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session.
Methods included from APIOperations::Create
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_subtotal ⇒ Object (readonly)
The subtotal amount of the requested session.
359 360 361 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 359 def amount_subtotal @amount_subtotal end |
#amount_total ⇒ Object (readonly)
The total amount of the requested session.
361 362 363 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 361 def amount_total @amount_total end |
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
363 364 365 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 363 def created_at @created_at end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
365 366 367 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 365 def currency @currency end |
#customer ⇒ Object (readonly)
The customer for this requested session.
367 368 369 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 367 def customer @customer end |
#expires_at ⇒ Object (readonly)
Time at which the requested session expires. Measured in seconds since the Unix epoch.
369 370 371 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 369 def expires_at @expires_at end |
#fulfillment_details ⇒ Object (readonly)
The details of the fulfillment.
371 372 373 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 371 def fulfillment_details @fulfillment_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
373 374 375 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 373 def id @id end |
#line_item_details ⇒ Object (readonly)
The line items to be purchased.
375 376 377 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 375 def line_item_details @line_item_details end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
377 378 379 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 377 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
379 380 381 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 379 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
381 382 383 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 381 def object @object end |
#order_details ⇒ Object (readonly)
The details of the order.
383 384 385 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 383 def order_details @order_details end |
#payment_method ⇒ Object (readonly)
The payment method used for the requested session.
385 386 387 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 385 def payment_method @payment_method end |
#payment_method_preview ⇒ Object (readonly)
The preview of the payment method to be created when the requested session is confirmed.
387 388 389 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 387 def payment_method_preview @payment_method_preview end |
#seller_details ⇒ Object (readonly)
Attribute for field seller_details
389 390 391 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 389 def seller_details @seller_details end |
#setup_future_usage ⇒ Object (readonly)
Whether or not the payment method should be saved for future use.
391 392 393 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 391 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object (readonly)
The metadata shared with the seller.
393 394 395 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 393 def @shared_metadata end |
#shared_payment_issued_token ⇒ Object (readonly)
The SPT used for payment.
395 396 397 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 395 def shared_payment_issued_token @shared_payment_issued_token end |
#status ⇒ Object (readonly)
The status of the requested session.
397 398 399 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 397 def status @status end |
#total_details ⇒ Object (readonly)
Attribute for field total_details
399 400 401 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 399 def total_details @total_details end |
#updated_at ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
401 402 403 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 401 def updated_at @updated_at end |
Class Method Details
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session
414 415 416 417 418 419 420 421 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 414 def self.confirm(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session
424 425 426 427 428 429 430 431 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 424 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/delegated_checkout/requested_sessions", params: params, opts: opts ) end |
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session
444 445 446 447 448 449 450 451 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 444 def self.expire(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
474 475 476 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 474 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
463 464 465 466 467 468 469 470 471 472 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 463 def self.inner_class_types @inner_class_types = { fulfillment_details: FulfillmentDetails, line_item_details: LineItemDetail, order_details: OrderDetails, payment_method_preview: PaymentMethodPreview, seller_details: SellerDetails, total_details: TotalDetails, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 12 def self.object_name "delegated_checkout.requested_session" end |
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session
454 455 456 457 458 459 460 461 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 454 def self.update(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
Instance Method Details
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session
404 405 406 407 408 409 410 411 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 404 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session
434 435 436 437 438 439 440 441 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 434 def expire(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |