Class: Stripe::DelegatedCheckout::RequestedSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::DelegatedCheckout::RequestedSession
- Extended by:
- APIOperations::Create
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Overview
A requested session is a session that has been requested by a customer.
Defined Under Namespace
Classes: FulfillmentDetails, LineItemDetail, OrderDetails, PaymentMethodPreview, SellerDetails, TotalDetails
Constant Summary collapse
- OBJECT_NAME =
"delegated_checkout.requested_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_subtotal ⇒ Object
readonly
The subtotal amount of the requested session.
-
#amount_total ⇒ Object
readonly
The total amount of the requested session.
-
#created_at ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
The customer for this requested session.
-
#expires_at ⇒ Object
readonly
Time at which the requested session expires.
-
#fulfillment_details ⇒ Object
readonly
The details of the fulfillment.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#line_item_details ⇒ Object
readonly
The line items to be purchased.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#order_details ⇒ Object
readonly
The details of the order.
-
#payment_method ⇒ Object
readonly
The payment method used for the requested session.
-
#payment_method_preview ⇒ Object
readonly
The preview of the payment method to be created when the requested session is confirmed.
-
#seller_details ⇒ Object
readonly
Attribute for field seller_details.
-
#setup_future_usage ⇒ Object
readonly
Whether or not the payment method should be saved for future use.
-
#shared_metadata ⇒ Object
readonly
The metadata shared with the seller.
-
#shared_payment_issued_token ⇒ Object
readonly
The SPT used for payment.
-
#status ⇒ Object
readonly
The status of the requested session.
-
#total_details ⇒ Object
readonly
Attribute for field total_details.
-
#updated_at ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session.
-
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
- .object_name ⇒ Object
-
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session.
Instance Method Summary collapse
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session.
-
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session.
Methods included from APIOperations::Create
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_subtotal ⇒ Object (readonly)
The subtotal amount of the requested session.
314 315 316 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 314 def amount_subtotal @amount_subtotal end |
#amount_total ⇒ Object (readonly)
The total amount of the requested session.
316 317 318 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 316 def amount_total @amount_total end |
#created_at ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
318 319 320 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 318 def created_at @created_at end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
320 321 322 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 320 def currency @currency end |
#customer ⇒ Object (readonly)
The customer for this requested session.
322 323 324 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 322 def customer @customer end |
#expires_at ⇒ Object (readonly)
Time at which the requested session expires. Measured in seconds since the Unix epoch.
324 325 326 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 324 def expires_at @expires_at end |
#fulfillment_details ⇒ Object (readonly)
The details of the fulfillment.
326 327 328 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 326 def fulfillment_details @fulfillment_details end |
#id ⇒ Object (readonly)
Unique identifier for the object.
328 329 330 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 328 def id @id end |
#line_item_details ⇒ Object (readonly)
The line items to be purchased.
330 331 332 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 330 def line_item_details @line_item_details end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
332 333 334 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 332 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
334 335 336 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 334 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
336 337 338 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 336 def object @object end |
#order_details ⇒ Object (readonly)
The details of the order.
338 339 340 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 338 def order_details @order_details end |
#payment_method ⇒ Object (readonly)
The payment method used for the requested session.
340 341 342 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 340 def payment_method @payment_method end |
#payment_method_preview ⇒ Object (readonly)
The preview of the payment method to be created when the requested session is confirmed.
342 343 344 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 342 def payment_method_preview @payment_method_preview end |
#seller_details ⇒ Object (readonly)
Attribute for field seller_details
344 345 346 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 344 def seller_details @seller_details end |
#setup_future_usage ⇒ Object (readonly)
Whether or not the payment method should be saved for future use.
346 347 348 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 346 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object (readonly)
The metadata shared with the seller.
348 349 350 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 348 def @shared_metadata end |
#shared_payment_issued_token ⇒ Object (readonly)
The SPT used for payment.
350 351 352 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 350 def shared_payment_issued_token @shared_payment_issued_token end |
#status ⇒ Object (readonly)
The status of the requested session.
352 353 354 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 352 def status @status end |
#total_details ⇒ Object (readonly)
Attribute for field total_details
354 355 356 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 354 def total_details @total_details end |
#updated_at ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
356 357 358 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 356 def updated_at @updated_at end |
Class Method Details
.confirm(requested_session, params = {}, opts = {}) ⇒ Object
Confirms a requested session
369 370 371 372 373 374 375 376 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 369 def self.confirm(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a requested session
379 380 381 382 383 384 385 386 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 379 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/delegated_checkout/requested_sessions", params: params, opts: opts ) end |
.expire(requested_session, params = {}, opts = {}) ⇒ Object
Expires a requested session
399 400 401 402 403 404 405 406 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 399 def self.expire(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
429 430 431 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 429 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
418 419 420 421 422 423 424 425 426 427 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 418 def self.inner_class_types @inner_class_types = { fulfillment_details: FulfillmentDetails, line_item_details: LineItemDetail, order_details: OrderDetails, payment_method_preview: PaymentMethodPreview, seller_details: SellerDetails, total_details: TotalDetails, } end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 12 def self.object_name "delegated_checkout.requested_session" end |
.update(requested_session, params = {}, opts = {}) ⇒ Object
Updates a requested session
409 410 411 412 413 414 415 416 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 409 def self.update(requested_session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s", { requested_session: CGI.escape(requested_session) }), params: params, opts: opts ) end |
Instance Method Details
#confirm(params = {}, opts = {}) ⇒ Object
Confirms a requested session
359 360 361 362 363 364 365 366 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 359 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#expire(params = {}, opts = {}) ⇒ Object
Expires a requested session
389 390 391 392 393 394 395 396 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 389 def expire(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |