Class: Stripe::DelegatedCheckout::RequestedSession

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/delegated_checkout/requested_session.rb

Overview

A requested session is a session that has been requested by a customer.

Defined Under Namespace

Classes: FulfillmentDetails, LineItemDetail, OrderDetails, PaymentMethodPreview, SellerDetails, TotalDetails

Constant Summary collapse

OBJECT_NAME =
"delegated_checkout.requested_session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_subtotalObject (readonly)

The subtotal amount of the requested session.



282
283
284
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 282

def amount_subtotal
  @amount_subtotal
end

#amount_totalObject (readonly)

The total amount of the requested session.



284
285
286
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 284

def amount_total
  @amount_total
end

#created_atObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



286
287
288
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 286

def created_at
  @created_at
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



288
289
290
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 288

def currency
  @currency
end

#customerObject (readonly)

The customer for this requested session.



290
291
292
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 290

def customer
  @customer
end

#expires_atObject (readonly)

Time at which the requested session expires. Measured in seconds since the Unix epoch.



292
293
294
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 292

def expires_at
  @expires_at
end

#fulfillment_detailsObject (readonly)

The details of the fulfillment.



294
295
296
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 294

def fulfillment_details
  @fulfillment_details
end

#idObject (readonly)

Unique identifier for the object.



296
297
298
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 296

def id
  @id
end

#line_item_detailsObject (readonly)

The line items to be purchased.



298
299
300
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 298

def line_item_details
  @line_item_details
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



300
301
302
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 300

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



302
303
304
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 302

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



304
305
306
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 304

def object
  @object
end

#order_detailsObject (readonly)

The details of the order.



306
307
308
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 306

def order_details
  @order_details
end

#payment_methodObject (readonly)

The payment method used for the requested session.



308
309
310
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 308

def payment_method
  @payment_method
end

#payment_method_previewObject (readonly)

The preview of the payment method to be created when the requested session is confirmed.



324
325
326
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 324

def payment_method_preview
  @payment_method_preview
end

#seller_detailsObject (readonly)

Attribute for field seller_details



310
311
312
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 310

def seller_details
  @seller_details
end

#setup_future_usageObject (readonly)

Whether or not the payment method should be saved for future use.



312
313
314
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 312

def setup_future_usage
  @setup_future_usage
end

#shared_metadataObject (readonly)

The metadata shared with the seller.



314
315
316
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 314

def 
  @shared_metadata
end

#shared_payment_issued_tokenObject (readonly)

The SPT used for payment.



316
317
318
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 316

def shared_payment_issued_token
  @shared_payment_issued_token
end

#statusObject (readonly)

The status of the requested session.



318
319
320
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 318

def status
  @status
end

#total_detailsObject (readonly)

Attribute for field total_details



320
321
322
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 320

def total_details
  @total_details
end

#updated_atObject (readonly)

Time at which the object was last updated. Measured in seconds since the Unix epoch.



322
323
324
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 322

def updated_at
  @updated_at
end

Class Method Details

.confirm(requested_session, params = {}, opts = {}) ⇒ Object

Confirms a requested session



337
338
339
340
341
342
343
344
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 337

def self.confirm(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a requested session



347
348
349
350
351
352
353
354
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 347

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/delegated_checkout/requested_sessions",
    params: params,
    opts: opts
  )
end

.expire(requested_session, params = {}, opts = {}) ⇒ Object

Expires a requested session



367
368
369
370
371
372
373
374
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 367

def self.expire(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



397
398
399
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 397

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



386
387
388
389
390
391
392
393
394
395
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 386

def self.inner_class_types
  @inner_class_types = {
    fulfillment_details: FulfillmentDetails,
    line_item_details: LineItemDetail,
    order_details: OrderDetails,
    seller_details: SellerDetails,
    total_details: TotalDetails,
    payment_method_preview: PaymentMethodPreview,
  }
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 12

def self.object_name
  "delegated_checkout.requested_session"
end

.update(requested_session, params = {}, opts = {}) ⇒ Object

Updates a requested session



377
378
379
380
381
382
383
384
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 377

def self.update(requested_session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s", { requested_session: CGI.escape(requested_session) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#confirm(params = {}, opts = {}) ⇒ Object

Confirms a requested session



327
328
329
330
331
332
333
334
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 327

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/confirm", { requested_session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#expire(params = {}, opts = {}) ⇒ Object

Expires a requested session



357
358
359
360
361
362
363
364
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 357

def expire(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/delegated_checkout/requested_sessions/%<requested_session>s/expire", { requested_session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end