Class: Stripe::DelegatedCheckout::RequestedSession::AffiliateAttribution
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::AffiliateAttribution
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Defined Under Namespace
Classes: Source
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#campaign_id ⇒ Object
readonly
Agent-scoped campaign identifier.
-
#creative_id ⇒ Object
readonly
Agent-scoped creative identifier.
-
#expires_at ⇒ Object
readonly
Timestamp when the attribution token expires.
-
#identification_token ⇒ Object
readonly
Agent-issued secret to validate the legitimacy of the source of this data.
-
#issued_at ⇒ Object
readonly
Timestamp for when the attribution token was issued.
-
#provider ⇒ Object
readonly
Identifier for the attribution agent / affiliate network namespace.
-
#publisher_id ⇒ Object
readonly
Agent-scoped affiliate/publisher identifier.
-
#shared_metadata ⇒ Object
readonly
Freeform key/value pairs for additional non-sensitive per-agent data.
-
#source ⇒ Object
readonly
Context about where the attribution originated.
-
#sub_id ⇒ Object
readonly
Agent-scoped sub-tracking identifier.
-
#touchpoint ⇒ Object
readonly
Whether this is the first or last touchpoint.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#campaign_id ⇒ Object (readonly)
Agent-scoped campaign identifier.
476 477 478 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 476 def campaign_id @campaign_id end |
#creative_id ⇒ Object (readonly)
Agent-scoped creative identifier.
478 479 480 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 478 def creative_id @creative_id end |
#expires_at ⇒ Object (readonly)
Timestamp when the attribution token expires.
480 481 482 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 480 def expires_at @expires_at end |
#identification_token ⇒ Object (readonly)
Agent-issued secret to validate the legitimacy of the source of this data.
482 483 484 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 482 def identification_token @identification_token end |
#issued_at ⇒ Object (readonly)
Timestamp for when the attribution token was issued.
484 485 486 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 484 def issued_at @issued_at end |
#provider ⇒ Object (readonly)
Identifier for the attribution agent / affiliate network namespace.
486 487 488 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 486 def provider @provider end |
#publisher_id ⇒ Object (readonly)
Agent-scoped affiliate/publisher identifier.
488 489 490 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 488 def publisher_id @publisher_id end |
#shared_metadata ⇒ Object (readonly)
Freeform key/value pairs for additional non-sensitive per-agent data.
490 491 492 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 490 def @shared_metadata end |
#source ⇒ Object (readonly)
Context about where the attribution originated.
492 493 494 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 492 def source @source end |
#sub_id ⇒ Object (readonly)
Agent-scoped sub-tracking identifier.
494 495 496 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 494 def sub_id @sub_id end |
#touchpoint ⇒ Object (readonly)
Whether this is the first or last touchpoint.
496 497 498 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 496 def touchpoint @touchpoint end |
Class Method Details
.field_remappings ⇒ Object
502 503 504 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 502 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
498 499 500 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 498 def self.inner_class_types @inner_class_types = { source: Source } end |