Class: Stripe::DelegatedCheckout::RequestedSession::FulfillmentDetails::FulfillmentOption::Digital::DigitalOption
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::FulfillmentDetails::FulfillmentOption::Digital::DigitalOption
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
The description of the digital fulfillment option.
-
#digital_amount ⇒ Object
readonly
The digital amount of the digital fulfillment option.
-
#display_name ⇒ Object
readonly
The display name of the digital fulfillment option.
-
#key ⇒ Object
readonly
The key of the digital fulfillment option.
-
#line_item_keys ⇒ Object
readonly
The line item keys associated with this digital fulfillment option.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
The description of the digital fulfillment option.
134 135 136 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 134 def description @description end |
#digital_amount ⇒ Object (readonly)
The digital amount of the digital fulfillment option.
136 137 138 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 136 def digital_amount @digital_amount end |
#display_name ⇒ Object (readonly)
The display name of the digital fulfillment option.
138 139 140 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 138 def display_name @display_name end |
#key ⇒ Object (readonly)
The key of the digital fulfillment option.
140 141 142 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 140 def key @key end |
#line_item_keys ⇒ Object (readonly)
The line item keys associated with this digital fulfillment option.
142 143 144 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 142 def line_item_keys @line_item_keys end |
Class Method Details
.field_remappings ⇒ Object
148 149 150 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 148 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
144 145 146 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 144 def self.inner_class_types @inner_class_types = {} end |