Class: Stripe::DelegatedCheckout::RequestedSession::FulfillmentDetails::FulfillmentOption::Shipping::ShippingOption
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::FulfillmentDetails::FulfillmentOption::Shipping::ShippingOption
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
The description of the shipping option.
-
#display_name ⇒ Object
readonly
The display name of the shipping option.
-
#earliest_delivery_time ⇒ Object
readonly
The earliest delivery time of the shipping option.
-
#key ⇒ Object
readonly
The key of the shipping option.
-
#latest_delivery_time ⇒ Object
readonly
The latest delivery time of the shipping option.
-
#line_item_keys ⇒ Object
readonly
The line item keys associated with this shipping option.
-
#shipping_amount ⇒ Object
readonly
The shipping amount of the shipping option.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
The description of the shipping option.
167 168 169 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 167 def description @description end |
#display_name ⇒ Object (readonly)
The display name of the shipping option.
169 170 171 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 169 def display_name @display_name end |
#earliest_delivery_time ⇒ Object (readonly)
The earliest delivery time of the shipping option.
171 172 173 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 171 def earliest_delivery_time @earliest_delivery_time end |
#key ⇒ Object (readonly)
The key of the shipping option.
173 174 175 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 173 def key @key end |
#latest_delivery_time ⇒ Object (readonly)
The latest delivery time of the shipping option.
175 176 177 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 175 def latest_delivery_time @latest_delivery_time end |
#line_item_keys ⇒ Object (readonly)
The line item keys associated with this shipping option.
177 178 179 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 177 def line_item_keys @line_item_keys end |
#shipping_amount ⇒ Object (readonly)
The shipping amount of the shipping option.
179 180 181 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 179 def shipping_amount @shipping_amount end |
Class Method Details
.field_remappings ⇒ Object
185 186 187 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 185 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
181 182 183 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 181 def self.inner_class_types @inner_class_types = {} end |