Class: Stripe::DelegatedCheckout::RequestedSession::FulfillmentDetails::FulfillmentOption::Shipping::ShippingOption
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::FulfillmentDetails::FulfillmentOption::Shipping::ShippingOption
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
The description of the shipping option.
-
#display_name ⇒ Object
readonly
The display name of the shipping option.
-
#earliest_delivery_time ⇒ Object
readonly
The earliest delivery time of the shipping option.
-
#key ⇒ Object
readonly
The key of the shipping option.
-
#latest_delivery_time ⇒ Object
readonly
The latest delivery time of the shipping option.
-
#line_item_keys ⇒ Object
readonly
The line item keys associated with this shipping option.
-
#shipping_amount ⇒ Object
readonly
The shipping amount of the shipping option.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#description ⇒ Object (readonly)
The description of the shipping option.
126 127 128 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 126 def description @description end |
#display_name ⇒ Object (readonly)
The display name of the shipping option.
128 129 130 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 128 def display_name @display_name end |
#earliest_delivery_time ⇒ Object (readonly)
The earliest delivery time of the shipping option.
130 131 132 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 130 def earliest_delivery_time @earliest_delivery_time end |
#key ⇒ Object (readonly)
The key of the shipping option.
132 133 134 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 132 def key @key end |
#latest_delivery_time ⇒ Object (readonly)
The latest delivery time of the shipping option.
134 135 136 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 134 def latest_delivery_time @latest_delivery_time end |
#line_item_keys ⇒ Object (readonly)
The line item keys associated with this shipping option.
136 137 138 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 136 def line_item_keys @line_item_keys end |
#shipping_amount ⇒ Object (readonly)
The shipping amount of the shipping option.
138 139 140 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 138 def shipping_amount @shipping_amount end |
Class Method Details
.field_remappings ⇒ Object
144 145 146 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 144 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
140 141 142 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 140 def self.inner_class_types @inner_class_types = {} end |