Class: Stripe::DelegatedCheckout::RequestedSession::LineItemDetail
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::LineItemDetail
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Defined Under Namespace
Classes: ProductDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_discount ⇒ Object
readonly
The total discount for this line item.
-
#amount_sale ⇒ Object
readonly
The sale amount for this line item.
-
#amount_subtotal ⇒ Object
readonly
The total before any discounts or taxes are applied.
-
#fulfillment_type ⇒ Object
readonly
The fulfillment type of the line item.
-
#key ⇒ Object
readonly
The key of the line item.
-
#product_details ⇒ Object
readonly
Attribute for field product_details.
-
#quantity ⇒ Object
readonly
The quantity of the line item.
-
#sku_id ⇒ Object
readonly
The SKU ID of the line item.
-
#unit_amount ⇒ Object
readonly
The per-unit amount of the item before any discounts or taxes are applied.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_discount ⇒ Object (readonly)
The total discount for this line item. If no discount were applied, defaults to 0.
454 455 456 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 454 def amount_discount @amount_discount end |
#amount_sale ⇒ Object (readonly)
The sale amount for this line item.
456 457 458 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 456 def amount_sale @amount_sale end |
#amount_subtotal ⇒ Object (readonly)
The total before any discounts or taxes are applied.
458 459 460 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 458 def amount_subtotal @amount_subtotal end |
#fulfillment_type ⇒ Object (readonly)
The fulfillment type of the line item.
460 461 462 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 460 def fulfillment_type @fulfillment_type end |
#key ⇒ Object (readonly)
The key of the line item.
462 463 464 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 462 def key @key end |
#product_details ⇒ Object (readonly)
Attribute for field product_details
464 465 466 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 464 def product_details @product_details end |
#quantity ⇒ Object (readonly)
The quantity of the line item.
466 467 468 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 466 def quantity @quantity end |
#sku_id ⇒ Object (readonly)
The SKU ID of the line item.
468 469 470 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 468 def sku_id @sku_id end |
#unit_amount ⇒ Object (readonly)
The per-unit amount of the item before any discounts or taxes are applied.
470 471 472 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 470 def unit_amount @unit_amount end |
Class Method Details
.field_remappings ⇒ Object
476 477 478 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 476 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
472 473 474 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 472 def self.inner_class_types @inner_class_types = { product_details: ProductDetails } end |