Class: Stripe::DelegatedCheckout::RequestedSession::LineItemDetail

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/delegated_checkout/requested_session.rb

Defined Under Namespace

Classes: ProductDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_discountObject (readonly)

The total discount for this line item. If no discount were applied, defaults to 0.



342
343
344
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 342

def amount_discount
  @amount_discount
end

#amount_subtotalObject (readonly)

The total before any discounts or taxes are applied.



344
345
346
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 344

def amount_subtotal
  @amount_subtotal
end

#fulfillment_typeObject (readonly)

The fulfillment type of the line item.



346
347
348
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 346

def fulfillment_type
  @fulfillment_type
end

#keyObject (readonly)

The key of the line item.



348
349
350
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 348

def key
  @key
end

#product_detailsObject (readonly)

Attribute for field product_details



350
351
352
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 350

def product_details
  @product_details
end

#quantityObject (readonly)

The quantity of the line item.



352
353
354
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 352

def quantity
  @quantity
end

#sku_idObject (readonly)

The SKU ID of the line item.



354
355
356
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 354

def sku_id
  @sku_id
end

#unit_amountObject (readonly)

The per-unit amount of the item before any discounts or taxes are applied.



356
357
358
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 356

def unit_amount
  @unit_amount
end

Class Method Details

.field_remappingsObject



362
363
364
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 362

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



358
359
360
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 358

def self.inner_class_types
  @inner_class_types = { product_details: ProductDetails }
end