Class: Stripe::DelegatedCheckout::RequestedSession::LineItemDetail
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::LineItemDetail
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_discount ⇒ Object
readonly
The total discount for this line item.
-
#amount_subtotal ⇒ Object
readonly
The total before any discounts or taxes are applied.
-
#description ⇒ Object
readonly
The description of the line item.
-
#images ⇒ Object
readonly
The images of the line item.
-
#key ⇒ Object
readonly
The key of the line item.
-
#name ⇒ Object
readonly
The name of the line item.
-
#quantity ⇒ Object
readonly
The quantity of the line item.
-
#sku_id ⇒ Object
readonly
The SKU ID of the line item.
-
#unit_amount ⇒ Object
readonly
The per-unit amount of the item before any discounts or taxes are applied.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_discount ⇒ Object (readonly)
The total discount for this line item. If no discount were applied, defaults to 0.
157 158 159 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 157 def amount_discount @amount_discount end |
#amount_subtotal ⇒ Object (readonly)
The total before any discounts or taxes are applied.
159 160 161 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 159 def amount_subtotal @amount_subtotal end |
#description ⇒ Object (readonly)
The description of the line item.
143 144 145 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 143 def description @description end |
#images ⇒ Object (readonly)
The images of the line item.
145 146 147 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 145 def images @images end |
#key ⇒ Object (readonly)
The key of the line item.
147 148 149 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 147 def key @key end |
#name ⇒ Object (readonly)
The name of the line item.
149 150 151 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 149 def name @name end |
#quantity ⇒ Object (readonly)
The quantity of the line item.
151 152 153 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 151 def quantity @quantity end |
#sku_id ⇒ Object (readonly)
The SKU ID of the line item.
153 154 155 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 153 def sku_id @sku_id end |
#unit_amount ⇒ Object (readonly)
The per-unit amount of the item before any discounts or taxes are applied.
155 156 157 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 155 def unit_amount @unit_amount end |
Class Method Details
.field_remappings ⇒ Object
165 166 167 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 165 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
161 162 163 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 161 def self.inner_class_types @inner_class_types = {} end |