Class: Stripe::DelegatedCheckout::RequestedSession::RiskDetails::ClientDeviceMetadataDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::RiskDetails::ClientDeviceMetadataDetails
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#radar_session ⇒ Object
readonly
The radar session for the client device.
-
#referrer ⇒ Object
readonly
The referrer of the client device.
-
#remote_ip ⇒ Object
readonly
The remote IP address of the client device.
-
#time_on_page_ms ⇒ Object
readonly
The time spent on the page by the client device.
-
#user_agent ⇒ Object
readonly
The user agent of the client device.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#radar_session ⇒ Object (readonly)
The radar session for the client device.
356 357 358 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 356 def radar_session @radar_session end |
#referrer ⇒ Object (readonly)
The referrer of the client device.
358 359 360 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 358 def referrer @referrer end |
#remote_ip ⇒ Object (readonly)
The remote IP address of the client device.
360 361 362 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 360 def remote_ip @remote_ip end |
#time_on_page_ms ⇒ Object (readonly)
The time spent on the page by the client device.
362 363 364 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 362 def time_on_page_ms @time_on_page_ms end |
#user_agent ⇒ Object (readonly)
The user agent of the client device.
364 365 366 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 364 def user_agent @user_agent end |
Class Method Details
.field_remappings ⇒ Object
370 371 372 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 370 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
366 367 368 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 366 def self.inner_class_types @inner_class_types = {} end |