Class: Stripe::DelegatedCheckout::RequestedSession::TotalDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::TotalDetails
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Defined Under Namespace
Classes: ApplicableFee, Breakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_cart_discount ⇒ Object
readonly
The amount of order-level discounts applied to the cart.
-
#amount_discount ⇒ Object
readonly
The total discount amount from discount codes across the session.
-
#amount_fulfillment ⇒ Object
readonly
The amount fulfillment of the total details.
-
#amount_items_discount ⇒ Object
readonly
The amount of item-level discounts applied to the cart.
-
#amount_sale ⇒ Object
readonly
The total sale amount across the session.
-
#amount_tax ⇒ Object
readonly
The amount tax of the total details.
-
#applicable_fees ⇒ Object
readonly
The applicable fees of the total details.
-
#breakdown ⇒ Object
readonly
The breakdown of discounts applied to the session.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_cart_discount ⇒ Object (readonly)
The amount of order-level discounts applied to the cart. The total discount amount for this session can be computed by summing the cart discount and the item discounts.
715 716 717 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 715 def amount_cart_discount @amount_cart_discount end |
#amount_discount ⇒ Object (readonly)
The total discount amount from discount codes across the session.
717 718 719 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 717 def amount_discount @amount_discount end |
#amount_fulfillment ⇒ Object (readonly)
The amount fulfillment of the total details.
719 720 721 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 719 def amount_fulfillment @amount_fulfillment end |
#amount_items_discount ⇒ Object (readonly)
The amount of item-level discounts applied to the cart. The total discount amount for this session can be computed by summing the cart discount and the item discounts.
721 722 723 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 721 def amount_items_discount @amount_items_discount end |
#amount_sale ⇒ Object (readonly)
The total sale amount across the session.
723 724 725 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 723 def amount_sale @amount_sale end |
#amount_tax ⇒ Object (readonly)
The amount tax of the total details.
725 726 727 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 725 def amount_tax @amount_tax end |
#applicable_fees ⇒ Object (readonly)
The applicable fees of the total details.
727 728 729 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 727 def applicable_fees @applicable_fees end |
#breakdown ⇒ Object (readonly)
The breakdown of discounts applied to the session.
729 730 731 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 729 def breakdown @breakdown end |
Class Method Details
.field_remappings ⇒ Object
735 736 737 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 735 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
731 732 733 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 731 def self.inner_class_types @inner_class_types = { applicable_fees: ApplicableFee, breakdown: Breakdown } end |