Class: Stripe::DelegatedCheckout::RequestedSession::TotalDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::DelegatedCheckout::RequestedSession::TotalDetails
- Defined in:
- lib/stripe/resources/delegated_checkout/requested_session.rb
Defined Under Namespace
Classes: ApplicableFee
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_cart_discount ⇒ Object
readonly
The amount of order-level discounts applied to the cart.
-
#amount_fulfillment ⇒ Object
readonly
The amount fulfillment of the total details.
-
#amount_items_discount ⇒ Object
readonly
The amount of item-level discounts applied to the cart.
-
#amount_tax ⇒ Object
readonly
The amount tax of the total details.
-
#applicable_fees ⇒ Object
readonly
The applicable fees of the total details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_cart_discount ⇒ Object (readonly)
The amount of order-level discounts applied to the cart. The total discount amount for this session can be computed by summing the cart discount and the item discounts.
543 544 545 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 543 def amount_cart_discount @amount_cart_discount end |
#amount_fulfillment ⇒ Object (readonly)
The amount fulfillment of the total details.
545 546 547 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 545 def amount_fulfillment @amount_fulfillment end |
#amount_items_discount ⇒ Object (readonly)
The amount of item-level discounts applied to the cart. The total discount amount for this session can be computed by summing the cart discount and the item discounts.
547 548 549 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 547 def amount_items_discount @amount_items_discount end |
#amount_tax ⇒ Object (readonly)
The amount tax of the total details.
549 550 551 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 549 def amount_tax @amount_tax end |
#applicable_fees ⇒ Object (readonly)
The applicable fees of the total details.
551 552 553 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 551 def applicable_fees @applicable_fees end |
Class Method Details
.field_remappings ⇒ Object
557 558 559 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 557 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
553 554 555 |
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 553 def self.inner_class_types @inner_class_types = { applicable_fees: ApplicableFee } end |