Class: Stripe::DelegatedCheckout::RequestedSession::TotalDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/delegated_checkout/requested_session.rb

Defined Under Namespace

Classes: ApplicableFee

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_cart_discountObject (readonly)

The amount of order-level discounts applied to the cart. The total discount amount for this session can be computed by summing the cart discount and the item discounts.



367
368
369
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 367

def amount_cart_discount
  @amount_cart_discount
end

#amount_fulfillmentObject (readonly)

The amount fulfillment of the total details.



369
370
371
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 369

def amount_fulfillment
  @amount_fulfillment
end

#amount_items_discountObject (readonly)

The amount of item-level discounts applied to the cart. The total discount amount for this session can be computed by summing the cart discount and the item discounts.



371
372
373
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 371

def amount_items_discount
  @amount_items_discount
end

#amount_taxObject (readonly)

The amount tax of the total details.



373
374
375
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 373

def amount_tax
  @amount_tax
end

#applicable_feesObject (readonly)

The applicable fees of the total details.



375
376
377
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 375

def applicable_fees
  @applicable_fees
end

Class Method Details

.field_remappingsObject



381
382
383
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 381

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



377
378
379
# File 'lib/stripe/resources/delegated_checkout/requested_session.rb', line 377

def self.inner_class_types
  @inner_class_types = { applicable_fees: ApplicableFee }
end