Class: Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb
Defined Under Namespace
Classes: AffiliateAttribution, BuyerConsents, RiskDetails
Instance Attribute Summary collapse
-
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
-
#buyer_consents ⇒ Object
The buyer’s consent choices for marketing communications.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
The metadata for this requested session.
-
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or complete a payment action.
-
#risk_details ⇒ Object
Risk details/signals associated with the requested session.
Instance Method Summary collapse
-
#initialize(affiliate_attribution: nil, buyer_consents: nil, expand: nil, metadata: nil, payment_method: nil, return_url: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
constructor
A new instance of RequestedSessionConfirmParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_attribution: nil, buyer_consents: nil, expand: nil, metadata: nil, payment_method: nil, return_url: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
Returns a new instance of RequestedSessionConfirmParams.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 149 def initialize( affiliate_attribution: nil, buyer_consents: nil, expand: nil, metadata: nil, payment_method: nil, return_url: nil, risk_details: nil ) @affiliate_attribution = affiliate_attribution @buyer_consents = @expand = @metadata = @payment_method = payment_method @return_url = return_url @risk_details = risk_details end |
Instance Attribute Details
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
135 136 137 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 135 def affiliate_attribution @affiliate_attribution end |
#buyer_consents ⇒ Object
The buyer’s consent choices for marketing communications.
137 138 139 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 137 def @buyer_consents end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
139 140 141 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 139 def @expand end |
#metadata ⇒ Object
The metadata for this requested session.
141 142 143 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 141 def @metadata end |
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
143 144 145 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 143 def payment_method @payment_method end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or complete a payment action. Required for redirect-based payment methods such as Affirm or Klarna.
145 146 147 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 145 def return_url @return_url end |
#risk_details ⇒ Object
Risk details/signals associated with the requested session
147 148 149 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 147 def risk_details @risk_details end |