Class: Stripe::DelegatedCheckout::RequestedSessionConfirmParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb

Defined Under Namespace

Classes: AffiliateAttribution, RiskDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(affiliate_attribution: nil, expand: nil, payment_method: nil, return_url: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams

Returns a new instance of RequestedSessionConfirmParams.



117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 117

def initialize(
  affiliate_attribution: nil,
  expand: nil,
  payment_method: nil,
  return_url: nil,
  risk_details: nil
)
  @affiliate_attribution = affiliate_attribution
  @expand = expand
  @payment_method = payment_method
  @return_url = return_url
  @risk_details = risk_details
end

Instance Attribute Details

#affiliate_attributionObject

Affiliate attribution data associated with this requested session.



107
108
109
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 107

def affiliate_attribution
  @affiliate_attribution
end

#expandObject

Specifies which fields in the response should be expanded.



109
110
111
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 109

def expand
  @expand
end

#payment_methodObject

The PaymentMethod to use with the requested session.



111
112
113
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 111

def payment_method
  @payment_method
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or complete a payment action. Required for redirect-based payment methods such as Affirm or Klarna.



113
114
115
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 113

def return_url
  @return_url
end

#risk_detailsObject

Risk details/signals associated with the requested session



115
116
117
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 115

def risk_details
  @risk_details
end