Class: Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb
Defined Under Namespace
Classes: AffiliateAttribution, PaymentMethodData, RiskDetails
Instance Attribute Summary collapse
-
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
-
#payment_method_data ⇒ Object
The payment method data for this requested session.
-
#risk_details ⇒ Object
Risk details/signals associated with the requested session.
Instance Method Summary collapse
-
#initialize(affiliate_attribution: nil, expand: nil, payment_method: nil, payment_method_data: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
constructor
A new instance of RequestedSessionConfirmParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_attribution: nil, expand: nil, payment_method: nil, payment_method_data: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
Returns a new instance of RequestedSessionConfirmParams.
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 197 def initialize( affiliate_attribution: nil, expand: nil, payment_method: nil, payment_method_data: nil, risk_details: nil ) @affiliate_attribution = affiliate_attribution @expand = @payment_method = payment_method @payment_method_data = payment_method_data @risk_details = risk_details end |
Instance Attribute Details
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
187 188 189 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 187 def affiliate_attribution @affiliate_attribution end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
189 190 191 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 189 def @expand end |
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
191 192 193 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 191 def payment_method @payment_method end |
#payment_method_data ⇒ Object
The payment method data for this requested session.
193 194 195 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 193 def payment_method_data @payment_method_data end |
#risk_details ⇒ Object
Risk details/signals associated with the requested session
195 196 197 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 195 def risk_details @risk_details end |