Class: Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb
Defined Under Namespace
Classes: AffiliateAttribution, RiskDetails
Instance Attribute Summary collapse
-
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
-
#risk_details ⇒ Object
Risk details/signals associated with the requested session.
Instance Method Summary collapse
-
#initialize(affiliate_attribution: nil, expand: nil, payment_method: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
constructor
A new instance of RequestedSessionConfirmParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_attribution: nil, expand: nil, payment_method: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
Returns a new instance of RequestedSessionConfirmParams.
115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 115 def initialize( affiliate_attribution: nil, expand: nil, payment_method: nil, risk_details: nil ) @affiliate_attribution = affiliate_attribution @expand = @payment_method = payment_method @risk_details = risk_details end |
Instance Attribute Details
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
107 108 109 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 107 def affiliate_attribution @affiliate_attribution end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
109 110 111 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 109 def @expand end |
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
111 112 113 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 111 def payment_method @payment_method end |
#risk_details ⇒ Object
Risk details/signals associated with the requested session
113 114 115 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 113 def risk_details @risk_details end |