Class: Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb
Defined Under Namespace
Classes: PaymentMethodData, RiskDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
-
#payment_method_data ⇒ Object
The payment method data for this requested session.
-
#risk_details ⇒ Object
Risk details/signals associated with the requested session.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
constructor
A new instance of RequestedSessionConfirmParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_method: nil, payment_method_data: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
Returns a new instance of RequestedSessionConfirmParams.
130 131 132 133 134 135 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 130 def initialize(expand: nil, payment_method: nil, payment_method_data: nil, risk_details: nil) @expand = @payment_method = payment_method @payment_method_data = payment_method_data @risk_details = risk_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
122 123 124 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 122 def @expand end |
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
124 125 126 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 124 def payment_method @payment_method end |
#payment_method_data ⇒ Object
The payment method data for this requested session.
126 127 128 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 126 def payment_method_data @payment_method_data end |
#risk_details ⇒ Object
Risk details/signals associated with the requested session
128 129 130 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 128 def risk_details @risk_details end |