Class: Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb
Defined Under Namespace
Classes: RiskDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
-
#risk_details ⇒ Object
Risk details/signals associated with the requested session.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_method: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
constructor
A new instance of RequestedSessionConfirmParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_method: nil, risk_details: nil) ⇒ RequestedSessionConfirmParams
Returns a new instance of RequestedSessionConfirmParams.
48 49 50 51 52 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 48 def initialize(expand: nil, payment_method: nil, risk_details: nil) @expand = @payment_method = payment_method @risk_details = risk_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
42 43 44 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 42 def @expand end |
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
44 45 46 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 44 def payment_method @payment_method end |
#risk_details ⇒ Object
Risk details/signals associated with the requested session
46 47 48 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 46 def risk_details @risk_details end |