Class: Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionConfirmParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_method: nil) ⇒ RequestedSessionConfirmParams
constructor
A new instance of RequestedSessionConfirmParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_method: nil) ⇒ RequestedSessionConfirmParams
Returns a new instance of RequestedSessionConfirmParams.
12 13 14 15 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 12 def initialize(expand: nil, payment_method: nil) @expand = @payment_method = payment_method end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 8 def @expand end |
#payment_method ⇒ Object
The PaymentMethod to use with the requested session.
10 11 12 |
# File 'lib/stripe/params/delegated_checkout/requested_session_confirm_params.rb', line 10 def payment_method @payment_method end |