Class: Stripe::DelegatedCheckout::RequestedSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionCreateParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_create_params.rb
Defined Under Namespace
Classes: AffiliateAttribution, FulfillmentDetails, LineItemDetail, PaymentMethodOptions, SellerDetails
Instance Attribute Summary collapse
-
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
-
#currency ⇒ Object
The currency for this requested session.
-
#customer ⇒ Object
The customer for this requested session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fulfillment_details ⇒ Object
The details of the fulfillment.
-
#line_item_details ⇒ Object
The details of the line items.
-
#metadata ⇒ Object
The metadata for this requested session.
-
#payment_method ⇒ Object
The payment method for this requested session.
-
#payment_method_options ⇒ Object
The payment method options for this requested session.
-
#seller_details ⇒ Object
The details of the seller.
-
#setup_future_usage ⇒ Object
The setup future usage for this requested session.
-
#shared_metadata ⇒ Object
The shared metadata for this requested session.
Instance Method Summary collapse
-
#initialize(affiliate_attribution: nil, currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_options: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil) ⇒ RequestedSessionCreateParams
constructor
A new instance of RequestedSessionCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_attribution: nil, currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_options: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil) ⇒ RequestedSessionCreateParams
Returns a new instance of RequestedSessionCreateParams.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 185 def initialize( affiliate_attribution: nil, currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_options: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil ) @affiliate_attribution = affiliate_attribution @currency = currency @customer = customer @expand = @fulfillment_details = fulfillment_details @line_item_details = line_item_details @metadata = @payment_method = payment_method @payment_method_options = @seller_details = seller_details @setup_future_usage = setup_future_usage @shared_metadata = end |
Instance Attribute Details
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
161 162 163 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 161 def affiliate_attribution @affiliate_attribution end |
#currency ⇒ Object
The currency for this requested session.
163 164 165 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 163 def currency @currency end |
#customer ⇒ Object
The customer for this requested session.
165 166 167 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 165 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
167 168 169 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 167 def @expand end |
#fulfillment_details ⇒ Object
The details of the fulfillment.
169 170 171 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 169 def fulfillment_details @fulfillment_details end |
#line_item_details ⇒ Object
The details of the line items.
171 172 173 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 171 def line_item_details @line_item_details end |
#metadata ⇒ Object
The metadata for this requested session.
173 174 175 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 173 def @metadata end |
#payment_method ⇒ Object
The payment method for this requested session.
175 176 177 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 175 def payment_method @payment_method end |
#payment_method_options ⇒ Object
The payment method options for this requested session.
177 178 179 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 177 def @payment_method_options end |
#seller_details ⇒ Object
The details of the seller.
179 180 181 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 179 def seller_details @seller_details end |
#setup_future_usage ⇒ Object
The setup future usage for this requested session.
181 182 183 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 181 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object
The shared metadata for this requested session.
183 184 185 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 183 def @shared_metadata end |