Class: Stripe::DelegatedCheckout::RequestedSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionCreateParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_create_params.rb
Defined Under Namespace
Classes: AffiliateAttribution, FulfillmentDetails, LineItemDetail, PaymentMethodData, SellerDetails
Instance Attribute Summary collapse
-
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
-
#currency ⇒ Object
The currency for this requested session.
-
#customer ⇒ Object
The customer for this requested session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fulfillment_details ⇒ Object
The details of the fulfillment.
-
#line_item_details ⇒ Object
The details of the line items.
-
#metadata ⇒ Object
The metadata for this requested session.
-
#payment_method ⇒ Object
The payment method for this requested session.
-
#payment_method_data ⇒ Object
The payment method data for this requested session.
-
#seller_details ⇒ Object
The details of the seller.
-
#setup_future_usage ⇒ Object
The setup future usage for this requested session.
-
#shared_metadata ⇒ Object
The shared metadata for this requested session.
Instance Method Summary collapse
-
#initialize(affiliate_attribution: nil, currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil) ⇒ RequestedSessionCreateParams
constructor
A new instance of RequestedSessionCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_attribution: nil, currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil) ⇒ RequestedSessionCreateParams
Returns a new instance of RequestedSessionCreateParams.
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 245 def initialize( affiliate_attribution: nil, currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil ) @affiliate_attribution = affiliate_attribution @currency = currency @customer = customer @expand = @fulfillment_details = fulfillment_details @line_item_details = line_item_details @metadata = @payment_method = payment_method @payment_method_data = payment_method_data @seller_details = seller_details @setup_future_usage = setup_future_usage @shared_metadata = end |
Instance Attribute Details
#affiliate_attribution ⇒ Object
Affiliate attribution data associated with this requested session.
221 222 223 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 221 def affiliate_attribution @affiliate_attribution end |
#currency ⇒ Object
The currency for this requested session.
223 224 225 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 223 def currency @currency end |
#customer ⇒ Object
The customer for this requested session.
225 226 227 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 225 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
227 228 229 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 227 def @expand end |
#fulfillment_details ⇒ Object
The details of the fulfillment.
229 230 231 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 229 def fulfillment_details @fulfillment_details end |
#line_item_details ⇒ Object
The details of the line items.
231 232 233 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 231 def line_item_details @line_item_details end |
#metadata ⇒ Object
The metadata for this requested session.
233 234 235 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 233 def @metadata end |
#payment_method ⇒ Object
The payment method for this requested session.
235 236 237 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 235 def payment_method @payment_method end |
#payment_method_data ⇒ Object
The payment method data for this requested session.
237 238 239 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 237 def payment_method_data @payment_method_data end |
#seller_details ⇒ Object
The details of the seller.
239 240 241 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 239 def seller_details @seller_details end |
#setup_future_usage ⇒ Object
The setup future usage for this requested session.
241 242 243 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 241 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object
The shared metadata for this requested session.
243 244 245 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 243 def @shared_metadata end |