Class: Stripe::DelegatedCheckout::RequestedSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionCreateParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_create_params.rb
Defined Under Namespace
Classes: FulfillmentDetails, LineItemDetail, PaymentMethodData, SellerDetails
Instance Attribute Summary collapse
-
#currency ⇒ Object
The currency for this requested session.
-
#customer ⇒ Object
The customer for this requested session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fulfillment_details ⇒ Object
The details of the fulfillment.
-
#line_item_details ⇒ Object
The details of the line items.
-
#metadata ⇒ Object
The metadata for this requested session.
-
#payment_method ⇒ Object
The payment method for this requested session.
-
#payment_method_data ⇒ Object
The payment method data for this requested session.
-
#seller_details ⇒ Object
The details of the seller.
-
#setup_future_usage ⇒ Object
The setup future usage for this requested session.
-
#shared_metadata ⇒ Object
The shared metadata for this requested session.
Instance Method Summary collapse
-
#initialize(currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil) ⇒ RequestedSessionCreateParams
constructor
A new instance of RequestedSessionCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil) ⇒ RequestedSessionCreateParams
Returns a new instance of RequestedSessionCreateParams.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 178 def initialize( currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil ) @currency = currency @customer = customer @expand = @fulfillment_details = fulfillment_details @line_item_details = line_item_details @metadata = @payment_method = payment_method @payment_method_data = payment_method_data @seller_details = seller_details @setup_future_usage = setup_future_usage @shared_metadata = end |
Instance Attribute Details
#currency ⇒ Object
The currency for this requested session.
156 157 158 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 156 def currency @currency end |
#customer ⇒ Object
The customer for this requested session.
158 159 160 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 158 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
160 161 162 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 160 def @expand end |
#fulfillment_details ⇒ Object
The details of the fulfillment.
162 163 164 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 162 def fulfillment_details @fulfillment_details end |
#line_item_details ⇒ Object
The details of the line items.
164 165 166 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 164 def line_item_details @line_item_details end |
#metadata ⇒ Object
The metadata for this requested session.
166 167 168 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 166 def @metadata end |
#payment_method ⇒ Object
The payment method for this requested session.
168 169 170 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 168 def payment_method @payment_method end |
#payment_method_data ⇒ Object
The payment method data for this requested session.
170 171 172 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 170 def payment_method_data @payment_method_data end |
#seller_details ⇒ Object
The details of the seller.
172 173 174 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 172 def seller_details @seller_details end |
#setup_future_usage ⇒ Object
The setup future usage for this requested session.
174 175 176 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 174 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object
The shared metadata for this requested session.
176 177 178 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 176 def @shared_metadata end |