Class: Stripe::DelegatedCheckout::RequestedSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionCreateParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_create_params.rb
Defined Under Namespace
Classes: FulfillmentDetails, LineItemDetail, PaymentMethodData, RiskDetails, SellerDetails
Instance Attribute Summary collapse
-
#currency ⇒ Object
The currency for this requested session.
-
#customer ⇒ Object
The customer for this requested session.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fulfillment_details ⇒ Object
The details of the fulfillment.
-
#line_item_details ⇒ Object
The details of the line items.
-
#metadata ⇒ Object
The metadata for this requested session.
-
#payment_method ⇒ Object
The payment method for this requested session.
-
#payment_method_data ⇒ Object
The payment method data for this requested session.
-
#risk_details ⇒ Object
The risk details for this requested session.
-
#seller_details ⇒ Object
The details of the seller.
-
#setup_future_usage ⇒ Object
The setup future usage for this requested session.
-
#shared_metadata ⇒ Object
The shared metadata for this requested session.
Instance Method Summary collapse
-
#initialize(currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, risk_details: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil) ⇒ RequestedSessionCreateParams
constructor
A new instance of RequestedSessionCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, risk_details: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil) ⇒ RequestedSessionCreateParams
Returns a new instance of RequestedSessionCreateParams.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 215 def initialize( currency: nil, customer: nil, expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, risk_details: nil, seller_details: nil, setup_future_usage: nil, shared_metadata: nil ) @currency = currency @customer = customer @expand = @fulfillment_details = fulfillment_details @line_item_details = line_item_details @metadata = @payment_method = payment_method @payment_method_data = payment_method_data @risk_details = risk_details @seller_details = seller_details @setup_future_usage = setup_future_usage @shared_metadata = end |
Instance Attribute Details
#currency ⇒ Object
The currency for this requested session.
191 192 193 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 191 def currency @currency end |
#customer ⇒ Object
The customer for this requested session.
193 194 195 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 193 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
195 196 197 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 195 def @expand end |
#fulfillment_details ⇒ Object
The details of the fulfillment.
197 198 199 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 197 def fulfillment_details @fulfillment_details end |
#line_item_details ⇒ Object
The details of the line items.
199 200 201 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 199 def line_item_details @line_item_details end |
#metadata ⇒ Object
The metadata for this requested session.
201 202 203 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 201 def @metadata end |
#payment_method ⇒ Object
The payment method for this requested session.
203 204 205 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 203 def payment_method @payment_method end |
#payment_method_data ⇒ Object
The payment method data for this requested session.
205 206 207 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 205 def payment_method_data @payment_method_data end |
#risk_details ⇒ Object
The risk details for this requested session.
207 208 209 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 207 def risk_details @risk_details end |
#seller_details ⇒ Object
The details of the seller.
209 210 211 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 209 def seller_details @seller_details end |
#setup_future_usage ⇒ Object
The setup future usage for this requested session.
211 212 213 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 211 def setup_future_usage @setup_future_usage end |
#shared_metadata ⇒ Object
The shared metadata for this requested session.
213 214 215 |
# File 'lib/stripe/params/delegated_checkout/requested_session_create_params.rb', line 213 def @shared_metadata end |