Class: Stripe::DelegatedCheckout::RequestedSessionUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionUpdateParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_update_params.rb
Defined Under Namespace
Classes: FulfillmentDetails, LineItemDetail, PaymentMethodOptions
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fulfillment_details ⇒ Object
The details of the fulfillment.
-
#line_item_details ⇒ Object
The details of the line items.
-
#metadata ⇒ Object
The metadata for this requested session.
-
#payment_method ⇒ Object
The payment method for this requested session.
-
#payment_method_options ⇒ Object
The payment method options for this requested session.
-
#shared_metadata ⇒ Object
The shared metadata for this requested session.
Instance Method Summary collapse
-
#initialize(expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_options: nil, shared_metadata: nil) ⇒ RequestedSessionUpdateParams
constructor
A new instance of RequestedSessionUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_options: nil, shared_metadata: nil) ⇒ RequestedSessionUpdateParams
Returns a new instance of RequestedSessionUpdateParams.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 181 def initialize( expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_options: nil, shared_metadata: nil ) @expand = @fulfillment_details = fulfillment_details @line_item_details = line_item_details @metadata = @payment_method = payment_method @payment_method_options = @shared_metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
167 168 169 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 167 def @expand end |
#fulfillment_details ⇒ Object
The details of the fulfillment.
169 170 171 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 169 def fulfillment_details @fulfillment_details end |
#line_item_details ⇒ Object
The details of the line items.
171 172 173 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 171 def line_item_details @line_item_details end |
#metadata ⇒ Object
The metadata for this requested session.
173 174 175 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 173 def @metadata end |
#payment_method ⇒ Object
The payment method for this requested session.
175 176 177 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 175 def payment_method @payment_method end |
#payment_method_options ⇒ Object
The payment method options for this requested session.
177 178 179 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 177 def @payment_method_options end |
#shared_metadata ⇒ Object
The shared metadata for this requested session.
179 180 181 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 179 def @shared_metadata end |