Class: Stripe::DelegatedCheckout::RequestedSessionUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionUpdateParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_update_params.rb
Defined Under Namespace
Classes: FulfillmentDetails, LineItemDetail, PaymentMethodData
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fulfillment_details ⇒ Object
The details of the fulfillment.
-
#line_item_details ⇒ Object
The details of the line items.
-
#metadata ⇒ Object
The metadata for this requested session.
-
#payment_method ⇒ Object
The payment method for this requested session.
-
#payment_method_data ⇒ Object
The payment method data for this requested session.
-
#shared_metadata ⇒ Object
The shared metadata for this requested session.
Instance Method Summary collapse
-
#initialize(expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, shared_metadata: nil) ⇒ RequestedSessionUpdateParams
constructor
A new instance of RequestedSessionUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, shared_metadata: nil) ⇒ RequestedSessionUpdateParams
Returns a new instance of RequestedSessionUpdateParams.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 241 def initialize( expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, shared_metadata: nil ) @expand = @fulfillment_details = fulfillment_details @line_item_details = line_item_details @metadata = @payment_method = payment_method @payment_method_data = payment_method_data @shared_metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
227 228 229 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 227 def @expand end |
#fulfillment_details ⇒ Object
The details of the fulfillment.
229 230 231 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 229 def fulfillment_details @fulfillment_details end |
#line_item_details ⇒ Object
The details of the line items.
231 232 233 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 231 def line_item_details @line_item_details end |
#metadata ⇒ Object
The metadata for this requested session.
233 234 235 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 233 def @metadata end |
#payment_method ⇒ Object
The payment method for this requested session.
235 236 237 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 235 def payment_method @payment_method end |
#payment_method_data ⇒ Object
The payment method data for this requested session.
237 238 239 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 237 def payment_method_data @payment_method_data end |
#shared_metadata ⇒ Object
The shared metadata for this requested session.
239 240 241 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 239 def @shared_metadata end |