Class: Stripe::DelegatedCheckout::RequestedSessionUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionUpdateParams
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_update_params.rb
Defined Under Namespace
Classes: FulfillmentDetails, LineItemDetail, PaymentMethodData
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fulfillment_details ⇒ Object
The details of the fulfillment.
-
#line_item_details ⇒ Object
The details of the line items.
-
#metadata ⇒ Object
The metadata for this requested session.
-
#payment_method ⇒ Object
The payment method for this requested session.
-
#payment_method_data ⇒ Object
The payment method data for this requested session.
-
#shared_metadata ⇒ Object
The shared metadata for this requested session.
Instance Method Summary collapse
-
#initialize(expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, shared_metadata: nil) ⇒ RequestedSessionUpdateParams
constructor
A new instance of RequestedSessionUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, shared_metadata: nil) ⇒ RequestedSessionUpdateParams
Returns a new instance of RequestedSessionUpdateParams.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 202 def initialize( expand: nil, fulfillment_details: nil, line_item_details: nil, metadata: nil, payment_method: nil, payment_method_data: nil, shared_metadata: nil ) @expand = @fulfillment_details = fulfillment_details @line_item_details = line_item_details @metadata = @payment_method = payment_method @payment_method_data = payment_method_data @shared_metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
188 189 190 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 188 def @expand end |
#fulfillment_details ⇒ Object
The details of the fulfillment.
190 191 192 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 190 def fulfillment_details @fulfillment_details end |
#line_item_details ⇒ Object
The details of the line items.
192 193 194 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 192 def line_item_details @line_item_details end |
#metadata ⇒ Object
The metadata for this requested session.
194 195 196 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 194 def @metadata end |
#payment_method ⇒ Object
The payment method for this requested session.
196 197 198 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 196 def payment_method @payment_method end |
#payment_method_data ⇒ Object
The payment method data for this requested session.
198 199 200 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 198 def payment_method_data @payment_method_data end |
#shared_metadata ⇒ Object
The shared metadata for this requested session.
200 201 202 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 200 def @shared_metadata end |