Class: Stripe::DelegatedCheckout::RequestedSessionUpdateParams::FulfillmentDetails::SelectedFulfillmentOptionOverride
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionUpdateParams::FulfillmentDetails::SelectedFulfillmentOptionOverride
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_update_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#digital ⇒ Object
The digital fulfillment option.
-
#line_item_keys ⇒ Object
The line item keys that this fulfillment option override applies to.
-
#shipping ⇒ Object
The shipping fulfillment option.
-
#type ⇒ Object
The type of fulfillment option.
Instance Method Summary collapse
-
#initialize(digital: nil, line_item_keys: nil, shipping: nil, type: nil) ⇒ SelectedFulfillmentOptionOverride
constructor
A new instance of SelectedFulfillmentOptionOverride.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(digital: nil, line_item_keys: nil, shipping: nil, type: nil) ⇒ SelectedFulfillmentOptionOverride
Returns a new instance of SelectedFulfillmentOptionOverride.
98 99 100 101 102 103 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 98 def initialize(digital: nil, line_item_keys: nil, shipping: nil, type: nil) @digital = digital @line_item_keys = line_item_keys @shipping = shipping @type = type end |
Instance Attribute Details
#digital ⇒ Object
The digital fulfillment option.
90 91 92 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 90 def digital @digital end |
#line_item_keys ⇒ Object
The line item keys that this fulfillment option override applies to.
92 93 94 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 92 def line_item_keys @line_item_keys end |
#shipping ⇒ Object
The shipping fulfillment option.
94 95 96 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 94 def shipping @shipping end |
#type ⇒ Object
The type of fulfillment option.
96 97 98 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 96 def type @type end |