Class: Stripe::DelegatedCheckout::RequestedSessionUpdateParams::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DelegatedCheckout::RequestedSessionUpdateParams::PaymentMethodOptions
- Defined in:
- lib/stripe/params/delegated_checkout/requested_session_update_params.rb
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ Object
Card-specific payment method options.
-
#excluded_payment_method_types ⇒ Object
The payment method types to exclude from the session.
Instance Method Summary collapse
-
#initialize(card: nil, excluded_payment_method_types: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(card: nil, excluded_payment_method_types: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
161 162 163 164 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 161 def initialize(card: nil, excluded_payment_method_types: nil) @card = card @excluded_payment_method_types = excluded_payment_method_types end |
Instance Attribute Details
#card ⇒ Object
Card-specific payment method options.
157 158 159 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 157 def card @card end |
#excluded_payment_method_types ⇒ Object
The payment method types to exclude from the session.
159 160 161 |
# File 'lib/stripe/params/delegated_checkout/requested_session_update_params.rb', line 159 def excluded_payment_method_types @excluded_payment_method_types end |