Class: Stripe::Dispute

Inherits:
APIResource show all
Extended by:
APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/dispute.rb

Overview

A dispute occurs when a customer questions your charge with their card issuer. When this happens, you have the opportunity to respond to the dispute with evidence that shows that the charge is legitimate.

Related guide: [Disputes and fraud](stripe.com/docs/disputes)

Defined Under Namespace

Classes: CloseParams, Evidence, EvidenceDetails, ListParams, PaymentMethodDetails, RetrieveParams, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"dispute"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Disputed amount. Usually the amount of the charge, but it can differ (usually because of currency fluctuation or because only part of the order is disputed).



602
603
604
# File 'lib/stripe/resources/dispute.rb', line 602

def amount
  @amount
end

#balance_transactionsObject (readonly)

List of zero, one, or two balance transactions that show funds withdrawn and reinstated to your Stripe account as a result of this dispute.



604
605
606
# File 'lib/stripe/resources/dispute.rb', line 604

def balance_transactions
  @balance_transactions
end

#chargeObject (readonly)

ID of the charge that’s disputed.



606
607
608
# File 'lib/stripe/resources/dispute.rb', line 606

def charge
  @charge
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



608
609
610
# File 'lib/stripe/resources/dispute.rb', line 608

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



610
611
612
# File 'lib/stripe/resources/dispute.rb', line 610

def currency
  @currency
end

#enhanced_eligibility_typesObject (readonly)

List of eligibility types that are included in ‘enhanced_evidence`.



612
613
614
# File 'lib/stripe/resources/dispute.rb', line 612

def enhanced_eligibility_types
  @enhanced_eligibility_types
end

#evidenceObject (readonly)

Attribute for field evidence



614
615
616
# File 'lib/stripe/resources/dispute.rb', line 614

def evidence
  @evidence
end

#evidence_detailsObject (readonly)

Attribute for field evidence_details



616
617
618
# File 'lib/stripe/resources/dispute.rb', line 616

def evidence_details
  @evidence_details
end

#idObject (readonly)

Unique identifier for the object.



618
619
620
# File 'lib/stripe/resources/dispute.rb', line 618

def id
  @id
end

#is_charge_refundableObject (readonly)

If true, it’s still possible to refund the disputed payment. After the payment has been fully refunded, no further funds are withdrawn from your Stripe account as a result of this dispute.



620
621
622
# File 'lib/stripe/resources/dispute.rb', line 620

def is_charge_refundable
  @is_charge_refundable
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



622
623
624
# File 'lib/stripe/resources/dispute.rb', line 622

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



624
625
626
# File 'lib/stripe/resources/dispute.rb', line 624

def 
  @metadata
end

#network_reason_codeObject (readonly)

Network-dependent reason code for the dispute.



626
627
628
# File 'lib/stripe/resources/dispute.rb', line 626

def network_reason_code
  @network_reason_code
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



628
629
630
# File 'lib/stripe/resources/dispute.rb', line 628

def object
  @object
end

#payment_intentObject (readonly)

ID of the PaymentIntent that’s disputed.



630
631
632
# File 'lib/stripe/resources/dispute.rb', line 630

def payment_intent
  @payment_intent
end

#payment_method_detailsObject (readonly)

Attribute for field payment_method_details



632
633
634
# File 'lib/stripe/resources/dispute.rb', line 632

def payment_method_details
  @payment_method_details
end

#reasonObject (readonly)

Reason given by cardholder for dispute. Possible values are ‘bank_cannot_process`, `check_returned`, `credit_not_processed`, `customer_initiated`, `debit_not_authorized`, `duplicate`, `fraudulent`, `general`, `incorrect_account_details`, `insufficient_funds`, `product_not_received`, `product_unacceptable`, `subscription_canceled`, or `unrecognized`. Learn more about [dispute reasons](stripe.com/docs/disputes/categories).



634
635
636
# File 'lib/stripe/resources/dispute.rb', line 634

def reason
  @reason
end

#statusObject (readonly)

Current status of dispute. Possible values are ‘warning_needs_response`, `warning_under_review`, `warning_closed`, `needs_response`, `under_review`, `won`, or `lost`.



636
637
638
# File 'lib/stripe/resources/dispute.rb', line 636

def status
  @status
end

Class Method Details

.close(dispute, params = {}, opts = {}) ⇒ Object

Closing the dispute for a charge indicates that you do not have any evidence to submit and are essentially dismissing the dispute, acknowledging it as lost.

The status of the dispute will change from needs_response to lost. Closing a dispute is irreversible.



653
654
655
656
657
658
659
660
# File 'lib/stripe/resources/dispute.rb', line 653

def self.close(dispute, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/disputes/%<dispute>s/close", { dispute: CGI.escape(dispute) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of your disputes.



663
664
665
# File 'lib/stripe/resources/dispute.rb', line 663

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/disputes", params: params, opts: opts)
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/dispute.rb', line 15

def self.object_name
  "dispute"
end

.update(dispute, params = {}, opts = {}) ⇒ Object

When you get a dispute, contacting your customer is always the best first step. If that doesn’t work, you can submit evidence to help us resolve the dispute in your favor. You can do this in your [dashboard](dashboard.stripe.com/disputes), but if you prefer, you can use the API to submit evidence programmatically.

Depending on your dispute type, different evidence fields will give you a better chance of winning your dispute. To figure out which evidence fields to provide, see our [guide to dispute types](stripe.com/docs/disputes/categories).



670
671
672
673
674
675
676
677
# File 'lib/stripe/resources/dispute.rb', line 670

def self.update(dispute, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/disputes/%<dispute>s", { dispute: CGI.escape(dispute) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#close(params = {}, opts = {}) ⇒ Object

Closing the dispute for a charge indicates that you do not have any evidence to submit and are essentially dismissing the dispute, acknowledging it as lost.

The status of the dispute will change from needs_response to lost. Closing a dispute is irreversible.



641
642
643
644
645
646
647
648
# File 'lib/stripe/resources/dispute.rb', line 641

def close(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/disputes/%<dispute>s/close", { dispute: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end