Class: Stripe::Dispute

Inherits:
APIResource show all
Extended by:
APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/dispute.rb

Overview

A dispute occurs when a customer questions your charge with their card issuer. When this happens, you have the opportunity to respond to the dispute with evidence that shows that the charge is legitimate.

Related guide: [Disputes and fraud](stripe.com/docs/disputes)

Defined Under Namespace

Classes: Evidence, EvidenceDetails, PaymentMethodDetails

Constant Summary collapse

OBJECT_NAME =
"dispute"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Disputed amount. Usually the amount of the charge, but it can differ (usually because of currency fluctuation or because only part of the order is disputed).



79
80
81
# File 'lib/stripe/resources/dispute.rb', line 79

def amount
  @amount
end

#balance_transactionsObject (readonly)

List of zero, one, or two balance transactions that show funds withdrawn and reinstated to your Stripe account as a result of this dispute.



81
82
83
# File 'lib/stripe/resources/dispute.rb', line 81

def balance_transactions
  @balance_transactions
end

#chargeObject (readonly)

ID of the charge that’s disputed.



83
84
85
# File 'lib/stripe/resources/dispute.rb', line 83

def charge
  @charge
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



85
86
87
# File 'lib/stripe/resources/dispute.rb', line 85

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



87
88
89
# File 'lib/stripe/resources/dispute.rb', line 87

def currency
  @currency
end

#enhanced_eligibility_typesObject (readonly)

List of eligibility types that are included in ‘enhanced_evidence`.



89
90
91
# File 'lib/stripe/resources/dispute.rb', line 89

def enhanced_eligibility_types
  @enhanced_eligibility_types
end

#evidenceObject (readonly)

Attribute for field evidence



91
92
93
# File 'lib/stripe/resources/dispute.rb', line 91

def evidence
  @evidence
end

#evidence_detailsObject (readonly)

Attribute for field evidence_details



93
94
95
# File 'lib/stripe/resources/dispute.rb', line 93

def evidence_details
  @evidence_details
end

#idObject (readonly)

Unique identifier for the object.



95
96
97
# File 'lib/stripe/resources/dispute.rb', line 95

def id
  @id
end

#is_charge_refundableObject (readonly)

If true, it’s still possible to refund the disputed payment. After the payment has been fully refunded, no further funds are withdrawn from your Stripe account as a result of this dispute.



97
98
99
# File 'lib/stripe/resources/dispute.rb', line 97

def is_charge_refundable
  @is_charge_refundable
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



99
100
101
# File 'lib/stripe/resources/dispute.rb', line 99

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



101
102
103
# File 'lib/stripe/resources/dispute.rb', line 101

def 
  @metadata
end

#network_reason_codeObject (readonly)

Network-dependent reason code for the dispute.



103
104
105
# File 'lib/stripe/resources/dispute.rb', line 103

def network_reason_code
  @network_reason_code
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



105
106
107
# File 'lib/stripe/resources/dispute.rb', line 105

def object
  @object
end

#payment_intentObject (readonly)

ID of the PaymentIntent that’s disputed.



107
108
109
# File 'lib/stripe/resources/dispute.rb', line 107

def payment_intent
  @payment_intent
end

#payment_method_detailsObject (readonly)

Attribute for field payment_method_details



109
110
111
# File 'lib/stripe/resources/dispute.rb', line 109

def payment_method_details
  @payment_method_details
end

#reasonObject (readonly)

Reason given by cardholder for dispute. Possible values are ‘bank_cannot_process`, `check_returned`, `credit_not_processed`, `customer_initiated`, `debit_not_authorized`, `duplicate`, `fraudulent`, `general`, `incorrect_account_details`, `insufficient_funds`, `product_not_received`, `product_unacceptable`, `subscription_canceled`, or `unrecognized`. Learn more about [dispute reasons](stripe.com/docs/disputes/categories).



111
112
113
# File 'lib/stripe/resources/dispute.rb', line 111

def reason
  @reason
end

#statusObject (readonly)

Current status of dispute. Possible values are ‘warning_needs_response`, `warning_under_review`, `warning_closed`, `needs_response`, `under_review`, `won`, or `lost`.



113
114
115
# File 'lib/stripe/resources/dispute.rb', line 113

def status
  @status
end

Class Method Details

.close(dispute, params = {}, opts = {}) ⇒ Object

Closing the dispute for a charge indicates that you do not have any evidence to submit and are essentially dismissing the dispute, acknowledging it as lost.

The status of the dispute will change from needs_response to lost. Closing a dispute is irreversible.



130
131
132
133
134
135
136
137
# File 'lib/stripe/resources/dispute.rb', line 130

def self.close(dispute, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/disputes/%<dispute>s/close", { dispute: CGI.escape(dispute) }),
    params: params,
    opts: opts
  )
end

.list(filters = {}, opts = {}) ⇒ Object

Returns a list of your disputes.



140
141
142
# File 'lib/stripe/resources/dispute.rb', line 140

def self.list(filters = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/disputes", params: filters, opts: opts)
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/dispute.rb', line 15

def self.object_name
  "dispute"
end

.update(id, params = {}, opts = {}) ⇒ Object

When you get a dispute, contacting your customer is always the best first step. If that doesn’t work, you can submit evidence to help us resolve the dispute in your favor. You can do this in your [dashboard](dashboard.stripe.com/disputes), but if you prefer, you can use the API to submit evidence programmatically.

Depending on your dispute type, different evidence fields will give you a better chance of winning your dispute. To figure out which evidence fields to provide, see our [guide to dispute types](stripe.com/docs/disputes/categories).



147
148
149
150
151
152
153
154
# File 'lib/stripe/resources/dispute.rb', line 147

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/disputes/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#close(params = {}, opts = {}) ⇒ Object

Closing the dispute for a charge indicates that you do not have any evidence to submit and are essentially dismissing the dispute, acknowledging it as lost.

The status of the dispute will change from needs_response to lost. Closing a dispute is irreversible.



118
119
120
121
122
123
124
125
# File 'lib/stripe/resources/dispute.rb', line 118

def close(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/disputes/%<dispute>s/close", { dispute: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end