Class: Stripe::Dispute::Evidence
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Dispute::Evidence
- Defined in:
- lib/stripe/resources/dispute.rb
Defined Under Namespace
Classes: EnhancedEvidence
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#access_activity_log ⇒ Object
readonly
Any server or activity logs showing proof that the customer accessed or downloaded the purchased digital product.
-
#billing_address ⇒ Object
readonly
The billing address provided by the customer.
-
#cancellation_policy ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your subscription cancellation policy, as shown to the customer.
-
#cancellation_policy_disclosure ⇒ Object
readonly
An explanation of how and when the customer was shown your refund policy prior to purchase.
-
#cancellation_rebuttal ⇒ Object
readonly
A justification for why the customer’s subscription was not canceled.
-
#customer_communication ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any communication with the customer that you feel is relevant to your case.
-
#customer_email_address ⇒ Object
readonly
The email address of the customer.
-
#customer_name ⇒ Object
readonly
The name of the customer.
-
#customer_purchase_ip ⇒ Object
readonly
The IP address that the customer used when making the purchase.
-
#customer_signature ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A relevant document or contract showing the customer’s signature.
-
#duplicate_charge_documentation ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation for the prior charge that can uniquely identify the charge, such as a receipt, shipping label, work order, etc.
-
#duplicate_charge_explanation ⇒ Object
readonly
An explanation of the difference between the disputed charge versus the prior charge that appears to be a duplicate.
-
#duplicate_charge_id ⇒ Object
readonly
The Stripe ID for the prior charge which appears to be a duplicate of the disputed charge.
-
#enhanced_evidence ⇒ Object
readonly
Attribute for field enhanced_evidence.
-
#product_description ⇒ Object
readonly
A description of the product or service that was sold.
-
#receipt ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any receipt or message sent to the customer notifying them of the charge.
-
#refund_policy ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your refund policy, as shown to the customer.
-
#refund_policy_disclosure ⇒ Object
readonly
Documentation demonstrating that the customer was shown your refund policy prior to purchase.
-
#refund_refusal_explanation ⇒ Object
readonly
A justification for why the customer is not entitled to a refund.
-
#service_date ⇒ Object
readonly
The date on which the customer received or began receiving the purchased service, in a clear human-readable format.
-
#service_documentation ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a service was provided to the customer.
-
#shipping_address ⇒ Object
readonly
The address to which a physical product was shipped.
-
#shipping_carrier ⇒ Object
readonly
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#shipping_date ⇒ Object
readonly
The date on which a physical product began its route to the shipping address, in a clear human-readable format.
-
#shipping_documentation ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a product was shipped to the customer at the same address the customer provided to you.
-
#shipping_tracking_number ⇒ Object
readonly
The tracking number for a physical product, obtained from the delivery service.
-
#uncategorized_file ⇒ Object
readonly
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any additional evidence or statements.
-
#uncategorized_text ⇒ Object
readonly
Any additional evidence or statements.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#access_activity_log ⇒ Object (readonly)
Any server or activity logs showing proof that the customer accessed or downloaded the purchased digital product. This information should include IP addresses, corresponding timestamps, and any detailed recorded activity.
103 104 105 |
# File 'lib/stripe/resources/dispute.rb', line 103 def access_activity_log @access_activity_log end |
#billing_address ⇒ Object (readonly)
The billing address provided by the customer.
105 106 107 |
# File 'lib/stripe/resources/dispute.rb', line 105 def billing_address @billing_address end |
#cancellation_policy ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your subscription cancellation policy, as shown to the customer.
107 108 109 |
# File 'lib/stripe/resources/dispute.rb', line 107 def cancellation_policy @cancellation_policy end |
#cancellation_policy_disclosure ⇒ Object (readonly)
An explanation of how and when the customer was shown your refund policy prior to purchase.
109 110 111 |
# File 'lib/stripe/resources/dispute.rb', line 109 def cancellation_policy_disclosure @cancellation_policy_disclosure end |
#cancellation_rebuttal ⇒ Object (readonly)
A justification for why the customer’s subscription was not canceled.
111 112 113 |
# File 'lib/stripe/resources/dispute.rb', line 111 def cancellation_rebuttal @cancellation_rebuttal end |
#customer_communication ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any communication with the customer that you feel is relevant to your case. Examples include emails proving that the customer received the product or service, or demonstrating their use of or satisfaction with the product or service.
113 114 115 |
# File 'lib/stripe/resources/dispute.rb', line 113 def customer_communication @customer_communication end |
#customer_email_address ⇒ Object (readonly)
The email address of the customer.
115 116 117 |
# File 'lib/stripe/resources/dispute.rb', line 115 def customer_email_address @customer_email_address end |
#customer_name ⇒ Object (readonly)
The name of the customer.
117 118 119 |
# File 'lib/stripe/resources/dispute.rb', line 117 def customer_name @customer_name end |
#customer_purchase_ip ⇒ Object (readonly)
The IP address that the customer used when making the purchase.
119 120 121 |
# File 'lib/stripe/resources/dispute.rb', line 119 def customer_purchase_ip @customer_purchase_ip end |
#customer_signature ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) A relevant document or contract showing the customer’s signature.
121 122 123 |
# File 'lib/stripe/resources/dispute.rb', line 121 def customer_signature @customer_signature end |
#duplicate_charge_documentation ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation for the prior charge that can uniquely identify the charge, such as a receipt, shipping label, work order, etc. This document should be paired with a similar document from the disputed payment that proves the two payments are separate.
123 124 125 |
# File 'lib/stripe/resources/dispute.rb', line 123 def duplicate_charge_documentation @duplicate_charge_documentation end |
#duplicate_charge_explanation ⇒ Object (readonly)
An explanation of the difference between the disputed charge versus the prior charge that appears to be a duplicate.
125 126 127 |
# File 'lib/stripe/resources/dispute.rb', line 125 def duplicate_charge_explanation @duplicate_charge_explanation end |
#duplicate_charge_id ⇒ Object (readonly)
The Stripe ID for the prior charge which appears to be a duplicate of the disputed charge.
127 128 129 |
# File 'lib/stripe/resources/dispute.rb', line 127 def duplicate_charge_id @duplicate_charge_id end |
#enhanced_evidence ⇒ Object (readonly)
Attribute for field enhanced_evidence
129 130 131 |
# File 'lib/stripe/resources/dispute.rb', line 129 def enhanced_evidence @enhanced_evidence end |
#product_description ⇒ Object (readonly)
A description of the product or service that was sold.
131 132 133 |
# File 'lib/stripe/resources/dispute.rb', line 131 def product_description @product_description end |
#receipt ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any receipt or message sent to the customer notifying them of the charge.
133 134 135 |
# File 'lib/stripe/resources/dispute.rb', line 133 def receipt @receipt end |
#refund_policy ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your refund policy, as shown to the customer.
135 136 137 |
# File 'lib/stripe/resources/dispute.rb', line 135 def refund_policy @refund_policy end |
#refund_policy_disclosure ⇒ Object (readonly)
Documentation demonstrating that the customer was shown your refund policy prior to purchase.
137 138 139 |
# File 'lib/stripe/resources/dispute.rb', line 137 def refund_policy_disclosure @refund_policy_disclosure end |
#refund_refusal_explanation ⇒ Object (readonly)
A justification for why the customer is not entitled to a refund.
139 140 141 |
# File 'lib/stripe/resources/dispute.rb', line 139 def refund_refusal_explanation @refund_refusal_explanation end |
#service_date ⇒ Object (readonly)
The date on which the customer received or began receiving the purchased service, in a clear human-readable format.
141 142 143 |
# File 'lib/stripe/resources/dispute.rb', line 141 def service_date @service_date end |
#service_documentation ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a service was provided to the customer. This could include a copy of a signed contract, work order, or other form of written agreement.
143 144 145 |
# File 'lib/stripe/resources/dispute.rb', line 143 def service_documentation @service_documentation end |
#shipping_address ⇒ Object (readonly)
The address to which a physical product was shipped. You should try to include as complete address information as possible.
145 146 147 |
# File 'lib/stripe/resources/dispute.rb', line 145 def shipping_address @shipping_address end |
#shipping_carrier ⇒ Object (readonly)
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. If multiple carriers were used for this purchase, please separate them with commas.
147 148 149 |
# File 'lib/stripe/resources/dispute.rb', line 147 def shipping_carrier @shipping_carrier end |
#shipping_date ⇒ Object (readonly)
The date on which a physical product began its route to the shipping address, in a clear human-readable format.
149 150 151 |
# File 'lib/stripe/resources/dispute.rb', line 149 def shipping_date @shipping_date end |
#shipping_documentation ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a product was shipped to the customer at the same address the customer provided to you. This could include a copy of the shipment receipt, shipping label, etc. It should show the customer’s full shipping address, if possible.
151 152 153 |
# File 'lib/stripe/resources/dispute.rb', line 151 def shipping_documentation @shipping_documentation end |
#shipping_tracking_number ⇒ Object (readonly)
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
153 154 155 |
# File 'lib/stripe/resources/dispute.rb', line 153 def shipping_tracking_number @shipping_tracking_number end |
#uncategorized_file ⇒ Object (readonly)
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any additional evidence or statements.
155 156 157 |
# File 'lib/stripe/resources/dispute.rb', line 155 def uncategorized_file @uncategorized_file end |
#uncategorized_text ⇒ Object (readonly)
Any additional evidence or statements.
157 158 159 |
# File 'lib/stripe/resources/dispute.rb', line 157 def uncategorized_text @uncategorized_text end |