Class: Stripe::Dispute::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Dispute::ListParams
- Defined in:
- lib/stripe/resources/dispute.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#charge ⇒ Object
Only return disputes associated to the charge specified by this charge ID.
-
#created ⇒ Object
Only return disputes that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_intent ⇒ Object
Only return disputes associated to the PaymentIntent specified by this PaymentIntent ID.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/stripe/resources/dispute.rb', line 261 def initialize( charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil ) @charge = charge @created = created @ending_before = ending_before @expand = @limit = limit @payment_intent = payment_intent @starting_after = starting_after end |
Instance Attribute Details
#charge ⇒ Object
Only return disputes associated to the charge specified by this charge ID.
247 248 249 |
# File 'lib/stripe/resources/dispute.rb', line 247 def charge @charge end |
#created ⇒ Object
Only return disputes that were created during the given date interval.
249 250 251 |
# File 'lib/stripe/resources/dispute.rb', line 249 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
251 252 253 |
# File 'lib/stripe/resources/dispute.rb', line 251 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
253 254 255 |
# File 'lib/stripe/resources/dispute.rb', line 253 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
255 256 257 |
# File 'lib/stripe/resources/dispute.rb', line 255 def limit @limit end |
#payment_intent ⇒ Object
Only return disputes associated to the PaymentIntent specified by this PaymentIntent ID.
257 258 259 |
# File 'lib/stripe/resources/dispute.rb', line 257 def payment_intent @payment_intent end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
259 260 261 |
# File 'lib/stripe/resources/dispute.rb', line 259 def starting_after @starting_after end |