Class: Stripe::Dispute::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(charge: nil, created: nil, ending_before: nil, expand: nil, limit: nil, payment_intent: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/stripe/resources/dispute.rb', line 336

def initialize(
  charge: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  payment_intent: nil,
  starting_after: nil
)
  @charge = charge
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @payment_intent = payment_intent
  @starting_after = starting_after
end

Instance Attribute Details

#chargeObject

Only return disputes associated to the charge specified by this charge ID.



316
317
318
# File 'lib/stripe/resources/dispute.rb', line 316

def charge
  @charge
end

#createdObject

Only return disputes that were created during the given date interval.



319
320
321
# File 'lib/stripe/resources/dispute.rb', line 319

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



322
323
324
# File 'lib/stripe/resources/dispute.rb', line 322

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



325
326
327
# File 'lib/stripe/resources/dispute.rb', line 325

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



328
329
330
# File 'lib/stripe/resources/dispute.rb', line 328

def limit
  @limit
end

#payment_intentObject

Only return disputes associated to the PaymentIntent specified by this PaymentIntent ID.



331
332
333
# File 'lib/stripe/resources/dispute.rb', line 331

def payment_intent
  @payment_intent
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



334
335
336
# File 'lib/stripe/resources/dispute.rb', line 334

def starting_after
  @starting_after
end