Class: Stripe::Dispute::SmartDisputes
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Dispute::SmartDisputes
- Defined in:
- lib/stripe/resources/dispute.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#recommended_evidence ⇒ Object
readonly
Evidence that could be provided to improve the SmartDisputes packet.
-
#status ⇒ Object
readonly
Smart Disputes auto representment packet availability status.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#recommended_evidence ⇒ Object (readonly)
Evidence that could be provided to improve the SmartDisputes packet
232 233 234 |
# File 'lib/stripe/resources/dispute.rb', line 232 def recommended_evidence @recommended_evidence end |
#status ⇒ Object (readonly)
Smart Disputes auto representment packet availability status.
234 235 236 |
# File 'lib/stripe/resources/dispute.rb', line 234 def status @status end |