Class: Stripe::Dispute::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Dispute::UpdateParams
- Defined in:
- lib/stripe/resources/dispute.rb
Defined Under Namespace
Classes: Evidence
Instance Attribute Summary collapse
-
#evidence ⇒ Object
Evidence to upload, to respond to a dispute.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#submit ⇒ Object
Whether to immediately submit evidence to the bank.
Instance Method Summary collapse
-
#initialize(evidence: nil, expand: nil, metadata: nil, submit: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(evidence: nil, expand: nil, metadata: nil, submit: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
578 579 580 581 582 583 |
# File 'lib/stripe/resources/dispute.rb', line 578 def initialize(evidence: nil, expand: nil, metadata: nil, submit: nil) @evidence = evidence @expand = @metadata = @submit = submit end |
Instance Attribute Details
#evidence ⇒ Object
Evidence to upload, to respond to a dispute. Updating any field in the hash will submit all fields in the hash for review. The combined character count of all fields is limited to 150,000.
570 571 572 |
# File 'lib/stripe/resources/dispute.rb', line 570 def evidence @evidence end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
572 573 574 |
# File 'lib/stripe/resources/dispute.rb', line 572 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
574 575 576 |
# File 'lib/stripe/resources/dispute.rb', line 574 def @metadata end |
#submit ⇒ Object
Whether to immediately submit evidence to the bank. If ‘false`, evidence is staged on the dispute. Staged evidence is visible in the API and Dashboard, and can be submitted to the bank by making another request with this attribute set to `true` (the default).
576 577 578 |
# File 'lib/stripe/resources/dispute.rb', line 576 def submit @submit end |