Class: Stripe::Dispute::UpdateParams::Evidence

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: EnhancedEvidence

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(access_activity_log: nil, billing_address: nil, cancellation_policy: nil, cancellation_policy_disclosure: nil, cancellation_rebuttal: nil, customer_communication: nil, customer_email_address: nil, customer_name: nil, customer_purchase_ip: nil, customer_signature: nil, duplicate_charge_documentation: nil, duplicate_charge_explanation: nil, duplicate_charge_id: nil, enhanced_evidence: nil, product_description: nil, receipt: nil, refund_policy: nil, refund_policy_disclosure: nil, refund_refusal_explanation: nil, service_date: nil, service_documentation: nil, shipping_address: nil, shipping_carrier: nil, shipping_date: nil, shipping_documentation: nil, shipping_tracking_number: nil, uncategorized_file: nil, uncategorized_text: nil) ⇒ Evidence

Returns a new instance of Evidence.



507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'lib/stripe/resources/dispute.rb', line 507

def initialize(
  access_activity_log: nil,
  billing_address: nil,
  cancellation_policy: nil,
  cancellation_policy_disclosure: nil,
  cancellation_rebuttal: nil,
  customer_communication: nil,
  customer_email_address: nil,
  customer_name: nil,
  customer_purchase_ip: nil,
  customer_signature: nil,
  duplicate_charge_documentation: nil,
  duplicate_charge_explanation: nil,
  duplicate_charge_id: nil,
  enhanced_evidence: nil,
  product_description: nil,
  receipt: nil,
  refund_policy: nil,
  refund_policy_disclosure: nil,
  refund_refusal_explanation: nil,
  service_date: nil,
  service_documentation: nil,
  shipping_address: nil,
  shipping_carrier: nil,
  shipping_date: nil,
  shipping_documentation: nil,
  shipping_tracking_number: nil,
  uncategorized_file: nil,
  uncategorized_text: nil
)
  @access_activity_log = access_activity_log
  @billing_address = billing_address
  @cancellation_policy = cancellation_policy
  @cancellation_policy_disclosure = cancellation_policy_disclosure
  @cancellation_rebuttal = cancellation_rebuttal
  @customer_communication = customer_communication
  @customer_email_address = customer_email_address
  @customer_name = customer_name
  @customer_purchase_ip = customer_purchase_ip
  @customer_signature = customer_signature
  @duplicate_charge_documentation = duplicate_charge_documentation
  @duplicate_charge_explanation = duplicate_charge_explanation
  @duplicate_charge_id = duplicate_charge_id
  @enhanced_evidence = enhanced_evidence
  @product_description = product_description
  @receipt = receipt
  @refund_policy = refund_policy
  @refund_policy_disclosure = refund_policy_disclosure
  @refund_refusal_explanation = refund_refusal_explanation
  @service_date = service_date
  @service_documentation = service_documentation
  @shipping_address = shipping_address
  @shipping_carrier = shipping_carrier
  @shipping_date = shipping_date
  @shipping_documentation = shipping_documentation
  @shipping_tracking_number = shipping_tracking_number
  @uncategorized_file = uncategorized_file
  @uncategorized_text = uncategorized_text
end

Instance Attribute Details

#access_activity_logObject

Any server or activity logs showing proof that the customer accessed or downloaded the purchased digital product. This information should include IP addresses, corresponding timestamps, and any detailed recorded activity. Has a maximum character count of 20,000.



451
452
453
# File 'lib/stripe/resources/dispute.rb', line 451

def access_activity_log
  @access_activity_log
end

#billing_addressObject

The billing address provided by the customer.



453
454
455
# File 'lib/stripe/resources/dispute.rb', line 453

def billing_address
  @billing_address
end

#cancellation_policyObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your subscription cancellation policy, as shown to the customer.



455
456
457
# File 'lib/stripe/resources/dispute.rb', line 455

def cancellation_policy
  @cancellation_policy
end

#cancellation_policy_disclosureObject

An explanation of how and when the customer was shown your refund policy prior to purchase. Has a maximum character count of 20,000.



457
458
459
# File 'lib/stripe/resources/dispute.rb', line 457

def cancellation_policy_disclosure
  @cancellation_policy_disclosure
end

#cancellation_rebuttalObject

A justification for why the customer’s subscription was not canceled. Has a maximum character count of 20,000.



459
460
461
# File 'lib/stripe/resources/dispute.rb', line 459

def cancellation_rebuttal
  @cancellation_rebuttal
end

#customer_communicationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any communication with the customer that you feel is relevant to your case. Examples include emails proving that the customer received the product or service, or demonstrating their use of or satisfaction with the product or service.



461
462
463
# File 'lib/stripe/resources/dispute.rb', line 461

def customer_communication
  @customer_communication
end

#customer_email_addressObject

The email address of the customer.



463
464
465
# File 'lib/stripe/resources/dispute.rb', line 463

def customer_email_address
  @customer_email_address
end

#customer_nameObject

The name of the customer.



465
466
467
# File 'lib/stripe/resources/dispute.rb', line 465

def customer_name
  @customer_name
end

#customer_purchase_ipObject

The IP address that the customer used when making the purchase.



467
468
469
# File 'lib/stripe/resources/dispute.rb', line 467

def customer_purchase_ip
  @customer_purchase_ip
end

#customer_signatureObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A relevant document or contract showing the customer’s signature.



469
470
471
# File 'lib/stripe/resources/dispute.rb', line 469

def customer_signature
  @customer_signature
end

#duplicate_charge_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation for the prior charge that can uniquely identify the charge, such as a receipt, shipping label, work order, etc. This document should be paired with a similar document from the disputed payment that proves the two payments are separate.



471
472
473
# File 'lib/stripe/resources/dispute.rb', line 471

def duplicate_charge_documentation
  @duplicate_charge_documentation
end

#duplicate_charge_explanationObject

An explanation of the difference between the disputed charge versus the prior charge that appears to be a duplicate. Has a maximum character count of 20,000.



473
474
475
# File 'lib/stripe/resources/dispute.rb', line 473

def duplicate_charge_explanation
  @duplicate_charge_explanation
end

#duplicate_charge_idObject

The Stripe ID for the prior charge which appears to be a duplicate of the disputed charge.



475
476
477
# File 'lib/stripe/resources/dispute.rb', line 475

def duplicate_charge_id
  @duplicate_charge_id
end

#enhanced_evidenceObject

Additional evidence for qualifying evidence programs.



477
478
479
# File 'lib/stripe/resources/dispute.rb', line 477

def enhanced_evidence
  @enhanced_evidence
end

#product_descriptionObject

A description of the product or service that was sold. Has a maximum character count of 20,000.



479
480
481
# File 'lib/stripe/resources/dispute.rb', line 479

def product_description
  @product_description
end

#receiptObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any receipt or message sent to the customer notifying them of the charge.



481
482
483
# File 'lib/stripe/resources/dispute.rb', line 481

def receipt
  @receipt
end

#refund_policyObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your refund policy, as shown to the customer.



483
484
485
# File 'lib/stripe/resources/dispute.rb', line 483

def refund_policy
  @refund_policy
end

#refund_policy_disclosureObject

Documentation demonstrating that the customer was shown your refund policy prior to purchase. Has a maximum character count of 20,000.



485
486
487
# File 'lib/stripe/resources/dispute.rb', line 485

def refund_policy_disclosure
  @refund_policy_disclosure
end

#refund_refusal_explanationObject

A justification for why the customer is not entitled to a refund. Has a maximum character count of 20,000.



487
488
489
# File 'lib/stripe/resources/dispute.rb', line 487

def refund_refusal_explanation
  @refund_refusal_explanation
end

#service_dateObject

The date on which the customer received or began receiving the purchased service, in a clear human-readable format.



489
490
491
# File 'lib/stripe/resources/dispute.rb', line 489

def service_date
  @service_date
end

#service_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a service was provided to the customer. This could include a copy of a signed contract, work order, or other form of written agreement.



491
492
493
# File 'lib/stripe/resources/dispute.rb', line 491

def service_documentation
  @service_documentation
end

#shipping_addressObject

The address to which a physical product was shipped. You should try to include as complete address information as possible.



493
494
495
# File 'lib/stripe/resources/dispute.rb', line 493

def shipping_address
  @shipping_address
end

#shipping_carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. If multiple carriers were used for this purchase, please separate them with commas.



495
496
497
# File 'lib/stripe/resources/dispute.rb', line 495

def shipping_carrier
  @shipping_carrier
end

#shipping_dateObject

The date on which a physical product began its route to the shipping address, in a clear human-readable format.



497
498
499
# File 'lib/stripe/resources/dispute.rb', line 497

def shipping_date
  @shipping_date
end

#shipping_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a product was shipped to the customer at the same address the customer provided to you. This could include a copy of the shipment receipt, shipping label, etc. It should show the customer’s full shipping address, if possible.



499
500
501
# File 'lib/stripe/resources/dispute.rb', line 499

def shipping_documentation
  @shipping_documentation
end

#shipping_tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



501
502
503
# File 'lib/stripe/resources/dispute.rb', line 501

def shipping_tracking_number
  @shipping_tracking_number
end

#uncategorized_fileObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any additional evidence or statements.



503
504
505
# File 'lib/stripe/resources/dispute.rb', line 503

def uncategorized_file
  @uncategorized_file
end

#uncategorized_textObject

Any additional evidence or statements. Has a maximum character count of 20,000.



505
506
507
# File 'lib/stripe/resources/dispute.rb', line 505

def uncategorized_text
  @uncategorized_text
end