Class: Stripe::Dispute::UpdateParams::Evidence

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: EnhancedEvidence

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(access_activity_log: nil, billing_address: nil, cancellation_policy: nil, cancellation_policy_disclosure: nil, cancellation_rebuttal: nil, customer_communication: nil, customer_email_address: nil, customer_name: nil, customer_purchase_ip: nil, customer_signature: nil, duplicate_charge_documentation: nil, duplicate_charge_explanation: nil, duplicate_charge_id: nil, enhanced_evidence: nil, product_description: nil, receipt: nil, refund_policy: nil, refund_policy_disclosure: nil, refund_refusal_explanation: nil, service_date: nil, service_documentation: nil, shipping_address: nil, shipping_carrier: nil, shipping_date: nil, shipping_documentation: nil, shipping_tracking_number: nil, uncategorized_file: nil, uncategorized_text: nil) ⇒ Evidence

Returns a new instance of Evidence.



644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
# File 'lib/stripe/resources/dispute.rb', line 644

def initialize(
  access_activity_log: nil,
  billing_address: nil,
  cancellation_policy: nil,
  cancellation_policy_disclosure: nil,
  cancellation_rebuttal: nil,
  customer_communication: nil,
  customer_email_address: nil,
  customer_name: nil,
  customer_purchase_ip: nil,
  customer_signature: nil,
  duplicate_charge_documentation: nil,
  duplicate_charge_explanation: nil,
  duplicate_charge_id: nil,
  enhanced_evidence: nil,
  product_description: nil,
  receipt: nil,
  refund_policy: nil,
  refund_policy_disclosure: nil,
  refund_refusal_explanation: nil,
  service_date: nil,
  service_documentation: nil,
  shipping_address: nil,
  shipping_carrier: nil,
  shipping_date: nil,
  shipping_documentation: nil,
  shipping_tracking_number: nil,
  uncategorized_file: nil,
  uncategorized_text: nil
)
  @access_activity_log = access_activity_log
  @billing_address = billing_address
  @cancellation_policy = cancellation_policy
  @cancellation_policy_disclosure = cancellation_policy_disclosure
  @cancellation_rebuttal = cancellation_rebuttal
  @customer_communication = customer_communication
  @customer_email_address = customer_email_address
  @customer_name = customer_name
  @customer_purchase_ip = customer_purchase_ip
  @customer_signature = customer_signature
  @duplicate_charge_documentation = duplicate_charge_documentation
  @duplicate_charge_explanation = duplicate_charge_explanation
  @duplicate_charge_id = duplicate_charge_id
  @enhanced_evidence = enhanced_evidence
  @product_description = product_description
  @receipt = receipt
  @refund_policy = refund_policy
  @refund_policy_disclosure = refund_policy_disclosure
  @refund_refusal_explanation = refund_refusal_explanation
  @service_date = service_date
  @service_documentation = service_documentation
  @shipping_address = shipping_address
  @shipping_carrier = shipping_carrier
  @shipping_date = shipping_date
  @shipping_documentation = shipping_documentation
  @shipping_tracking_number = shipping_tracking_number
  @uncategorized_file = uncategorized_file
  @uncategorized_text = uncategorized_text
end

Instance Attribute Details

#access_activity_logObject

Any server or activity logs showing proof that the customer accessed or downloaded the purchased digital product. This information should include IP addresses, corresponding timestamps, and any detailed recorded activity. Has a maximum character count of 20,000.



561
562
563
# File 'lib/stripe/resources/dispute.rb', line 561

def access_activity_log
  @access_activity_log
end

#billing_addressObject

The billing address provided by the customer.



564
565
566
# File 'lib/stripe/resources/dispute.rb', line 564

def billing_address
  @billing_address
end

#cancellation_policyObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your subscription cancellation policy, as shown to the customer.



567
568
569
# File 'lib/stripe/resources/dispute.rb', line 567

def cancellation_policy
  @cancellation_policy
end

#cancellation_policy_disclosureObject

An explanation of how and when the customer was shown your refund policy prior to purchase. Has a maximum character count of 20,000.



570
571
572
# File 'lib/stripe/resources/dispute.rb', line 570

def cancellation_policy_disclosure
  @cancellation_policy_disclosure
end

#cancellation_rebuttalObject

A justification for why the customer’s subscription was not canceled. Has a maximum character count of 20,000.



573
574
575
# File 'lib/stripe/resources/dispute.rb', line 573

def cancellation_rebuttal
  @cancellation_rebuttal
end

#customer_communicationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any communication with the customer that you feel is relevant to your case. Examples include emails proving that the customer received the product or service, or demonstrating their use of or satisfaction with the product or service.



576
577
578
# File 'lib/stripe/resources/dispute.rb', line 576

def customer_communication
  @customer_communication
end

#customer_email_addressObject

The email address of the customer.



579
580
581
# File 'lib/stripe/resources/dispute.rb', line 579

def customer_email_address
  @customer_email_address
end

#customer_nameObject

The name of the customer.



582
583
584
# File 'lib/stripe/resources/dispute.rb', line 582

def customer_name
  @customer_name
end

#customer_purchase_ipObject

The IP address that the customer used when making the purchase.



585
586
587
# File 'lib/stripe/resources/dispute.rb', line 585

def customer_purchase_ip
  @customer_purchase_ip
end

#customer_signatureObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) A relevant document or contract showing the customer’s signature.



588
589
590
# File 'lib/stripe/resources/dispute.rb', line 588

def customer_signature
  @customer_signature
end

#duplicate_charge_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation for the prior charge that can uniquely identify the charge, such as a receipt, shipping label, work order, etc. This document should be paired with a similar document from the disputed payment that proves the two payments are separate.



591
592
593
# File 'lib/stripe/resources/dispute.rb', line 591

def duplicate_charge_documentation
  @duplicate_charge_documentation
end

#duplicate_charge_explanationObject

An explanation of the difference between the disputed charge versus the prior charge that appears to be a duplicate. Has a maximum character count of 20,000.



594
595
596
# File 'lib/stripe/resources/dispute.rb', line 594

def duplicate_charge_explanation
  @duplicate_charge_explanation
end

#duplicate_charge_idObject

The Stripe ID for the prior charge which appears to be a duplicate of the disputed charge.



597
598
599
# File 'lib/stripe/resources/dispute.rb', line 597

def duplicate_charge_id
  @duplicate_charge_id
end

#enhanced_evidenceObject

Additional evidence for qualifying evidence programs.



600
601
602
# File 'lib/stripe/resources/dispute.rb', line 600

def enhanced_evidence
  @enhanced_evidence
end

#product_descriptionObject

A description of the product or service that was sold. Has a maximum character count of 20,000.



603
604
605
# File 'lib/stripe/resources/dispute.rb', line 603

def product_description
  @product_description
end

#receiptObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any receipt or message sent to the customer notifying them of the charge.



606
607
608
# File 'lib/stripe/resources/dispute.rb', line 606

def receipt
  @receipt
end

#refund_policyObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Your refund policy, as shown to the customer.



609
610
611
# File 'lib/stripe/resources/dispute.rb', line 609

def refund_policy
  @refund_policy
end

#refund_policy_disclosureObject

Documentation demonstrating that the customer was shown your refund policy prior to purchase. Has a maximum character count of 20,000.



612
613
614
# File 'lib/stripe/resources/dispute.rb', line 612

def refund_policy_disclosure
  @refund_policy_disclosure
end

#refund_refusal_explanationObject

A justification for why the customer is not entitled to a refund. Has a maximum character count of 20,000.



615
616
617
# File 'lib/stripe/resources/dispute.rb', line 615

def refund_refusal_explanation
  @refund_refusal_explanation
end

#service_dateObject

The date on which the customer received or began receiving the purchased service, in a clear human-readable format.



618
619
620
# File 'lib/stripe/resources/dispute.rb', line 618

def service_date
  @service_date
end

#service_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a service was provided to the customer. This could include a copy of a signed contract, work order, or other form of written agreement.



621
622
623
# File 'lib/stripe/resources/dispute.rb', line 621

def service_documentation
  @service_documentation
end

#shipping_addressObject

The address to which a physical product was shipped. You should try to include as complete address information as possible.



624
625
626
# File 'lib/stripe/resources/dispute.rb', line 624

def shipping_address
  @shipping_address
end

#shipping_carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc. If multiple carriers were used for this purchase, please separate them with commas.



627
628
629
# File 'lib/stripe/resources/dispute.rb', line 627

def shipping_carrier
  @shipping_carrier
end

#shipping_dateObject

The date on which a physical product began its route to the shipping address, in a clear human-readable format.



630
631
632
# File 'lib/stripe/resources/dispute.rb', line 630

def shipping_date
  @shipping_date
end

#shipping_documentationObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Documentation showing proof that a product was shipped to the customer at the same address the customer provided to you. This could include a copy of the shipment receipt, shipping label, etc. It should show the customer’s full shipping address, if possible.



633
634
635
# File 'lib/stripe/resources/dispute.rb', line 633

def shipping_documentation
  @shipping_documentation
end

#shipping_tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



636
637
638
# File 'lib/stripe/resources/dispute.rb', line 636

def shipping_tracking_number
  @shipping_tracking_number
end

#uncategorized_fileObject

(ID of a [file upload](stripe.com/docs/guides/file-upload)) Any additional evidence or statements.



639
640
641
# File 'lib/stripe/resources/dispute.rb', line 639

def uncategorized_file
  @uncategorized_file
end

#uncategorized_textObject

Any additional evidence or statements. Has a maximum character count of 20,000.



642
643
644
# File 'lib/stripe/resources/dispute.rb', line 642

def uncategorized_text
  @uncategorized_text
end