Class: Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::DisputedTransaction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::DisputedTransaction
- Defined in:
- lib/stripe/resources/dispute.rb
Defined Under Namespace
Classes: ShippingAddress
Instance Attribute Summary collapse
-
#customer_account_id ⇒ Object
User Account ID used to log into business platform.
-
#customer_device_fingerprint ⇒ Object
Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes.
-
#customer_device_id ⇒ Object
Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]).
-
#customer_email_address ⇒ Object
The email address of the customer.
-
#customer_purchase_ip ⇒ Object
The IP address that the customer used when making the purchase.
-
#merchandise_or_services ⇒ Object
Categorization of disputed payment.
-
#product_description ⇒ Object
A description of the product or service that was sold.
-
#shipping_address ⇒ Object
The address to which a physical product was shipped.
Instance Method Summary collapse
-
#initialize(customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, merchandise_or_services: nil, product_description: nil, shipping_address: nil) ⇒ DisputedTransaction
constructor
A new instance of DisputedTransaction.
Methods inherited from RequestParams
Constructor Details
#initialize(customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, merchandise_or_services: nil, product_description: nil, shipping_address: nil) ⇒ DisputedTransaction
Returns a new instance of DisputedTransaction.
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/stripe/resources/dispute.rb', line 341 def initialize( customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, merchandise_or_services: nil, product_description: nil, shipping_address: nil ) @customer_account_id = customer_account_id @customer_device_fingerprint = customer_device_fingerprint @customer_device_id = customer_device_id @customer_email_address = customer_email_address @customer_purchase_ip = customer_purchase_ip @merchandise_or_services = merchandise_or_services @product_description = product_description @shipping_address = shipping_address end |
Instance Attribute Details
#customer_account_id ⇒ Object
User Account ID used to log into business platform. Must be recognizable by the user.
325 326 327 |
# File 'lib/stripe/resources/dispute.rb', line 325 def customer_account_id @customer_account_id end |
#customer_device_fingerprint ⇒ Object
Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.
327 328 329 |
# File 'lib/stripe/resources/dispute.rb', line 327 def customer_device_fingerprint @customer_device_fingerprint end |
#customer_device_id ⇒ Object
Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.
329 330 331 |
# File 'lib/stripe/resources/dispute.rb', line 329 def customer_device_id @customer_device_id end |
#customer_email_address ⇒ Object
The email address of the customer.
331 332 333 |
# File 'lib/stripe/resources/dispute.rb', line 331 def customer_email_address @customer_email_address end |
#customer_purchase_ip ⇒ Object
The IP address that the customer used when making the purchase.
333 334 335 |
# File 'lib/stripe/resources/dispute.rb', line 333 def customer_purchase_ip @customer_purchase_ip end |
#merchandise_or_services ⇒ Object
Categorization of disputed payment.
335 336 337 |
# File 'lib/stripe/resources/dispute.rb', line 335 def merchandise_or_services @merchandise_or_services end |
#product_description ⇒ Object
A description of the product or service that was sold.
337 338 339 |
# File 'lib/stripe/resources/dispute.rb', line 337 def product_description @product_description end |
#shipping_address ⇒ Object
The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.
339 340 341 |
# File 'lib/stripe/resources/dispute.rb', line 339 def shipping_address @shipping_address end |