Class: Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::PriorUndisputedTransaction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: ShippingAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil) ⇒ PriorUndisputedTransaction

Returns a new instance of PriorUndisputedTransaction.



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
# File 'lib/stripe/resources/dispute.rb', line 509

def initialize(
  charge: nil,
  customer_account_id: nil,
  customer_device_fingerprint: nil,
  customer_device_id: nil,
  customer_email_address: nil,
  customer_purchase_ip: nil,
  product_description: nil,
  shipping_address: nil
)
  @charge = charge
  @customer_account_id = 
  @customer_device_fingerprint = customer_device_fingerprint
  @customer_device_id = customer_device_id
  @customer_email_address = customer_email_address
  @customer_purchase_ip = customer_purchase_ip
  @product_description = product_description
  @shipping_address = shipping_address
end

Instance Attribute Details

#chargeObject

Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.



486
487
488
# File 'lib/stripe/resources/dispute.rb', line 486

def charge
  @charge
end

#customer_account_idObject

User Account ID used to log into business platform. Must be recognizable by the user.



489
490
491
# File 'lib/stripe/resources/dispute.rb', line 489

def 
  @customer_account_id
end

#customer_device_fingerprintObject

Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.



492
493
494
# File 'lib/stripe/resources/dispute.rb', line 492

def customer_device_fingerprint
  @customer_device_fingerprint
end

#customer_device_idObject

Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.



495
496
497
# File 'lib/stripe/resources/dispute.rb', line 495

def customer_device_id
  @customer_device_id
end

#customer_email_addressObject

The email address of the customer.



498
499
500
# File 'lib/stripe/resources/dispute.rb', line 498

def customer_email_address
  @customer_email_address
end

#customer_purchase_ipObject

The IP address that the customer used when making the purchase.



501
502
503
# File 'lib/stripe/resources/dispute.rb', line 501

def customer_purchase_ip
  @customer_purchase_ip
end

#product_descriptionObject

A description of the product or service that was sold.



504
505
506
# File 'lib/stripe/resources/dispute.rb', line 504

def product_description
  @product_description
end

#shipping_addressObject

The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.



507
508
509
# File 'lib/stripe/resources/dispute.rb', line 507

def shipping_address
  @shipping_address
end