Class: Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::PriorUndisputedTransaction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/dispute.rb

Defined Under Namespace

Classes: ShippingAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil) ⇒ PriorUndisputedTransaction

Returns a new instance of PriorUndisputedTransaction.



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/stripe/resources/dispute.rb', line 410

def initialize(
  charge: nil,
  customer_account_id: nil,
  customer_device_fingerprint: nil,
  customer_device_id: nil,
  customer_email_address: nil,
  customer_purchase_ip: nil,
  product_description: nil,
  shipping_address: nil
)
  @charge = charge
  @customer_account_id = 
  @customer_device_fingerprint = customer_device_fingerprint
  @customer_device_id = customer_device_id
  @customer_email_address = customer_email_address
  @customer_purchase_ip = customer_purchase_ip
  @product_description = product_description
  @shipping_address = shipping_address
end

Instance Attribute Details

#chargeObject

Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.



394
395
396
# File 'lib/stripe/resources/dispute.rb', line 394

def charge
  @charge
end

#customer_account_idObject

User Account ID used to log into business platform. Must be recognizable by the user.



396
397
398
# File 'lib/stripe/resources/dispute.rb', line 396

def 
  @customer_account_id
end

#customer_device_fingerprintObject

Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.



398
399
400
# File 'lib/stripe/resources/dispute.rb', line 398

def customer_device_fingerprint
  @customer_device_fingerprint
end

#customer_device_idObject

Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.



400
401
402
# File 'lib/stripe/resources/dispute.rb', line 400

def customer_device_id
  @customer_device_id
end

#customer_email_addressObject

The email address of the customer.



402
403
404
# File 'lib/stripe/resources/dispute.rb', line 402

def customer_email_address
  @customer_email_address
end

#customer_purchase_ipObject

The IP address that the customer used when making the purchase.



404
405
406
# File 'lib/stripe/resources/dispute.rb', line 404

def customer_purchase_ip
  @customer_purchase_ip
end

#product_descriptionObject

A description of the product or service that was sold.



406
407
408
# File 'lib/stripe/resources/dispute.rb', line 406

def product_description
  @product_description
end

#shipping_addressObject

The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.



408
409
410
# File 'lib/stripe/resources/dispute.rb', line 408

def shipping_address
  @shipping_address
end