Class: Stripe::Dispute::UpdateParams::Evidence::EnhancedEvidence::VisaCompliance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/dispute.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(fee_acknowledged: nil) ⇒ VisaCompliance

Returns a new instance of VisaCompliance.



545
546
547
# File 'lib/stripe/resources/dispute.rb', line 545

def initialize(fee_acknowledged: nil)
  @fee_acknowledged = fee_acknowledged
end

Instance Attribute Details

#fee_acknowledgedObject

A field acknowledging the fee incurred when countering a Visa Compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute, and you may incur a $500 fee if the case is lost.



543
544
545
# File 'lib/stripe/resources/dispute.rb', line 543

def fee_acknowledged
  @fee_acknowledged
end