Class: Stripe::DisputeService::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::PriorUndisputedTransaction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DisputeService::UpdateParams::Evidence::EnhancedEvidence::VisaCompellingEvidence3::PriorUndisputedTransaction
- Defined in:
- lib/stripe/services/dispute_service.rb
Defined Under Namespace
Classes: ShippingAddress
Instance Attribute Summary collapse
-
#charge ⇒ Object
Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.
-
#customer_account_id ⇒ Object
User Account ID used to log into business platform.
-
#customer_device_fingerprint ⇒ Object
Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes.
-
#customer_device_id ⇒ Object
Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]).
-
#customer_email_address ⇒ Object
The email address of the customer.
-
#customer_purchase_ip ⇒ Object
The IP address that the customer used when making the purchase.
-
#product_description ⇒ Object
A description of the product or service that was sold.
-
#shipping_address ⇒ Object
The address to which a physical product was shipped.
Instance Method Summary collapse
-
#initialize(charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil) ⇒ PriorUndisputedTransaction
constructor
A new instance of PriorUndisputedTransaction.
Methods inherited from RequestParams
Constructor Details
#initialize(charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil) ⇒ PriorUndisputedTransaction
Returns a new instance of PriorUndisputedTransaction.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/stripe/services/dispute_service.rb', line 221 def initialize( charge: nil, customer_account_id: nil, customer_device_fingerprint: nil, customer_device_id: nil, customer_email_address: nil, customer_purchase_ip: nil, product_description: nil, shipping_address: nil ) @charge = charge @customer_account_id = customer_account_id @customer_device_fingerprint = customer_device_fingerprint @customer_device_id = customer_device_id @customer_email_address = customer_email_address @customer_purchase_ip = customer_purchase_ip @product_description = product_description @shipping_address = shipping_address end |
Instance Attribute Details
#charge ⇒ Object
Stripe charge ID for the Visa Compelling Evidence 3.0 eligible prior charge.
198 199 200 |
# File 'lib/stripe/services/dispute_service.rb', line 198 def charge @charge end |
#customer_account_id ⇒ Object
User Account ID used to log into business platform. Must be recognizable by the user.
201 202 203 |
# File 'lib/stripe/services/dispute_service.rb', line 201 def customer_account_id @customer_account_id end |
#customer_device_fingerprint ⇒ Object
Unique identifier of the cardholder’s device derived from a combination of at least two hardware and software attributes. Must be at least 20 characters.
204 205 206 |
# File 'lib/stripe/services/dispute_service.rb', line 204 def customer_device_fingerprint @customer_device_fingerprint end |
#customer_device_id ⇒ Object
Unique identifier of the cardholder’s device such as a device serial number (e.g., International Mobile Equipment Identity [IMEI]). Must be at least 15 characters.
207 208 209 |
# File 'lib/stripe/services/dispute_service.rb', line 207 def customer_device_id @customer_device_id end |
#customer_email_address ⇒ Object
The email address of the customer.
210 211 212 |
# File 'lib/stripe/services/dispute_service.rb', line 210 def customer_email_address @customer_email_address end |
#customer_purchase_ip ⇒ Object
The IP address that the customer used when making the purchase.
213 214 215 |
# File 'lib/stripe/services/dispute_service.rb', line 213 def customer_purchase_ip @customer_purchase_ip end |
#product_description ⇒ Object
A description of the product or service that was sold.
216 217 218 |
# File 'lib/stripe/services/dispute_service.rb', line 216 def product_description @product_description end |
#shipping_address ⇒ Object
The address to which a physical product was shipped. All fields are required for Visa Compelling Evidence 3.0 evidence submission.
219 220 221 |
# File 'lib/stripe/services/dispute_service.rb', line 219 def shipping_address @shipping_address end |