Class: Stripe::DisputeService::UpdateParams::Evidence::EnhancedEvidence::VisaCompliance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/dispute_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(fee_acknowledged: nil) ⇒ VisaCompliance

Returns a new instance of VisaCompliance.



223
224
225
# File 'lib/stripe/services/dispute_service.rb', line 223

def initialize(fee_acknowledged: nil)
  @fee_acknowledged = fee_acknowledged
end

Instance Attribute Details

#fee_acknowledgedObject

A field acknowledging the fee incurred when countering a Visa compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute. Stripe collects a 500 USD (or local equivalent) amount to cover the network costs associated with resolving compliance disputes. Stripe refunds the 500 USD network fee if you win the dispute.



221
222
223
# File 'lib/stripe/services/dispute_service.rb', line 221

def fee_acknowledged
  @fee_acknowledged
end