Class: Stripe::DisputeService::UpdateParams::Evidence::EnhancedEvidence::VisaCompliance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/dispute_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(fee_acknowledged: nil) ⇒ VisaCompliance

Returns a new instance of VisaCompliance.



257
258
259
# File 'lib/stripe/services/dispute_service.rb', line 257

def initialize(fee_acknowledged: nil)
  @fee_acknowledged = fee_acknowledged
end

Instance Attribute Details

#fee_acknowledgedObject

A field acknowledging the fee incurred when countering a Visa Compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute, and you may incur a $500 fee if the case is lost.



255
256
257
# File 'lib/stripe/services/dispute_service.rb', line 255

def fee_acknowledged
  @fee_acknowledged
end