Class: Stripe::DisputeService::UpdateParams::Evidence::EnhancedEvidence::VisaCompliance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DisputeService::UpdateParams::Evidence::EnhancedEvidence::VisaCompliance
- Defined in:
- lib/stripe/services/dispute_service.rb
Instance Attribute Summary collapse
-
#fee_acknowledged ⇒ Object
A field acknowledging the fee incurred when countering a Visa Compliance dispute.
Instance Method Summary collapse
-
#initialize(fee_acknowledged: nil) ⇒ VisaCompliance
constructor
A new instance of VisaCompliance.
Methods inherited from RequestParams
Constructor Details
#initialize(fee_acknowledged: nil) ⇒ VisaCompliance
Returns a new instance of VisaCompliance.
257 258 259 |
# File 'lib/stripe/services/dispute_service.rb', line 257 def initialize(fee_acknowledged: nil) @fee_acknowledged = fee_acknowledged end |
Instance Attribute Details
#fee_acknowledged ⇒ Object
A field acknowledging the fee incurred when countering a Visa Compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute, and you may incur a $500 fee if the case is lost.
255 256 257 |
# File 'lib/stripe/services/dispute_service.rb', line 255 def fee_acknowledged @fee_acknowledged end |