Class: Stripe::DisputeUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/dispute_update_params.rb

Defined Under Namespace

Classes: Evidence

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(evidence: nil, expand: nil, intended_submission_method: nil, metadata: nil, submit: nil) ⇒ DisputeUpdateParams

Returns a new instance of DisputeUpdateParams.



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/stripe/params/dispute_update_params.rb', line 319

def initialize(
  evidence: nil,
  expand: nil,
  intended_submission_method: nil,
  metadata: nil,
  submit: nil
)
  @evidence = evidence
  @expand = expand
  @intended_submission_method = intended_submission_method
  @metadata = 
  @submit = submit
end

Instance Attribute Details

#evidenceObject

Evidence to upload, to respond to a dispute. Updating any field in the hash will submit all fields in the hash for review. The combined character count of all fields is limited to 150,000.



309
310
311
# File 'lib/stripe/params/dispute_update_params.rb', line 309

def evidence
  @evidence
end

#expandObject

Specifies which fields in the response should be expanded.



311
312
313
# File 'lib/stripe/params/dispute_update_params.rb', line 311

def expand
  @expand
end

#intended_submission_methodObject

Intended submission method for the dispute.



313
314
315
# File 'lib/stripe/params/dispute_update_params.rb', line 313

def intended_submission_method
  @intended_submission_method
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



315
316
317
# File 'lib/stripe/params/dispute_update_params.rb', line 315

def 
  @metadata
end

#submitObject

Whether to immediately submit evidence to the bank. If ‘false`, evidence is staged on the dispute. Staged evidence is visible in the API and Dashboard, and can be submitted to the bank by making another request with this attribute set to `true` (the default).



317
318
319
# File 'lib/stripe/params/dispute_update_params.rb', line 317

def submit
  @submit
end