Class: Stripe::DisputeUpdateParams::Evidence::EnhancedEvidence::MastercardCompliance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::DisputeUpdateParams::Evidence::EnhancedEvidence::MastercardCompliance
- Defined in:
- lib/stripe/params/dispute_update_params.rb
Instance Attribute Summary collapse
-
#fee_acknowledged ⇒ Object
A field acknowledging the fee incurred when countering a Mastercard compliance dispute.
Instance Method Summary collapse
-
#initialize(fee_acknowledged: nil) ⇒ MastercardCompliance
constructor
A new instance of MastercardCompliance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(fee_acknowledged: nil) ⇒ MastercardCompliance
Returns a new instance of MastercardCompliance.
12 13 14 |
# File 'lib/stripe/params/dispute_update_params.rb', line 12 def initialize(fee_acknowledged: nil) @fee_acknowledged = fee_acknowledged end |
Instance Attribute Details
#fee_acknowledged ⇒ Object
A field acknowledging the fee incurred when countering a Mastercard compliance dispute. If this field is set to true, evidence can be submitted for the compliance dispute.
10 11 12 |
# File 'lib/stripe/params/dispute_update_params.rb', line 10 def fee_acknowledged @fee_acknowledged end |