Class: Stripe::Entitlements::Feature::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/entitlements/feature.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



67
68
69
70
71
72
# File 'lib/stripe/resources/entitlements/feature.rb', line 67

def initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil)
  @expand = expand
  @lookup_key = lookup_key
  @metadata = 
  @name = name
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



56
57
58
# File 'lib/stripe/resources/entitlements/feature.rb', line 56

def expand
  @expand
end

#lookup_keyObject

A unique key you provide as your own system identifier. This may be up to 80 characters.



59
60
61
# File 'lib/stripe/resources/entitlements/feature.rb', line 59

def lookup_key
  @lookup_key
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



62
63
64
# File 'lib/stripe/resources/entitlements/feature.rb', line 62

def 
  @metadata
end

#nameObject

The feature’s name, for your own purpose, not meant to be displayable to the customer.



65
66
67
# File 'lib/stripe/resources/entitlements/feature.rb', line 65

def name
  @name
end