Class: Stripe::Entitlements::Feature::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Entitlements::Feature::CreateParams
- Defined in:
- lib/stripe/resources/entitlements/feature.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#lookup_key ⇒ Object
A unique key you provide as your own system identifier.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
The feature’s name, for your own purpose, not meant to be displayable to the customer.
Instance Method Summary collapse
-
#initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
67 68 69 70 71 72 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 67 def initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil) @expand = @lookup_key = lookup_key @metadata = @name = name end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
56 57 58 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 56 def @expand end |
#lookup_key ⇒ Object
A unique key you provide as your own system identifier. This may be up to 80 characters.
59 60 61 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 59 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
62 63 64 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 62 def @metadata end |
#name ⇒ Object
The feature’s name, for your own purpose, not meant to be displayable to the customer.
65 66 67 |
# File 'lib/stripe/resources/entitlements/feature.rb', line 65 def name @name end |