Class: Stripe::Entitlements::Feature::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/entitlements/feature.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



97
98
99
100
101
102
# File 'lib/stripe/resources/entitlements/feature.rb', line 97

def initialize(active: nil, expand: nil, metadata: nil, name: nil)
  @active = active
  @expand = expand
  @metadata = 
  @name = name
end

Instance Attribute Details

#activeObject

Inactive features cannot be attached to new products and will not be returned from the features list endpoint.



86
87
88
# File 'lib/stripe/resources/entitlements/feature.rb', line 86

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



89
90
91
# File 'lib/stripe/resources/entitlements/feature.rb', line 89

def expand
  @expand
end

#metadataObject

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



92
93
94
# File 'lib/stripe/resources/entitlements/feature.rb', line 92

def 
  @metadata
end

#nameObject

The feature’s name, for your own purpose, not meant to be displayable to the customer.



95
96
97
# File 'lib/stripe/resources/entitlements/feature.rb', line 95

def name
  @name
end