Class: Stripe::Entitlements::FeatureService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Entitlements::FeatureService::CreateParams
- Defined in:
- lib/stripe/services/entitlements/feature_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#lookup_key ⇒ Object
A unique key you provide as your own system identifier.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
The feature’s name, for your own purpose, not meant to be displayable to the customer.
Instance Method Summary collapse
-
#initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
56 57 58 59 60 61 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 56 def initialize(expand: nil, lookup_key: nil, metadata: nil, name: nil) @expand = @lookup_key = lookup_key @metadata = @name = name end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
45 46 47 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 45 def @expand end |
#lookup_key ⇒ Object
A unique key you provide as your own system identifier. This may be up to 80 characters.
48 49 50 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 48 def lookup_key @lookup_key end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
51 52 53 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 51 def @metadata end |
#name ⇒ Object
The feature’s name, for your own purpose, not meant to be displayable to the customer.
54 55 56 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 54 def name @name end |