Class: Stripe::Entitlements::FeatureService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Entitlements::FeatureService::UpdateParams
- Defined in:
- lib/stripe/services/entitlements/feature_service.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Inactive features cannot be attached to new products and will not be returned from the features list endpoint.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#name ⇒ Object
The feature’s name, for your own purpose, not meant to be displayable to the customer.
Instance Method Summary collapse
-
#initialize(active: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
75 76 77 78 79 80 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 75 def initialize(active: nil, expand: nil, metadata: nil, name: nil) @active = active @expand = @metadata = @name = name end |
Instance Attribute Details
#active ⇒ Object
Inactive features cannot be attached to new products and will not be returned from the features list endpoint.
67 68 69 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 67 def active @active end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
69 70 71 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 69 def @expand end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
71 72 73 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 71 def @metadata end |
#name ⇒ Object
The feature’s name, for your own purpose, not meant to be displayable to the customer.
73 74 75 |
# File 'lib/stripe/services/entitlements/feature_service.rb', line 73 def name @name end |