Class: Stripe::EphemeralKeyService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::EphemeralKeyService::CreateParams
- Defined in:
- lib/stripe/services/ephemeral_key_service.rb
Instance Attribute Summary collapse
-
#customer ⇒ Object
The ID of the Customer you’d like to modify using the resulting ephemeral key.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#issuing_card ⇒ Object
The ID of the Issuing Card you’d like to access using the resulting ephemeral key.
-
#nonce ⇒ Object
A single-use token, created by Stripe.js, used for creating ephemeral keys for Issuing Cards without exchanging sensitive information.
-
#verification_session ⇒ Object
The ID of the Identity VerificationSession you’d like to access using the resulting ephemeral key.
Instance Method Summary collapse
-
#initialize(customer: nil, expand: nil, issuing_card: nil, nonce: nil, verification_session: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(customer: nil, expand: nil, issuing_card: nil, nonce: nil, verification_session: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
31 32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/stripe/services/ephemeral_key_service.rb', line 31 def initialize( customer: nil, expand: nil, issuing_card: nil, nonce: nil, verification_session: nil ) @customer = customer @expand = @issuing_card = issuing_card @nonce = nonce @verification_session = verification_session end |
Instance Attribute Details
#customer ⇒ Object
The ID of the Customer you’d like to modify using the resulting ephemeral key.
17 18 19 |
# File 'lib/stripe/services/ephemeral_key_service.rb', line 17 def customer @customer end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
20 21 22 |
# File 'lib/stripe/services/ephemeral_key_service.rb', line 20 def @expand end |
#issuing_card ⇒ Object
The ID of the Issuing Card you’d like to access using the resulting ephemeral key.
23 24 25 |
# File 'lib/stripe/services/ephemeral_key_service.rb', line 23 def issuing_card @issuing_card end |
#nonce ⇒ Object
A single-use token, created by Stripe.js, used for creating ephemeral keys for Issuing Cards without exchanging sensitive information.
26 27 28 |
# File 'lib/stripe/services/ephemeral_key_service.rb', line 26 def nonce @nonce end |
#verification_session ⇒ Object
The ID of the Identity VerificationSession you’d like to access using the resulting ephemeral key
29 30 31 |
# File 'lib/stripe/services/ephemeral_key_service.rb', line 29 def verification_session @verification_session end |