Class: Stripe::Event::Data
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Event::Data
- Defined in:
- lib/stripe/resources/event.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#object ⇒ Object
readonly
Object containing the API resource relevant to the event.
-
#previous_attributes ⇒ Object
readonly
Object containing the names of the updated attributes and their values prior to the event (only included in events of type ‘*.updated`).
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#object ⇒ Object (readonly)
Object containing the API resource relevant to the event. For example, an ‘invoice.created` event will have a full [invoice object](stripe.com/docs/api#invoice_object) as the value of the object key.
45 46 47 |
# File 'lib/stripe/resources/event.rb', line 45 def object @object end |
#previous_attributes ⇒ Object (readonly)
Object containing the names of the updated attributes and their values prior to the event (only included in events of type ‘*.updated`). If an array attribute has any updated elements, this object contains the entire array. In Stripe API versions 2017-04-06 or earlier, an updated array attribute in this object includes only the updated array elements.
47 48 49 |
# File 'lib/stripe/resources/event.rb', line 47 def previous_attributes @previous_attributes end |