Class: Stripe::Event::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/event.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, delivery_success: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, types: nil) ⇒ ListParams

Returns a new instance of ListParams.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/stripe/resources/event.rb', line 109

def initialize(
  created: nil,
  delivery_success: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil,
  types: nil
)
  @created = created
  @delivery_success = delivery_success
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
  @types = types
end

Instance Attribute Details

#createdObject

Only return events that were created during the given date interval.



93
94
95
# File 'lib/stripe/resources/event.rb', line 93

def created
  @created
end

#delivery_successObject

Filter events by whether all webhooks were successfully delivered. If false, events which are still pending or have failed all delivery attempts to a webhook endpoint will be returned.



95
96
97
# File 'lib/stripe/resources/event.rb', line 95

def delivery_success
  @delivery_success
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



97
98
99
# File 'lib/stripe/resources/event.rb', line 97

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



99
100
101
# File 'lib/stripe/resources/event.rb', line 99

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



101
102
103
# File 'lib/stripe/resources/event.rb', line 101

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



103
104
105
# File 'lib/stripe/resources/event.rb', line 103

def starting_after
  @starting_after
end

#typeObject

A string containing a specific event name, or group of events using * as a wildcard. The list will be filtered to include only events with a matching event property.



105
106
107
# File 'lib/stripe/resources/event.rb', line 105

def type
  @type
end

#typesObject

An array of up to 20 strings containing specific event names. The list will be filtered to include only events with a matching event property. You may pass either ‘type` or `types`, but not both.



107
108
109
# File 'lib/stripe/resources/event.rb', line 107

def types
  @types
end