Class: Stripe::Event::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Event::ListParams
- Defined in:
- lib/stripe/resources/event.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return events that were created during the given date interval.
-
#delivery_success ⇒ Object
Filter events by whether all webhooks were successfully delivered.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#type ⇒ Object
A string containing a specific event name, or group of events using * as a wildcard.
-
#types ⇒ Object
An array of up to 20 strings containing specific event names.
Instance Method Summary collapse
-
#initialize(created: nil, delivery_success: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, types: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, delivery_success: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, types: nil) ⇒ ListParams
Returns a new instance of ListParams.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/stripe/resources/event.rb', line 92 def initialize( created: nil, delivery_success: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, types: nil ) @created = created @delivery_success = delivery_success @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @type = type @types = types end |
Instance Attribute Details
#created ⇒ Object
Only return events that were created during the given date interval.
76 77 78 |
# File 'lib/stripe/resources/event.rb', line 76 def created @created end |
#delivery_success ⇒ Object
Filter events by whether all webhooks were successfully delivered. If false, events which are still pending or have failed all delivery attempts to a webhook endpoint will be returned.
78 79 80 |
# File 'lib/stripe/resources/event.rb', line 78 def delivery_success @delivery_success end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
80 81 82 |
# File 'lib/stripe/resources/event.rb', line 80 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
82 83 84 |
# File 'lib/stripe/resources/event.rb', line 82 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
84 85 86 |
# File 'lib/stripe/resources/event.rb', line 84 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
86 87 88 |
# File 'lib/stripe/resources/event.rb', line 86 def starting_after @starting_after end |
#type ⇒ Object
A string containing a specific event name, or group of events using * as a wildcard. The list will be filtered to include only events with a matching event property.
88 89 90 |
# File 'lib/stripe/resources/event.rb', line 88 def type @type end |
#types ⇒ Object
An array of up to 20 strings containing specific event names. The list will be filtered to include only events with a matching event property. You may pass either ‘type` or `types`, but not both.
90 91 92 |
# File 'lib/stripe/resources/event.rb', line 90 def types @types end |