Class: Stripe::EventService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/event_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, delivery_success: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, types: nil) ⇒ ListParams

Returns a new instance of ListParams.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/stripe/services/event_service.rb', line 51

def initialize(
  created: nil,
  delivery_success: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil,
  types: nil
)
  @created = created
  @delivery_success = delivery_success
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
  @types = types
end

Instance Attribute Details

#createdObject

Only return events that were created during the given date interval.



28
29
30
# File 'lib/stripe/services/event_service.rb', line 28

def created
  @created
end

#delivery_successObject

Filter events by whether all webhooks were successfully delivered. If false, events which are still pending or have failed all delivery attempts to a webhook endpoint will be returned.



31
32
33
# File 'lib/stripe/services/event_service.rb', line 31

def delivery_success
  @delivery_success
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



34
35
36
# File 'lib/stripe/services/event_service.rb', line 34

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



37
38
39
# File 'lib/stripe/services/event_service.rb', line 37

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



40
41
42
# File 'lib/stripe/services/event_service.rb', line 40

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



43
44
45
# File 'lib/stripe/services/event_service.rb', line 43

def starting_after
  @starting_after
end

#typeObject

A string containing a specific event name, or group of events using * as a wildcard. The list will be filtered to include only events with a matching event property.



46
47
48
# File 'lib/stripe/services/event_service.rb', line 46

def type
  @type
end

#typesObject

An array of up to 20 strings containing specific event names. The list will be filtered to include only events with a matching event property. You may pass either ‘type` or `types`, but not both.



49
50
51
# File 'lib/stripe/services/event_service.rb', line 49

def types
  @types
end