Class: Stripe::Events::V2CoreHealthApiErrorResolvedEvent::V2CoreHealthApiErrorResolvedEventData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2CoreHealthApiErrorResolvedEvent::V2CoreHealthApiErrorResolvedEventData
- Defined in:
- lib/stripe/events/v2_core_health_api_error_resolved_event.rb
Defined Under Namespace
Classes: Impact
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#alert_id ⇒ Object
readonly
The alert ID.
-
#grouping_key ⇒ Object
readonly
The grouping key for the alert.
-
#impact ⇒ Object
readonly
The user impact.
-
#resolved_at ⇒ Object
readonly
The time when the user experience has returned to expected levels.
-
#started_at ⇒ Object
readonly
The time when impact on the user experience was first detected.
-
#summary ⇒ Object
readonly
A short description of the alert.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#alert_id ⇒ Object (readonly)
The alert ID.
72 73 74 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 72 def alert_id @alert_id end |
#grouping_key ⇒ Object (readonly)
The grouping key for the alert.
78 79 80 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 78 def grouping_key @grouping_key end |
#impact ⇒ Object (readonly)
The user impact.
74 75 76 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 74 def impact @impact end |
#resolved_at ⇒ Object (readonly)
The time when the user experience has returned to expected levels.
70 71 72 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 70 def resolved_at @resolved_at end |
#started_at ⇒ Object (readonly)
The time when impact on the user experience was first detected.
76 77 78 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 76 def started_at @started_at end |
#summary ⇒ Object (readonly)
A short description of the alert.
68 69 70 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 68 def summary @summary end |
Class Method Details
.field_encodings ⇒ Object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 88 def self.field_encodings @field_encodings = { impact: { kind: :object, fields: { impacted_requests_percentage: :decimal_string, top_impacted_accounts: { kind: :array, element: { kind: :object, fields: { impacted_requests_percentage: :decimal_string } }, }, }, }, } end |
.field_remappings ⇒ Object
84 85 86 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 84 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
80 81 82 |
# File 'lib/stripe/events/v2_core_health_api_error_resolved_event.rb', line 80 def self.inner_class_types @inner_class_types = { impact: Impact } end |