Class: Stripe::Events::V2CoreHealthEventGenerationFailureResolvedEvent::V2CoreHealthEventGenerationFailureResolvedEventData::Impact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Events::V2CoreHealthEventGenerationFailureResolvedEvent::V2CoreHealthEventGenerationFailureResolvedEventData::Impact
- Defined in:
- lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The account id the event should have been generated for.
-
#event_type ⇒ Object
readonly
The type of event that Stripe failed to generate.
-
#livemode ⇒ Object
readonly
Indicates if the event was for livemode or not.
-
#missing_delivery_attempts ⇒ Object
readonly
The number of webhooks that Stripe failed to create and deliver.
-
#related_object_id ⇒ Object
readonly
The related object id.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The account id the event should have been generated for. Only present when the account is a connected account.
15 16 17 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 15 def account @account end |
#event_type ⇒ Object (readonly)
The type of event that Stripe failed to generate.
17 18 19 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 17 def event_type @event_type end |
#livemode ⇒ Object (readonly)
Indicates if the event was for livemode or not.
19 20 21 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 19 def livemode @livemode end |
#missing_delivery_attempts ⇒ Object (readonly)
The number of webhooks that Stripe failed to create and deliver.
21 22 23 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 21 def missing_delivery_attempts @missing_delivery_attempts end |
#related_object_id ⇒ Object (readonly)
The related object id.
23 24 25 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 23 def @related_object_id end |
Class Method Details
.field_remappings ⇒ Object
29 30 31 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 29 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
25 26 27 |
# File 'lib/stripe/events/v2_core_health_event_generation_failure_resolved_event.rb', line 25 def self.inner_class_types @inner_class_types = {} end |