Class: Stripe::Events::V2MoneyManagementFinancialAccountStatementRestatedEventNotification
- Inherits:
-
V2::Core::EventNotification
- Object
- V2::Core::EventNotification
- Stripe::Events::V2MoneyManagementFinancialAccountStatementRestatedEventNotification
- Defined in:
- lib/stripe/events/v2_money_management_financial_account_statement_restated_event.rb
Overview
Occurs when a Financial Account Statement has been restated. A restatement occurs when a new statement is generated for a period that already had an existing statement. The related object references the original statement that was restated. The new replacement statement will also fire a FinancialAccountStatementCreated event.
Instance Attribute Summary collapse
-
#related_object ⇒ Object
readonly
Returns the value of attribute related_object.
Attributes inherited from V2::Core::EventNotification
#context, #created, #id, #livemode, #reason, #type
Class Method Summary collapse
Instance Method Summary collapse
-
#fetch_related_object ⇒ Object
Retrieves the FinancialAccountStatement related to this EventNotification from the Stripe API.
Methods inherited from V2::Core::EventNotification
Constructor Details
This class inherits a constructor from Stripe::V2::Core::EventNotification
Instance Attribute Details
#related_object ⇒ Object (readonly)
Returns the value of attribute related_object.
57 58 59 |
# File 'lib/stripe/events/v2_money_management_financial_account_statement_restated_event.rb', line 57 def @related_object end |
Class Method Details
.lookup_type ⇒ Object
53 54 55 |
# File 'lib/stripe/events/v2_money_management_financial_account_statement_restated_event.rb', line 53 def self.lookup_type "v2.money_management.financial_account_statement.restated" end |
Instance Method Details
#fetch_related_object ⇒ Object
Retrieves the FinancialAccountStatement related to this EventNotification from the Stripe API. Makes an API request on every call.
60 61 62 63 64 65 66 67 68 |
# File 'lib/stripe/events/v2_money_management_financial_account_statement_restated_event.rb', line 60 def resp = @client.raw_request( :get, .url, opts: { stripe_context: context, "Stripe-Request-Trigger": "event=#{id}" }, usage: ["fetch_related_object"] ) @client.deserialize(resp.http_body, api_mode: Util.get_api_mode(.url)) end |