Method: Stripe::ExchangeRateService#list
- Defined in:
- lib/stripe/services/exchange_rate_service.rb
#list(params = {}, opts = {}) ⇒ Object
- Deprecated
-
The ExchangeRate APIs are deprecated. Please use the [FX Quotes API](docs.stripe.com/payments/currencies/localize-prices/fx-quotes-api) instead.
Returns a list of objects that contain the rates at which foreign currencies are converted to one another. Only shows the currencies for which Stripe supports.
9 10 11 12 13 14 15 16 17 |
# File 'lib/stripe/services/exchange_rate_service.rb', line 9 def list(params = {}, opts = {}) request( method: :get, path: "/v1/exchange_rates", params: params, opts: opts, base_address: :api ) end |