Class: Stripe::ExternalAccountService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::ExternalAccountService
- Defined in:
- lib/stripe/services/external_account_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Create an external account for a given connected account.
-
#delete(id, params = {}, opts = {}) ⇒ Object
Delete a specified external account for a given account.
-
#list(params = {}, opts = {}) ⇒ Object
List external accounts for an account.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a specified external account for a given account.
-
#update(id, params = {}, opts = {}) ⇒ Object
Updates the metadata, account holder name, account holder type of a bank account belonging to a connected account and optionally sets it as the default for its currency.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Create an external account for a given connected account.
256 257 258 259 260 261 262 263 264 |
# File 'lib/stripe/services/external_account_service.rb', line 256 def create(params = {}, opts = {}) request( method: :post, path: "/v1/external_accounts", params: params, opts: opts, base_address: :api ) end |
#delete(id, params = {}, opts = {}) ⇒ Object
Delete a specified external account for a given account.
267 268 269 270 271 272 273 274 275 |
# File 'lib/stripe/services/external_account_service.rb', line 267 def delete(id, params = {}, opts = {}) request( method: :delete, path: format("/v1/external_accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List external accounts for an account.
278 279 280 281 282 283 284 285 286 |
# File 'lib/stripe/services/external_account_service.rb', line 278 def list(params = {}, opts = {}) request( method: :get, path: "/v1/external_accounts", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a specified external account for a given account.
289 290 291 292 293 294 295 296 297 |
# File 'lib/stripe/services/external_account_service.rb', line 289 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/external_accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Updates the metadata, account holder name, account holder type of a bank account belonging to a connected account and optionally sets it as the default for its currency. Other bank account details are not editable by design.
You can only update bank accounts when [account.controller.requirement_collection is application, which includes <a href=“/connect/custom-accounts”>Custom accounts](docs.stripe.com/api/accounts/object#account_object-controller-requirement_collection).
You can re-enable a disabled bank account by performing an update call without providing any arguments or changes.
307 308 309 310 311 312 313 314 315 |
# File 'lib/stripe/services/external_account_service.rb', line 307 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v1/external_accounts/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |