Class: Stripe::ExternalAccountService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::ExternalAccountService::CreateParams
- Defined in:
- lib/stripe/services/external_account_service.rb
Instance Attribute Summary collapse
-
#default_for_currency ⇒ Object
When set to true, or if this is the first external account added in this currency, this account becomes the default external account for its currency.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#external_account ⇒ Object
Either a token, like the ones returned by [Stripe.js](stripe.com/docs/js), or a dictionary containing a user’s external account details (with the options shown below).
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(default_for_currency: nil, expand: nil, external_account: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(default_for_currency: nil, expand: nil, external_account: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
136 137 138 139 140 141 |
# File 'lib/stripe/services/external_account_service.rb', line 136 def initialize(default_for_currency: nil, expand: nil, external_account: nil, metadata: nil) @default_for_currency = default_for_currency @expand = @external_account = external_account @metadata = end |
Instance Attribute Details
#default_for_currency ⇒ Object
When set to true, or if this is the first external account added in this currency, this account becomes the default external account for its currency.
128 129 130 |
# File 'lib/stripe/services/external_account_service.rb', line 128 def default_for_currency @default_for_currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
130 131 132 |
# File 'lib/stripe/services/external_account_service.rb', line 130 def @expand end |
#external_account ⇒ Object
Either a token, like the ones returned by [Stripe.js](stripe.com/docs/js), or a dictionary containing a user’s external account details (with the options shown below).
132 133 134 |
# File 'lib/stripe/services/external_account_service.rb', line 132 def external_account @external_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
134 135 136 |
# File 'lib/stripe/services/external_account_service.rb', line 134 def @metadata end |