Class: Stripe::ExternalAccountService::UpdateParams::Documents

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/external_account_service.rb

Defined Under Namespace

Classes: BankAccountOwnershipVerification

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(bank_account_ownership_verification: nil) ⇒ Documents

Returns a new instance of Documents.



31
32
33
# File 'lib/stripe/services/external_account_service.rb', line 31

def initialize(bank_account_ownership_verification: nil)
  @bank_account_ownership_verification = 
end

Instance Attribute Details

#bank_account_ownership_verificationObject

One or more documents that support the [Bank account ownership verification](support.stripe.com/questions/bank-account-ownership-verification) requirement. Must be a document associated with the bank account that displays the last 4 digits of the account number, either a statement or a check.



29
30
31
# File 'lib/stripe/services/external_account_service.rb', line 29

def 
  @bank_account_ownership_verification
end