Class: Stripe::FileLinkService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FileLinkService::UpdateParams
- Defined in:
- lib/stripe/services/file_link_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expires_at ⇒ Object
A future timestamp after which the link will no longer be usable, or ‘now` to expire the link immediately.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, expires_at: nil, metadata: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, expires_at: nil, metadata: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
107 108 109 110 111 |
# File 'lib/stripe/services/file_link_service.rb', line 107 def initialize(expand: nil, expires_at: nil, metadata: nil) @expand = @expires_at = expires_at @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
99 100 101 |
# File 'lib/stripe/services/file_link_service.rb', line 99 def @expand end |
#expires_at ⇒ Object
A future timestamp after which the link will no longer be usable, or ‘now` to expire the link immediately.
102 103 104 |
# File 'lib/stripe/services/file_link_service.rb', line 102 def expires_at @expires_at end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
105 106 107 |
# File 'lib/stripe/services/file_link_service.rb', line 105 def @metadata end |