Class: Stripe::FinancialConnections::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Account
- Extended by:
- APIOperations::List, APIOperations::NestedResource
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Overview
A Financial Connections Account represents an account that exists outside of Stripe, to which you have been granted some degree of access.
Defined Under Namespace
Classes: AccountHolder, AccountNumber, Balance, BalanceRefresh, InferredBalancesRefresh, OwnershipRefresh, StatusDetails, TransactionRefresh
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
readonly
The account holder that this account belongs to.
-
#account_numbers ⇒ Object
readonly
Details about the account numbers.
-
#authorization ⇒ Object
readonly
The ID of the Financial Connections Authorization this account belongs to.
-
#balance ⇒ Object
readonly
The most recent information about the account’s balance.
-
#balance_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account balance.
-
#category ⇒ Object
readonly
The type of the account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#inferred_balances_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account’s inferred balance history.
-
#institution ⇒ Object
readonly
The ID of the Financial Connections Institution this account belongs to.
-
#institution_name ⇒ Object
readonly
The name of the institution that holds this account.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#ownership ⇒ Object
readonly
The most recent information about the account’s owners.
-
#ownership_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account owners.
-
#permissions ⇒ Object
readonly
The list of permissions granted by this account.
-
#status ⇒ Object
readonly
The status of the link to the account.
-
#status_details ⇒ Object
readonly
Attribute for field status_details.
-
#subcategory ⇒ Object
readonly
If ‘category` is `cash`, one of:.
-
#subscriptions ⇒ Object
readonly
The list of data refresh subscriptions requested on this account.
-
#supported_payment_method_types ⇒ Object
readonly
The [PaymentMethod type](docs.stripe.com/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
-
#transaction_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account transactions.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
-
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
- .object_name ⇒ Object
-
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Instance Method Summary collapse
-
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
-
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
-
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder ⇒ Object (readonly)
The account holder that this account belongs to.
230 231 232 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 230 def account_holder @account_holder end |
#account_numbers ⇒ Object (readonly)
Details about the account numbers.
232 233 234 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 232 def account_numbers @account_numbers end |
#authorization ⇒ Object (readonly)
The ID of the Financial Connections Authorization this account belongs to.
234 235 236 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 234 def @authorization end |
#balance ⇒ Object (readonly)
The most recent information about the account’s balance.
236 237 238 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 236 def balance @balance end |
#balance_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account balance.
238 239 240 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 238 def balance_refresh @balance_refresh end |
#category ⇒ Object (readonly)
The type of the account. Account category is further divided in ‘subcategory`.
240 241 242 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 240 def category @category end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
242 243 244 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 242 def created @created end |
#display_name ⇒ Object (readonly)
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
244 245 246 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 244 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
246 247 248 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 246 def id @id end |
#inferred_balances_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account’s inferred balance history.
248 249 250 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 248 def inferred_balances_refresh @inferred_balances_refresh end |
#institution ⇒ Object (readonly)
The ID of the Financial Connections Institution this account belongs to. Note that this relationship may sometimes change in rare circumstances (e.g. institution mergers).
250 251 252 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 250 def institution @institution end |
#institution_name ⇒ Object (readonly)
The name of the institution that holds this account.
252 253 254 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 252 def institution_name @institution_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number. If present, this will be 4 numeric characters.
254 255 256 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 254 def last4 @last4 end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
256 257 258 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 256 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
258 259 260 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 258 def object @object end |
#ownership ⇒ Object (readonly)
The most recent information about the account’s owners.
260 261 262 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 260 def ownership @ownership end |
#ownership_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account owners.
262 263 264 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 262 def ownership_refresh @ownership_refresh end |
#permissions ⇒ Object (readonly)
The list of permissions granted by this account.
264 265 266 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 264 def @permissions end |
#status ⇒ Object (readonly)
The status of the link to the account.
266 267 268 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 266 def status @status end |
#status_details ⇒ Object (readonly)
Attribute for field status_details
268 269 270 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 268 def status_details @status_details end |
#subcategory ⇒ Object (readonly)
If ‘category` is `cash`, one of:
- `checking`
- `savings`
- `other`
If ‘category` is `credit`, one of:
- `mortgage`
- `line_of_credit`
- `credit_card`
- `other`
If ‘category` is `investment` or `other`, this will be `other`.
283 284 285 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 283 def subcategory @subcategory end |
#subscriptions ⇒ Object (readonly)
The list of data refresh subscriptions requested on this account.
285 286 287 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 285 def subscriptions @subscriptions end |
#supported_payment_method_types ⇒ Object (readonly)
The [PaymentMethod type](docs.stripe.com/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
287 288 289 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 287 def supported_payment_method_types @supported_payment_method_types end |
#transaction_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account transactions.
289 290 291 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 289 def transaction_refresh @transaction_refresh end |
Class Method Details
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
302 303 304 305 306 307 308 309 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 302 def self.disconnect(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
414 415 416 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 414 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 401 def self.inner_class_types @inner_class_types = { account_holder: AccountHolder, account_numbers: AccountNumber, balance: Balance, balance_refresh: BalanceRefresh, inferred_balances_refresh: InferredBalancesRefresh, ownership_refresh: OwnershipRefresh, status_details: StatusDetails, transaction_refresh: TransactionRefresh, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
312 313 314 315 316 317 318 319 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 312 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/financial_connections/accounts", params: params, opts: opts ) end |
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
332 333 334 335 336 337 338 339 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 332 def self.list_owners(account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 12 def self.object_name "financial_connections.account" end |
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
352 353 354 355 356 357 358 359 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 352 def self.refresh_account(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account. When the account status is active, data is typically refreshed once a day.
372 373 374 375 376 377 378 379 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 372 def self.subscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
392 393 394 395 396 397 398 399 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 392 def self.unsubscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
Instance Method Details
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
292 293 294 295 296 297 298 299 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 292 def disconnect(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
322 323 324 325 326 327 328 329 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 322 def list_owners(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
342 343 344 345 346 347 348 349 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 342 def refresh_account(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account. When the account status is active, data is typically refreshed once a day.
362 363 364 365 366 367 368 369 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 362 def subscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
382 383 384 385 386 387 388 389 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 382 def unsubscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |