Class: Stripe::FinancialConnections::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Account
- Extended by:
- APIOperations::List, APIOperations::NestedResource
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Overview
A Financial Connections Account represents an account that exists outside of Stripe, to which you have been granted some degree of access.
Defined Under Namespace
Classes: AccountHolder, AccountNumber, Balance, BalanceRefresh, InferredBalancesRefresh, OwnershipRefresh, StatusDetails, TransactionRefresh
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
readonly
The account holder that this account belongs to.
-
#account_numbers ⇒ Object
readonly
Details about the account numbers.
-
#authorization ⇒ Object
readonly
The ID of the Financial Connections Authorization this account belongs to.
-
#balance ⇒ Object
readonly
The most recent information about the account’s balance.
-
#balance_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account balance.
-
#category ⇒ Object
readonly
The type of the account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#inferred_balances_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account’s inferred balance history.
-
#institution ⇒ Object
readonly
The ID of the Financial Connections Institution this account belongs to.
-
#institution_name ⇒ Object
readonly
The name of the institution that holds this account.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#ownership ⇒ Object
readonly
The most recent information about the account’s owners.
-
#ownership_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account owners.
-
#permissions ⇒ Object
readonly
The list of permissions granted by this account.
-
#status ⇒ Object
readonly
The status of the link to the account.
-
#status_details ⇒ Object
readonly
Attribute for field status_details.
-
#subcategory ⇒ Object
readonly
If ‘category` is `cash`, one of:.
-
#subscriptions ⇒ Object
readonly
The list of data refresh subscriptions requested on this account.
-
#supported_payment_method_types ⇒ Object
readonly
The [PaymentMethod type](docs.stripe.com/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
-
#transaction_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account transactions.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
-
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
- .object_name ⇒ Object
-
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Instance Method Summary collapse
-
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
-
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
-
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder ⇒ Object (readonly)
The account holder that this account belongs to.
211 212 213 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 211 def account_holder @account_holder end |
#account_numbers ⇒ Object (readonly)
Details about the account numbers.
213 214 215 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 213 def account_numbers @account_numbers end |
#authorization ⇒ Object (readonly)
The ID of the Financial Connections Authorization this account belongs to.
215 216 217 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 215 def @authorization end |
#balance ⇒ Object (readonly)
The most recent information about the account’s balance.
217 218 219 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 217 def balance @balance end |
#balance_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account balance.
219 220 221 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 219 def balance_refresh @balance_refresh end |
#category ⇒ Object (readonly)
The type of the account. Account category is further divided in ‘subcategory`.
221 222 223 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 221 def category @category end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
223 224 225 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 223 def created @created end |
#display_name ⇒ Object (readonly)
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
225 226 227 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 225 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
227 228 229 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 227 def id @id end |
#inferred_balances_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account’s inferred balance history.
229 230 231 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 229 def inferred_balances_refresh @inferred_balances_refresh end |
#institution ⇒ Object (readonly)
The ID of the Financial Connections Institution this account belongs to. Note that this relationship may sometimes change in rare circumstances (e.g. institution mergers).
231 232 233 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 231 def institution @institution end |
#institution_name ⇒ Object (readonly)
The name of the institution that holds this account.
233 234 235 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 233 def institution_name @institution_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number. If present, this will be 4 numeric characters.
235 236 237 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 235 def last4 @last4 end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
237 238 239 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 237 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
239 240 241 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 239 def object @object end |
#ownership ⇒ Object (readonly)
The most recent information about the account’s owners.
241 242 243 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 241 def ownership @ownership end |
#ownership_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account owners.
243 244 245 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 243 def ownership_refresh @ownership_refresh end |
#permissions ⇒ Object (readonly)
The list of permissions granted by this account.
245 246 247 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 245 def @permissions end |
#status ⇒ Object (readonly)
The status of the link to the account.
247 248 249 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 247 def status @status end |
#status_details ⇒ Object (readonly)
Attribute for field status_details
249 250 251 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 249 def status_details @status_details end |
#subcategory ⇒ Object (readonly)
If ‘category` is `cash`, one of:
- `checking`
- `savings`
- `other`
If ‘category` is `credit`, one of:
- `mortgage`
- `line_of_credit`
- `credit_card`
- `other`
If ‘category` is `investment` or `other`, this will be `other`.
264 265 266 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 264 def subcategory @subcategory end |
#subscriptions ⇒ Object (readonly)
The list of data refresh subscriptions requested on this account.
266 267 268 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 266 def subscriptions @subscriptions end |
#supported_payment_method_types ⇒ Object (readonly)
The [PaymentMethod type](docs.stripe.com/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
268 269 270 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 268 def supported_payment_method_types @supported_payment_method_types end |
#transaction_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account transactions.
270 271 272 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 270 def transaction_refresh @transaction_refresh end |
Class Method Details
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
283 284 285 286 287 288 289 290 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 283 def self.disconnect(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
395 396 397 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 395 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 382 def self.inner_class_types @inner_class_types = { account_holder: AccountHolder, account_numbers: AccountNumber, balance: Balance, balance_refresh: BalanceRefresh, inferred_balances_refresh: InferredBalancesRefresh, ownership_refresh: OwnershipRefresh, status_details: StatusDetails, transaction_refresh: TransactionRefresh, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
293 294 295 296 297 298 299 300 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 293 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/financial_connections/accounts", params: params, opts: opts ) end |
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
313 314 315 316 317 318 319 320 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 313 def self.list_owners(account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 12 def self.object_name "financial_connections.account" end |
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
333 334 335 336 337 338 339 340 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 333 def self.refresh_account(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account. When the account status is active, data is typically refreshed once a day.
353 354 355 356 357 358 359 360 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 353 def self.subscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
373 374 375 376 377 378 379 380 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 373 def self.unsubscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
Instance Method Details
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
273 274 275 276 277 278 279 280 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 273 def disconnect(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
303 304 305 306 307 308 309 310 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 303 def list_owners(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
323 324 325 326 327 328 329 330 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 323 def refresh_account(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account. When the account status is active, data is typically refreshed once a day.
343 344 345 346 347 348 349 350 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 343 def subscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
363 364 365 366 367 368 369 370 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 363 def unsubscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |