Class: Stripe::FinancialConnections::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Account
- Extended by:
- APIOperations::List, APIOperations::NestedResource
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Overview
A Financial Connections Account represents an account that exists outside of Stripe, to which you have been granted some degree of access.
Defined Under Namespace
Classes: AccountHolder, Balance, BalanceRefresh, InferredBalancesRefresh, OwnershipRefresh, TransactionRefresh
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
readonly
The account holder that this account belongs to.
-
#balance ⇒ Object
readonly
The most recent information about the account’s balance.
-
#balance_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account balance.
-
#category ⇒ Object
readonly
The type of the account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#inferred_balances_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account’s inferred balance history.
-
#institution ⇒ Object
readonly
The ID of the Financial Connections Institution this account belongs to.
-
#institution_name ⇒ Object
readonly
The name of the institution that holds this account.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#ownership ⇒ Object
readonly
The most recent information about the account’s owners.
-
#ownership_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account owners.
-
#permissions ⇒ Object
readonly
The list of permissions granted by this account.
-
#status ⇒ Object
readonly
The status of the link to the account.
-
#subcategory ⇒ Object
readonly
If ‘category` is `cash`, one of:.
-
#subscriptions ⇒ Object
readonly
The list of data refresh subscriptions requested on this account.
-
#supported_payment_method_types ⇒ Object
readonly
The [PaymentMethod type](stripe.com/docs/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
-
#transaction_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account transactions.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
-
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
- .object_name ⇒ Object
-
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Instance Method Summary collapse
-
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
-
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
-
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder ⇒ Object (readonly)
The account holder that this account belongs to.
165 166 167 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 165 def account_holder @account_holder end |
#balance ⇒ Object (readonly)
The most recent information about the account’s balance.
167 168 169 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 167 def balance @balance end |
#balance_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account balance.
169 170 171 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 169 def balance_refresh @balance_refresh end |
#category ⇒ Object (readonly)
The type of the account. Account category is further divided in ‘subcategory`.
171 172 173 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 171 def category @category end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
173 174 175 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 173 def created @created end |
#display_name ⇒ Object (readonly)
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
175 176 177 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 175 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
177 178 179 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 177 def id @id end |
#inferred_balances_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account’s inferred balance history.
179 180 181 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 179 def inferred_balances_refresh @inferred_balances_refresh end |
#institution ⇒ Object (readonly)
The ID of the Financial Connections Institution this account belongs to. Note that this relationship may sometimes change in rare circumstances (e.g. institution mergers).
181 182 183 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 181 def institution @institution end |
#institution_name ⇒ Object (readonly)
The name of the institution that holds this account.
183 184 185 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 183 def institution_name @institution_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number. If present, this will be 4 numeric characters.
185 186 187 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 185 def last4 @last4 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
187 188 189 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 187 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
189 190 191 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 189 def object @object end |
#ownership ⇒ Object (readonly)
The most recent information about the account’s owners.
191 192 193 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 191 def ownership @ownership end |
#ownership_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account owners.
193 194 195 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 193 def ownership_refresh @ownership_refresh end |
#permissions ⇒ Object (readonly)
The list of permissions granted by this account.
195 196 197 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 195 def @permissions end |
#status ⇒ Object (readonly)
The status of the link to the account.
197 198 199 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 197 def status @status end |
#subcategory ⇒ Object (readonly)
If ‘category` is `cash`, one of:
- `checking`
- `savings`
- `other`
If ‘category` is `credit`, one of:
- `mortgage`
- `line_of_credit`
- `credit_card`
- `other`
If ‘category` is `investment` or `other`, this will be `other`.
212 213 214 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 212 def subcategory @subcategory end |
#subscriptions ⇒ Object (readonly)
The list of data refresh subscriptions requested on this account.
214 215 216 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 214 def subscriptions @subscriptions end |
#supported_payment_method_types ⇒ Object (readonly)
The [PaymentMethod type](stripe.com/docs/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
216 217 218 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 216 def supported_payment_method_types @supported_payment_method_types end |
#transaction_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account transactions.
218 219 220 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 218 def transaction_refresh @transaction_refresh end |
Class Method Details
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
231 232 233 234 235 236 237 238 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 231 def self.disconnect(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
341 342 343 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 341 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
330 331 332 333 334 335 336 337 338 339 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 330 def self.inner_class_types @inner_class_types = { account_holder: AccountHolder, balance: Balance, balance_refresh: BalanceRefresh, inferred_balances_refresh: InferredBalancesRefresh, ownership_refresh: OwnershipRefresh, transaction_refresh: TransactionRefresh, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
241 242 243 244 245 246 247 248 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 241 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/financial_connections/accounts", params: params, opts: opts ) end |
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
261 262 263 264 265 266 267 268 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 261 def self.list_owners(account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 12 def self.object_name "financial_connections.account" end |
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
281 282 283 284 285 286 287 288 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 281 def self.refresh_account(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
301 302 303 304 305 306 307 308 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 301 def self.subscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
321 322 323 324 325 326 327 328 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 321 def self.unsubscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
Instance Method Details
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
221 222 223 224 225 226 227 228 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 221 def disconnect(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
251 252 253 254 255 256 257 258 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 251 def list_owners(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
271 272 273 274 275 276 277 278 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 271 def refresh_account(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
291 292 293 294 295 296 297 298 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 291 def subscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
311 312 313 314 315 316 317 318 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 311 def unsubscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |