Class: Stripe::FinancialConnections::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Account
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Overview
A Financial Connections Account represents an account that exists outside of Stripe, to which you have been granted some degree of access.
Defined Under Namespace
Classes: AccountHolder, Balance, BalanceRefresh, OwnershipRefresh, TransactionRefresh
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
readonly
The account holder that this account belongs to.
-
#balance ⇒ Object
readonly
The most recent information about the account’s balance.
-
#balance_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account balance.
-
#category ⇒ Object
readonly
The type of the account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#institution_name ⇒ Object
readonly
The name of the institution that holds this account.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#ownership ⇒ Object
readonly
The most recent information about the account’s owners.
-
#ownership_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account owners.
-
#permissions ⇒ Object
readonly
The list of permissions granted by this account.
-
#status ⇒ Object
readonly
The status of the link to the account.
-
#subcategory ⇒ Object
readonly
If ‘category` is `cash`, one of:.
-
#subscriptions ⇒ Object
readonly
The list of data refresh subscriptions requested on this account.
-
#supported_payment_method_types ⇒ Object
readonly
The [PaymentMethod type](stripe.com/docs/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
-
#transaction_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account transactions.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
-
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
- .object_name ⇒ Object
-
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Instance Method Summary collapse
-
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
-
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
-
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder ⇒ Object (readonly)
The account holder that this account belongs to.
143 144 145 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 143 def account_holder @account_holder end |
#balance ⇒ Object (readonly)
The most recent information about the account’s balance.
145 146 147 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 145 def balance @balance end |
#balance_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account balance.
147 148 149 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 147 def balance_refresh @balance_refresh end |
#category ⇒ Object (readonly)
The type of the account. Account category is further divided in ‘subcategory`.
149 150 151 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 149 def category @category end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
151 152 153 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 151 def created @created end |
#display_name ⇒ Object (readonly)
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
153 154 155 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 153 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
155 156 157 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 155 def id @id end |
#institution_name ⇒ Object (readonly)
The name of the institution that holds this account.
157 158 159 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 157 def institution_name @institution_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number. If present, this will be 4 numeric characters.
159 160 161 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 159 def last4 @last4 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
161 162 163 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 161 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
163 164 165 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 163 def object @object end |
#ownership ⇒ Object (readonly)
The most recent information about the account’s owners.
165 166 167 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 165 def ownership @ownership end |
#ownership_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account owners.
167 168 169 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 167 def ownership_refresh @ownership_refresh end |
#permissions ⇒ Object (readonly)
The list of permissions granted by this account.
169 170 171 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 169 def @permissions end |
#status ⇒ Object (readonly)
The status of the link to the account.
171 172 173 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 171 def status @status end |
#subcategory ⇒ Object (readonly)
If ‘category` is `cash`, one of:
- `checking`
- `savings`
- `other`
If ‘category` is `credit`, one of:
- `mortgage`
- `line_of_credit`
- `credit_card`
- `other`
If ‘category` is `investment` or `other`, this will be `other`.
186 187 188 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 186 def subcategory @subcategory end |
#subscriptions ⇒ Object (readonly)
The list of data refresh subscriptions requested on this account.
188 189 190 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 188 def subscriptions @subscriptions end |
#supported_payment_method_types ⇒ Object (readonly)
The [PaymentMethod type](stripe.com/docs/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
190 191 192 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 190 def supported_payment_method_types @supported_payment_method_types end |
#transaction_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account transactions.
192 193 194 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 192 def transaction_refresh @transaction_refresh end |
Class Method Details
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
205 206 207 208 209 210 211 212 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 205 def self.disconnect(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
314 315 316 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 314 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
304 305 306 307 308 309 310 311 312 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 304 def self.inner_class_types @inner_class_types = { account_holder: AccountHolder, balance: Balance, balance_refresh: BalanceRefresh, ownership_refresh: OwnershipRefresh, transaction_refresh: TransactionRefresh, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
215 216 217 218 219 220 221 222 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 215 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/financial_connections/accounts", params: params, opts: opts ) end |
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
235 236 237 238 239 240 241 242 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 235 def self.list_owners(account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 11 def self.object_name "financial_connections.account" end |
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
255 256 257 258 259 260 261 262 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 255 def self.refresh_account(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
275 276 277 278 279 280 281 282 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 275 def self.subscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
295 296 297 298 299 300 301 302 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 295 def self.unsubscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
Instance Method Details
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
195 196 197 198 199 200 201 202 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 195 def disconnect(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
225 226 227 228 229 230 231 232 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 225 def list_owners(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
245 246 247 248 249 250 251 252 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 245 def refresh_account(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
265 266 267 268 269 270 271 272 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 265 def subscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
285 286 287 288 289 290 291 292 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 285 def unsubscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |