Class: Stripe::FinancialConnections::Account

Inherits:
APIResource show all
Extended by:
APIOperations::List, APIOperations::NestedResource
Defined in:
lib/stripe/resources/financial_connections/account.rb

Overview

A Financial Connections Account represents an account that exists outside of Stripe, to which you have been granted some degree of access.

Defined Under Namespace

Classes: AccountHolder, Balance, BalanceRefresh, DisconnectParams, InferredBalancesRefresh, ListOwnersParams, ListParams, OwnershipRefresh, RefreshAccountParams, SubscribeParams, TransactionRefresh, UnsubscribeParams

Constant Summary collapse

OBJECT_NAME =
"financial_connections.account"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder that this account belongs to.



282
283
284
# File 'lib/stripe/resources/financial_connections/account.rb', line 282

def 
  @account_holder
end

#balanceObject (readonly)

The most recent information about the account’s balance.



284
285
286
# File 'lib/stripe/resources/financial_connections/account.rb', line 284

def balance
  @balance
end

#balance_refreshObject (readonly)

The state of the most recent attempt to refresh the account balance.



286
287
288
# File 'lib/stripe/resources/financial_connections/account.rb', line 286

def balance_refresh
  @balance_refresh
end

#categoryObject (readonly)

The type of the account. Account category is further divided in ‘subcategory`.



288
289
290
# File 'lib/stripe/resources/financial_connections/account.rb', line 288

def category
  @category
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



290
291
292
# File 'lib/stripe/resources/financial_connections/account.rb', line 290

def created
  @created
end

#display_nameObject (readonly)

A human-readable name that has been assigned to this account, either by the account holder or by the institution.



292
293
294
# File 'lib/stripe/resources/financial_connections/account.rb', line 292

def display_name
  @display_name
end

#idObject (readonly)

Unique identifier for the object.



294
295
296
# File 'lib/stripe/resources/financial_connections/account.rb', line 294

def id
  @id
end

#inferred_balances_refreshObject (readonly)

The state of the most recent attempt to refresh the account’s inferred balance history.



296
297
298
# File 'lib/stripe/resources/financial_connections/account.rb', line 296

def inferred_balances_refresh
  @inferred_balances_refresh
end

#institutionObject (readonly)

The ID of the Financial Connections Institution this account belongs to. Note that this relationship may sometimes change in rare circumstances (e.g. institution mergers).



298
299
300
# File 'lib/stripe/resources/financial_connections/account.rb', line 298

def institution
  @institution
end

#institution_nameObject (readonly)

The name of the institution that holds this account.



300
301
302
# File 'lib/stripe/resources/financial_connections/account.rb', line 300

def institution_name
  @institution_name
end

#last4Object (readonly)

The last 4 digits of the account number. If present, this will be 4 numeric characters.



302
303
304
# File 'lib/stripe/resources/financial_connections/account.rb', line 302

def last4
  @last4
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



304
305
306
# File 'lib/stripe/resources/financial_connections/account.rb', line 304

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



306
307
308
# File 'lib/stripe/resources/financial_connections/account.rb', line 306

def object
  @object
end

#ownershipObject (readonly)

The most recent information about the account’s owners.



308
309
310
# File 'lib/stripe/resources/financial_connections/account.rb', line 308

def ownership
  @ownership
end

#ownership_refreshObject (readonly)

The state of the most recent attempt to refresh the account owners.



310
311
312
# File 'lib/stripe/resources/financial_connections/account.rb', line 310

def ownership_refresh
  @ownership_refresh
end

#permissionsObject (readonly)

The list of permissions granted by this account.



312
313
314
# File 'lib/stripe/resources/financial_connections/account.rb', line 312

def permissions
  @permissions
end

#statusObject (readonly)

The status of the link to the account.



314
315
316
# File 'lib/stripe/resources/financial_connections/account.rb', line 314

def status
  @status
end

#subcategoryObject (readonly)

If ‘category` is `cash`, one of:

- `checking`
- `savings`
- `other`

If ‘category` is `credit`, one of:

- `mortgage`
- `line_of_credit`
- `credit_card`
- `other`

If ‘category` is `investment` or `other`, this will be `other`.



329
330
331
# File 'lib/stripe/resources/financial_connections/account.rb', line 329

def subcategory
  @subcategory
end

#subscriptionsObject (readonly)

The list of data refresh subscriptions requested on this account.



331
332
333
# File 'lib/stripe/resources/financial_connections/account.rb', line 331

def subscriptions
  @subscriptions
end

#supported_payment_method_typesObject (readonly)

The [PaymentMethod type](stripe.com/docs/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.



333
334
335
# File 'lib/stripe/resources/financial_connections/account.rb', line 333

def supported_payment_method_types
  @supported_payment_method_types
end

#transaction_refreshObject (readonly)

The state of the most recent attempt to refresh the account transactions.



335
336
337
# File 'lib/stripe/resources/financial_connections/account.rb', line 335

def transaction_refresh
  @transaction_refresh
end

Class Method Details

.disconnect(account, params = {}, opts = {}) ⇒ Object

Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).



348
349
350
351
352
353
354
355
# File 'lib/stripe/resources/financial_connections/account.rb', line 348

def self.disconnect(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



458
459
460
# File 'lib/stripe/resources/financial_connections/account.rb', line 458

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



447
448
449
450
451
452
453
454
455
456
# File 'lib/stripe/resources/financial_connections/account.rb', line 447

def self.inner_class_types
  @inner_class_types = {
    account_holder: AccountHolder,
    balance: Balance,
    balance_refresh: BalanceRefresh,
    inferred_balances_refresh: InferredBalancesRefresh,
    ownership_refresh: OwnershipRefresh,
    transaction_refresh: TransactionRefresh,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Financial Connections Account objects.



358
359
360
361
362
363
364
365
# File 'lib/stripe/resources/financial_connections/account.rb', line 358

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/financial_connections/accounts",
    params: params,
    opts: opts
  )
end

.list_owners(account, params = {}, opts = {}) ⇒ Object

Lists all owners for a given Account



378
379
380
381
382
383
384
385
# File 'lib/stripe/resources/financial_connections/account.rb', line 378

def self.list_owners(, params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/financial_connections/account.rb', line 12

def self.object_name
  "financial_connections.account"
end

.refresh_account(account, params = {}, opts = {}) ⇒ Object

Refreshes the data associated with a Financial Connections Account.



398
399
400
401
402
403
404
405
# File 'lib/stripe/resources/financial_connections/account.rb', line 398

def self.(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.subscribe(account, params = {}, opts = {}) ⇒ Object

Subscribes to periodic refreshes of data associated with a Financial Connections Account.



418
419
420
421
422
423
424
425
# File 'lib/stripe/resources/financial_connections/account.rb', line 418

def self.subscribe(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

.unsubscribe(account, params = {}, opts = {}) ⇒ Object

Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.



438
439
440
441
442
443
444
445
# File 'lib/stripe/resources/financial_connections/account.rb', line 438

def self.unsubscribe(, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape() }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#disconnect(params = {}, opts = {}) ⇒ Object

Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).



338
339
340
341
342
343
344
345
# File 'lib/stripe/resources/financial_connections/account.rb', line 338

def disconnect(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#list_owners(params = {}, opts = {}) ⇒ Object

Lists all owners for a given Account



368
369
370
371
372
373
374
375
# File 'lib/stripe/resources/financial_connections/account.rb', line 368

def list_owners(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#refresh_account(params = {}, opts = {}) ⇒ Object

Refreshes the data associated with a Financial Connections Account.



388
389
390
391
392
393
394
395
# File 'lib/stripe/resources/financial_connections/account.rb', line 388

def (params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#subscribe(params = {}, opts = {}) ⇒ Object

Subscribes to periodic refreshes of data associated with a Financial Connections Account.



408
409
410
411
412
413
414
415
# File 'lib/stripe/resources/financial_connections/account.rb', line 408

def subscribe(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#unsubscribe(params = {}, opts = {}) ⇒ Object

Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.



428
429
430
431
432
433
434
435
# File 'lib/stripe/resources/financial_connections/account.rb', line 428

def unsubscribe(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end