Class: Stripe::FinancialConnections::Account
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Account
- Extended by:
- APIOperations::List, APIOperations::NestedResource
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Overview
A Financial Connections Account represents an account that exists outside of Stripe, to which you have been granted some degree of access.
Defined Under Namespace
Classes: AccountHolder, Balance, BalanceRefresh, DisconnectParams, InferredBalancesRefresh, ListOwnersParams, ListParams, OwnershipRefresh, RefreshAccountParams, RetrieveParams, SubscribeParams, TransactionRefresh, UnsubscribeParams
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.account"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
readonly
The account holder that this account belongs to.
-
#balance ⇒ Object
readonly
The most recent information about the account’s balance.
-
#balance_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account balance.
-
#category ⇒ Object
readonly
The type of the account.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#display_name ⇒ Object
readonly
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#inferred_balances_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account’s inferred balance history.
-
#institution_name ⇒ Object
readonly
The name of the institution that holds this account.
-
#last4 ⇒ Object
readonly
The last 4 digits of the account number.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#ownership ⇒ Object
readonly
The most recent information about the account’s owners.
-
#ownership_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account owners.
-
#permissions ⇒ Object
readonly
The list of permissions granted by this account.
-
#status ⇒ Object
readonly
The status of the link to the account.
-
#subcategory ⇒ Object
readonly
If ‘category` is `cash`, one of:.
-
#subscriptions ⇒ Object
readonly
The list of data refresh subscriptions requested on this account.
-
#supported_payment_method_types ⇒ Object
readonly
The [PaymentMethod type](stripe.com/docs/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
-
#transaction_refresh ⇒ Object
readonly
The state of the most recent attempt to refresh the account transactions.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
-
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
- .object_name ⇒ Object
-
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Instance Method Summary collapse
-
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account.
-
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account.
-
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
-
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
-
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder ⇒ Object (readonly)
The account holder that this account belongs to.
222 223 224 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 222 def account_holder @account_holder end |
#balance ⇒ Object (readonly)
The most recent information about the account’s balance.
224 225 226 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 224 def balance @balance end |
#balance_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account balance.
226 227 228 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 226 def balance_refresh @balance_refresh end |
#category ⇒ Object (readonly)
The type of the account. Account category is further divided in ‘subcategory`.
228 229 230 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 228 def category @category end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
230 231 232 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 230 def created @created end |
#display_name ⇒ Object (readonly)
A human-readable name that has been assigned to this account, either by the account holder or by the institution.
232 233 234 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 232 def display_name @display_name end |
#id ⇒ Object (readonly)
Unique identifier for the object.
234 235 236 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 234 def id @id end |
#inferred_balances_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account’s inferred balance history.
236 237 238 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 236 def inferred_balances_refresh @inferred_balances_refresh end |
#institution_name ⇒ Object (readonly)
The name of the institution that holds this account.
238 239 240 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 238 def institution_name @institution_name end |
#last4 ⇒ Object (readonly)
The last 4 digits of the account number. If present, this will be 4 numeric characters.
240 241 242 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 240 def last4 @last4 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
242 243 244 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 242 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
244 245 246 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 244 def object @object end |
#ownership ⇒ Object (readonly)
The most recent information about the account’s owners.
246 247 248 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 246 def ownership @ownership end |
#ownership_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account owners.
248 249 250 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 248 def ownership_refresh @ownership_refresh end |
#permissions ⇒ Object (readonly)
The list of permissions granted by this account.
250 251 252 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 250 def @permissions end |
#status ⇒ Object (readonly)
The status of the link to the account.
252 253 254 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 252 def status @status end |
#subcategory ⇒ Object (readonly)
If ‘category` is `cash`, one of:
- `checking`
- `savings`
- `other`
If ‘category` is `credit`, one of:
- `mortgage`
- `line_of_credit`
- `credit_card`
- `other`
If ‘category` is `investment` or `other`, this will be `other`.
267 268 269 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 267 def subcategory @subcategory end |
#subscriptions ⇒ Object (readonly)
The list of data refresh subscriptions requested on this account.
269 270 271 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 269 def subscriptions @subscriptions end |
#supported_payment_method_types ⇒ Object (readonly)
The [PaymentMethod type](stripe.com/docs/api/payment_methods/object#payment_method_object-type)(s) that can be created from this account.
271 272 273 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 271 def supported_payment_method_types @supported_payment_method_types end |
#transaction_refresh ⇒ Object (readonly)
The state of the most recent attempt to refresh the account transactions.
273 274 275 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 273 def transaction_refresh @transaction_refresh end |
Class Method Details
.disconnect(account, params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
286 287 288 289 290 291 292 293 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 286 def self.disconnect(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Account objects.
296 297 298 299 300 301 302 303 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 296 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/financial_connections/accounts", params: params, opts: opts ) end |
.list_owners(account, params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
316 317 318 319 320 321 322 323 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 316 def self.list_owners(account, params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 12 def self.object_name "financial_connections.account" end |
.refresh_account(account, params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
336 337 338 339 340 341 342 343 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 336 def self.refresh_account(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.subscribe(account, params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
356 357 358 359 360 361 362 363 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 356 def self.subscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
.unsubscribe(account, params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
376 377 378 379 380 381 382 383 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 376 def self.unsubscribe(account, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(account) }), params: params, opts: opts ) end |
Instance Method Details
#disconnect(params = {}, opts = {}) ⇒ Object
Disables your access to a Financial Connections Account. You will no longer be able to access data associated with the account (e.g. balances, transactions).
276 277 278 279 280 281 282 283 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 276 def disconnect(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/disconnect", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#list_owners(params = {}, opts = {}) ⇒ Object
Lists all owners for a given Account
306 307 308 309 310 311 312 313 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 306 def list_owners(params = {}, opts = {}) request_stripe_object( method: :get, path: format("/v1/financial_connections/accounts/%<account>s/owners", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#refresh_account(params = {}, opts = {}) ⇒ Object
Refreshes the data associated with a Financial Connections Account.
326 327 328 329 330 331 332 333 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 326 def refresh_account(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/refresh", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#subscribe(params = {}, opts = {}) ⇒ Object
Subscribes to periodic refreshes of data associated with a Financial Connections Account.
346 347 348 349 350 351 352 353 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 346 def subscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/subscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#unsubscribe(params = {}, opts = {}) ⇒ Object
Unsubscribes from periodic refreshes of data associated with a Financial Connections Account.
366 367 368 369 370 371 372 373 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 366 def unsubscribe(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/financial_connections/accounts/%<account>s/unsubscribe", { account: CGI.escape(self["id"]) }), params: params, opts: opts ) end |