Class: Stripe::FinancialConnections::Account::Balance
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FinancialConnections::Account::Balance
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#as_of ⇒ Object
readonly
The time that the external institution calculated this balance.
-
#cash ⇒ Object
readonly
Attribute for field cash.
-
#credit ⇒ Object
readonly
Attribute for field credit.
-
#current ⇒ Object
readonly
The balances owed to (or by) the account holder, before subtracting any outbound pending transactions or adding any inbound pending transactions.
-
#type ⇒ Object
readonly
The ‘type` of the balance.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#as_of ⇒ Object (readonly)
The time that the external institution calculated this balance. Measured in seconds since the Unix epoch.
46 47 48 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 46 def as_of @as_of end |
#cash ⇒ Object (readonly)
Attribute for field cash
48 49 50 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 48 def cash @cash end |
#credit ⇒ Object (readonly)
Attribute for field credit
50 51 52 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 50 def credit @credit end |
#current ⇒ Object (readonly)
The balances owed to (or by) the account holder, before subtracting any outbound pending transactions or adding any inbound pending transactions.
Each key is a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
Each value is a integer amount. A positive amount indicates money owed to the account holder. A negative amount indicates money owed by the account holder.
56 57 58 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 56 def current @current end |
#type ⇒ Object (readonly)
The ‘type` of the balance. An additional hash is included on the balance with a name matching this value.
58 59 60 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 58 def type @type end |