Class: Stripe::FinancialConnections::Account::InferredBalancesRefresh
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FinancialConnections::Account::InferredBalancesRefresh
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#last_attempted_at ⇒ Object
readonly
The time at which the last refresh attempt was initiated.
-
#next_refresh_available_at ⇒ Object
readonly
Time at which the next inferred balance refresh can be initiated.
-
#status ⇒ Object
readonly
The status of the last refresh attempt.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#last_attempted_at ⇒ Object (readonly)
The time at which the last refresh attempt was initiated. Measured in seconds since the Unix epoch.
133 134 135 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 133 def last_attempted_at @last_attempted_at end |
#next_refresh_available_at ⇒ Object (readonly)
Time at which the next inferred balance refresh can be initiated. This value will be null when status is pending. Measured in seconds since the Unix epoch.
135 136 137 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 135 def next_refresh_available_at @next_refresh_available_at end |
#status ⇒ Object (readonly)
The status of the last refresh attempt.
137 138 139 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 137 def status @status end |
Class Method Details
.field_remappings ⇒ Object
143 144 145 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 143 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
139 140 141 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 139 def self.inner_class_types @inner_class_types = {} end |