Class: Stripe::FinancialConnections::Account::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Defined Under Namespace

Classes: AccountHolder

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder: nil, ending_before: nil, expand: nil, limit: nil, session: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/stripe/resources/financial_connections/account.rb', line 145

def initialize(
  account_holder: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  session: nil,
  starting_after: nil
)
  @account_holder = 
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @session = session
  @starting_after = starting_after
end

Instance Attribute Details

#account_holderObject

If present, only return accounts that belong to the specified account holder. ‘account_holder` and `account_holder` are mutually exclusive.



128
129
130
# File 'lib/stripe/resources/financial_connections/account.rb', line 128

def 
  @account_holder
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



131
132
133
# File 'lib/stripe/resources/financial_connections/account.rb', line 131

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



134
135
136
# File 'lib/stripe/resources/financial_connections/account.rb', line 134

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



137
138
139
# File 'lib/stripe/resources/financial_connections/account.rb', line 137

def limit
  @limit
end

#sessionObject

If present, only return accounts that were collected as part of the given session.



140
141
142
# File 'lib/stripe/resources/financial_connections/account.rb', line 140

def session
  @session
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



143
144
145
# File 'lib/stripe/resources/financial_connections/account.rb', line 143

def starting_after
  @starting_after
end