Class: Stripe::FinancialConnections::Account::ListParams::AccountHolder
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Account::ListParams::AccountHolder
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
-
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
-
#customer_account ⇒ Object
The Account ID of the Stripe customer whose accounts will be retrieved.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder
constructor
A new instance of AccountHolder.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder
Returns a new instance of AccountHolder.
110 111 112 113 114 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 110 def initialize(account: nil, customer: nil, customer_account: nil) @account = account @customer = customer @customer_account = customer_account end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
104 105 106 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 104 def account @account end |
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
106 107 108 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 106 def customer @customer end |
#customer_account ⇒ Object
The Account ID of the Stripe customer whose accounts will be retrieved.
108 109 110 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 108 def customer_account @customer_account end |