Class: Stripe::FinancialConnections::Account::ListParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



94
95
96
97
# File 'lib/stripe/resources/financial_connections/account.rb', line 94

def initialize(account: nil, customer: nil)
  @account = 
  @customer = customer
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved.



90
91
92
# File 'lib/stripe/resources/financial_connections/account.rb', line 90

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved.



92
93
94
# File 'lib/stripe/resources/financial_connections/account.rb', line 92

def customer
  @customer
end