Class: Stripe::FinancialConnections::Account::ListParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



110
111
112
113
114
# File 'lib/stripe/resources/financial_connections/account.rb', line 110

def initialize(account: nil, customer: nil, customer_account: nil)
  @account = 
  @customer = customer
  @customer_account = 
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved.



104
105
106
# File 'lib/stripe/resources/financial_connections/account.rb', line 104

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved.



106
107
108
# File 'lib/stripe/resources/financial_connections/account.rb', line 106

def customer
  @customer
end

#customer_accountObject

The Account ID of the Stripe customer whose accounts will be retrieved.



108
109
110
# File 'lib/stripe/resources/financial_connections/account.rb', line 108

def 
  @customer_account
end