Class: Stripe::FinancialConnections::Account::ListParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



106
107
108
109
# File 'lib/stripe/resources/financial_connections/account.rb', line 106

def initialize(account: nil, customer: nil)
  @account = 
  @customer = customer
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved.



102
103
104
# File 'lib/stripe/resources/financial_connections/account.rb', line 102

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved.



104
105
106
# File 'lib/stripe/resources/financial_connections/account.rb', line 104

def customer
  @customer
end