Class: Stripe::FinancialConnections::Account::ListParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



122
123
124
125
# File 'lib/stripe/resources/financial_connections/account.rb', line 122

def initialize(account: nil, customer: nil)
  @account = 
  @customer = customer
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved.



117
118
119
# File 'lib/stripe/resources/financial_connections/account.rb', line 117

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved.



120
121
122
# File 'lib/stripe/resources/financial_connections/account.rb', line 120

def customer
  @customer
end