Class: Stripe::FinancialConnections::Account::ListParams::AccountHolder
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Account::ListParams::AccountHolder
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
-
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil) ⇒ AccountHolder
constructor
A new instance of AccountHolder.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, customer: nil) ⇒ AccountHolder
Returns a new instance of AccountHolder.
122 123 124 125 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 122 def initialize(account: nil, customer: nil) @account = account @customer = customer end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
117 118 119 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 117 def account @account end |
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
120 121 122 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 120 def customer @customer end |