Class: Stripe::FinancialConnections::Account::OwnershipRefresh
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FinancialConnections::Account::OwnershipRefresh
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#last_attempted_at ⇒ Object
readonly
The time at which the last refresh attempt was initiated.
-
#next_refresh_available_at ⇒ Object
readonly
Time at which the next ownership refresh can be initiated.
-
#status ⇒ Object
readonly
The status of the last refresh attempt.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#last_attempted_at ⇒ Object (readonly)
The time at which the last refresh attempt was initiated. Measured in seconds since the Unix epoch.
188 189 190 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 188 def last_attempted_at @last_attempted_at end |
#next_refresh_available_at ⇒ Object (readonly)
Time at which the next ownership refresh can be initiated. This value will be null when status is pending. Measured in seconds since the Unix epoch.
190 191 192 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 190 def next_refresh_available_at @next_refresh_available_at end |
#status ⇒ Object (readonly)
The status of the last refresh attempt.
192 193 194 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 192 def status @status end |
Class Method Details
.field_remappings ⇒ Object
198 199 200 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 198 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
194 195 196 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 194 def self.inner_class_types @inner_class_types = {} end |