Class: Stripe::FinancialConnections::Account::OwnershipRefresh

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#last_attempted_atObject (readonly)

The time at which the last refresh attempt was initiated. Measured in seconds since the Unix epoch.



150
151
152
# File 'lib/stripe/resources/financial_connections/account.rb', line 150

def last_attempted_at
  @last_attempted_at
end

#next_refresh_available_atObject (readonly)

Time at which the next ownership refresh can be initiated. This value will be null when status is pending. Measured in seconds since the Unix epoch.



152
153
154
# File 'lib/stripe/resources/financial_connections/account.rb', line 152

def next_refresh_available_at
  @next_refresh_available_at
end

#statusObject (readonly)

The status of the last refresh attempt.



154
155
156
# File 'lib/stripe/resources/financial_connections/account.rb', line 154

def status
  @status
end

Class Method Details

.field_remappingsObject



160
161
162
# File 'lib/stripe/resources/financial_connections/account.rb', line 160

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



156
157
158
# File 'lib/stripe/resources/financial_connections/account.rb', line 156

def self.inner_class_types
  @inner_class_types = {}
end