Class: Stripe::FinancialConnections::Account::RefreshAccountParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Account::RefreshAccountParams
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
The list of account features that you would like to refresh.
Instance Method Summary collapse
-
#initialize(expand: nil, features: nil) ⇒ RefreshAccountParams
constructor
A new instance of RefreshAccountParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, features: nil) ⇒ RefreshAccountParams
Returns a new instance of RefreshAccountParams.
192 193 194 195 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 192 def initialize(expand: nil, features: nil) @expand = @features = features end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
188 189 190 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 188 def @expand end |
#features ⇒ Object
The list of account features that you would like to refresh.
190 191 192 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 190 def features @features end |