Class: Stripe::FinancialConnections::Account::SubscribeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Account::SubscribeParams
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
The list of account features to which you would like to subscribe.
Instance Method Summary collapse
-
#initialize(expand: nil, features: nil) ⇒ SubscribeParams
constructor
A new instance of SubscribeParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, features: nil) ⇒ SubscribeParams
Returns a new instance of SubscribeParams.
264 265 266 267 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 264 def initialize(expand: nil, features: nil) @expand = @features = features end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
260 261 262 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 260 def @expand end |
#features ⇒ Object
The list of account features to which you would like to subscribe.
262 263 264 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 262 def features @features end |