Class: Stripe::FinancialConnections::Account::SubscribeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Account::SubscribeParams
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
The list of account features to which you would like to subscribe.
Instance Method Summary collapse
-
#initialize(expand: nil, features: nil) ⇒ SubscribeParams
constructor
A new instance of SubscribeParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, features: nil) ⇒ SubscribeParams
Returns a new instance of SubscribeParams.
200 201 202 203 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 200 def initialize(expand: nil, features: nil) @expand = @features = features end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
196 197 198 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 196 def @expand end |
#features ⇒ Object
The list of account features to which you would like to subscribe.
198 199 200 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 198 def features @features end |