Class: Stripe::FinancialConnections::Account::SubscribeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Account::SubscribeParams
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
The list of account features to which you would like to subscribe.
Instance Method Summary collapse
-
#initialize(expand: nil, features: nil) ⇒ SubscribeParams
constructor
A new instance of SubscribeParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, features: nil) ⇒ SubscribeParams
Returns a new instance of SubscribeParams.
183 184 185 186 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 183 def initialize(expand: nil, features: nil) @expand = @features = features end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
179 180 181 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 179 def @expand end |
#features ⇒ Object
The list of account features to which you would like to subscribe.
181 182 183 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 181 def features @features end |