Class: Stripe::FinancialConnections::Account::SubscribeParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ SubscribeParams

Returns a new instance of SubscribeParams.



204
205
206
207
# File 'lib/stripe/resources/financial_connections/account.rb', line 204

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



200
201
202
# File 'lib/stripe/resources/financial_connections/account.rb', line 200

def expand
  @expand
end

#featuresObject

The list of account features to which you would like to subscribe.



202
203
204
# File 'lib/stripe/resources/financial_connections/account.rb', line 202

def features
  @features
end