Class: Stripe::FinancialConnections::Account::SubscribeParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ SubscribeParams

Returns a new instance of SubscribeParams.



231
232
233
234
# File 'lib/stripe/resources/financial_connections/account.rb', line 231

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



226
227
228
# File 'lib/stripe/resources/financial_connections/account.rb', line 226

def expand
  @expand
end

#featuresObject

The list of account features to which you would like to subscribe.



229
230
231
# File 'lib/stripe/resources/financial_connections/account.rb', line 229

def features
  @features
end