Class: Stripe::FinancialConnections::Account::TransactionRefresh
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FinancialConnections::Account::TransactionRefresh
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_attempted_at ⇒ Object
readonly
The time at which the last refresh attempt was initiated.
-
#next_refresh_available_at ⇒ Object
readonly
Time at which the next transaction refresh can be initiated.
-
#status ⇒ Object
readonly
The status of the last refresh attempt.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
Unique identifier for the object.
251 252 253 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 251 def id @id end |
#last_attempted_at ⇒ Object (readonly)
The time at which the last refresh attempt was initiated. Measured in seconds since the Unix epoch.
253 254 255 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 253 def last_attempted_at @last_attempted_at end |
#next_refresh_available_at ⇒ Object (readonly)
Time at which the next transaction refresh can be initiated. This value will be null when status is pending. Measured in seconds since the Unix epoch.
255 256 257 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 255 def next_refresh_available_at @next_refresh_available_at end |
#status ⇒ Object (readonly)
The status of the last refresh attempt.
257 258 259 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 257 def status @status end |
Class Method Details
.field_remappings ⇒ Object
263 264 265 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 263 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
259 260 261 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 259 def self.inner_class_types @inner_class_types = {} end |