Class: Stripe::FinancialConnections::Account::TransactionRefresh

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/account.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#idObject (readonly)

Unique identifier for the object.



213
214
215
# File 'lib/stripe/resources/financial_connections/account.rb', line 213

def id
  @id
end

#last_attempted_atObject (readonly)

The time at which the last refresh attempt was initiated. Measured in seconds since the Unix epoch.



215
216
217
# File 'lib/stripe/resources/financial_connections/account.rb', line 215

def last_attempted_at
  @last_attempted_at
end

#next_refresh_available_atObject (readonly)

Time at which the next transaction refresh can be initiated. This value will be null when status is pending. Measured in seconds since the Unix epoch.



217
218
219
# File 'lib/stripe/resources/financial_connections/account.rb', line 217

def next_refresh_available_at
  @next_refresh_available_at
end

#statusObject (readonly)

The status of the last refresh attempt.



219
220
221
# File 'lib/stripe/resources/financial_connections/account.rb', line 219

def status
  @status
end

Class Method Details

.field_remappingsObject



225
226
227
# File 'lib/stripe/resources/financial_connections/account.rb', line 225

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



221
222
223
# File 'lib/stripe/resources/financial_connections/account.rb', line 221

def self.inner_class_types
  @inner_class_types = {}
end