Class: Stripe::FinancialConnections::Account::UnsubscribeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Account::UnsubscribeParams
- Defined in:
- lib/stripe/resources/financial_connections/account.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
The list of account features from which you would like to unsubscribe.
Instance Method Summary collapse
-
#initialize(expand: nil, features: nil) ⇒ UnsubscribeParams
constructor
A new instance of UnsubscribeParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, features: nil) ⇒ UnsubscribeParams
Returns a new instance of UnsubscribeParams.
195 196 197 198 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 195 def initialize(expand: nil, features: nil) @expand = @features = features end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
191 192 193 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 191 def @expand end |
#features ⇒ Object
The list of account features from which you would like to unsubscribe.
193 194 195 |
# File 'lib/stripe/resources/financial_connections/account.rb', line 193 def features @features end |