Class: Stripe::FinancialConnections::AccountInferredBalance
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::AccountInferredBalance
- Defined in:
- lib/stripe/resources/financial_connections/account_inferred_balance.rb
Overview
A historical balance for the account on a particular day. It may be sourced from a balance snapshot provided by a financial institution, or inferred using transactions data.
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.account_inferred_balance"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#as_of ⇒ Object
readonly
The time for which this balance was calculated, measured in seconds since the Unix epoch.
-
#current ⇒ Object
readonly
The balances owed to (or by) the account holder, before subtracting any outbound pending transactions or adding any inbound pending transactions.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#as_of ⇒ Object (readonly)
The time for which this balance was calculated, measured in seconds since the Unix epoch. If the balance was computed by Stripe and not provided directly by a financial institution, it will always be 23:59:59 UTC.
14 15 16 |
# File 'lib/stripe/resources/financial_connections/account_inferred_balance.rb', line 14 def as_of @as_of end |
#current ⇒ Object (readonly)
The balances owed to (or by) the account holder, before subtracting any outbound pending transactions or adding any inbound pending transactions.
Each key is a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
Each value is a integer amount. A positive amount indicates money owed to the account holder. A negative amount indicates money owed by the account holder.
21 22 23 |
# File 'lib/stripe/resources/financial_connections/account_inferred_balance.rb', line 21 def current @current end |
#id ⇒ Object (readonly)
Unique identifier for the object.
24 25 26 |
# File 'lib/stripe/resources/financial_connections/account_inferred_balance.rb', line 24 def id @id end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
27 28 29 |
# File 'lib/stripe/resources/financial_connections/account_inferred_balance.rb', line 27 def object @object end |
Class Method Details
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/financial_connections/account_inferred_balance.rb', line 9 def self.object_name "financial_connections.account_inferred_balance" end |