Class: Stripe::FinancialConnections::AccountListParams::AccountHolder
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::AccountListParams::AccountHolder
- Defined in:
- lib/stripe/params/financial_connections/account_list_params.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose accounts you will retrieve.
-
#customer ⇒ Object
The ID of the Stripe customer whose accounts you will retrieve.
-
#customer_account ⇒ Object
The ID of the Account representing a customer whose accounts you will retrieve.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder
constructor
A new instance of AccountHolder.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account: nil, customer: nil, customer_account: nil) ⇒ AccountHolder
Returns a new instance of AccountHolder.
15 16 17 18 19 |
# File 'lib/stripe/params/financial_connections/account_list_params.rb', line 15 def initialize(account: nil, customer: nil, customer_account: nil) @account = account @customer = customer @customer_account = customer_account end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose accounts you will retrieve.
9 10 11 |
# File 'lib/stripe/params/financial_connections/account_list_params.rb', line 9 def account @account end |
#customer ⇒ Object
The ID of the Stripe customer whose accounts you will retrieve.
11 12 13 |
# File 'lib/stripe/params/financial_connections/account_list_params.rb', line 11 def customer @customer end |
#customer_account ⇒ Object
The ID of the Account representing a customer whose accounts you will retrieve.
13 14 15 |
# File 'lib/stripe/params/financial_connections/account_list_params.rb', line 13 def customer_account @customer_account end |