Class: Stripe::FinancialConnections::AccountService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::AccountService::ListParams
- Defined in:
- lib/stripe/services/financial_connections/account_service.rb
Defined Under Namespace
Classes: AccountHolder
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
If present, only return accounts that belong to the specified account holder.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#session ⇒ Object
If present, only return accounts that were collected as part of the given session.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(account_holder: nil, ending_before: nil, expand: nil, limit: nil, session: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder: nil, ending_before: nil, expand: nil, limit: nil, session: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 44 def initialize( account_holder: nil, ending_before: nil, expand: nil, limit: nil, session: nil, starting_after: nil ) @account_holder = account_holder @ending_before = ending_before @expand = @limit = limit @session = session @starting_after = starting_after end |
Instance Attribute Details
#account_holder ⇒ Object
If present, only return accounts that belong to the specified account holder. ‘account_holder` and `account_holder` are mutually exclusive.
32 33 34 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 32 def account_holder @account_holder end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
34 35 36 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 34 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
36 37 38 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 36 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
38 39 40 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 38 def limit @limit end |
#session ⇒ Object
If present, only return accounts that were collected as part of the given session.
40 41 42 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 40 def session @session end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
42 43 44 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 42 def starting_after @starting_after end |