Class: Stripe::FinancialConnections::AccountService::RefreshParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/financial_connections/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ RefreshParams

Returns a new instance of RefreshParams.



82
83
84
85
# File 'lib/stripe/services/financial_connections/account_service.rb', line 82

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



78
79
80
# File 'lib/stripe/services/financial_connections/account_service.rb', line 78

def expand
  @expand
end

#featuresObject

The list of account features that you would like to refresh.



80
81
82
# File 'lib/stripe/services/financial_connections/account_service.rb', line 80

def features
  @features
end