Class: Stripe::FinancialConnections::AccountService::RefreshParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/financial_connections/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ RefreshParams

Returns a new instance of RefreshParams.



89
90
91
92
# File 'lib/stripe/services/financial_connections/account_service.rb', line 89

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



84
85
86
# File 'lib/stripe/services/financial_connections/account_service.rb', line 84

def expand
  @expand
end

#featuresObject

The list of account features that you would like to refresh.



87
88
89
# File 'lib/stripe/services/financial_connections/account_service.rb', line 87

def features
  @features
end