Class: Stripe::FinancialConnections::AccountService::SubscribeParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::AccountService::SubscribeParams
- Defined in:
- lib/stripe/services/financial_connections/account_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#features ⇒ Object
The list of account features to which you would like to subscribe.
Instance Method Summary collapse
-
#initialize(expand: nil, features: nil) ⇒ SubscribeParams
constructor
A new instance of SubscribeParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, features: nil) ⇒ SubscribeParams
Returns a new instance of SubscribeParams.
94 95 96 97 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 94 def initialize(expand: nil, features: nil) @expand = @features = features end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
90 91 92 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 90 def @expand end |
#features ⇒ Object
The list of account features to which you would like to subscribe.
92 93 94 |
# File 'lib/stripe/services/financial_connections/account_service.rb', line 92 def features @features end |