Class: Stripe::FinancialConnections::AccountService::SubscribeParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/financial_connections/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ SubscribeParams

Returns a new instance of SubscribeParams.



94
95
96
97
# File 'lib/stripe/services/financial_connections/account_service.rb', line 94

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



90
91
92
# File 'lib/stripe/services/financial_connections/account_service.rb', line 90

def expand
  @expand
end

#featuresObject

The list of account features to which you would like to subscribe.



92
93
94
# File 'lib/stripe/services/financial_connections/account_service.rb', line 92

def features
  @features
end