Class: Stripe::FinancialConnections::AccountService::UnsubscribeParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/financial_connections/account_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, features: nil) ⇒ UnsubscribeParams

Returns a new instance of UnsubscribeParams.



115
116
117
118
# File 'lib/stripe/services/financial_connections/account_service.rb', line 115

def initialize(expand: nil, features: nil)
  @expand = expand
  @features = features
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



110
111
112
# File 'lib/stripe/services/financial_connections/account_service.rb', line 110

def expand
  @expand
end

#featuresObject

The list of account features from which you would like to unsubscribe.



113
114
115
# File 'lib/stripe/services/financial_connections/account_service.rb', line 113

def features
  @features
end