Class: Stripe::FinancialConnections::Authorization
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Authorization
- Defined in:
- lib/stripe/resources/financial_connections/authorization.rb
Overview
An Authorization represents the set of credentials used to connect a group of Financial Connections Accounts.
Defined Under Namespace
Classes: AccountHolder, StatusDetails
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.authorization"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
readonly
The account holder that this authorization belongs to.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#institution ⇒ Object
readonly
The ID of the Financial Connections Institution this account belongs to.
-
#institution_name ⇒ Object
readonly
The name of the institution that this authorization belongs to.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
The status of the connection to the Authorization.
-
#status_details ⇒ Object
readonly
Attribute for field status_details.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder ⇒ Object (readonly)
The account holder that this authorization belongs to.
57 58 59 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 57 def account_holder @account_holder end |
#id ⇒ Object (readonly)
Unique identifier for the object.
59 60 61 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 59 def id @id end |
#institution ⇒ Object (readonly)
The ID of the Financial Connections Institution this account belongs to. Note that this relationship may sometimes change in rare circumstances (e.g. institution mergers).
61 62 63 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 61 def institution @institution end |
#institution_name ⇒ Object (readonly)
The name of the institution that this authorization belongs to.
63 64 65 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 63 def institution_name @institution_name end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
65 66 67 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 65 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
67 68 69 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 67 def object @object end |
#status ⇒ Object (readonly)
The status of the connection to the Authorization.
69 70 71 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 69 def status @status end |
#status_details ⇒ Object (readonly)
Attribute for field status_details
71 72 73 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 71 def status_details @status_details end |
Class Method Details
.field_remappings ⇒ Object
77 78 79 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 77 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
73 74 75 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 73 def self.inner_class_types @inner_class_types = { account_holder: AccountHolder, status_details: StatusDetails } end |
.object_name ⇒ Object
9 10 11 |
# File 'lib/stripe/resources/financial_connections/authorization.rb', line 9 def self.object_name "financial_connections.authorization" end |