Class: Stripe::FinancialConnections::Institution

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/financial_connections/institution.rb

Overview

An institution represents a financial institution to which an end user can connect using the Financial Connections authentication flow.

Defined Under Namespace

Classes: Features, ListParams

Constant Summary collapse

OBJECT_NAME =
"financial_connections.institution"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countriesObject (readonly)

The list of countries supported by this institution, formatted as ISO country codes.



108
109
110
# File 'lib/stripe/resources/financial_connections/institution.rb', line 108

def countries
  @countries
end

#featuresObject (readonly)

Attribute for field features



110
111
112
# File 'lib/stripe/resources/financial_connections/institution.rb', line 110

def features
  @features
end

#idObject (readonly)

Unique identifier for the object.



112
113
114
# File 'lib/stripe/resources/financial_connections/institution.rb', line 112

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



114
115
116
# File 'lib/stripe/resources/financial_connections/institution.rb', line 114

def livemode
  @livemode
end

#nameObject (readonly)

The name of this institution.



116
117
118
# File 'lib/stripe/resources/financial_connections/institution.rb', line 116

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



118
119
120
# File 'lib/stripe/resources/financial_connections/institution.rb', line 118

def object
  @object
end

#routing_numbersObject (readonly)

A list of routing numbers which are known to correspond to this institution. Due to the many to many relationship between institutions and routing numbers, this list may not be comprehensive and routing numbers may also be shared between institutions.



120
121
122
# File 'lib/stripe/resources/financial_connections/institution.rb', line 120

def routing_numbers
  @routing_numbers
end

#statusObject (readonly)

The status of this institution in the Financial Connections authentication flow.



122
123
124
# File 'lib/stripe/resources/financial_connections/institution.rb', line 122

def status
  @status
end

#urlObject (readonly)

A URL corresponding to this institution. This URL is also displayed in the authentication flow to help end users confirm that they are authenticating with the right institution.



124
125
126
# File 'lib/stripe/resources/financial_connections/institution.rb', line 124

def url
  @url
end

Class Method Details

.field_remappingsObject



140
141
142
# File 'lib/stripe/resources/financial_connections/institution.rb', line 140

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



136
137
138
# File 'lib/stripe/resources/financial_connections/institution.rb', line 136

def self.inner_class_types
  @inner_class_types = { features: Features }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Financial Connections Institution objects.



127
128
129
130
131
132
133
134
# File 'lib/stripe/resources/financial_connections/institution.rb', line 127

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/financial_connections/institutions",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/institution.rb', line 11

def self.object_name
  "financial_connections.institution"
end