Class: Stripe::FinancialConnections::Institution

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/financial_connections/institution.rb

Overview

An institution represents a financial institution to which an end user can connect using the Financial Connections authentication flow.

Defined Under Namespace

Classes: Features

Constant Summary collapse

OBJECT_NAME =
"financial_connections.institution"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#featuresObject (readonly)

Attribute for field features



34
35
36
# File 'lib/stripe/resources/financial_connections/institution.rb', line 34

def features
  @features
end

#idObject (readonly)

Unique identifier for the object.



36
37
38
# File 'lib/stripe/resources/financial_connections/institution.rb', line 36

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



38
39
40
# File 'lib/stripe/resources/financial_connections/institution.rb', line 38

def livemode
  @livemode
end

#nameObject (readonly)

The name of this institution.



40
41
42
# File 'lib/stripe/resources/financial_connections/institution.rb', line 40

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



42
43
44
# File 'lib/stripe/resources/financial_connections/institution.rb', line 42

def object
  @object
end

#routing_numbersObject (readonly)

A list of routing numbers which are known to correspond to this institution. Due to the many to many relationship between institutions and routing numbers, this list may not be comprehensive and routing numbers may also be shared between institutions.



44
45
46
# File 'lib/stripe/resources/financial_connections/institution.rb', line 44

def routing_numbers
  @routing_numbers
end

#statusObject (readonly)

The status of this institution in the Financial Connections authentication flow.



46
47
48
# File 'lib/stripe/resources/financial_connections/institution.rb', line 46

def status
  @status
end

#urlObject (readonly)

A URL corresponding to this institution. This URL is also displayed in the authentication flow to help end users confirm that they are authenticating with the right institution.



48
49
50
# File 'lib/stripe/resources/financial_connections/institution.rb', line 48

def url
  @url
end

Class Method Details

.list(filters = {}, opts = {}) ⇒ Object

Returns a list of Financial Connections Institution objects.



51
52
53
54
55
56
57
58
# File 'lib/stripe/resources/financial_connections/institution.rb', line 51

def self.list(filters = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/financial_connections/institutions",
    params: filters,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/institution.rb', line 11

def self.object_name
  "financial_connections.institution"
end