Class: Stripe::FinancialConnections::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/financial_connections/session.rb

Overview

A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.

Defined Under Namespace

Classes: AccountHolder, Filters, Hosted, Limits, ManualEntry, RelinkOptions, RelinkResult, StatusDetails

Constant Summary collapse

OBJECT_NAME =
"financial_connections.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder for whom accounts are collected in this session.



151
152
153
# File 'lib/stripe/resources/financial_connections/session.rb', line 151

def 
  @account_holder
end

#accountsObject (readonly)

The accounts that were collected as part of this Session.



153
154
155
# File 'lib/stripe/resources/financial_connections/session.rb', line 153

def accounts
  @accounts
end

#bank_account_tokenObject (readonly)

Tokenization is the process Stripe uses to collect sensitive card or bank account details, or personally identifiable information (PII), directly from your customers in a secure manner. A token representing this information is returned to your server to use. Use our recommended payments integrations to perform this process on the client-side. This guarantees that no sensitive card data touches your server, and allows your integration to operate in a PCI-compliant way.

If you can't use client-side tokenization, you can also create tokens using the API with either your publishable or secret API key. If your integration uses this method, you're responsible for any PCI compliance that it might require, and you must keep your secret API key safe. Unlike with client-side tokenization, your customer's information isn't sent directly to Stripe, so we can't determine how it's handled or stored.

You can't store or use tokens more than once. To store card or bank account information for later use, create Customer objects or External accounts. Radar, our integrated solution for automatic fraud protection, performs best with integrations that use client-side tokenization.



174
175
176
# File 'lib/stripe/resources/financial_connections/session.rb', line 174

def 
  @bank_account_token
end

#client_secretObject (readonly)

A value that will be passed to the client to launch the authentication flow.



176
177
178
# File 'lib/stripe/resources/financial_connections/session.rb', line 176

def client_secret
  @client_secret
end

#filtersObject (readonly)

Attribute for field filters



178
179
180
# File 'lib/stripe/resources/financial_connections/session.rb', line 178

def filters
  @filters
end

#hostedObject (readonly)

Settings for the Hosted UI mode.



180
181
182
# File 'lib/stripe/resources/financial_connections/session.rb', line 180

def hosted
  @hosted
end

#idObject (readonly)

Unique identifier for the object.



182
183
184
# File 'lib/stripe/resources/financial_connections/session.rb', line 182

def id
  @id
end

#limitsObject (readonly)

Attribute for field limits



184
185
186
# File 'lib/stripe/resources/financial_connections/session.rb', line 184

def limits
  @limits
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



186
187
188
# File 'lib/stripe/resources/financial_connections/session.rb', line 186

def livemode
  @livemode
end

#manual_entryObject (readonly)

Attribute for field manual_entry



188
189
190
# File 'lib/stripe/resources/financial_connections/session.rb', line 188

def manual_entry
  @manual_entry
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



190
191
192
# File 'lib/stripe/resources/financial_connections/session.rb', line 190

def object
  @object
end

#permissionsObject (readonly)

Permissions requested for accounts collected during this session.



192
193
194
# File 'lib/stripe/resources/financial_connections/session.rb', line 192

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



194
195
196
# File 'lib/stripe/resources/financial_connections/session.rb', line 194

def prefetch
  @prefetch
end

Attribute for field relink_options



196
197
198
# File 'lib/stripe/resources/financial_connections/session.rb', line 196

def relink_options
  @relink_options
end

Attribute for field relink_result



198
199
200
# File 'lib/stripe/resources/financial_connections/session.rb', line 198

def relink_result
  @relink_result
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



200
201
202
# File 'lib/stripe/resources/financial_connections/session.rb', line 200

def return_url
  @return_url
end

#statusObject (readonly)

The current state of the session.



202
203
204
# File 'lib/stripe/resources/financial_connections/session.rb', line 202

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



204
205
206
# File 'lib/stripe/resources/financial_connections/session.rb', line 204

def status_details
  @status_details
end

#ui_modeObject (readonly)

The UI mode for this session.



206
207
208
# File 'lib/stripe/resources/financial_connections/session.rb', line 206

def ui_mode
  @ui_mode
end

#urlObject (readonly)

The hosted URL for this Session. Redirect customers to this URL to take them to the hosted authentication flow. This value is only present when the Session is active and the ui_mode is hosted.



208
209
210
# File 'lib/stripe/resources/financial_connections/session.rb', line 208

def url
  @url
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

To launch the Financial Connections authorization flow, create a Session. The session's client_secret can be used to launch the flow using Stripe.js.



211
212
213
214
215
216
217
218
# File 'lib/stripe/resources/financial_connections/session.rb', line 211

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/financial_connections/sessions",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



233
234
235
# File 'lib/stripe/resources/financial_connections/session.rb', line 233

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/stripe/resources/financial_connections/session.rb', line 220

def self.inner_class_types
  @inner_class_types = {
    account_holder: AccountHolder,
    filters: Filters,
    hosted: Hosted,
    limits: Limits,
    manual_entry: ManualEntry,
    relink_options: RelinkOptions,
    relink_result: RelinkResult,
    status_details: StatusDetails,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/session.rb', line 11

def self.object_name
  "financial_connections.session"
end