Class: Stripe::FinancialConnections::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/financial_connections/session.rb

Overview

A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.

Defined Under Namespace

Classes: AccountHolder, Filters, Hosted, Limits, ManualEntry, RelinkOptions, RelinkResult, StatusDetails

Constant Summary collapse

OBJECT_NAME =
"financial_connections.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder for whom accounts are collected in this session.



146
147
148
# File 'lib/stripe/resources/financial_connections/session.rb', line 146

def 
  @account_holder
end

#accountsObject (readonly)

The accounts that were collected as part of this Session.



148
149
150
# File 'lib/stripe/resources/financial_connections/session.rb', line 148

def accounts
  @accounts
end

#client_secretObject (readonly)

A value that will be passed to the client to launch the authentication flow.



150
151
152
# File 'lib/stripe/resources/financial_connections/session.rb', line 150

def client_secret
  @client_secret
end

#filtersObject (readonly)

Attribute for field filters



152
153
154
# File 'lib/stripe/resources/financial_connections/session.rb', line 152

def filters
  @filters
end

#hostedObject (readonly)

Settings for the Hosted UI mode.



154
155
156
# File 'lib/stripe/resources/financial_connections/session.rb', line 154

def hosted
  @hosted
end

#idObject (readonly)

Unique identifier for the object.



156
157
158
# File 'lib/stripe/resources/financial_connections/session.rb', line 156

def id
  @id
end

#limitsObject (readonly)

Attribute for field limits



158
159
160
# File 'lib/stripe/resources/financial_connections/session.rb', line 158

def limits
  @limits
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



160
161
162
# File 'lib/stripe/resources/financial_connections/session.rb', line 160

def livemode
  @livemode
end

#manual_entryObject (readonly)

Attribute for field manual_entry



162
163
164
# File 'lib/stripe/resources/financial_connections/session.rb', line 162

def manual_entry
  @manual_entry
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



164
165
166
# File 'lib/stripe/resources/financial_connections/session.rb', line 164

def object
  @object
end

#permissionsObject (readonly)

Permissions requested for accounts collected during this session.



166
167
168
# File 'lib/stripe/resources/financial_connections/session.rb', line 166

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



168
169
170
# File 'lib/stripe/resources/financial_connections/session.rb', line 168

def prefetch
  @prefetch
end

Attribute for field relink_options



170
171
172
# File 'lib/stripe/resources/financial_connections/session.rb', line 170

def relink_options
  @relink_options
end

Attribute for field relink_result



172
173
174
# File 'lib/stripe/resources/financial_connections/session.rb', line 172

def relink_result
  @relink_result
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



174
175
176
# File 'lib/stripe/resources/financial_connections/session.rb', line 174

def return_url
  @return_url
end

#statusObject (readonly)

The current state of the session.



176
177
178
# File 'lib/stripe/resources/financial_connections/session.rb', line 176

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



178
179
180
# File 'lib/stripe/resources/financial_connections/session.rb', line 178

def status_details
  @status_details
end

#ui_modeObject (readonly)

The UI mode for this session.



180
181
182
# File 'lib/stripe/resources/financial_connections/session.rb', line 180

def ui_mode
  @ui_mode
end

#urlObject (readonly)

The hosted URL for this Session. Redirect customers to this URL to take them to the hosted authentication flow. This value is only present when the Session is active and the ‘ui_mode` is `hosted`.



182
183
184
# File 'lib/stripe/resources/financial_connections/session.rb', line 182

def url
  @url
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

To launch the Financial Connections authorization flow, create a Session. The session’s client_secret can be used to launch the flow using Stripe.js.



185
186
187
188
189
190
191
192
# File 'lib/stripe/resources/financial_connections/session.rb', line 185

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/financial_connections/sessions",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



207
208
209
# File 'lib/stripe/resources/financial_connections/session.rb', line 207

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/stripe/resources/financial_connections/session.rb', line 194

def self.inner_class_types
  @inner_class_types = {
    account_holder: AccountHolder,
    filters: Filters,
    hosted: Hosted,
    limits: Limits,
    manual_entry: ManualEntry,
    relink_options: RelinkOptions,
    relink_result: RelinkResult,
    status_details: StatusDetails,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/session.rb', line 11

def self.object_name
  "financial_connections.session"
end