Class: Stripe::FinancialConnections::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/financial_connections/session.rb

Overview

A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.

Defined Under Namespace

Classes: AccountHolder, Filters, Limits, ManualEntry, RelinkOptions, RelinkResult, StatusDetails

Constant Summary collapse

OBJECT_NAME =
"financial_connections.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder for whom accounts are collected in this session.



131
132
133
# File 'lib/stripe/resources/financial_connections/session.rb', line 131

def 
  @account_holder
end

#accountsObject (readonly)

The accounts that were collected as part of this Session.



133
134
135
# File 'lib/stripe/resources/financial_connections/session.rb', line 133

def accounts
  @accounts
end

#client_secretObject (readonly)

A value that will be passed to the client to launch the authentication flow.



135
136
137
# File 'lib/stripe/resources/financial_connections/session.rb', line 135

def client_secret
  @client_secret
end

#filtersObject (readonly)

Attribute for field filters



137
138
139
# File 'lib/stripe/resources/financial_connections/session.rb', line 137

def filters
  @filters
end

#idObject (readonly)

Unique identifier for the object.



139
140
141
# File 'lib/stripe/resources/financial_connections/session.rb', line 139

def id
  @id
end

#limitsObject (readonly)

Attribute for field limits



141
142
143
# File 'lib/stripe/resources/financial_connections/session.rb', line 141

def limits
  @limits
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



143
144
145
# File 'lib/stripe/resources/financial_connections/session.rb', line 143

def livemode
  @livemode
end

#manual_entryObject (readonly)

Attribute for field manual_entry



145
146
147
# File 'lib/stripe/resources/financial_connections/session.rb', line 145

def manual_entry
  @manual_entry
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



147
148
149
# File 'lib/stripe/resources/financial_connections/session.rb', line 147

def object
  @object
end

#permissionsObject (readonly)

Permissions requested for accounts collected during this session.



149
150
151
# File 'lib/stripe/resources/financial_connections/session.rb', line 149

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



151
152
153
# File 'lib/stripe/resources/financial_connections/session.rb', line 151

def prefetch
  @prefetch
end

Attribute for field relink_options



153
154
155
# File 'lib/stripe/resources/financial_connections/session.rb', line 153

def relink_options
  @relink_options
end

Attribute for field relink_result



155
156
157
# File 'lib/stripe/resources/financial_connections/session.rb', line 155

def relink_result
  @relink_result
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



157
158
159
# File 'lib/stripe/resources/financial_connections/session.rb', line 157

def return_url
  @return_url
end

#statusObject (readonly)

The current state of the session.



159
160
161
# File 'lib/stripe/resources/financial_connections/session.rb', line 159

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



161
162
163
# File 'lib/stripe/resources/financial_connections/session.rb', line 161

def status_details
  @status_details
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

To launch the Financial Connections authorization flow, create a Session. The session’s client_secret can be used to launch the flow using Stripe.js.



164
165
166
167
168
169
170
171
# File 'lib/stripe/resources/financial_connections/session.rb', line 164

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/financial_connections/sessions",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



185
186
187
# File 'lib/stripe/resources/financial_connections/session.rb', line 185

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



173
174
175
176
177
178
179
180
181
182
183
# File 'lib/stripe/resources/financial_connections/session.rb', line 173

def self.inner_class_types
  @inner_class_types = {
    account_holder: AccountHolder,
    filters: Filters,
    limits: Limits,
    manual_entry: ManualEntry,
    relink_options: RelinkOptions,
    relink_result: RelinkResult,
    status_details: StatusDetails,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/session.rb', line 11

def self.object_name
  "financial_connections.session"
end