Class: Stripe::FinancialConnections::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/financial_connections/session.rb

Overview

A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.

Defined Under Namespace

Classes: AccountHolder, Filters, Limits, ManualEntry, StatusDetails

Constant Summary collapse

OBJECT_NAME =
"financial_connections.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder for whom accounts are collected in this session.



99
100
101
# File 'lib/stripe/resources/financial_connections/session.rb', line 99

def 
  @account_holder
end

#accountsObject (readonly)

The accounts that were collected as part of this Session.



101
102
103
# File 'lib/stripe/resources/financial_connections/session.rb', line 101

def accounts
  @accounts
end

#client_secretObject (readonly)

A value that will be passed to the client to launch the authentication flow.



103
104
105
# File 'lib/stripe/resources/financial_connections/session.rb', line 103

def client_secret
  @client_secret
end

#filtersObject (readonly)

Attribute for field filters



105
106
107
# File 'lib/stripe/resources/financial_connections/session.rb', line 105

def filters
  @filters
end

#idObject (readonly)

Unique identifier for the object.



107
108
109
# File 'lib/stripe/resources/financial_connections/session.rb', line 107

def id
  @id
end

#limitsObject (readonly)

Attribute for field limits



109
110
111
# File 'lib/stripe/resources/financial_connections/session.rb', line 109

def limits
  @limits
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



111
112
113
# File 'lib/stripe/resources/financial_connections/session.rb', line 111

def livemode
  @livemode
end

#manual_entryObject (readonly)

Attribute for field manual_entry



113
114
115
# File 'lib/stripe/resources/financial_connections/session.rb', line 113

def manual_entry
  @manual_entry
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



115
116
117
# File 'lib/stripe/resources/financial_connections/session.rb', line 115

def object
  @object
end

#permissionsObject (readonly)

Permissions requested for accounts collected during this session.



117
118
119
# File 'lib/stripe/resources/financial_connections/session.rb', line 117

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



119
120
121
# File 'lib/stripe/resources/financial_connections/session.rb', line 119

def prefetch
  @prefetch
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



121
122
123
# File 'lib/stripe/resources/financial_connections/session.rb', line 121

def return_url
  @return_url
end

#statusObject (readonly)

The current state of the session.



123
124
125
# File 'lib/stripe/resources/financial_connections/session.rb', line 123

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



125
126
127
# File 'lib/stripe/resources/financial_connections/session.rb', line 125

def status_details
  @status_details
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

To launch the Financial Connections authorization flow, create a Session. The session’s client_secret can be used to launch the flow using Stripe.js.



128
129
130
131
132
133
134
135
# File 'lib/stripe/resources/financial_connections/session.rb', line 128

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/financial_connections/sessions",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



147
148
149
# File 'lib/stripe/resources/financial_connections/session.rb', line 147

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



137
138
139
140
141
142
143
144
145
# File 'lib/stripe/resources/financial_connections/session.rb', line 137

def self.inner_class_types
  @inner_class_types = {
    account_holder: AccountHolder,
    filters: Filters,
    limits: Limits,
    manual_entry: ManualEntry,
    status_details: StatusDetails,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/session.rb', line 11

def self.object_name
  "financial_connections.session"
end