Class: Stripe::FinancialConnections::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/financial_connections/session.rb

Overview

A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.

Defined Under Namespace

Classes: AccountHolder, CreateParams, Filters, Limits, ManualEntry, StatusDetails

Constant Summary collapse

OBJECT_NAME =
"financial_connections.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder for whom accounts are collected in this session.



190
191
192
# File 'lib/stripe/resources/financial_connections/session.rb', line 190

def 
  @account_holder
end

#accountsObject (readonly)

The accounts that were collected as part of this Session.



192
193
194
# File 'lib/stripe/resources/financial_connections/session.rb', line 192

def accounts
  @accounts
end

#client_secretObject (readonly)

A value that will be passed to the client to launch the authentication flow.



194
195
196
# File 'lib/stripe/resources/financial_connections/session.rb', line 194

def client_secret
  @client_secret
end

#filtersObject (readonly)

Attribute for field filters



196
197
198
# File 'lib/stripe/resources/financial_connections/session.rb', line 196

def filters
  @filters
end

#idObject (readonly)

Unique identifier for the object.



198
199
200
# File 'lib/stripe/resources/financial_connections/session.rb', line 198

def id
  @id
end

#limitsObject (readonly)

Attribute for field limits



200
201
202
# File 'lib/stripe/resources/financial_connections/session.rb', line 200

def limits
  @limits
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



202
203
204
# File 'lib/stripe/resources/financial_connections/session.rb', line 202

def livemode
  @livemode
end

#manual_entryObject (readonly)

Attribute for field manual_entry



204
205
206
# File 'lib/stripe/resources/financial_connections/session.rb', line 204

def manual_entry
  @manual_entry
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



206
207
208
# File 'lib/stripe/resources/financial_connections/session.rb', line 206

def object
  @object
end

#permissionsObject (readonly)

Permissions requested for accounts collected during this session.



208
209
210
# File 'lib/stripe/resources/financial_connections/session.rb', line 208

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



210
211
212
# File 'lib/stripe/resources/financial_connections/session.rb', line 210

def prefetch
  @prefetch
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



212
213
214
# File 'lib/stripe/resources/financial_connections/session.rb', line 212

def return_url
  @return_url
end

#statusObject (readonly)

The current state of the session.



214
215
216
# File 'lib/stripe/resources/financial_connections/session.rb', line 214

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



216
217
218
# File 'lib/stripe/resources/financial_connections/session.rb', line 216

def status_details
  @status_details
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

To launch the Financial Connections authorization flow, create a Session. The session’s client_secret can be used to launch the flow using Stripe.js.



219
220
221
222
223
224
225
226
# File 'lib/stripe/resources/financial_connections/session.rb', line 219

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/financial_connections/sessions",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



238
239
240
# File 'lib/stripe/resources/financial_connections/session.rb', line 238

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



228
229
230
231
232
233
234
235
236
# File 'lib/stripe/resources/financial_connections/session.rb', line 228

def self.inner_class_types
  @inner_class_types = {
    account_holder: AccountHolder,
    filters: Filters,
    limits: Limits,
    manual_entry: ManualEntry,
    status_details: StatusDetails,
  }
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/session.rb', line 11

def self.object_name
  "financial_connections.session"
end