Class: Stripe::FinancialConnections::Session
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Session
- Extended by:
- APIOperations::Create
- Defined in:
- lib/stripe/resources/financial_connections/session.rb
Overview
A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.
Defined Under Namespace
Classes: AccountHolder, CreateParams, Filters, Limits, ManualEntry, StatusDetails
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
readonly
The account holder for whom accounts are collected in this session.
-
#accounts ⇒ Object
readonly
The accounts that were collected as part of this Session.
-
#client_secret ⇒ Object
readonly
A value that will be passed to the client to launch the authentication flow.
-
#filters ⇒ Object
readonly
Attribute for field filters.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#limits ⇒ Object
readonly
Attribute for field limits.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#manual_entry ⇒ Object
readonly
Attribute for field manual_entry.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#permissions ⇒ Object
readonly
Permissions requested for accounts collected during this session.
-
#prefetch ⇒ Object
readonly
Data features requested to be retrieved upon account creation.
-
#return_url ⇒ Object
readonly
For webview integrations only.
-
#status ⇒ Object
readonly
The current state of the session.
-
#status_details ⇒ Object
readonly
Attribute for field status_details.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
To launch the Financial Connections authorization flow, create a Session.
- .object_name ⇒ Object
Methods included from APIOperations::Create
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder ⇒ Object (readonly)
The account holder for whom accounts are collected in this session.
142 143 144 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 142 def account_holder @account_holder end |
#accounts ⇒ Object (readonly)
The accounts that were collected as part of this Session.
144 145 146 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 144 def accounts @accounts end |
#client_secret ⇒ Object (readonly)
A value that will be passed to the client to launch the authentication flow.
146 147 148 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 146 def client_secret @client_secret end |
#filters ⇒ Object (readonly)
Attribute for field filters
148 149 150 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 148 def filters @filters end |
#id ⇒ Object (readonly)
Unique identifier for the object.
150 151 152 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 150 def id @id end |
#limits ⇒ Object (readonly)
Attribute for field limits
152 153 154 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 152 def limits @limits end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
154 155 156 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 154 def livemode @livemode end |
#manual_entry ⇒ Object (readonly)
Attribute for field manual_entry
156 157 158 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 156 def manual_entry @manual_entry end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
158 159 160 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 158 def object @object end |
#permissions ⇒ Object (readonly)
Permissions requested for accounts collected during this session.
160 161 162 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 160 def @permissions end |
#prefetch ⇒ Object (readonly)
Data features requested to be retrieved upon account creation.
162 163 164 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 162 def prefetch @prefetch end |
#return_url ⇒ Object (readonly)
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
164 165 166 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 164 def return_url @return_url end |
#status ⇒ Object (readonly)
The current state of the session.
166 167 168 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 166 def status @status end |
#status_details ⇒ Object (readonly)
Attribute for field status_details
168 169 170 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 168 def status_details @status_details end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
To launch the Financial Connections authorization flow, create a Session. The session’s client_secret can be used to launch the flow using Stripe.js.
171 172 173 174 175 176 177 178 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 171 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/financial_connections/sessions", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 11 def self.object_name "financial_connections.session" end |