Class: Stripe::FinancialConnections::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/financial_connections/session.rb

Overview

A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.

Defined Under Namespace

Classes: AccountHolder, CreateParams, Filters

Constant Summary collapse

OBJECT_NAME =
"financial_connections.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder for whom accounts are collected in this session.



90
91
92
# File 'lib/stripe/resources/financial_connections/session.rb', line 90

def 
  @account_holder
end

#accountsObject (readonly)

The accounts that were collected as part of this Session.



92
93
94
# File 'lib/stripe/resources/financial_connections/session.rb', line 92

def accounts
  @accounts
end

#client_secretObject (readonly)

A value that will be passed to the client to launch the authentication flow.



94
95
96
# File 'lib/stripe/resources/financial_connections/session.rb', line 94

def client_secret
  @client_secret
end

#filtersObject (readonly)

Attribute for field filters



96
97
98
# File 'lib/stripe/resources/financial_connections/session.rb', line 96

def filters
  @filters
end

#idObject (readonly)

Unique identifier for the object.



98
99
100
# File 'lib/stripe/resources/financial_connections/session.rb', line 98

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



100
101
102
# File 'lib/stripe/resources/financial_connections/session.rb', line 100

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



102
103
104
# File 'lib/stripe/resources/financial_connections/session.rb', line 102

def object
  @object
end

#permissionsObject (readonly)

Permissions requested for accounts collected during this session.



104
105
106
# File 'lib/stripe/resources/financial_connections/session.rb', line 104

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



106
107
108
# File 'lib/stripe/resources/financial_connections/session.rb', line 106

def prefetch
  @prefetch
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



108
109
110
# File 'lib/stripe/resources/financial_connections/session.rb', line 108

def return_url
  @return_url
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

To launch the Financial Connections authorization flow, create a Session. The session’s client_secret can be used to launch the flow using Stripe.js.



111
112
113
114
115
116
117
118
# File 'lib/stripe/resources/financial_connections/session.rb', line 111

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/financial_connections/sessions",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/session.rb', line 11

def self.object_name
  "financial_connections.session"
end