Class: Stripe::FinancialConnections::Session

Inherits:
APIResource show all
Extended by:
APIOperations::Create
Defined in:
lib/stripe/resources/financial_connections/session.rb

Overview

A Financial Connections Session is the secure way to programmatically launch the client-side Stripe.js modal that lets your users link their accounts.

Defined Under Namespace

Classes: AccountHolder, Filters, Limits, ManualEntry, StatusDetails

Constant Summary collapse

OBJECT_NAME =
"financial_connections.session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holderObject (readonly)

The account holder for whom accounts are collected in this session.



36
37
38
# File 'lib/stripe/resources/financial_connections/session.rb', line 36

def 
  @account_holder
end

#accountsObject (readonly)

The accounts that were collected as part of this Session.



38
39
40
# File 'lib/stripe/resources/financial_connections/session.rb', line 38

def accounts
  @accounts
end

#client_secretObject (readonly)

A value that will be passed to the client to launch the authentication flow.



40
41
42
# File 'lib/stripe/resources/financial_connections/session.rb', line 40

def client_secret
  @client_secret
end

#filtersObject (readonly)

Attribute for field filters



42
43
44
# File 'lib/stripe/resources/financial_connections/session.rb', line 42

def filters
  @filters
end

#idObject (readonly)

Unique identifier for the object.



44
45
46
# File 'lib/stripe/resources/financial_connections/session.rb', line 44

def id
  @id
end

#limitsObject (readonly)

Attribute for field limits



46
47
48
# File 'lib/stripe/resources/financial_connections/session.rb', line 46

def limits
  @limits
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



48
49
50
# File 'lib/stripe/resources/financial_connections/session.rb', line 48

def livemode
  @livemode
end

#manual_entryObject (readonly)

Attribute for field manual_entry



50
51
52
# File 'lib/stripe/resources/financial_connections/session.rb', line 50

def manual_entry
  @manual_entry
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



52
53
54
# File 'lib/stripe/resources/financial_connections/session.rb', line 52

def object
  @object
end

#permissionsObject (readonly)

Permissions requested for accounts collected during this session.



54
55
56
# File 'lib/stripe/resources/financial_connections/session.rb', line 54

def permissions
  @permissions
end

#prefetchObject (readonly)

Data features requested to be retrieved upon account creation.



56
57
58
# File 'lib/stripe/resources/financial_connections/session.rb', line 56

def prefetch
  @prefetch
end

#return_urlObject (readonly)

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



58
59
60
# File 'lib/stripe/resources/financial_connections/session.rb', line 58

def return_url
  @return_url
end

#statusObject (readonly)

The current state of the session.



60
61
62
# File 'lib/stripe/resources/financial_connections/session.rb', line 60

def status
  @status
end

#status_detailsObject (readonly)

Attribute for field status_details



62
63
64
# File 'lib/stripe/resources/financial_connections/session.rb', line 62

def status_details
  @status_details
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

To launch the Financial Connections authorization flow, create a Session. The session’s client_secret can be used to launch the flow using Stripe.js.



65
66
67
68
69
70
71
72
# File 'lib/stripe/resources/financial_connections/session.rb', line 65

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/financial_connections/sessions",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/session.rb', line 11

def self.object_name
  "financial_connections.session"
end