Class: Stripe::FinancialConnections::Session::CreateParams::AccountHolder
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Session::CreateParams::AccountHolder
- Defined in:
- lib/stripe/resources/financial_connections/session.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
-
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
-
#customer_account ⇒ Object
The ID of the Stripe customer Account whose accounts will be retrieved.
-
#type ⇒ Object
Type of account holder to collect accounts for.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, customer_account: nil, type: nil) ⇒ AccountHolder
constructor
A new instance of AccountHolder.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, customer: nil, customer_account: nil, type: nil) ⇒ AccountHolder
Returns a new instance of AccountHolder.
110 111 112 113 114 115 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 110 def initialize(account: nil, customer: nil, customer_account: nil, type: nil) @account = account @customer = customer @customer_account = customer_account @type = type end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved. Should only be present if ‘type` is `account`.
102 103 104 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 102 def account @account end |
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved. Should only be present if ‘type` is `customer`.
104 105 106 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 104 def customer @customer end |
#customer_account ⇒ Object
The ID of the Stripe customer Account whose accounts will be retrieved. Should only be present if ‘type` is `customer`.
106 107 108 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 106 def customer_account @customer_account end |
#type ⇒ Object
Type of account holder to collect accounts for.
108 109 110 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 108 def type @type end |