Class: Stripe::FinancialConnections::Session::CreateParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil, customer_account: nil, type: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



62
63
64
65
66
67
# File 'lib/stripe/resources/financial_connections/session.rb', line 62

def initialize(account: nil, customer: nil, customer_account: nil, type: nil)
  @account = 
  @customer = customer
  @customer_account = 
  @type = type
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved. Should only be present if ‘type` is `account`.



54
55
56
# File 'lib/stripe/resources/financial_connections/session.rb', line 54

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved. Should only be present if ‘type` is `customer`.



56
57
58
# File 'lib/stripe/resources/financial_connections/session.rb', line 56

def customer
  @customer
end

#customer_accountObject

The ID of the Stripe customer Account whose accounts will be retrieved. Should only be present if ‘type` is `customer`.



58
59
60
# File 'lib/stripe/resources/financial_connections/session.rb', line 58

def 
  @customer_account
end

#typeObject

Type of account holder to collect accounts for.



60
61
62
# File 'lib/stripe/resources/financial_connections/session.rb', line 60

def type
  @type
end