Class: Stripe::FinancialConnections::Session::CreateParams::AccountHolder
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Session::CreateParams::AccountHolder
- Defined in:
- lib/stripe/resources/financial_connections/session.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
-
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
-
#customer_account ⇒ Object
The ID of the Stripe customer Account whose accounts will be retrieved.
-
#type ⇒ Object
Type of account holder to collect accounts for.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, customer_account: nil, type: nil) ⇒ AccountHolder
constructor
A new instance of AccountHolder.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, customer: nil, customer_account: nil, type: nil) ⇒ AccountHolder
Returns a new instance of AccountHolder.
62 63 64 65 66 67 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 62 def initialize(account: nil, customer: nil, customer_account: nil, type: nil) @account = account @customer = customer @customer_account = customer_account @type = type end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved. Should only be present if ‘type` is `account`.
54 55 56 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 54 def account @account end |
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved. Should only be present if ‘type` is `customer`.
56 57 58 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 56 def customer @customer end |
#customer_account ⇒ Object
The ID of the Stripe customer Account whose accounts will be retrieved. Should only be present if ‘type` is `customer`.
58 59 60 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 58 def customer_account @customer_account end |
#type ⇒ Object
Type of account holder to collect accounts for.
60 61 62 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 60 def type @type end |