Class: Stripe::FinancialConnections::Session::CreateParams::AccountHolder

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, customer: nil, type: nil) ⇒ AccountHolder

Returns a new instance of AccountHolder.



73
74
75
76
77
# File 'lib/stripe/resources/financial_connections/session.rb', line 73

def initialize(account: nil, customer: nil, type: nil)
  @account = 
  @customer = customer
  @type = type
end

Instance Attribute Details

#accountObject

The ID of the Stripe account whose accounts will be retrieved. Should only be present if ‘type` is `account`.



65
66
67
# File 'lib/stripe/resources/financial_connections/session.rb', line 65

def 
  @account
end

#customerObject

The ID of the Stripe customer whose accounts will be retrieved. Should only be present if ‘type` is `customer`.



68
69
70
# File 'lib/stripe/resources/financial_connections/session.rb', line 68

def customer
  @customer
end

#typeObject

Type of account holder to collect accounts for.



71
72
73
# File 'lib/stripe/resources/financial_connections/session.rb', line 71

def type
  @type
end