Class: Stripe::FinancialConnections::Session::CreateParams::AccountHolder
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Session::CreateParams::AccountHolder
- Defined in:
- lib/stripe/resources/financial_connections/session.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
-
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
-
#type ⇒ Object
Type of account holder to collect accounts for.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, type: nil) ⇒ AccountHolder
constructor
A new instance of AccountHolder.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, customer: nil, type: nil) ⇒ AccountHolder
Returns a new instance of AccountHolder.
73 74 75 76 77 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 73 def initialize(account: nil, customer: nil, type: nil) @account = account @customer = customer @type = type end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved. Should only be present if ‘type` is `account`.
65 66 67 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 65 def account @account end |
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved. Should only be present if ‘type` is `customer`.
68 69 70 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 68 def customer @customer end |
#type ⇒ Object
Type of account holder to collect accounts for.
71 72 73 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 71 def type @type end |