Class: Stripe::FinancialConnections::Session::Hosted
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::FinancialConnections::Session::Hosted
- Defined in:
- lib/stripe/resources/financial_connections/session.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#delivery_method ⇒ Object
readonly
How the user enters the hosted flow.
-
#return_url ⇒ Object
readonly
The URL to redirect your customer back to after they link their accounts or cancel this Session.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#delivery_method ⇒ Object (readonly)
How the user enters the hosted flow. You can only use the values ‘email` and `url` if you provide `relink_options`.
133 134 135 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 133 def delivery_method @delivery_method end |
#return_url ⇒ Object (readonly)
The URL to redirect your customer back to after they link their accounts or cancel this Session. This parameter is required if ‘ui_mode` is `hosted`.
135 136 137 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 135 def return_url @return_url end |
Class Method Details
.field_remappings ⇒ Object
141 142 143 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 141 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
137 138 139 |
# File 'lib/stripe/resources/financial_connections/session.rb', line 137 def self.inner_class_types @inner_class_types = {} end |