Class: Stripe::FinancialConnections::SessionCreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/financial_connections/session_create_params.rb

Defined Under Namespace

Classes: AccountHolder, Filters, Limits, ManualEntry, RelinkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, relink_options: nil, return_url: nil) ⇒ SessionCreateParams

Returns a new instance of SessionCreateParams.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 90

def initialize(
  account_holder: nil,
  expand: nil,
  filters: nil,
  limits: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  relink_options: nil,
  return_url: nil
)
  @account_holder = 
  @expand = expand
  @filters = filters
  @limits = limits
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @relink_options = relink_options
  @return_url = return_url
end

Instance Attribute Details

#account_holderObject

The account holder to link accounts for.



70
71
72
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 70

def 
  @account_holder
end

#expandObject

Specifies which fields in the response should be expanded.



72
73
74
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 72

def expand
  @expand
end

#filtersObject

Filters to restrict the kinds of accounts to collect.



74
75
76
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 74

def filters
  @filters
end

#limitsObject

Settings for configuring Session-specific limits.



76
77
78
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 76

def limits
  @limits
end

#manual_entryObject

Customize manual entry behavior



78
79
80
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 78

def manual_entry
  @manual_entry
end

#permissionsObject

List of data features that you would like to request access to.

Possible values are ‘balances`, `transactions`, `ownership`, and `payment_method`.



82
83
84
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 82

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



84
85
86
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 84

def prefetch
  @prefetch
end

Options for specifying a Session targeted to relinking an authorization.



86
87
88
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 86

def relink_options
  @relink_options
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



88
89
90
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 88

def return_url
  @return_url
end