Class: Stripe::FinancialConnections::SessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::SessionCreateParams
- Defined in:
- lib/stripe/params/financial_connections/session_create_params.rb
Defined Under Namespace
Classes: AccountHolder, Filters, Limits, ManualEntry
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
The account holder to link accounts for.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#filters ⇒ Object
Filters to restrict the kinds of accounts to collect.
-
#limits ⇒ Object
Settings for configuring Session-specific limits.
-
#manual_entry ⇒ Object
Customize manual entry behavior.
-
#permissions ⇒ Object
List of data features that you would like to request access to.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ SessionCreateParams
constructor
A new instance of SessionCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ SessionCreateParams
Returns a new instance of SessionCreateParams.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 76 def initialize( account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @account_holder = account_holder @expand = @filters = filters @limits = limits @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#account_holder ⇒ Object
The account holder to link accounts for.
58 59 60 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 58 def account_holder @account_holder end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
60 61 62 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 60 def @expand end |
#filters ⇒ Object
Filters to restrict the kinds of accounts to collect.
62 63 64 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 62 def filters @filters end |
#limits ⇒ Object
Settings for configuring Session-specific limits.
64 65 66 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 64 def limits @limits end |
#manual_entry ⇒ Object
Customize manual entry behavior
66 67 68 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 66 def manual_entry @manual_entry end |
#permissions ⇒ Object
List of data features that you would like to request access to.
Possible values are ‘balances`, `transactions`, `ownership`, and `payment_method`.
70 71 72 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 70 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
72 73 74 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 72 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
74 75 76 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 74 def return_url @return_url end |