Class: Stripe::FinancialConnections::SessionCreateParams::Filters
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::SessionCreateParams::Filters
- Defined in:
- lib/stripe/params/financial_connections/session_create_params.rb
Instance Attribute Summary collapse
-
#account_subcategories ⇒ Object
Restricts the Session to subcategories of accounts that can be linked.
-
#countries ⇒ Object
List of countries from which to collect accounts.
-
#institution ⇒ Object
Stripe ID of the institution with which the customer should be directed to log in.
Instance Method Summary collapse
-
#initialize(account_subcategories: nil, countries: nil, institution: nil) ⇒ Filters
constructor
A new instance of Filters.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(account_subcategories: nil, countries: nil, institution: nil) ⇒ Filters
Returns a new instance of Filters.
33 34 35 36 37 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 33 def initialize(account_subcategories: nil, countries: nil, institution: nil) @account_subcategories = account_subcategories @countries = countries @institution = institution end |
Instance Attribute Details
#account_subcategories ⇒ Object
Restricts the Session to subcategories of accounts that can be linked. Valid subcategories are: ‘checking`, `savings`, `mortgage`, `line_of_credit`, `credit_card`.
27 28 29 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 27 def account_subcategories @account_subcategories end |
#countries ⇒ Object
List of countries from which to collect accounts.
29 30 31 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 29 def countries @countries end |
#institution ⇒ Object
Stripe ID of the institution with which the customer should be directed to log in.
31 32 33 |
# File 'lib/stripe/params/financial_connections/session_create_params.rb', line 31 def institution @institution end |