Class: Stripe::FinancialConnections::SessionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::SessionService::CreateParams
- Defined in:
- lib/stripe/services/financial_connections/session_service.rb
Defined Under Namespace
Classes: AccountHolder, Filters, Limits, ManualEntry
Instance Attribute Summary collapse
-
#account_holder ⇒ Object
The account holder to link accounts for.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#filters ⇒ Object
Filters to restrict the kinds of accounts to collect.
-
#limits ⇒ Object
Settings for configuring Session-specific limits.
-
#manual_entry ⇒ Object
Settings for configuring manual entry of account details for this Session.
-
#permissions ⇒ Object
List of data features that you would like to request access to.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
-
#return_url ⇒ Object
For webview integrations only.
Instance Method Summary collapse
-
#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 83 def initialize( account_holder: nil, expand: nil, filters: nil, limits: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil ) @account_holder = account_holder @expand = @filters = filters @limits = limits @manual_entry = manual_entry @permissions = @prefetch = prefetch @return_url = return_url end |
Instance Attribute Details
#account_holder ⇒ Object
The account holder to link accounts for.
65 66 67 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 65 def account_holder @account_holder end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
67 68 69 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 67 def @expand end |
#filters ⇒ Object
Filters to restrict the kinds of accounts to collect.
69 70 71 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 69 def filters @filters end |
#limits ⇒ Object
Settings for configuring Session-specific limits.
71 72 73 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 71 def limits @limits end |
#manual_entry ⇒ Object
Settings for configuring manual entry of account details for this Session.
73 74 75 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 73 def manual_entry @manual_entry end |
#permissions ⇒ Object
List of data features that you would like to request access to.
Possible values are ‘balances`, `transactions`, `ownership`, and `payment_method`.
77 78 79 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 77 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
79 80 81 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 79 def prefetch @prefetch end |
#return_url ⇒ Object
For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.
81 82 83 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 81 def return_url @return_url end |