Class: Stripe::FinancialConnections::SessionService::CreateParams::AccountHolder
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::SessionService::CreateParams::AccountHolder
- Defined in:
- lib/stripe/services/financial_connections/session_service.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved.
-
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved.
-
#type ⇒ Object
Type of account holder to collect accounts for.
Instance Method Summary collapse
-
#initialize(account: nil, customer: nil, type: nil) ⇒ AccountHolder
constructor
A new instance of AccountHolder.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, customer: nil, type: nil) ⇒ AccountHolder
Returns a new instance of AccountHolder.
25 26 27 28 29 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 25 def initialize(account: nil, customer: nil, type: nil) @account = account @customer = customer @type = type end |
Instance Attribute Details
#account ⇒ Object
The ID of the Stripe account whose accounts will be retrieved. Should only be present if ‘type` is `account`.
19 20 21 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 19 def account @account end |
#customer ⇒ Object
The ID of the Stripe customer whose accounts will be retrieved. Should only be present if ‘type` is `customer`.
21 22 23 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 21 def customer @customer end |
#type ⇒ Object
Type of account holder to collect accounts for.
23 24 25 |
# File 'lib/stripe/services/financial_connections/session_service.rb', line 23 def type @type end |