Class: Stripe::FinancialConnections::Transaction

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/financial_connections/transaction.rb

Overview

A Transaction represents a real transaction that affects a Financial Connections Account balance.

Defined Under Namespace

Classes: ListParams, RetrieveParams, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"financial_connections.transaction"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#accountObject (readonly)

The ID of the Financial Connections Account this transaction belongs to.



92
93
94
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 92

def 
  @account
end

#amountObject (readonly)

The amount of this transaction, in cents (or local equivalent).



94
95
96
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 94

def amount
  @amount
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



96
97
98
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 96

def currency
  @currency
end

#descriptionObject (readonly)

The description of this transaction.



98
99
100
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 98

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



100
101
102
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 100

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



102
103
104
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 102

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



104
105
106
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 104

def object
  @object
end

#statusObject (readonly)

The status of the transaction.



106
107
108
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 106

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



108
109
110
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 108

def status_transitions
  @status_transitions
end

#transacted_atObject (readonly)

Time at which the transaction was transacted. Measured in seconds since the Unix epoch.



110
111
112
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 110

def transacted_at
  @transacted_at
end

#transaction_refreshObject (readonly)

The token of the transaction refresh that last updated or created this transaction.



112
113
114
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 112

def transaction_refresh
  @transaction_refresh
end

#updatedObject (readonly)

Time at which the object was last updated. Measured in seconds since the Unix epoch.



114
115
116
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 114

def updated
  @updated
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Financial Connections Transaction objects.



117
118
119
120
121
122
123
124
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 117

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/financial_connections/transactions",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 11

def self.object_name
  "financial_connections.transaction"
end