Class: Stripe::FinancialConnections::Transaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FinancialConnections::Transaction
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/financial_connections/transaction.rb
Overview
A Transaction represents a real transaction that affects a Financial Connections Account balance.
Defined Under Namespace
Classes: StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"financial_connections.transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account ⇒ Object
readonly
The ID of the Financial Connections Account this transaction belongs to.
-
#amount ⇒ Object
readonly
The amount of this transaction, in cents (or local equivalent).
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
readonly
The description of this transaction.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
The status of the transaction.
-
#status_transitions ⇒ Object
readonly
Attribute for field status_transitions.
-
#transacted_at ⇒ Object
readonly
Time at which the transaction was transacted.
-
#transaction_refresh ⇒ Object
readonly
The token of the transaction refresh that last updated or created this transaction.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Transaction objects.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account ⇒ Object (readonly)
The ID of the Financial Connections Account this transaction belongs to.
19 20 21 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 19 def account @account end |
#amount ⇒ Object (readonly)
The amount of this transaction, in cents (or local equivalent).
21 22 23 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 21 def amount @amount end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
23 24 25 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 23 def currency @currency end |
#description ⇒ Object (readonly)
The description of this transaction.
25 26 27 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 25 def description @description end |
#id ⇒ Object (readonly)
Unique identifier for the object.
27 28 29 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 27 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
29 30 31 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 29 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
31 32 33 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 31 def object @object end |
#status ⇒ Object (readonly)
The status of the transaction.
33 34 35 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 33 def status @status end |
#status_transitions ⇒ Object (readonly)
Attribute for field status_transitions
35 36 37 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 35 def status_transitions @status_transitions end |
#transacted_at ⇒ Object (readonly)
Time at which the transaction was transacted. Measured in seconds since the Unix epoch.
37 38 39 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 37 def transacted_at @transacted_at end |
#transaction_refresh ⇒ Object (readonly)
The token of the transaction refresh that last updated or created this transaction.
39 40 41 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 39 def transaction_refresh @transaction_refresh end |
#updated ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
41 42 43 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 41 def updated @updated end |
Class Method Details
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Financial Connections Transaction objects.
44 45 46 47 48 49 50 51 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 44 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/financial_connections/transactions", params: filters, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 11 def self.object_name "financial_connections.transaction" end |