Class: Stripe::FinancialConnections::Transaction::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FinancialConnections::Transaction::ListParams
- Defined in:
- lib/stripe/resources/financial_connections/transaction.rb
Defined Under Namespace
Classes: TransactedAt, TransactionRefresh
Instance Attribute Summary collapse
-
#account ⇒ Object
The ID of the Financial Connections Account whose transactions will be retrieved.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#transacted_at ⇒ Object
A filter on the list based on the object ‘transacted_at` field.
-
#transaction_refresh ⇒ Object
A filter on the list based on the object ‘transaction_refresh` field.
Instance Method Summary collapse
-
#initialize(account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, transacted_at: nil, transaction_refresh: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, transacted_at: nil, transaction_refresh: nil) ⇒ ListParams
Returns a new instance of ListParams.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 64 def initialize( account: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, transacted_at: nil, transaction_refresh: nil ) @account = account @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @transacted_at = transacted_at @transaction_refresh = transaction_refresh end |
Instance Attribute Details
#account ⇒ Object
The ID of the Financial Connections Account whose transactions will be retrieved.
50 51 52 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 50 def account @account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
52 53 54 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 52 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
54 55 56 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 54 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
56 57 58 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 56 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
58 59 60 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 58 def starting_after @starting_after end |
#transacted_at ⇒ Object
A filter on the list based on the object ‘transacted_at` field. The value can be a string with an integer Unix timestamp, or it can be a dictionary with the following options:
60 61 62 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 60 def transacted_at @transacted_at end |
#transaction_refresh ⇒ Object
A filter on the list based on the object ‘transaction_refresh` field. The value can be a dictionary with the following options:
62 63 64 |
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 62 def transaction_refresh @transaction_refresh end |