Class: Stripe::FinancialConnections::Transaction::ListParams::TransactionRefresh

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/financial_connections/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(after: nil) ⇒ TransactionRefresh

Returns a new instance of TransactionRefresh.



49
50
51
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 49

def initialize(after: nil)
  @after = after
end

Instance Attribute Details

#afterObject

Return results where the transactions were created or updated by a refresh that took place after this refresh (non-inclusive).



47
48
49
# File 'lib/stripe/resources/financial_connections/transaction.rb', line 47

def after
  @after
end