Class: Stripe::Forwarding::Request::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/forwarding/request.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/stripe/resources/forwarding/request.rb', line 97

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Similar to other List endpoints, filters results based on created timestamp. You can pass gt, gte, lt, and lte timestamp values.



87
88
89
# File 'lib/stripe/resources/forwarding/request.rb', line 87

def created
  @created
end

#ending_beforeObject

A pagination cursor to fetch the previous page of the list. The value must be a ForwardingRequest ID.



89
90
91
# File 'lib/stripe/resources/forwarding/request.rb', line 89

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



91
92
93
# File 'lib/stripe/resources/forwarding/request.rb', line 91

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



93
94
95
# File 'lib/stripe/resources/forwarding/request.rb', line 93

def limit
  @limit
end

#starting_afterObject

A pagination cursor to fetch the next page of the list. The value must be a ForwardingRequest ID.



95
96
97
# File 'lib/stripe/resources/forwarding/request.rb', line 95

def starting_after
  @starting_after
end