Class: Stripe::Forwarding::Request::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Forwarding::Request::ListParams
- Defined in:
- lib/stripe/resources/forwarding/request.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Similar to other List endpoints, filters results based on created timestamp.
-
#ending_before ⇒ Object
A pagination cursor to fetch the previous page of the list.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A pagination cursor to fetch the next page of the list.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/stripe/resources/forwarding/request.rb', line 111 def initialize( created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil ) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Similar to other List endpoints, filters results based on created timestamp. You can pass gt, gte, lt, and lte timestamp values.
97 98 99 |
# File 'lib/stripe/resources/forwarding/request.rb', line 97 def created @created end |
#ending_before ⇒ Object
A pagination cursor to fetch the previous page of the list. The value must be a ForwardingRequest ID.
100 101 102 |
# File 'lib/stripe/resources/forwarding/request.rb', line 100 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
103 104 105 |
# File 'lib/stripe/resources/forwarding/request.rb', line 103 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
106 107 108 |
# File 'lib/stripe/resources/forwarding/request.rb', line 106 def limit @limit end |
#starting_after ⇒ Object
A pagination cursor to fetch the next page of the list. The value must be a ForwardingRequest ID.
109 110 111 |
# File 'lib/stripe/resources/forwarding/request.rb', line 109 def starting_after @starting_after end |