Class: Stripe::Forwarding::Request::ListParams::Created

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/forwarding/request.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Created

Returns a new instance of Created.



89
90
91
92
93
94
# File 'lib/stripe/resources/forwarding/request.rb', line 89

def initialize(gt: nil, gte: nil, lt: nil, lte: nil)
  @gt = gt
  @gte = gte
  @lt = lt
  @lte = lte
end

Instance Attribute Details

#gtObject

Return results where the ‘created` field is greater than this value.



78
79
80
# File 'lib/stripe/resources/forwarding/request.rb', line 78

def gt
  @gt
end

#gteObject

Return results where the ‘created` field is greater than or equal to this value.



81
82
83
# File 'lib/stripe/resources/forwarding/request.rb', line 81

def gte
  @gte
end

#ltObject

Return results where the ‘created` field is less than this value.



84
85
86
# File 'lib/stripe/resources/forwarding/request.rb', line 84

def lt
  @lt
end

#lteObject

Return results where the ‘created` field is less than or equal to this value.



87
88
89
# File 'lib/stripe/resources/forwarding/request.rb', line 87

def lte
  @lte
end