Class: Stripe::Forwarding::Request::ListParams::Created
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Forwarding::Request::ListParams::Created
- Defined in:
- lib/stripe/resources/forwarding/request.rb
Instance Attribute Summary collapse
-
#gt ⇒ Object
Return results where the ‘created` field is greater than this value.
-
#gte ⇒ Object
Return results where the ‘created` field is greater than or equal to this value.
-
#lt ⇒ Object
Return results where the ‘created` field is less than this value.
-
#lte ⇒ Object
Return results where the ‘created` field is less than or equal to this value.
Instance Method Summary collapse
-
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Created
constructor
A new instance of Created.
Methods inherited from RequestParams
Constructor Details
#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Created
Returns a new instance of Created.
89 90 91 92 93 94 |
# File 'lib/stripe/resources/forwarding/request.rb', line 89 def initialize(gt: nil, gte: nil, lt: nil, lte: nil) @gt = gt @gte = gte @lt = lt @lte = lte end |
Instance Attribute Details
#gt ⇒ Object
Return results where the ‘created` field is greater than this value.
78 79 80 |
# File 'lib/stripe/resources/forwarding/request.rb', line 78 def gt @gt end |
#gte ⇒ Object
Return results where the ‘created` field is greater than or equal to this value.
81 82 83 |
# File 'lib/stripe/resources/forwarding/request.rb', line 81 def gte @gte end |
#lt ⇒ Object
Return results where the ‘created` field is less than this value.
84 85 86 |
# File 'lib/stripe/resources/forwarding/request.rb', line 84 def lt @lt end |
#lte ⇒ Object
Return results where the ‘created` field is less than or equal to this value.
87 88 89 |
# File 'lib/stripe/resources/forwarding/request.rb', line 87 def lte @lte end |