Class: Stripe::Forwarding::RequestService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Forwarding::RequestService::CreateParams
- Defined in:
- lib/stripe/services/forwarding/request_service.rb
Defined Under Namespace
Classes: Request
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment_method ⇒ Object
The PaymentMethod to insert into the forwarded request.
-
#replacements ⇒ Object
The field kinds to be replaced in the forwarded request.
-
#request ⇒ Object
The request body and headers to be sent to the destination endpoint.
-
#url ⇒ Object
The destination URL for the forwarded request.
Instance Method Summary collapse
-
#initialize(expand: nil, metadata: nil, payment_method: nil, replacements: nil, request: nil, url: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, metadata: nil, payment_method: nil, replacements: nil, request: nil, url: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 101 def initialize( expand: nil, metadata: nil, payment_method: nil, replacements: nil, request: nil, url: nil ) @expand = @metadata = @payment_method = payment_method @replacements = replacements @request = request @url = url end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
84 85 86 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 84 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
87 88 89 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 87 def @metadata end |
#payment_method ⇒ Object
The PaymentMethod to insert into the forwarded request. Forwarding previously consumed PaymentMethods is allowed.
90 91 92 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 90 def payment_method @payment_method end |
#replacements ⇒ Object
The field kinds to be replaced in the forwarded request.
93 94 95 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 93 def replacements @replacements end |
#request ⇒ Object
The request body and headers to be sent to the destination endpoint.
96 97 98 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 96 def request @request end |
#url ⇒ Object
The destination URL for the forwarded request. Must be supported by the config.
99 100 101 |
# File 'lib/stripe/services/forwarding/request_service.rb', line 99 def url @url end |