Class: Stripe::Forwarding::RequestService::ListParams::Created

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/forwarding/request_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(gt: nil, gte: nil, lt: nil, lte: nil) ⇒ Created

Returns a new instance of Created.



21
22
23
24
25
26
# File 'lib/stripe/services/forwarding/request_service.rb', line 21

def initialize(gt: nil, gte: nil, lt: nil, lte: nil)
  @gt = gt
  @gte = gte
  @lt = lt
  @lte = lte
end

Instance Attribute Details

#gtObject

Return results where the ‘created` field is greater than this value.



10
11
12
# File 'lib/stripe/services/forwarding/request_service.rb', line 10

def gt
  @gt
end

#gteObject

Return results where the ‘created` field is greater than or equal to this value.



13
14
15
# File 'lib/stripe/services/forwarding/request_service.rb', line 13

def gte
  @gte
end

#ltObject

Return results where the ‘created` field is less than this value.



16
17
18
# File 'lib/stripe/services/forwarding/request_service.rb', line 16

def lt
  @lt
end

#lteObject

Return results where the ‘created` field is less than or equal to this value.



19
20
21
# File 'lib/stripe/services/forwarding/request_service.rb', line 19

def lte
  @lte
end