Class: Stripe::FrMealVouchersOnboarding
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FrMealVouchersOnboarding
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/fr_meal_vouchers_onboarding.rb
Overview
The French Meal Vouchers Onboarding resource encapsulates the onboarding status and other related information for a single restaurant (SIRET number) in the context of the French Meal Vouchers program.
Defined Under Namespace
Classes: Providers
Constant Summary collapse
- OBJECT_NAME =
"fr_meal_vouchers_onboarding"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
Name of the restaurant.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#postal_code ⇒ Object
readonly
Postal code of the restaurant.
-
#providers ⇒ Object
readonly
This represents the onboarding state of the restaurant on different providers.
-
#siret ⇒ Object
readonly
SIRET number associated with the restaurant.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a French Meal Vouchers Onboarding object that represents a restaurant’s onboarding status and starts the onboarding process.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Lists French Meal Vouchers Onboarding objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates the details of a restaurant’s French Meal Vouchers Onboarding object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#id ⇒ Object (readonly)
Unique identifier for the object.
89 90 91 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 89 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
91 92 93 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 91 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
93 94 95 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 93 def @metadata end |
#name ⇒ Object (readonly)
Name of the restaurant.
95 96 97 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 95 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
97 98 99 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 97 def object @object end |
#postal_code ⇒ Object (readonly)
Postal code of the restaurant.
99 100 101 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 99 def postal_code @postal_code end |
#providers ⇒ Object (readonly)
This represents the onboarding state of the restaurant on different providers.
101 102 103 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 101 def providers @providers end |
#siret ⇒ Object (readonly)
SIRET number associated with the restaurant.
103 104 105 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 103 def siret @siret end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a French Meal Vouchers Onboarding object that represents a restaurant’s onboarding status and starts the onboarding process.
106 107 108 109 110 111 112 113 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 106 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/fr_meal_vouchers_onboardings", params: params, opts: opts ) end |
.field_remappings ⇒ Object
139 140 141 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 139 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
135 136 137 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 135 def self.inner_class_types @inner_class_types = { providers: Providers } end |
.list(params = {}, opts = {}) ⇒ Object
Lists French Meal Vouchers Onboarding objects
116 117 118 119 120 121 122 123 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 116 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/fr_meal_vouchers_onboardings", params: params, opts: opts ) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 13 def self.object_name "fr_meal_vouchers_onboarding" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates the details of a restaurant’s French Meal Vouchers Onboarding object
126 127 128 129 130 131 132 133 |
# File 'lib/stripe/resources/fr_meal_vouchers_onboarding.rb', line 126 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/fr_meal_vouchers_onboardings/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |