Class: Stripe::FrMealVouchersOnboardingService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::FrMealVouchersOnboardingService
- Defined in:
- lib/stripe/services/fr_meal_vouchers_onboarding_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a French Meal Vouchers Onboarding object that represents a restaurant’s onboarding status and starts the onboarding process.
-
#list(params = {}, opts = {}) ⇒ Object
Lists French Meal Vouchers Onboarding objects.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of a French Meal Vouchers Onboarding object.
-
#update(id, params = {}, opts = {}) ⇒ Object
Updates the details of a restaurant’s French Meal Vouchers Onboarding object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a French Meal Vouchers Onboarding object that represents a restaurant’s onboarding status and starts the onboarding process.
7 8 9 10 11 12 13 14 15 |
# File 'lib/stripe/services/fr_meal_vouchers_onboarding_service.rb', line 7 def create(params = {}, opts = {}) request( method: :post, path: "/v1/fr_meal_vouchers_onboardings", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Lists French Meal Vouchers Onboarding objects
18 19 20 21 22 23 24 25 26 |
# File 'lib/stripe/services/fr_meal_vouchers_onboarding_service.rb', line 18 def list(params = {}, opts = {}) request( method: :get, path: "/v1/fr_meal_vouchers_onboardings", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of a French Meal Vouchers Onboarding object
29 30 31 32 33 34 35 36 37 |
# File 'lib/stripe/services/fr_meal_vouchers_onboarding_service.rb', line 29 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/fr_meal_vouchers_onboardings/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Updates the details of a restaurant’s French Meal Vouchers Onboarding object
40 41 42 43 44 45 46 47 48 |
# File 'lib/stripe/services/fr_meal_vouchers_onboarding_service.rb', line 40 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v1/fr_meal_vouchers_onboardings/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |