Class: Stripe::FundingInstructions

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/funding_instructions.rb

Overview

Each customer has a [‘balance`](stripe.com/docs/api/customers/object#customer_object-balance) that is automatically applied to future invoices and payments using the `customer_balance` payment method. Customers can fund this balance by initiating a bank transfer to any account in the `financial_addresses` field. Related guide: [Customer balance funding instructions](stripe.com/docs/payments/customer-balance/funding-instructions)

Defined Under Namespace

Classes: BankTransfer

Constant Summary collapse

OBJECT_NAME =
"funding_instructions"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_transferObject (readonly)

Attribute for field bank_transfer



417
418
419
# File 'lib/stripe/resources/funding_instructions.rb', line 417

def bank_transfer
  @bank_transfer
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



420
421
422
# File 'lib/stripe/resources/funding_instructions.rb', line 420

def currency
  @currency
end

#funding_typeObject (readonly)

The ‘funding_type` of the returned instructions



423
424
425
# File 'lib/stripe/resources/funding_instructions.rb', line 423

def funding_type
  @funding_type
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



426
427
428
# File 'lib/stripe/resources/funding_instructions.rb', line 426

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



429
430
431
# File 'lib/stripe/resources/funding_instructions.rb', line 429

def object
  @object
end

Class Method Details

.object_nameObject



12
13
14
# File 'lib/stripe/resources/funding_instructions.rb', line 12

def self.object_name
  "funding_instructions"
end

Instance Method Details

#resource_urlObject



431
432
433
434
435
436
437
# File 'lib/stripe/resources/funding_instructions.rb', line 431

def resource_url
  if !respond_to?(:customer) || customer.nil?
    raise NotImplementedError,
          "FundingInstructions cannot be accessed without a customer ID."
  end
  "#{Customer.resource_url}/#{CGI.escape(customer)}/funding_instructions" "/#{CGI.escape(id)}"
end