Class: Stripe::FundingInstructions
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::FundingInstructions
- Defined in:
- lib/stripe/resources/funding_instructions.rb
Overview
Each customer has a [‘balance`](stripe.com/docs/api/customers/object#customer_object-balance) that is automatically applied to future invoices and payments using the `customer_balance` payment method. Customers can fund this balance by initiating a bank transfer to any account in the `financial_addresses` field. Related guide: [Customer balance funding instructions](stripe.com/docs/payments/customer-balance/funding-instructions)
Defined Under Namespace
Classes: BankTransfer
Constant Summary collapse
- OBJECT_NAME =
"funding_instructions"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_transfer ⇒ Object
readonly
Attribute for field bank_transfer.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#funding_type ⇒ Object
readonly
The ‘funding_type` of the returned instructions.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_transfer ⇒ Object (readonly)
Attribute for field bank_transfer
88 89 90 |
# File 'lib/stripe/resources/funding_instructions.rb', line 88 def bank_transfer @bank_transfer end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
90 91 92 |
# File 'lib/stripe/resources/funding_instructions.rb', line 90 def currency @currency end |
#funding_type ⇒ Object (readonly)
The ‘funding_type` of the returned instructions
92 93 94 |
# File 'lib/stripe/resources/funding_instructions.rb', line 92 def funding_type @funding_type end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
94 95 96 |
# File 'lib/stripe/resources/funding_instructions.rb', line 94 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
96 97 98 |
# File 'lib/stripe/resources/funding_instructions.rb', line 96 def object @object end |
Class Method Details
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/funding_instructions.rb', line 12 def self.object_name "funding_instructions" end |
Instance Method Details
#resource_url ⇒ Object
98 99 100 101 102 103 104 |
# File 'lib/stripe/resources/funding_instructions.rb', line 98 def resource_url if !respond_to?(:customer) || customer.nil? raise NotImplementedError, "FundingInstructions cannot be accessed without a customer ID." end "#{Customer.resource_url}/#{CGI.escape(customer)}/funding_instructions" "/#{CGI.escape(id)}" end |