Class: Stripe::FxQuote::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/fx_quote.rb

Defined Under Namespace

Classes: Usage

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/stripe/resources/fx_quote.rb', line 139

def initialize(
  expand: nil,
  from_currencies: nil,
  lock_duration: nil,
  to_currency: nil,
  usage: nil
)
  @expand = expand
  @from_currencies = from_currencies
  @lock_duration = lock_duration
  @to_currency = to_currency
  @usage = usage
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



129
130
131
# File 'lib/stripe/resources/fx_quote.rb', line 129

def expand
  @expand
end

#from_currenciesObject

A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be [supported currencies](stripe.com/docs/currencies).



131
132
133
# File 'lib/stripe/resources/fx_quote.rb', line 131

def from_currencies
  @from_currencies
end

#lock_durationObject

The duration that you wish the quote to be locked for. The quote will be usable for the duration specified. The default is ‘none`. The maximum is 1 day.



133
134
135
# File 'lib/stripe/resources/fx_quote.rb', line 133

def lock_duration
  @lock_duration
end

#to_currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



135
136
137
# File 'lib/stripe/resources/fx_quote.rb', line 135

def to_currency
  @to_currency
end

#usageObject

The usage specific information for the quote.



137
138
139
# File 'lib/stripe/resources/fx_quote.rb', line 137

def usage
  @usage
end