Class: Stripe::FxQuote::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FxQuote::CreateParams
- Defined in:
- lib/stripe/resources/fx_quote.rb
Defined Under Namespace
Classes: Usage
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_currencies ⇒ Object
A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#lock_duration ⇒ Object
The duration that you wish the quote to be locked for.
-
#to_currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#usage ⇒ Object
The usage specific information for the quote.
Instance Method Summary collapse
-
#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/stripe/resources/fx_quote.rb', line 137 def initialize( expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil ) @expand = @from_currencies = from_currencies @lock_duration = lock_duration @to_currency = to_currency @usage = usage end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
127 128 129 |
# File 'lib/stripe/resources/fx_quote.rb', line 127 def @expand end |
#from_currencies ⇒ Object
A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be [supported currencies](stripe.com/docs/currencies).
129 130 131 |
# File 'lib/stripe/resources/fx_quote.rb', line 129 def from_currencies @from_currencies end |
#lock_duration ⇒ Object
The duration that you wish the quote to be locked for. The quote will be usable for the duration specified. The default is ‘none`. The maximum is 1 day.
131 132 133 |
# File 'lib/stripe/resources/fx_quote.rb', line 131 def lock_duration @lock_duration end |
#to_currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
133 134 135 |
# File 'lib/stripe/resources/fx_quote.rb', line 133 def to_currency @to_currency end |
#usage ⇒ Object
The usage specific information for the quote.
135 136 137 |
# File 'lib/stripe/resources/fx_quote.rb', line 135 def usage @usage end |