Class: Stripe::FxQuote::CreateParams::Usage

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/fx_quote.rb

Defined Under Namespace

Classes: Payment, Transfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment: nil, transfer: nil, type: nil) ⇒ Usage

Returns a new instance of Usage.



122
123
124
125
126
# File 'lib/stripe/resources/fx_quote.rb', line 122

def initialize(payment: nil, transfer: nil, type: nil)
  @payment = payment
  @transfer = transfer
  @type = type
end

Instance Attribute Details

#paymentObject

The payment transaction details that are intended for the FX Quote.



114
115
116
# File 'lib/stripe/resources/fx_quote.rb', line 114

def payment
  @payment
end

#transferObject

The transfer transaction details that are intended for the FX Quote.



116
117
118
# File 'lib/stripe/resources/fx_quote.rb', line 116

def transfer
  @transfer
end

#typeObject

Which transaction the FX Quote will be used for

Can be “payment” | “transfer”



120
121
122
# File 'lib/stripe/resources/fx_quote.rb', line 120

def type
  @type
end