Class: Stripe::FxQuote::CreateParams::Usage

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/fx_quote.rb

Defined Under Namespace

Classes: Payment, Transfer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment: nil, transfer: nil, type: nil) ⇒ Usage

Returns a new instance of Usage.



120
121
122
123
124
# File 'lib/stripe/resources/fx_quote.rb', line 120

def initialize(payment: nil, transfer: nil, type: nil)
  @payment = payment
  @transfer = transfer
  @type = type
end

Instance Attribute Details

#paymentObject

The payment transaction details that are intended for the FX Quote.



112
113
114
# File 'lib/stripe/resources/fx_quote.rb', line 112

def payment
  @payment
end

#transferObject

The transfer transaction details that are intended for the FX Quote.



114
115
116
# File 'lib/stripe/resources/fx_quote.rb', line 114

def transfer
  @transfer
end

#typeObject

Which transaction the FX Quote will be used for

Can be “payment” | “transfer”



118
119
120
# File 'lib/stripe/resources/fx_quote.rb', line 118

def type
  @type
end