Class: Stripe::FxQuoteCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FxQuoteCreateParams
- Defined in:
- lib/stripe/params/fx_quote_create_params.rb
Defined Under Namespace
Classes: Usage
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_currencies ⇒ Object
A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#lock_duration ⇒ Object
The duration that you wish the quote to be locked for.
-
#to_currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#usage ⇒ Object
The usage specific information for the quote.
Instance Method Summary collapse
-
#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ FxQuoteCreateParams
constructor
A new instance of FxQuoteCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ FxQuoteCreateParams
Returns a new instance of FxQuoteCreateParams.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 59 def initialize( expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil ) @expand = @from_currencies = from_currencies @lock_duration = lock_duration @to_currency = to_currency @usage = usage end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
49 50 51 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 49 def @expand end |
#from_currencies ⇒ Object
A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be [supported currencies](stripe.com/docs/currencies).
51 52 53 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 51 def from_currencies @from_currencies end |
#lock_duration ⇒ Object
The duration that you wish the quote to be locked for. The quote will be usable for the duration specified. The default is ‘none`. The maximum is 1 day.
53 54 55 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 53 def lock_duration @lock_duration end |
#to_currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
55 56 57 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 55 def to_currency @to_currency end |
#usage ⇒ Object
The usage specific information for the quote.
57 58 59 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 57 def usage @usage end |