Class: Stripe::FxQuoteCreateParams::Usage
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FxQuoteCreateParams::Usage
- Defined in:
- lib/stripe/params/fx_quote_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#payment ⇒ Object
The payment transaction details that are intended for the FX Quote.
-
#transfer ⇒ Object
The transfer transaction details that are intended for the FX Quote.
-
#type ⇒ Object
Which transaction the FX Quote will be used for.
Instance Method Summary collapse
-
#initialize(payment: nil, transfer: nil, type: nil) ⇒ Usage
constructor
A new instance of Usage.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(payment: nil, transfer: nil, type: nil) ⇒ Usage
Returns a new instance of Usage.
42 43 44 45 46 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 42 def initialize(payment: nil, transfer: nil, type: nil) @payment = payment @transfer = transfer @type = type end |
Instance Attribute Details
#payment ⇒ Object
The payment transaction details that are intended for the FX Quote.
34 35 36 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 34 def payment @payment end |
#transfer ⇒ Object
The transfer transaction details that are intended for the FX Quote.
36 37 38 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 36 def transfer @transfer end |
#type ⇒ Object
Which transaction the FX Quote will be used for
Can be “payment” | “transfer”
40 41 42 |
# File 'lib/stripe/params/fx_quote_create_params.rb', line 40 def type @type end |