Class: Stripe::FxQuoteService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::FxQuoteService::CreateParams
- Defined in:
- lib/stripe/services/fx_quote_service.rb
Defined Under Namespace
Classes: Usage
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#from_currencies ⇒ Object
A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#lock_duration ⇒ Object
The duration that you wish the quote to be locked for.
-
#to_currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#usage ⇒ Object
The usage specific information for the quote.
Instance Method Summary collapse
-
#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/stripe/services/fx_quote_service.rb', line 78 def initialize( expand: nil, from_currencies: nil, lock_duration: nil, to_currency: nil, usage: nil ) @expand = @from_currencies = from_currencies @lock_duration = lock_duration @to_currency = to_currency @usage = usage end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
68 69 70 |
# File 'lib/stripe/services/fx_quote_service.rb', line 68 def @expand end |
#from_currencies ⇒ Object
A list of three letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be [supported currencies](stripe.com/docs/currencies).
70 71 72 |
# File 'lib/stripe/services/fx_quote_service.rb', line 70 def from_currencies @from_currencies end |
#lock_duration ⇒ Object
The duration that you wish the quote to be locked for. The quote will be usable for the duration specified. The default is ‘none`. The maximum is 1 day.
72 73 74 |
# File 'lib/stripe/services/fx_quote_service.rb', line 72 def lock_duration @lock_duration end |
#to_currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
74 75 76 |
# File 'lib/stripe/services/fx_quote_service.rb', line 74 def to_currency @to_currency end |
#usage ⇒ Object
The usage specific information for the quote.
76 77 78 |
# File 'lib/stripe/services/fx_quote_service.rb', line 76 def usage @usage end |