Class: Stripe::GiftCardActivateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCardActivateParams
- Defined in:
- lib/stripe/params/gift_card_activate_params.rb
Defined Under Namespace
Classes: Balance
Instance Attribute Summary collapse
-
#balance ⇒ Object
The initial balance to set on the gift card.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
Instance Method Summary collapse
-
#initialize(balance: nil, expand: nil, on_behalf_of: nil) ⇒ GiftCardActivateParams
constructor
A new instance of GiftCardActivateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(balance: nil, expand: nil, on_behalf_of: nil) ⇒ GiftCardActivateParams
Returns a new instance of GiftCardActivateParams.
24 25 26 27 28 |
# File 'lib/stripe/params/gift_card_activate_params.rb', line 24 def initialize(balance: nil, expand: nil, on_behalf_of: nil) @balance = balance @expand = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#balance ⇒ Object
The initial balance to set on the gift card.
18 19 20 |
# File 'lib/stripe/params/gift_card_activate_params.rb', line 18 def balance @balance end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
20 21 22 |
# File 'lib/stripe/params/gift_card_activate_params.rb', line 20 def @expand end |
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
22 23 24 |
# File 'lib/stripe/params/gift_card_activate_params.rb', line 22 def on_behalf_of @on_behalf_of end |