Class: Stripe::GiftCardActivateParams::Balance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCardActivateParams::Balance
- Defined in:
- lib/stripe/params/gift_card_activate_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The initial balance amount to be loaded when activating the gift card, in the smallest currency unit.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil) ⇒ Balance
constructor
A new instance of Balance.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil) ⇒ Balance
Returns a new instance of Balance.
12 13 14 15 |
# File 'lib/stripe/params/gift_card_activate_params.rb', line 12 def initialize(amount: nil, currency: nil) @amount = amount @currency = currency end |
Instance Attribute Details
#amount ⇒ Object
The initial balance amount to be loaded when activating the gift card, in the smallest currency unit
8 9 10 |
# File 'lib/stripe/params/gift_card_activate_params.rb', line 8 def amount @amount end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
10 11 12 |
# File 'lib/stripe/params/gift_card_activate_params.rb', line 10 def currency @currency end |