Class: Stripe::GiftCardReloadParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCardReloadParams
- Defined in:
- lib/stripe/params/gift_card_reload_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount to add to the gift card balance, in the smallest currency unit.
-
#currency ⇒ Object
Three-letter ISO currency code, in lowercase.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, expand: nil, on_behalf_of: nil) ⇒ GiftCardReloadParams
constructor
A new instance of GiftCardReloadParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil, expand: nil, on_behalf_of: nil) ⇒ GiftCardReloadParams
Returns a new instance of GiftCardReloadParams.
15 16 17 18 19 20 |
# File 'lib/stripe/params/gift_card_reload_params.rb', line 15 def initialize(amount: nil, currency: nil, expand: nil, on_behalf_of: nil) @amount = amount @currency = currency @expand = @on_behalf_of = on_behalf_of end |
Instance Attribute Details
#amount ⇒ Object
The amount to add to the gift card balance, in the smallest currency unit.
7 8 9 |
# File 'lib/stripe/params/gift_card_reload_params.rb', line 7 def amount @amount end |
#currency ⇒ Object
Three-letter ISO currency code, in lowercase. Must be a supported currency.
9 10 11 |
# File 'lib/stripe/params/gift_card_reload_params.rb', line 9 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
11 12 13 |
# File 'lib/stripe/params/gift_card_reload_params.rb', line 11 def @expand end |
#on_behalf_of ⇒ Object
The Stripe account ID to process the gift card operation on behalf of.
13 14 15 |
# File 'lib/stripe/params/gift_card_reload_params.rb', line 13 def on_behalf_of @on_behalf_of end |