Class: Stripe::GiftCards::Card
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::GiftCards::Card
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/gift_cards/card.rb
Overview
A gift card represents a single gift card owned by a customer, including the remaining balance, gift card code, and whether or not it is active.
Defined Under Namespace
Classes: CreateParams, CreatedBy, ListParams, RetrieveParams, UpdateParams, ValidateParams
Constant Summary collapse
- OBJECT_NAME =
"gift_cards.card"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active ⇒ Object
readonly
Whether this gift card can be used or not.
-
#amount_available ⇒ Object
readonly
The amount of funds available for new transactions.
-
#amount_held ⇒ Object
readonly
The amount of funds marked as held.
-
#code ⇒ Object
readonly
Code used to redeem this gift card.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#created_by ⇒ Object
readonly
The related Stripe objects that created this gift card.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#transactions ⇒ Object
readonly
Transactions on this gift card.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new gift card object.
-
.list(params = {}, opts = {}) ⇒ Object
List gift cards for an account.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Update a gift card.
-
.validate(params = {}, opts = {}) ⇒ Object
Validates a gift card code, returning the matching gift card object if it exists.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active ⇒ Object (readonly)
Whether this gift card can be used or not.
172 173 174 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 172 def active @active end |
#amount_available ⇒ Object (readonly)
The amount of funds available for new transactions.
175 176 177 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 175 def amount_available @amount_available end |
#amount_held ⇒ Object (readonly)
The amount of funds marked as held.
178 179 180 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 178 def amount_held @amount_held end |
#code ⇒ Object (readonly)
Code used to redeem this gift card.
181 182 183 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 181 def code @code end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
184 185 186 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 184 def created @created end |
#created_by ⇒ Object (readonly)
The related Stripe objects that created this gift card.
187 188 189 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 187 def created_by @created_by end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
190 191 192 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 190 def currency @currency end |
#id ⇒ Object (readonly)
Unique identifier for the object.
193 194 195 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 193 def id @id end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
196 197 198 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 196 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
199 200 201 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 199 def object @object end |
#transactions ⇒ Object (readonly)
Transactions on this gift card.
202 203 204 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 202 def transactions @transactions end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new gift card object.
205 206 207 208 209 210 211 212 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 205 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/gift_cards/cards", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
List gift cards for an account
215 216 217 218 219 220 221 222 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 215 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/gift_cards/cards", params: params, opts: opts ) end |
.object_name ⇒ Object
14 15 16 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 14 def self.object_name "gift_cards.card" end |
.update(id, params = {}, opts = {}) ⇒ Object
Update a gift card
225 226 227 228 229 230 231 232 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 225 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/gift_cards/cards/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
.validate(params = {}, opts = {}) ⇒ Object
Validates a gift card code, returning the matching gift card object if it exists.
235 236 237 238 239 240 241 242 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 235 def self.validate(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/gift_cards/cards/validate", params: params, opts: opts ) end |