Class: Stripe::GiftCards::Card::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/gift_cards/card.rb

Defined Under Namespace

Classes: CreatedBy

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/stripe/resources/gift_cards/card.rb', line 112

def initialize(
  active: nil,
  created_by: nil,
  currency: nil,
  expand: nil,
  initial_amount: nil,
  metadata: nil
)
  @active = active
  @created_by = created_by
  @currency = currency
  @expand = expand
  @initial_amount = initial_amount
  @metadata = 
end

Instance Attribute Details

#activeObject

The active state for the new gift card, defaults to false. The active state can be updated after creation.



95
96
97
# File 'lib/stripe/resources/gift_cards/card.rb', line 95

def active
  @active
end

#created_byObject

Related objects which created this gift card.



98
99
100
# File 'lib/stripe/resources/gift_cards/card.rb', line 98

def created_by
  @created_by
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



101
102
103
# File 'lib/stripe/resources/gift_cards/card.rb', line 101

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



104
105
106
# File 'lib/stripe/resources/gift_cards/card.rb', line 104

def expand
  @expand
end

#initial_amountObject

The initial amount to load onto the new gift card, defaults to 0.



107
108
109
# File 'lib/stripe/resources/gift_cards/card.rb', line 107

def initial_amount
  @initial_amount
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



110
111
112
# File 'lib/stripe/resources/gift_cards/card.rb', line 110

def 
  @metadata
end