Class: Stripe::GiftCards::Card::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Card::CreateParams
- Defined in:
- lib/stripe/resources/gift_cards/card.rb
Defined Under Namespace
Classes: CreatedBy
Instance Attribute Summary collapse
-
#active ⇒ Object
The active state for the new gift card, defaults to false.
-
#created_by ⇒ Object
Related objects which created this gift card.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#initial_amount ⇒ Object
The initial amount to load onto the new gift card, defaults to 0.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 98 def initialize( active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil ) @active = active @created_by = created_by @currency = currency @expand = @initial_amount = initial_amount @metadata = end |
Instance Attribute Details
#active ⇒ Object
The active state for the new gift card, defaults to false. The active state can be updated after creation.
86 87 88 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 86 def active @active end |
#created_by ⇒ Object
Related objects which created this gift card.
88 89 90 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 88 def created_by @created_by end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
90 91 92 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 90 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
92 93 94 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 92 def @expand end |
#initial_amount ⇒ Object
The initial amount to load onto the new gift card, defaults to 0.
94 95 96 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 94 def initial_amount @initial_amount end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
96 97 98 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 96 def @metadata end |