Class: Stripe::GiftCards::Card::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Card::CreateParams
- Defined in:
- lib/stripe/resources/gift_cards/card.rb
Defined Under Namespace
Classes: CreatedBy
Instance Attribute Summary collapse
-
#active ⇒ Object
The active state for the new gift card, defaults to false.
-
#created_by ⇒ Object
Related objects which created this gift card.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#initial_amount ⇒ Object
The initial amount to load onto the new gift card, defaults to 0.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 112 def initialize( active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil ) @active = active @created_by = created_by @currency = currency @expand = @initial_amount = initial_amount @metadata = end |
Instance Attribute Details
#active ⇒ Object
The active state for the new gift card, defaults to false. The active state can be updated after creation.
95 96 97 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 95 def active @active end |
#created_by ⇒ Object
Related objects which created this gift card.
98 99 100 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 98 def created_by @created_by end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
101 102 103 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 101 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
104 105 106 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 104 def @expand end |
#initial_amount ⇒ Object
The initial amount to load onto the new gift card, defaults to 0.
107 108 109 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 107 def initial_amount @initial_amount end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
110 111 112 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 110 def @metadata end |