Class: Stripe::GiftCards::Card::ValidateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Card::ValidateParams
- Defined in:
- lib/stripe/resources/gift_cards/card.rb
Instance Attribute Summary collapse
-
#code ⇒ Object
The gift card code to be validated.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#giftcard_pin ⇒ Object
The pin associated with the gift card.
Instance Method Summary collapse
-
#initialize(code: nil, expand: nil, giftcard_pin: nil) ⇒ ValidateParams
constructor
A new instance of ValidateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(code: nil, expand: nil, giftcard_pin: nil) ⇒ ValidateParams
Returns a new instance of ValidateParams.
165 166 167 168 169 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 165 def initialize(code: nil, expand: nil, giftcard_pin: nil) @code = code @expand = @giftcard_pin = giftcard_pin end |
Instance Attribute Details
#code ⇒ Object
The gift card code to be validated.
157 158 159 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 157 def code @code end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
160 161 162 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 160 def @expand end |
#giftcard_pin ⇒ Object
The pin associated with the gift card. Not all gift cards have pins.
163 164 165 |
# File 'lib/stripe/resources/gift_cards/card.rb', line 163 def giftcard_pin @giftcard_pin end |