Class: Stripe::GiftCards::CardService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::GiftCards::CardService
- Defined in:
- lib/stripe/services/gift_cards/card_service.rb
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new gift card object.
-
#list(params = {}, opts = {}) ⇒ Object
List gift cards for an account.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a gift card by id.
-
#update(id, params = {}, opts = {}) ⇒ Object
Update a gift card.
-
#validate(params = {}, opts = {}) ⇒ Object
Validates a gift card code, returning the matching gift card object if it exists.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates a new gift card object.
8 9 10 11 12 13 14 15 16 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 8 def create(params = {}, opts = {}) request( method: :post, path: "/v1/gift_cards/cards", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
List gift cards for an account
19 20 21 22 23 24 25 26 27 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 19 def list(params = {}, opts = {}) request( method: :get, path: "/v1/gift_cards/cards", params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieve a gift card by id
30 31 32 33 34 35 36 37 38 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 30 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/gift_cards/cards/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Update a gift card
41 42 43 44 45 46 47 48 49 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 41 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v1/gift_cards/cards/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#validate(params = {}, opts = {}) ⇒ Object
Validates a gift card code, returning the matching gift card object if it exists.
52 53 54 55 56 57 58 59 60 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 52 def validate(params = {}, opts = {}) request( method: :post, path: "/v1/gift_cards/cards/validate", params: params, opts: opts, base_address: :api ) end |