Class: Stripe::GiftCards::CardService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::CardService::CreateParams
- Defined in:
- lib/stripe/services/gift_cards/card_service.rb
Defined Under Namespace
Classes: CreatedBy
Instance Attribute Summary collapse
-
#active ⇒ Object
The active state for the new gift card, defaults to false.
-
#created_by ⇒ Object
Related objects which created this gift card.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#initial_amount ⇒ Object
The initial amount to load onto the new gift card, defaults to 0.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 58 def initialize( active: nil, created_by: nil, currency: nil, expand: nil, initial_amount: nil, metadata: nil ) @active = active @created_by = created_by @currency = currency @expand = @initial_amount = initial_amount @metadata = end |
Instance Attribute Details
#active ⇒ Object
The active state for the new gift card, defaults to false. The active state can be updated after creation.
46 47 48 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 46 def active @active end |
#created_by ⇒ Object
Related objects which created this gift card.
48 49 50 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 48 def created_by @created_by end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
50 51 52 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 50 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
52 53 54 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 52 def @expand end |
#initial_amount ⇒ Object
The initial amount to load onto the new gift card, defaults to 0.
54 55 56 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 54 def initial_amount @initial_amount end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
56 57 58 |
# File 'lib/stripe/services/gift_cards/card_service.rb', line 56 def @metadata end |