Class: Stripe::GiftCards::Transaction::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/gift_cards/transaction.rb

Defined Under Namespace

Classes: CreatedBy

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, confirm: nil, created_by: nil, currency: nil, description: nil, expand: nil, gift_card: nil, metadata: nil, transfer_group: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 140

def initialize(
  amount: nil,
  confirm: nil,
  created_by: nil,
  currency: nil,
  description: nil,
  expand: nil,
  gift_card: nil,
  metadata: nil,
  transfer_group: nil
)
  @amount = amount
  @confirm = confirm
  @created_by = created_by
  @currency = currency
  @description = description
  @expand = expand
  @gift_card = gift_card
  @metadata = 
  @transfer_group = transfer_group
end

Instance Attribute Details

#amountObject

The amount of the transaction. A negative amount deducts funds, and a positive amount adds funds.



114
115
116
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 114

def amount
  @amount
end

#confirmObject

Whether this is a confirmed transaction. A confirmed transaction immediately deducts from/adds to the ‘amount_available` on the gift card. Otherwise, it creates a held transaction that increments the `amount_held` on the gift card.



117
118
119
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 117

def confirm
  @confirm
end

#created_byObject

Related objects which created this transaction.



120
121
122
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 120

def created_by
  @created_by
end

#currencyObject

The currency of the transaction. This must match the currency of the gift card.



123
124
125
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 123

def currency
  @currency
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



126
127
128
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 126

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



129
130
131
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 129

def expand
  @expand
end

#gift_cardObject

The gift card to create a new transaction on.



132
133
134
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 132

def gift_card
  @gift_card
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



135
136
137
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 135

def 
  @metadata
end

#transfer_groupObject

A string that identifies this transaction as part of a group. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers) for details.



138
139
140
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 138

def transfer_group
  @transfer_group
end