Class: Stripe::GiftCards::Transaction::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::GiftCards::Transaction::ListParams
- Defined in:
- lib/stripe/resources/gift_cards/transaction.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#gift_card ⇒ Object
The gift card to list transactions for.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, gift_card: nil, limit: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, gift_card: nil, limit: nil, starting_after: nil, transfer_group: nil) ⇒ ListParams
Returns a new instance of ListParams.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 75 def initialize( ending_before: nil, expand: nil, gift_card: nil, limit: nil, starting_after: nil, transfer_group: nil ) @ending_before = ending_before @expand = @gift_card = gift_card @limit = limit @starting_after = starting_after @transfer_group = transfer_group end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
58 59 60 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 58 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
61 62 63 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 61 def @expand end |
#gift_card ⇒ Object
The gift card to list transactions for.
64 65 66 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 64 def gift_card @gift_card end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
67 68 69 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 67 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
70 71 72 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 70 def starting_after @starting_after end |
#transfer_group ⇒ Object
A string that identifies this transaction as part of a group. See the [Connect documentation](stripe.com/docs/connect/separate-charges-and-transfers) for details.
73 74 75 |
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 73 def transfer_group @transfer_group end |