Class: Stripe::GiftCards::Transaction::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/gift_cards/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



182
183
184
185
186
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 182

def initialize(description: nil, expand: nil, metadata: nil)
  @description = description
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



174
175
176
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 174

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



177
178
179
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 177

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



180
181
182
# File 'lib/stripe/resources/gift_cards/transaction.rb', line 180

def 
  @metadata
end