Class: Stripe::GiftCards::TransactionService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/gift_cards/transaction_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



133
134
135
136
137
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 133

def initialize(description: nil, expand: nil, metadata: nil)
  @description = description
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



125
126
127
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 125

def description
  @description
end

#expandObject

Specifies which fields in the response should be expanded.



128
129
130
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 128

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



131
132
133
# File 'lib/stripe/services/gift_cards/transaction_service.rb', line 131

def 
  @metadata
end