Class: Stripe::Identity::VerificationReport
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Identity::VerificationReport
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/identity/verification_report.rb
Overview
A VerificationReport is the result of an attempt to collect and verify data from a user. The collection of verification checks performed is determined from the ‘type` and `options` parameters used. You can find the result of each verification check performed in the appropriate sub-resource: `document`, `id_number`, `selfie`.
Each VerificationReport contains a copy of any data collected by the user as well as reference IDs which can be used to access collected images through the [FileUpload](stripe.com/docs/api/files) API. To configure and create VerificationReports, use the [VerificationSession](stripe.com/docs/api/identity/verification_sessions) API.
Related guide: [Accessing verification results](stripe.com/docs/identity/verification-sessions#results).
Defined Under Namespace
Classes: Document, Email, IdNumber, ListParams, Options, Phone, Selfie
Constant Summary collapse
- OBJECT_NAME =
"identity.verification_report"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#client_reference_id ⇒ Object
readonly
A string to reference this user.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#document ⇒ Object
readonly
Result from a document check.
-
#email ⇒ Object
readonly
Result from a email check.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#id_number ⇒ Object
readonly
Result from an id_number check.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#options ⇒ Object
readonly
Attribute for field options.
-
#phone ⇒ Object
readonly
Result from a phone check.
-
#selfie ⇒ Object
readonly
Result from a selfie check.
-
#type ⇒ Object
readonly
Type of report.
-
#verification_flow ⇒ Object
readonly
The configuration token of a verification flow from the dashboard.
-
#verification_session ⇒ Object
readonly
ID of the VerificationSession that created this report.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
List all verification reports.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#client_reference_id ⇒ Object (readonly)
A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
410 411 412 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 410 def client_reference_id @client_reference_id end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
412 413 414 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 412 def created @created end |
#document ⇒ Object (readonly)
Result from a document check
414 415 416 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 414 def document @document end |
#email ⇒ Object (readonly)
Result from a email check
416 417 418 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 416 def email @email end |
#id ⇒ Object (readonly)
Unique identifier for the object.
418 419 420 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 418 def id @id end |
#id_number ⇒ Object (readonly)
Result from an id_number check
420 421 422 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 420 def id_number @id_number end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
422 423 424 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 422 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
424 425 426 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 424 def object @object end |
#options ⇒ Object (readonly)
Attribute for field options
426 427 428 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 426 def @options end |
#phone ⇒ Object (readonly)
Result from a phone check
428 429 430 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 428 def phone @phone end |
#selfie ⇒ Object (readonly)
Result from a selfie check
430 431 432 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 430 def selfie @selfie end |
#type ⇒ Object (readonly)
Type of report.
432 433 434 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 432 def type @type end |
#verification_flow ⇒ Object (readonly)
The configuration token of a verification flow from the dashboard.
434 435 436 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 434 def verification_flow @verification_flow end |
#verification_session ⇒ Object (readonly)
ID of the VerificationSession that created this report.
436 437 438 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 436 def verification_session @verification_session end |
Class Method Details
.field_remappings ⇒ Object
459 460 461 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 459 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
448 449 450 451 452 453 454 455 456 457 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 448 def self.inner_class_types @inner_class_types = { document: Document, email: Email, id_number: IdNumber, options: Options, phone: Phone, selfie: Selfie, } end |
.list(params = {}, opts = {}) ⇒ Object
List all verification reports.
439 440 441 442 443 444 445 446 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 439 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/identity/verification_reports", params: params, opts: opts ) end |
.object_name ⇒ Object
21 22 23 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 21 def self.object_name "identity.verification_report" end |