Class: Stripe::Identity::VerificationReport

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/identity/verification_report.rb

Overview

A VerificationReport is the result of an attempt to collect and verify data from a user. The collection of verification checks performed is determined from the ‘type` and `options` parameters used. You can find the result of each verification check performed in the appropriate sub-resource: `document`, `id_number`, `selfie`.

Each VerificationReport contains a copy of any data collected by the user as well as reference IDs which can be used to access collected images through the [FileUpload](stripe.com/docs/api/files) API. To configure and create VerificationReports, use the [VerificationSession](stripe.com/docs/api/identity/verification_sessions) API.

Related guide: [Accessing verification results](stripe.com/docs/identity/verification-sessions#results).

Defined Under Namespace

Classes: Document, Email, IdNumber, ListParams, Options, Phone, RetrieveParams, Selfie

Constant Summary collapse

OBJECT_NAME =
"identity.verification_report"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#client_reference_idObject (readonly)

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



319
320
321
# File 'lib/stripe/resources/identity/verification_report.rb', line 319

def client_reference_id
  @client_reference_id
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



322
323
324
# File 'lib/stripe/resources/identity/verification_report.rb', line 322

def created
  @created
end

#documentObject (readonly)

Result from a document check



325
326
327
# File 'lib/stripe/resources/identity/verification_report.rb', line 325

def document
  @document
end

#emailObject (readonly)

Result from a email check



328
329
330
# File 'lib/stripe/resources/identity/verification_report.rb', line 328

def email
  @email
end

#idObject (readonly)

Unique identifier for the object.



331
332
333
# File 'lib/stripe/resources/identity/verification_report.rb', line 331

def id
  @id
end

#id_numberObject (readonly)

Result from an id_number check



334
335
336
# File 'lib/stripe/resources/identity/verification_report.rb', line 334

def id_number
  @id_number
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



337
338
339
# File 'lib/stripe/resources/identity/verification_report.rb', line 337

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



340
341
342
# File 'lib/stripe/resources/identity/verification_report.rb', line 340

def object
  @object
end

#optionsObject (readonly)

Attribute for field options



343
344
345
# File 'lib/stripe/resources/identity/verification_report.rb', line 343

def options
  @options
end

#phoneObject (readonly)

Result from a phone check



346
347
348
# File 'lib/stripe/resources/identity/verification_report.rb', line 346

def phone
  @phone
end

#selfieObject (readonly)

Result from a selfie check



349
350
351
# File 'lib/stripe/resources/identity/verification_report.rb', line 349

def selfie
  @selfie
end

#typeObject (readonly)

Type of report.



352
353
354
# File 'lib/stripe/resources/identity/verification_report.rb', line 352

def type
  @type
end

#verification_flowObject (readonly)

The configuration token of a verification flow from the dashboard.



355
356
357
# File 'lib/stripe/resources/identity/verification_report.rb', line 355

def verification_flow
  @verification_flow
end

#verification_sessionObject (readonly)

ID of the VerificationSession that created this report.



358
359
360
# File 'lib/stripe/resources/identity/verification_report.rb', line 358

def verification_session
  @verification_session
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

List all verification reports.



361
362
363
364
365
366
367
368
# File 'lib/stripe/resources/identity/verification_report.rb', line 361

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/identity/verification_reports",
    params: params,
    opts: opts
  )
end

.object_nameObject



21
22
23
# File 'lib/stripe/resources/identity/verification_report.rb', line 21

def self.object_name
  "identity.verification_report"
end