Class: Stripe::Identity::VerificationReport

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/identity/verification_report.rb

Overview

A VerificationReport is the result of an attempt to collect and verify data from a user. The collection of verification checks performed is determined from the ‘type` and `options` parameters used. You can find the result of each verification check performed in the appropriate sub-resource: `document`, `id_number`, `selfie`.

Each VerificationReport contains a copy of any data collected by the user as well as reference IDs which can be used to access collected images through the [FileUpload](stripe.com/docs/api/files) API. To configure and create VerificationReports, use the [VerificationSession](stripe.com/docs/api/identity/verification_sessions) API.

Related guide: [Accessing verification results](stripe.com/docs/identity/verification-sessions#results).

Defined Under Namespace

Classes: Document, Email, IdNumber, Options, Phone, Selfie

Constant Summary collapse

OBJECT_NAME =
"identity.verification_report"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#client_reference_idObject (readonly)

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



89
90
91
# File 'lib/stripe/resources/identity/verification_report.rb', line 89

def client_reference_id
  @client_reference_id
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



91
92
93
# File 'lib/stripe/resources/identity/verification_report.rb', line 91

def created
  @created
end

#documentObject (readonly)

Result from a document check



93
94
95
# File 'lib/stripe/resources/identity/verification_report.rb', line 93

def document
  @document
end

#emailObject (readonly)

Result from a email check



95
96
97
# File 'lib/stripe/resources/identity/verification_report.rb', line 95

def email
  @email
end

#idObject (readonly)

Unique identifier for the object.



97
98
99
# File 'lib/stripe/resources/identity/verification_report.rb', line 97

def id
  @id
end

#id_numberObject (readonly)

Result from an id_number check



99
100
101
# File 'lib/stripe/resources/identity/verification_report.rb', line 99

def id_number
  @id_number
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



101
102
103
# File 'lib/stripe/resources/identity/verification_report.rb', line 101

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



103
104
105
# File 'lib/stripe/resources/identity/verification_report.rb', line 103

def object
  @object
end

#optionsObject (readonly)

Attribute for field options



105
106
107
# File 'lib/stripe/resources/identity/verification_report.rb', line 105

def options
  @options
end

#phoneObject (readonly)

Result from a phone check



107
108
109
# File 'lib/stripe/resources/identity/verification_report.rb', line 107

def phone
  @phone
end

#selfieObject (readonly)

Result from a selfie check



109
110
111
# File 'lib/stripe/resources/identity/verification_report.rb', line 109

def selfie
  @selfie
end

#typeObject (readonly)

Type of report.



111
112
113
# File 'lib/stripe/resources/identity/verification_report.rb', line 111

def type
  @type
end

#verification_flowObject (readonly)

The configuration token of a verification flow from the dashboard.



113
114
115
# File 'lib/stripe/resources/identity/verification_report.rb', line 113

def verification_flow
  @verification_flow
end

#verification_sessionObject (readonly)

ID of the VerificationSession that created this report.



115
116
117
# File 'lib/stripe/resources/identity/verification_report.rb', line 115

def verification_session
  @verification_session
end

Class Method Details

.list(filters = {}, opts = {}) ⇒ Object

List all verification reports.



118
119
120
121
122
123
124
125
# File 'lib/stripe/resources/identity/verification_report.rb', line 118

def self.list(filters = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/identity/verification_reports",
    params: filters,
    opts: opts
  )
end

.object_nameObject



21
22
23
# File 'lib/stripe/resources/identity/verification_report.rb', line 21

def self.object_name
  "identity.verification_report"
end