Class: Stripe::Identity::VerificationReport::Document
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Identity::VerificationReport::Document
- Defined in:
- lib/stripe/resources/identity/verification_report.rb
Defined Under Namespace
Classes: Address, Dob, Error, ExpirationDate, IssuedDate
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Address as it appears in the document.
-
#dob ⇒ Object
readonly
Date of birth as it appears in the document.
-
#error ⇒ Object
readonly
Details on the verification error.
-
#expiration_date ⇒ Object
readonly
Expiration date of the document.
-
#files ⇒ Object
readonly
Array of [File](stripe.com/docs/api/files) ids containing images for this document.
-
#first_name ⇒ Object
readonly
First name as it appears in the document.
-
#issued_date ⇒ Object
readonly
Issued date of the document.
-
#issuing_country ⇒ Object
readonly
Issuing country of the document.
-
#last_name ⇒ Object
readonly
Last name as it appears in the document.
-
#number ⇒ Object
readonly
Document ID number.
-
#status ⇒ Object
readonly
Status of this ‘document` check.
-
#type ⇒ Object
readonly
Type of the document.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Address as it appears in the document.
75 76 77 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 75 def address @address end |
#dob ⇒ Object (readonly)
Date of birth as it appears in the document.
77 78 79 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 77 def dob @dob end |
#error ⇒ Object (readonly)
Details on the verification error. Present when status is ‘unverified`.
79 80 81 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 79 def error @error end |
#expiration_date ⇒ Object (readonly)
Expiration date of the document.
81 82 83 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 81 def expiration_date @expiration_date end |
#files ⇒ Object (readonly)
Array of [File](stripe.com/docs/api/files) ids containing images for this document.
83 84 85 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 83 def files @files end |
#first_name ⇒ Object (readonly)
First name as it appears in the document.
85 86 87 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 85 def first_name @first_name end |
#issued_date ⇒ Object (readonly)
Issued date of the document.
87 88 89 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 87 def issued_date @issued_date end |
#issuing_country ⇒ Object (readonly)
Issuing country of the document.
89 90 91 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 89 def issuing_country @issuing_country end |
#last_name ⇒ Object (readonly)
Last name as it appears in the document.
91 92 93 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 91 def last_name @last_name end |
#number ⇒ Object (readonly)
Document ID number.
93 94 95 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 93 def number @number end |
#status ⇒ Object (readonly)
Status of this ‘document` check.
95 96 97 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 95 def status @status end |
#type ⇒ Object (readonly)
Type of the document.
97 98 99 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 97 def type @type end |