Class: Stripe::Identity::VerificationReport::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_report.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, verification_session: nil) ⇒ ListParams

Returns a new instance of ListParams.



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/stripe/resources/identity/verification_report.rb', line 233

def initialize(
  client_reference_id: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil,
  verification_session: nil
)
  @client_reference_id = client_reference_id
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
  @verification_session = verification_session
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



217
218
219
# File 'lib/stripe/resources/identity/verification_report.rb', line 217

def client_reference_id
  @client_reference_id
end

#createdObject

Only return VerificationReports that were created during the given date interval.



219
220
221
# File 'lib/stripe/resources/identity/verification_report.rb', line 219

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



221
222
223
# File 'lib/stripe/resources/identity/verification_report.rb', line 221

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



223
224
225
# File 'lib/stripe/resources/identity/verification_report.rb', line 223

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



225
226
227
# File 'lib/stripe/resources/identity/verification_report.rb', line 225

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



227
228
229
# File 'lib/stripe/resources/identity/verification_report.rb', line 227

def starting_after
  @starting_after
end

#typeObject

Only return VerificationReports of this type



229
230
231
# File 'lib/stripe/resources/identity/verification_report.rb', line 229

def type
  @type
end

#verification_sessionObject

Only return VerificationReports created by this VerificationSession ID. It is allowed to provide a VerificationIntent ID.



231
232
233
# File 'lib/stripe/resources/identity/verification_report.rb', line 231

def verification_session
  @verification_session
end