Class: Stripe::Identity::VerificationReport::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_report.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, type: nil, verification_session: nil) ⇒ ListParams

Returns a new instance of ListParams.



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/stripe/resources/identity/verification_report.rb', line 289

def initialize(
  client_reference_id: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  type: nil,
  verification_session: nil
)
  @client_reference_id = client_reference_id
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @type = type
  @verification_session = verification_session
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



266
267
268
# File 'lib/stripe/resources/identity/verification_report.rb', line 266

def client_reference_id
  @client_reference_id
end

#createdObject

Only return VerificationReports that were created during the given date interval.



269
270
271
# File 'lib/stripe/resources/identity/verification_report.rb', line 269

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



272
273
274
# File 'lib/stripe/resources/identity/verification_report.rb', line 272

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



275
276
277
# File 'lib/stripe/resources/identity/verification_report.rb', line 275

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



278
279
280
# File 'lib/stripe/resources/identity/verification_report.rb', line 278

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



281
282
283
# File 'lib/stripe/resources/identity/verification_report.rb', line 281

def starting_after
  @starting_after
end

#typeObject

Only return VerificationReports of this type



284
285
286
# File 'lib/stripe/resources/identity/verification_report.rb', line 284

def type
  @type
end

#verification_sessionObject

Only return VerificationReports created by this VerificationSession ID. It is allowed to provide a VerificationIntent ID.



287
288
289
# File 'lib/stripe/resources/identity/verification_report.rb', line 287

def verification_session
  @verification_session
end