Class: Stripe::Identity::VerificationReport::Selfie
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Identity::VerificationReport::Selfie
- Defined in:
- lib/stripe/resources/identity/verification_report.rb
Defined Under Namespace
Classes: Error
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#blocked_by_entry ⇒ Object
readonly
If selfie was not verified due to being on the blocklist, this is the token of the BlocklistEntry that blocked it.
-
#document ⇒ Object
readonly
ID of the [File](docs.stripe.com/api/files) holding the image of the identity document used in this check.
-
#error ⇒ Object
readonly
Details on the verification error.
-
#selfie ⇒ Object
readonly
ID of the [File](docs.stripe.com/api/files) holding the image of the selfie used in this check.
-
#status ⇒ Object
readonly
Status of this ‘selfie` check.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#blocked_by_entry ⇒ Object (readonly)
If selfie was not verified due to being on the blocklist, this is the token of the BlocklistEntry that blocked it
358 359 360 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 358 def blocked_by_entry @blocked_by_entry end |
#document ⇒ Object (readonly)
ID of the [File](docs.stripe.com/api/files) holding the image of the identity document used in this check.
360 361 362 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 360 def document @document end |
#error ⇒ Object (readonly)
Details on the verification error. Present when status is ‘unverified`.
362 363 364 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 362 def error @error end |
#selfie ⇒ Object (readonly)
ID of the [File](docs.stripe.com/api/files) holding the image of the selfie used in this check.
364 365 366 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 364 def selfie @selfie end |
#status ⇒ Object (readonly)
Status of this ‘selfie` check.
366 367 368 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 366 def status @status end |
Class Method Details
.field_remappings ⇒ Object
372 373 374 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 372 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
368 369 370 |
# File 'lib/stripe/resources/identity/verification_report.rb', line 368 def self.inner_class_types @inner_class_types = { error: Error } end |