Class: Stripe::Identity::VerificationReport::Selfie

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_report.rb

Defined Under Namespace

Classes: Error

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#documentObject (readonly)

ID of the [File](stripe.com/docs/api/files) holding the image of the identity document used in this check.



232
233
234
# File 'lib/stripe/resources/identity/verification_report.rb', line 232

def document
  @document
end

#errorObject (readonly)

Details on the verification error. Present when status is ‘unverified`.



235
236
237
# File 'lib/stripe/resources/identity/verification_report.rb', line 235

def error
  @error
end

#selfieObject (readonly)

ID of the [File](stripe.com/docs/api/files) holding the image of the selfie used in this check.



238
239
240
# File 'lib/stripe/resources/identity/verification_report.rb', line 238

def selfie
  @selfie
end

#statusObject (readonly)

Status of this ‘selfie` check.



241
242
243
# File 'lib/stripe/resources/identity/verification_report.rb', line 241

def status
  @status
end