Class: Stripe::Identity::VerificationSession

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/identity/verification_session.rb

Overview

A VerificationSession guides you through the process of collecting and verifying the identities of your users. It contains details about the type of verification, such as what [verification check](stripe.com/docs/identity/verification-checks) to perform. Only create one VerificationSession for each verification in your system.

A VerificationSession transitions through [multiple statuses](stripe.com/docs/identity/how-sessions-work) throughout its lifetime as it progresses through the verification flow. The VerificationSession contains the user’s verified data after verification checks are complete.

Related guide: [The Verification Sessions API](stripe.com/docs/identity/verification-sessions)

Defined Under Namespace

Classes: CancelParams, CreateParams, LastError, ListParams, Options, ProvidedDetails, RedactParams, Redaction, RetrieveParams, UpdateParams, VerifiedOutputs

Constant Summary collapse

OBJECT_NAME =
"identity.verification_session"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#client_reference_idObject (readonly)

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



404
405
406
# File 'lib/stripe/resources/identity/verification_session.rb', line 404

def client_reference_id
  @client_reference_id
end

#client_secretObject (readonly)

The short-lived client secret used by Stripe.js to [show a verification modal](stripe.com/docs/js/identity/modal) inside your app. This client secret expires after 24 hours and can only be used once. Don’t store it, log it, embed it in a URL, or expose it to anyone other than the user. Make sure that you have TLS enabled on any page that includes the client secret. Refer to our docs on [passing the client secret to the frontend](stripe.com/docs/identity/verification-sessions#client-secret) to learn more.



407
408
409
# File 'lib/stripe/resources/identity/verification_session.rb', line 407

def client_secret
  @client_secret
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



410
411
412
# File 'lib/stripe/resources/identity/verification_session.rb', line 410

def created
  @created
end

#idObject (readonly)

Unique identifier for the object.



413
414
415
# File 'lib/stripe/resources/identity/verification_session.rb', line 413

def id
  @id
end

#last_errorObject (readonly)

If present, this property tells you the last error encountered when processing the verification.



416
417
418
# File 'lib/stripe/resources/identity/verification_session.rb', line 416

def last_error
  @last_error
end

#last_verification_reportObject (readonly)

ID of the most recent VerificationReport. [Learn more about accessing detailed verification results.](stripe.com/docs/identity/verification-sessions#results)



419
420
421
# File 'lib/stripe/resources/identity/verification_session.rb', line 419

def last_verification_report
  @last_verification_report
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



422
423
424
# File 'lib/stripe/resources/identity/verification_session.rb', line 422

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



425
426
427
# File 'lib/stripe/resources/identity/verification_session.rb', line 425

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



428
429
430
# File 'lib/stripe/resources/identity/verification_session.rb', line 428

def object
  @object
end

#optionsObject (readonly)

A set of options for the session’s verification checks.



431
432
433
# File 'lib/stripe/resources/identity/verification_session.rb', line 431

def options
  @options
end

#provided_detailsObject (readonly)

Details provided about the user being verified. These details may be shown to the user.



434
435
436
# File 'lib/stripe/resources/identity/verification_session.rb', line 434

def provided_details
  @provided_details
end

#redactionObject (readonly)

Redaction status of this VerificationSession. If the VerificationSession is not redacted, this field will be null.



437
438
439
# File 'lib/stripe/resources/identity/verification_session.rb', line 437

def redaction
  @redaction
end

Token referencing a Customer resource.



440
441
442
# File 'lib/stripe/resources/identity/verification_session.rb', line 440

def related_customer
  @related_customer
end

#statusObject (readonly)

Status of this VerificationSession. [Learn more about the lifecycle of sessions](stripe.com/docs/identity/how-sessions-work).



443
444
445
# File 'lib/stripe/resources/identity/verification_session.rb', line 443

def status
  @status
end

#typeObject (readonly)

The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.



446
447
448
# File 'lib/stripe/resources/identity/verification_session.rb', line 446

def type
  @type
end

#urlObject (readonly)

The short-lived URL that you use to redirect a user to Stripe to submit their identity information. This URL expires after 48 hours and can only be used once. Don’t store it, log it, send it in emails or expose it to anyone other than the user. Refer to our docs on [verifying identity documents](stripe.com/docs/identity/verify-identity-documents?platform=web&type=redirect) to learn how to redirect users to Stripe.



449
450
451
# File 'lib/stripe/resources/identity/verification_session.rb', line 449

def url
  @url
end

#verification_flowObject (readonly)

The configuration token of a verification flow from the dashboard.



452
453
454
# File 'lib/stripe/resources/identity/verification_session.rb', line 452

def verification_flow
  @verification_flow
end

#verified_outputsObject (readonly)

The user’s verified data.



455
456
457
# File 'lib/stripe/resources/identity/verification_session.rb', line 455

def verified_outputs
  @verified_outputs
end

Class Method Details

.cancel(session, params = {}, opts = {}) ⇒ Object

A VerificationSession object can be canceled when it is in requires_input [status](stripe.com/docs/identity/how-sessions-work).

Once canceled, future submission attempts are disabled. This cannot be undone. [Learn more](stripe.com/docs/identity/verification-sessions#cancel).



472
473
474
475
476
477
478
479
# File 'lib/stripe/resources/identity/verification_session.rb', line 472

def self.cancel(session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/identity/verification_sessions/%<session>s/cancel", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a VerificationSession object.

After the VerificationSession is created, display a verification modal using the session client_secret or send your users to the session’s url.

If your API key is in test mode, verification checks won’t actually process, though everything else will occur as if in live mode.

Related guide: [Verify your users’ identity documents](stripe.com/docs/identity/verify-identity-documents)



488
489
490
491
492
493
494
495
# File 'lib/stripe/resources/identity/verification_session.rb', line 488

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/identity/verification_sessions",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of VerificationSessions



498
499
500
501
502
503
504
505
# File 'lib/stripe/resources/identity/verification_session.rb', line 498

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/identity/verification_sessions",
    params: params,
    opts: opts
  )
end

.object_nameObject



23
24
25
# File 'lib/stripe/resources/identity/verification_session.rb', line 23

def self.object_name
  "identity.verification_session"
end

.redact(session, params = {}, opts = {}) ⇒ Object

Redact a VerificationSession to remove all collected information from Stripe. This will redact the VerificationSession and all objects related to it, including VerificationReports, Events, request logs, etc.

A VerificationSession object can be redacted when it is in requires_input or verified [status](stripe.com/docs/identity/how-sessions-work). Redacting a VerificationSession in requires_action state will automatically cancel it.

The redaction process may take up to four days. When the redaction process is in progress, the VerificationSession’s redaction.status field will be set to processing; when the process is finished, it will change to redacted and an identity.verification_session.redacted event will be emitted.

Redaction is irreversible. Redacted objects are still accessible in the Stripe API, but all the fields that contain personal data will be replaced by the string [redacted] or a similar placeholder. The metadata field will also be erased. Redacted objects cannot be updated or used for any purpose.

[Learn more](stripe.com/docs/identity/verification-sessions#redact).



554
555
556
557
558
559
560
561
# File 'lib/stripe/resources/identity/verification_session.rb', line 554

def self.redact(session, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/identity/verification_sessions/%<session>s/redact", { session: CGI.escape(session) }),
    params: params,
    opts: opts
  )
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates a VerificationSession object.

When the session status is requires_input, you can use this method to update the verification check and options.



567
568
569
570
571
572
573
574
# File 'lib/stripe/resources/identity/verification_session.rb', line 567

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/identity/verification_sessions/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#cancel(params = {}, opts = {}) ⇒ Object

A VerificationSession object can be canceled when it is in requires_input [status](stripe.com/docs/identity/how-sessions-work).

Once canceled, future submission attempts are disabled. This cannot be undone. [Learn more](stripe.com/docs/identity/verification-sessions#cancel).



460
461
462
463
464
465
466
467
# File 'lib/stripe/resources/identity/verification_session.rb', line 460

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/identity/verification_sessions/%<session>s/cancel", { session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#redact(params = {}, opts = {}) ⇒ Object

Redact a VerificationSession to remove all collected information from Stripe. This will redact the VerificationSession and all objects related to it, including VerificationReports, Events, request logs, etc.

A VerificationSession object can be redacted when it is in requires_input or verified [status](stripe.com/docs/identity/how-sessions-work). Redacting a VerificationSession in requires_action state will automatically cancel it.

The redaction process may take up to four days. When the redaction process is in progress, the VerificationSession’s redaction.status field will be set to processing; when the process is finished, it will change to redacted and an identity.verification_session.redacted event will be emitted.

Redaction is irreversible. Redacted objects are still accessible in the Stripe API, but all the fields that contain personal data will be replaced by the string [redacted] or a similar placeholder. The metadata field will also be erased. Redacted objects cannot be updated or used for any purpose.

[Learn more](stripe.com/docs/identity/verification-sessions#redact).



526
527
528
529
530
531
532
533
# File 'lib/stripe/resources/identity/verification_session.rb', line 526

def redact(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/identity/verification_sessions/%<session>s/redact", { session: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end