Class: Stripe::Identity::VerificationSession
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Identity::VerificationSession
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Overview
A VerificationSession guides you through the process of collecting and verifying the identities of your users. It contains details about the type of verification, such as what [verification check](stripe.com/docs/identity/verification-checks) to perform. Only create one VerificationSession for each verification in your system.
A VerificationSession transitions through [multiple statuses](stripe.com/docs/identity/how-sessions-work) throughout its lifetime as it progresses through the verification flow. The VerificationSession contains the user’s verified data after verification checks are complete.
Related guide: [The Verification Sessions API](stripe.com/docs/identity/verification-sessions)
Defined Under Namespace
Classes: LastError, Options, ProvidedDetails, Redaction, VerifiedOutputs
Constant Summary collapse
- OBJECT_NAME =
"identity.verification_session"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#client_reference_id ⇒ Object
readonly
A string to reference this user.
-
#client_secret ⇒ Object
readonly
The short-lived client secret used by Stripe.js to [show a verification modal](stripe.com/docs/js/identity/modal) inside your app.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_error ⇒ Object
readonly
If present, this property tells you the last error encountered when processing the verification.
-
#last_verification_report ⇒ Object
readonly
ID of the most recent VerificationReport.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#options ⇒ Object
readonly
A set of options for the session’s verification checks.
-
#provided_details ⇒ Object
readonly
Details provided about the user being verified.
-
#redaction ⇒ Object
readonly
Redaction status of this VerificationSession.
-
#related_customer ⇒ Object
readonly
Token referencing a Customer resource.
-
#status ⇒ Object
readonly
Status of this VerificationSession.
-
#type ⇒ Object
readonly
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
-
#url ⇒ Object
readonly
The short-lived URL that you use to redirect a user to Stripe to submit their identity information.
-
#verification_flow ⇒ Object
readonly
The configuration token of a verification flow from the dashboard.
-
#verified_outputs ⇒ Object
readonly
The user’s verified data.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.cancel(session, params = {}, opts = {}) ⇒ Object
A VerificationSession object can be canceled when it is in requires_input [status](stripe.com/docs/identity/how-sessions-work).
-
.create(params = {}, opts = {}) ⇒ Object
Creates a VerificationSession object.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of VerificationSessions.
- .object_name ⇒ Object
-
.redact(session, params = {}, opts = {}) ⇒ Object
Redact a VerificationSession to remove all collected information from Stripe.
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates a VerificationSession object.
Instance Method Summary collapse
-
#cancel(params = {}, opts = {}) ⇒ Object
A VerificationSession object can be canceled when it is in requires_input [status](stripe.com/docs/identity/how-sessions-work).
-
#redact(params = {}, opts = {}) ⇒ Object
Redact a VerificationSession to remove all collected information from Stripe.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#client_reference_id ⇒ Object (readonly)
A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
67 68 69 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 67 def client_reference_id @client_reference_id end |
#client_secret ⇒ Object (readonly)
The short-lived client secret used by Stripe.js to [show a verification modal](stripe.com/docs/js/identity/modal) inside your app. This client secret expires after 24 hours and can only be used once. Don’t store it, log it, embed it in a URL, or expose it to anyone other than the user. Make sure that you have TLS enabled on any page that includes the client secret. Refer to our docs on [passing the client secret to the frontend](stripe.com/docs/identity/verification-sessions#client-secret) to learn more.
69 70 71 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 69 def client_secret @client_secret end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
71 72 73 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 71 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
73 74 75 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 73 def id @id end |
#last_error ⇒ Object (readonly)
If present, this property tells you the last error encountered when processing the verification.
75 76 77 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 75 def last_error @last_error end |
#last_verification_report ⇒ Object (readonly)
ID of the most recent VerificationReport. [Learn more about accessing detailed verification results.](stripe.com/docs/identity/verification-sessions#results)
77 78 79 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 77 def last_verification_report @last_verification_report end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
79 80 81 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 79 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
81 82 83 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 81 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
83 84 85 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 83 def object @object end |
#options ⇒ Object (readonly)
A set of options for the session’s verification checks.
85 86 87 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 85 def @options end |
#provided_details ⇒ Object (readonly)
Details provided about the user being verified. These details may be shown to the user.
87 88 89 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 87 def provided_details @provided_details end |
#redaction ⇒ Object (readonly)
Redaction status of this VerificationSession. If the VerificationSession is not redacted, this field will be null.
89 90 91 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 89 def redaction @redaction end |
#related_customer ⇒ Object (readonly)
Token referencing a Customer resource.
91 92 93 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 91 def @related_customer end |
#status ⇒ Object (readonly)
Status of this VerificationSession. [Learn more about the lifecycle of sessions](stripe.com/docs/identity/how-sessions-work).
93 94 95 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 93 def status @status end |
#type ⇒ Object (readonly)
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
95 96 97 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 95 def type @type end |
#url ⇒ Object (readonly)
The short-lived URL that you use to redirect a user to Stripe to submit their identity information. This URL expires after 48 hours and can only be used once. Don’t store it, log it, send it in emails or expose it to anyone other than the user. Refer to our docs on [verifying identity documents](stripe.com/docs/identity/verify-identity-documents?platform=web&type=redirect) to learn how to redirect users to Stripe.
97 98 99 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 97 def url @url end |
#verification_flow ⇒ Object (readonly)
The configuration token of a verification flow from the dashboard.
99 100 101 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 99 def verification_flow @verification_flow end |
#verified_outputs ⇒ Object (readonly)
The user’s verified data.
101 102 103 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 101 def verified_outputs @verified_outputs end |
Class Method Details
.cancel(session, params = {}, opts = {}) ⇒ Object
A VerificationSession object can be canceled when it is in requires_input [status](stripe.com/docs/identity/how-sessions-work).
Once canceled, future submission attempts are disabled. This cannot be undone. [Learn more](stripe.com/docs/identity/verification-sessions#cancel).
118 119 120 121 122 123 124 125 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 118 def self.cancel(session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/identity/verification_sessions/%<session>s/cancel", { session: CGI.escape(session) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a VerificationSession object.
After the VerificationSession is created, display a verification modal using the session client_secret or send your users to the session’s url.
If your API key is in test mode, verification checks won’t actually process, though everything else will occur as if in live mode.
Related guide: [Verify your users’ identity documents](stripe.com/docs/identity/verify-identity-documents)
134 135 136 137 138 139 140 141 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 134 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/identity/verification_sessions", params: params, opts: opts ) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of VerificationSessions
144 145 146 147 148 149 150 151 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 144 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/identity/verification_sessions", params: filters, opts: opts ) end |
.object_name ⇒ Object
23 24 25 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 23 def self.object_name "identity.verification_session" end |
.redact(session, params = {}, opts = {}) ⇒ Object
Redact a VerificationSession to remove all collected information from Stripe. This will redact the VerificationSession and all objects related to it, including VerificationReports, Events, request logs, etc.
A VerificationSession object can be redacted when it is in requires_input or verified [status](stripe.com/docs/identity/how-sessions-work). Redacting a VerificationSession in requires_action state will automatically cancel it.
The redaction process may take up to four days. When the redaction process is in progress, the VerificationSession’s redaction.status field will be set to processing; when the process is finished, it will change to redacted and an identity.verification_session.redacted event will be emitted.
Redaction is irreversible. Redacted objects are still accessible in the Stripe API, but all the fields that contain personal data will be replaced by the string [redacted] or a similar placeholder. The metadata field will also be erased. Redacted objects cannot be updated or used for any purpose.
[Learn more](stripe.com/docs/identity/verification-sessions#redact).
200 201 202 203 204 205 206 207 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 200 def self.redact(session, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/identity/verification_sessions/%<session>s/redact", { session: CGI.escape(session) }), params: params, opts: opts ) end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates a VerificationSession object.
When the session status is requires_input, you can use this method to update the verification check and options.
213 214 215 216 217 218 219 220 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 213 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/identity/verification_sessions/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#cancel(params = {}, opts = {}) ⇒ Object
A VerificationSession object can be canceled when it is in requires_input [status](stripe.com/docs/identity/how-sessions-work).
Once canceled, future submission attempts are disabled. This cannot be undone. [Learn more](stripe.com/docs/identity/verification-sessions#cancel).
106 107 108 109 110 111 112 113 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 106 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/identity/verification_sessions/%<session>s/cancel", { session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#redact(params = {}, opts = {}) ⇒ Object
Redact a VerificationSession to remove all collected information from Stripe. This will redact the VerificationSession and all objects related to it, including VerificationReports, Events, request logs, etc.
A VerificationSession object can be redacted when it is in requires_input or verified [status](stripe.com/docs/identity/how-sessions-work). Redacting a VerificationSession in requires_action state will automatically cancel it.
The redaction process may take up to four days. When the redaction process is in progress, the VerificationSession’s redaction.status field will be set to processing; when the process is finished, it will change to redacted and an identity.verification_session.redacted event will be emitted.
Redaction is irreversible. Redacted objects are still accessible in the Stripe API, but all the fields that contain personal data will be replaced by the string [redacted] or a similar placeholder. The metadata field will also be erased. Redacted objects cannot be updated or used for any purpose.
[Learn more](stripe.com/docs/identity/verification-sessions#redact).
172 173 174 175 176 177 178 179 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 172 def redact(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/identity/verification_sessions/%<session>s/redact", { session: CGI.escape(self["id"]) }), params: params, opts: opts ) end |