Class: Stripe::Identity::VerificationSession::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::CreateParams
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Defined Under Namespace
Classes: Options, ProvidedDetails, RelatedPerson
Instance Attribute Summary collapse
-
#client_reference_id ⇒ Object
A string to reference this user.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#options ⇒ Object
A set of options for the session’s verification checks.
-
#provided_details ⇒ Object
Details provided about the user being verified.
-
#related_customer ⇒ Object
Customer ID.
-
#related_customer_account ⇒ Object
Token referencing a Customer Account resource.
-
#related_person ⇒ Object
Tokens referencing a Person resource and it’s associated account.
-
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the verification flow.
-
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
-
#verification_flow ⇒ Object
The ID of a verification flow from the Dashboard.
Instance Method Summary collapse
-
#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 391 def initialize( client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil ) @client_reference_id = client_reference_id @expand = @metadata = @options = @provided_details = provided_details @related_customer = @related_customer_account = @related_person = @return_url = return_url @type = type @verification_flow = verification_flow end |
Instance Attribute Details
#client_reference_id ⇒ Object
A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
369 370 371 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 369 def client_reference_id @client_reference_id end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
371 372 373 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 371 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
373 374 375 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 373 def @metadata end |
#options ⇒ Object
A set of options for the session’s verification checks.
375 376 377 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 375 def @options end |
#provided_details ⇒ Object
Details provided about the user being verified. These details may be shown to the user.
377 378 379 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 377 def provided_details @provided_details end |
#related_customer ⇒ Object
Customer ID
379 380 381 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 379 def @related_customer end |
#related_customer_account ⇒ Object
Token referencing a Customer Account resource.
381 382 383 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 381 def @related_customer_account end |
#related_person ⇒ Object
Tokens referencing a Person resource and it’s associated account.
383 384 385 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 383 def @related_person end |
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the verification flow.
385 386 387 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 385 def return_url @return_url end |
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.
387 388 389 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 387 def type @type end |
#verification_flow ⇒ Object
The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.
389 390 391 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 389 def verification_flow @verification_flow end |