Class: Stripe::Identity::VerificationSession::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::CreateParams
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Defined Under Namespace
Classes: Options, ProvidedDetails, RelatedPerson
Instance Attribute Summary collapse
-
#client_reference_id ⇒ Object
A string to reference this user.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#options ⇒ Object
A set of options for the session’s verification checks.
-
#provided_details ⇒ Object
Details provided about the user being verified.
-
#related_customer ⇒ Object
Customer ID.
-
#related_customer_account ⇒ Object
Token referencing a Customer Account resource.
-
#related_person ⇒ Object
Tokens referencing a Person resource and it’s associated account.
-
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the verification flow.
-
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
-
#verification_flow ⇒ Object
The ID of a verification flow from the Dashboard.
Instance Method Summary collapse
-
#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 281 def initialize( client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil ) @client_reference_id = client_reference_id @expand = @metadata = @options = @provided_details = provided_details @related_customer = @related_customer_account = @related_person = @return_url = return_url @type = type @verification_flow = verification_flow end |
Instance Attribute Details
#client_reference_id ⇒ Object
A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
259 260 261 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 259 def client_reference_id @client_reference_id end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
261 262 263 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 261 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
263 264 265 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 263 def @metadata end |
#options ⇒ Object
A set of options for the session’s verification checks.
265 266 267 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 265 def @options end |
#provided_details ⇒ Object
Details provided about the user being verified. These details may be shown to the user.
267 268 269 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 267 def provided_details @provided_details end |
#related_customer ⇒ Object
Customer ID
269 270 271 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 269 def @related_customer end |
#related_customer_account ⇒ Object
Token referencing a Customer Account resource.
271 272 273 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 271 def @related_customer_account end |
#related_person ⇒ Object
Tokens referencing a Person resource and it’s associated account.
273 274 275 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 273 def @related_person end |
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the verification flow.
275 276 277 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 275 def return_url @return_url end |
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.
277 278 279 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 277 def type @type end |
#verification_flow ⇒ Object
The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.
279 280 281 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 279 def verification_flow @verification_flow end |