Class: Stripe::Identity::VerificationSession::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_session.rb

Defined Under Namespace

Classes: Options, ProvidedDetails, RelatedPerson

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/stripe/resources/identity/verification_session.rb', line 275

def initialize(
  client_reference_id: nil,
  expand: nil,
  metadata: nil,
  options: nil,
  provided_details: nil,
  related_customer: nil,
  related_person: nil,
  return_url: nil,
  type: nil,
  verification_flow: nil
)
  @client_reference_id = client_reference_id
  @expand = expand
  @metadata = 
  @options = options
  @provided_details = provided_details
  @related_customer = related_customer
  @related_person = related_person
  @return_url = return_url
  @type = type
  @verification_flow = verification_flow
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



255
256
257
# File 'lib/stripe/resources/identity/verification_session.rb', line 255

def client_reference_id
  @client_reference_id
end

#expandObject

Specifies which fields in the response should be expanded.



257
258
259
# File 'lib/stripe/resources/identity/verification_session.rb', line 257

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



259
260
261
# File 'lib/stripe/resources/identity/verification_session.rb', line 259

def 
  @metadata
end

#optionsObject

A set of options for the session’s verification checks.



261
262
263
# File 'lib/stripe/resources/identity/verification_session.rb', line 261

def options
  @options
end

#provided_detailsObject

Details provided about the user being verified. These details may be shown to the user.



263
264
265
# File 'lib/stripe/resources/identity/verification_session.rb', line 263

def provided_details
  @provided_details
end

Customer ID



265
266
267
# File 'lib/stripe/resources/identity/verification_session.rb', line 265

def related_customer
  @related_customer
end

Tokens referencing a Person resource and it’s associated account.



267
268
269
# File 'lib/stripe/resources/identity/verification_session.rb', line 267

def related_person
  @related_person
end

#return_urlObject

The URL that the user will be redirected to upon completing the verification flow.



269
270
271
# File 'lib/stripe/resources/identity/verification_session.rb', line 269

def return_url
  @return_url
end

#typeObject

The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.



271
272
273
# File 'lib/stripe/resources/identity/verification_session.rb', line 271

def type
  @type
end

#verification_flowObject

The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.



273
274
275
# File 'lib/stripe/resources/identity/verification_session.rb', line 273

def verification_flow
  @verification_flow
end