Class: Stripe::Identity::VerificationSession::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_session.rb

Defined Under Namespace

Classes: Options, ProvidedDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/stripe/resources/identity/verification_session.rb', line 251

def initialize(
  client_reference_id: nil,
  expand: nil,
  metadata: nil,
  options: nil,
  provided_details: nil,
  related_customer: nil,
  related_customer_account: nil,
  return_url: nil,
  type: nil,
  verification_flow: nil
)
  @client_reference_id = client_reference_id
  @expand = expand
  @metadata = 
  @options = options
  @provided_details = provided_details
  @related_customer = related_customer
  @related_customer_account = 
  @return_url = return_url
  @type = type
  @verification_flow = verification_flow
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



231
232
233
# File 'lib/stripe/resources/identity/verification_session.rb', line 231

def client_reference_id
  @client_reference_id
end

#expandObject

Specifies which fields in the response should be expanded.



233
234
235
# File 'lib/stripe/resources/identity/verification_session.rb', line 233

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



235
236
237
# File 'lib/stripe/resources/identity/verification_session.rb', line 235

def 
  @metadata
end

#optionsObject

A set of options for the session’s verification checks.



237
238
239
# File 'lib/stripe/resources/identity/verification_session.rb', line 237

def options
  @options
end

#provided_detailsObject

Details provided about the user being verified. These details may be shown to the user.



239
240
241
# File 'lib/stripe/resources/identity/verification_session.rb', line 239

def provided_details
  @provided_details
end

Customer ID



241
242
243
# File 'lib/stripe/resources/identity/verification_session.rb', line 241

def related_customer
  @related_customer
end

Token referencing a Customer Account resource.



243
244
245
# File 'lib/stripe/resources/identity/verification_session.rb', line 243

def 
  @related_customer_account
end

#return_urlObject

The URL that the user will be redirected to upon completing the verification flow.



245
246
247
# File 'lib/stripe/resources/identity/verification_session.rb', line 245

def return_url
  @return_url
end

#typeObject

The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.



247
248
249
# File 'lib/stripe/resources/identity/verification_session.rb', line 247

def type
  @type
end

#verification_flowObject

The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.



249
250
251
# File 'lib/stripe/resources/identity/verification_session.rb', line 249

def verification_flow
  @verification_flow
end