Class: Stripe::Identity::VerificationSession::CreateParams::RelatedPerson

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/identity/verification_session.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account: nil, person: nil) ⇒ RelatedPerson

Returns a new instance of RelatedPerson.



249
250
251
252
# File 'lib/stripe/resources/identity/verification_session.rb', line 249

def initialize(account: nil, person: nil)
  @account = 
  @person = person
end

Instance Attribute Details

#accountObject

A token representing a connected account. If provided, the person parameter is also required and must be associated with the account.



245
246
247
# File 'lib/stripe/resources/identity/verification_session.rb', line 245

def 
  @account
end

#personObject

A token referencing a Person resource that this verification is being used to verify.



247
248
249
# File 'lib/stripe/resources/identity/verification_session.rb', line 247

def person
  @person
end