Class: Stripe::Identity::VerificationSession::CreateParams::RelatedPerson
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::CreateParams::RelatedPerson
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
A token representing a connected account.
-
#person ⇒ Object
A token referencing a Person resource that this verification is being used to verify.
Instance Method Summary collapse
-
#initialize(account: nil, person: nil) ⇒ RelatedPerson
constructor
A new instance of RelatedPerson.
Methods inherited from RequestParams
Constructor Details
#initialize(account: nil, person: nil) ⇒ RelatedPerson
Returns a new instance of RelatedPerson.
249 250 251 252 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 249 def initialize(account: nil, person: nil) @account = account @person = person end |
Instance Attribute Details
#account ⇒ Object
A token representing a connected account. If provided, the person parameter is also required and must be associated with the account.
245 246 247 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 245 def account @account end |
#person ⇒ Object
A token referencing a Person resource that this verification is being used to verify.
247 248 249 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 247 def person @person end |