Class: Stripe::Identity::VerificationSession::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::ListParams
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#client_reference_id ⇒ Object
A string to reference this user.
-
#created ⇒ Object
Only return VerificationSessions that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#related_customer ⇒ Object
Attribute for param field related_customer.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return VerificationSessions with this status.
Instance Method Summary collapse
-
#initialize(client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, related_customer: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, related_customer: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 178 def initialize( client_reference_id: nil, created: nil, ending_before: nil, expand: nil, limit: nil, related_customer: nil, starting_after: nil, status: nil ) @client_reference_id = client_reference_id @created = created @ending_before = ending_before @expand = @limit = limit @related_customer = @starting_after = starting_after @status = status end |
Instance Attribute Details
#client_reference_id ⇒ Object
A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
162 163 164 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 162 def client_reference_id @client_reference_id end |
#created ⇒ Object
Only return VerificationSessions that were created during the given date interval.
164 165 166 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 164 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
166 167 168 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 166 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
168 169 170 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 168 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
170 171 172 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 170 def limit @limit end |
#related_customer ⇒ Object
Attribute for param field related_customer
172 173 174 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 172 def @related_customer end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
174 175 176 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 174 def starting_after @starting_after end |
#status ⇒ Object
Only return VerificationSessions with this status. [Learn more about the lifecycle of sessions](stripe.com/docs/identity/how-sessions-work).
176 177 178 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 176 def status @status end |