Class: Stripe::Identity::VerificationSession::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSession::UpdateParams
- Defined in:
- lib/stripe/resources/identity/verification_session.rb
Defined Under Namespace
Classes: Options, ProvidedDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#options ⇒ Object
A set of options for the session’s verification checks.
-
#provided_details ⇒ Object
Details provided about the user being verified.
-
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
Instance Method Summary collapse
-
#initialize(expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
325 326 327 328 329 330 331 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 325 def initialize(expand: nil, metadata: nil, options: nil, provided_details: nil, type: nil) @expand = @metadata = @options = @provided_details = provided_details @type = type end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
315 316 317 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 315 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
317 318 319 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 317 def @metadata end |
#options ⇒ Object
A set of options for the session’s verification checks.
319 320 321 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 319 def @options end |
#provided_details ⇒ Object
Details provided about the user being verified. These details may be shown to the user.
321 322 323 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 321 def provided_details @provided_details end |
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
323 324 325 |
# File 'lib/stripe/resources/identity/verification_session.rb', line 323 def type @type end |