Class: Stripe::Identity::VerificationSessionCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSessionCreateParams
- Defined in:
- lib/stripe/params/identity/verification_session_create_params.rb
Defined Under Namespace
Classes: Options, ProvidedDetails, RelatedPerson
Instance Attribute Summary collapse
-
#client_reference_id ⇒ Object
A string to reference this user.
-
#confirm ⇒ Object
Confirm and submit the provided details for verification.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#options ⇒ Object
A set of options for the session’s verification checks.
-
#provided_details ⇒ Object
Details provided about the user being verified.
-
#related_customer ⇒ Object
Customer ID.
-
#related_customer_account ⇒ Object
The ID of the Account representing a customer.
-
#related_person ⇒ Object
Tokens referencing a Person resource and it’s associated account.
-
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the verification flow.
-
#type ⇒ Object
The type of [verification check](docs.stripe.com/identity/verification-checks) to be performed.
-
#verification_flow ⇒ Object
The ID of a verification flow from the Dashboard.
Instance Method Summary collapse
-
#initialize(client_reference_id: nil, confirm: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ VerificationSessionCreateParams
constructor
A new instance of VerificationSessionCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(client_reference_id: nil, confirm: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ VerificationSessionCreateParams
Returns a new instance of VerificationSessionCreateParams.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 86 def initialize( client_reference_id: nil, confirm: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, related_person: nil, return_url: nil, type: nil, verification_flow: nil ) @client_reference_id = client_reference_id @confirm = confirm @expand = @metadata = @options = @provided_details = provided_details @related_customer = @related_customer_account = @related_person = @return_url = return_url @type = type @verification_flow = verification_flow end |
Instance Attribute Details
#client_reference_id ⇒ Object
A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
62 63 64 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 62 def client_reference_id @client_reference_id end |
#confirm ⇒ Object
Confirm and submit the provided details for verification.
64 65 66 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 64 def confirm @confirm end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
66 67 68 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 66 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
68 69 70 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 68 def @metadata end |
#options ⇒ Object
A set of options for the session’s verification checks.
70 71 72 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 70 def @options end |
#provided_details ⇒ Object
Details provided about the user being verified. These details may be shown to the user.
72 73 74 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 72 def provided_details @provided_details end |
#related_customer ⇒ Object
Customer ID
74 75 76 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 74 def @related_customer end |
#related_customer_account ⇒ Object
The ID of the Account representing a customer.
76 77 78 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 76 def @related_customer_account end |
#related_person ⇒ Object
Tokens referencing a Person resource and it’s associated account.
78 79 80 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 78 def @related_person end |
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the verification flow.
80 81 82 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 80 def return_url @return_url end |
#type ⇒ Object
The type of [verification check](docs.stripe.com/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.
82 83 84 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 82 def type @type end |
#verification_flow ⇒ Object
The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.
84 85 86 |
# File 'lib/stripe/params/identity/verification_session_create_params.rb', line 84 def verification_flow @verification_flow end |