Class: Stripe::Identity::VerificationSessionService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Identity::VerificationSessionService::CreateParams
- Defined in:
- lib/stripe/services/identity/verification_session_service.rb
Defined Under Namespace
Classes: Options, ProvidedDetails
Instance Attribute Summary collapse
-
#client_reference_id ⇒ Object
A string to reference this user.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#options ⇒ Object
A set of options for the session’s verification checks.
-
#provided_details ⇒ Object
Details provided about the user being verified.
-
#related_customer ⇒ Object
Customer ID.
-
#related_customer_account ⇒ Object
Token referencing a Customer Account resource.
-
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the verification flow.
-
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed.
-
#verification_flow ⇒ Object
The ID of a verification flow from the Dashboard.
Instance Method Summary collapse
-
#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 131 def initialize( client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, related_customer_account: nil, return_url: nil, type: nil, verification_flow: nil ) @client_reference_id = client_reference_id @expand = @metadata = @options = @provided_details = provided_details @related_customer = @related_customer_account = @return_url = return_url @type = type @verification_flow = verification_flow end |
Instance Attribute Details
#client_reference_id ⇒ Object
A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
111 112 113 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 111 def client_reference_id @client_reference_id end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
113 114 115 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 113 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
115 116 117 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 115 def @metadata end |
#options ⇒ Object
A set of options for the session’s verification checks.
117 118 119 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 117 def @options end |
#provided_details ⇒ Object
Details provided about the user being verified. These details may be shown to the user.
119 120 121 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 119 def provided_details @provided_details end |
#related_customer ⇒ Object
Customer ID
121 122 123 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 121 def @related_customer end |
#related_customer_account ⇒ Object
Token referencing a Customer Account resource.
123 124 125 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 123 def @related_customer_account end |
#return_url ⇒ Object
The URL that the user will be redirected to upon completing the verification flow.
125 126 127 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 125 def return_url @return_url end |
#type ⇒ Object
The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.
127 128 129 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 127 def type @type end |
#verification_flow ⇒ Object
The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.
129 130 131 |
# File 'lib/stripe/services/identity/verification_session_service.rb', line 129 def verification_flow @verification_flow end |