Class: Stripe::Identity::VerificationSessionService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/identity/verification_session_service.rb

Defined Under Namespace

Classes: Options, ProvidedDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(client_reference_id: nil, expand: nil, metadata: nil, options: nil, provided_details: nil, related_customer: nil, return_url: nil, type: nil, verification_flow: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/stripe/services/identity/verification_session_service.rb', line 147

def initialize(
  client_reference_id: nil,
  expand: nil,
  metadata: nil,
  options: nil,
  provided_details: nil,
  related_customer: nil,
  return_url: nil,
  type: nil,
  verification_flow: nil
)
  @client_reference_id = client_reference_id
  @expand = expand
  @metadata = 
  @options = options
  @provided_details = provided_details
  @related_customer = related_customer
  @return_url = return_url
  @type = type
  @verification_flow = verification_flow
end

Instance Attribute Details

#client_reference_idObject

A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.



121
122
123
# File 'lib/stripe/services/identity/verification_session_service.rb', line 121

def client_reference_id
  @client_reference_id
end

#expandObject

Specifies which fields in the response should be expanded.



124
125
126
# File 'lib/stripe/services/identity/verification_session_service.rb', line 124

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



127
128
129
# File 'lib/stripe/services/identity/verification_session_service.rb', line 127

def 
  @metadata
end

#optionsObject

A set of options for the session’s verification checks.



130
131
132
# File 'lib/stripe/services/identity/verification_session_service.rb', line 130

def options
  @options
end

#provided_detailsObject

Details provided about the user being verified. These details may be shown to the user.



133
134
135
# File 'lib/stripe/services/identity/verification_session_service.rb', line 133

def provided_details
  @provided_details
end

Token referencing a Customer resource.



136
137
138
# File 'lib/stripe/services/identity/verification_session_service.rb', line 136

def related_customer
  @related_customer
end

#return_urlObject

The URL that the user will be redirected to upon completing the verification flow.



139
140
141
# File 'lib/stripe/services/identity/verification_session_service.rb', line 139

def return_url
  @return_url
end

#typeObject

The type of [verification check](stripe.com/docs/identity/verification-checks) to be performed. You must provide a ‘type` if not passing `verification_flow`.



142
143
144
# File 'lib/stripe/services/identity/verification_session_service.rb', line 142

def type
  @type
end

#verification_flowObject

The ID of a verification flow from the Dashboard. See docs.stripe.com/identity/verification-flows.



145
146
147
# File 'lib/stripe/services/identity/verification_session_service.rb', line 145

def verification_flow
  @verification_flow
end