Class: Stripe::Invoice
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Invoice
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/invoice.rb
Overview
Invoices are statements of amounts owed by a customer, and are either generated one-off, or generated periodically from a subscription.
They contain [invoice items](stripe.com/docs/api#invoiceitems), and proration adjustments that may be caused by subscription upgrades/downgrades (if necessary).
If your invoice is configured to be billed through automatic charges, Stripe automatically finalizes your invoice and attempts payment. Note that finalizing the invoice, [when automatic](stripe.com/docs/invoicing/integration/automatic-advancement-collection), does not happen immediately as the invoice is created. Stripe waits until one hour after the last webhook was successfully sent (or the last webhook timed out after failing). If you (and the platforms you may have connected to) have no webhooks configured, Stripe waits one hour after creation to finalize the invoice.
If your invoice is configured to be billed by sending an email, then based on your [email settings](dashboard.stripe.com/account/billing/automatic), Stripe will email the invoice to your customer and await payment. These emails can contain a link to a hosted page to pay the invoice.
Stripe applies any customer credit on the account before determining the amount due for the invoice (i.e., the amount that will be actually charged). If the amount due for the invoice is less than Stripe’s [minimum allowed charge per currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts), the invoice is automatically marked paid, and we add the amount due to the customer’s credit balance which is applied to the next invoice.
More details on the customer’s credit balance are [here](stripe.com/docs/billing/customer/balance).
Related guide: [Send invoices to customers](stripe.com/docs/billing/invoices/sending)
Defined Under Namespace
Classes: AddLinesParams, AmountsDue, AttachPaymentIntentParams, AttachPaymentParams, AutomaticTax, ConfirmationSecret, CreateParams, CreatePreviewParams, CustomField, CustomerAddress, CustomerShipping, CustomerTaxId, DeleteParams, FinalizeInvoiceParams, FromInvoice, Issuer, LastFinalizationError, ListParams, MarkUncollectibleParams, Parent, PayParams, PaymentSettings, RemoveLinesParams, Rendering, SearchParams, SendInvoiceParams, ShippingCost, ShippingDetails, StatusTransitions, ThresholdReason, TotalDiscountAmount, TotalMarginAmount, TotalPretaxCreditAmount, TotalTax, UpdateLinesParams, UpdateParams, VoidInvoiceParams
Constant Summary collapse
- OBJECT_NAME =
"invoice"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_country ⇒ Object
readonly
The country of the business associated with this invoice, most often the business creating the invoice.
-
#account_name ⇒ Object
readonly
The public name of the business associated with this invoice, most often the business creating the invoice.
-
#account_tax_ids ⇒ Object
readonly
The account tax IDs associated with the invoice.
-
#amount_due ⇒ Object
readonly
Final amount due at this time for this invoice.
-
#amount_overpaid ⇒ Object
readonly
Amount that was overpaid on the invoice.
-
#amount_paid ⇒ Object
readonly
The amount, in cents (or local equivalent), that was paid.
-
#amount_remaining ⇒ Object
readonly
The difference between amount_due and amount_paid, in cents (or local equivalent).
-
#amount_shipping ⇒ Object
readonly
This is the sum of all the shipping amounts.
-
#amounts_due ⇒ Object
readonly
List of expected payments and corresponding due dates.
-
#application ⇒ Object
readonly
ID of the Connect Application that created the invoice.
-
#attempt_count ⇒ Object
readonly
Number of payment attempts made for this invoice, from the perspective of the payment retry schedule.
-
#attempted ⇒ Object
readonly
Whether an attempt has been made to pay the invoice.
-
#auto_advance ⇒ Object
readonly
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice.
-
#automatic_tax ⇒ Object
readonly
Attribute for field automatic_tax.
-
#automatically_finalizes_at ⇒ Object
readonly
The time when this invoice is currently scheduled to be automatically finalized.
-
#billing_reason ⇒ Object
readonly
Indicates the reason why the invoice was created.
-
#collection_method ⇒ Object
readonly
Either ‘charge_automatically`, or `send_invoice`.
-
#confirmation_secret ⇒ Object
readonly
The confirmation secret associated with this invoice.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#custom_fields ⇒ Object
readonly
Custom fields displayed on the invoice.
-
#customer ⇒ Object
readonly
The ID of the customer who will be billed.
-
#customer_account ⇒ Object
readonly
The ID of the account who will be billed.
-
#customer_address ⇒ Object
readonly
The customer’s address.
-
#customer_email ⇒ Object
readonly
The customer’s email.
-
#customer_name ⇒ Object
readonly
The customer’s name.
-
#customer_phone ⇒ Object
readonly
The customer’s phone number.
-
#customer_shipping ⇒ Object
readonly
The customer’s shipping information.
-
#customer_tax_exempt ⇒ Object
readonly
The customer’s tax exempt status.
-
#customer_tax_ids ⇒ Object
readonly
The customer’s tax IDs.
-
#default_margins ⇒ Object
readonly
The margins applied to the invoice.
-
#default_payment_method ⇒ Object
readonly
ID of the default payment method for the invoice.
-
#default_source ⇒ Object
readonly
ID of the default payment source for the invoice.
-
#default_tax_rates ⇒ Object
readonly
The tax rates applied to this invoice, if any.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#discounts ⇒ Object
readonly
The discounts applied to the invoice.
-
#due_date ⇒ Object
readonly
The date on which payment for this invoice is due.
-
#effective_at ⇒ Object
readonly
The date when this invoice is in effect.
-
#ending_balance ⇒ Object
readonly
Ending customer balance after the invoice is finalized.
-
#footer ⇒ Object
readonly
Footer displayed on the invoice.
-
#from_invoice ⇒ Object
readonly
Details of the invoice that was cloned.
-
#hosted_invoice_url ⇒ Object
readonly
The URL for the hosted invoice page, which allows customers to view and pay an invoice.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice_pdf ⇒ Object
readonly
The link to download the PDF for the invoice.
-
#issuer ⇒ Object
readonly
Attribute for field issuer.
-
#last_finalization_error ⇒ Object
readonly
The error encountered during the previous attempt to finalize the invoice.
-
#latest_revision ⇒ Object
readonly
The ID of the most recent non-draft revision of this invoice.
-
#lines ⇒ Object
readonly
The individual line items that make up the invoice.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#next_payment_attempt ⇒ Object
readonly
The time at which payment will next be attempted.
-
#number ⇒ Object
readonly
A unique, identifying string that appears on emails sent to the customer for this invoice.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) for which the funds of the invoice payment are intended.
-
#parent ⇒ Object
readonly
The parent that generated this invoice.
-
#payment_settings ⇒ Object
readonly
Attribute for field payment_settings.
-
#payments ⇒ Object
readonly
Payments for this invoice.
-
#period_end ⇒ Object
readonly
End of the usage period during which invoice items were added to this invoice.
-
#period_start ⇒ Object
readonly
Start of the usage period during which invoice items were added to this invoice.
-
#post_payment_credit_notes_amount ⇒ Object
readonly
Total amount of all post-payment credit notes issued for this invoice.
-
#pre_payment_credit_notes_amount ⇒ Object
readonly
Total amount of all pre-payment credit notes issued for this invoice.
-
#receipt_number ⇒ Object
readonly
This is the transaction number that appears on email receipts sent for this invoice.
-
#rendering ⇒ Object
readonly
The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.
-
#shipping_cost ⇒ Object
readonly
The details of the cost of shipping, including the ShippingRate applied on the invoice.
-
#shipping_details ⇒ Object
readonly
Shipping details for the invoice.
-
#starting_balance ⇒ Object
readonly
Starting customer balance before the invoice is finalized.
-
#statement_descriptor ⇒ Object
readonly
Extra information about an invoice for the customer’s credit card statement.
-
#status ⇒ Object
readonly
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`.
-
#status_transitions ⇒ Object
readonly
Attribute for field status_transitions.
-
#subtotal ⇒ Object
readonly
Total of all subscriptions, invoice items, and prorations on the invoice before any invoice level discount or exclusive tax is applied.
-
#subtotal_excluding_tax ⇒ Object
readonly
The integer amount in cents (or local equivalent) representing the subtotal of the invoice before any invoice level discount or tax is applied.
-
#test_clock ⇒ Object
readonly
ID of the test clock this invoice belongs to.
-
#threshold_reason ⇒ Object
readonly
Attribute for field threshold_reason.
-
#total ⇒ Object
readonly
Total after discounts and taxes.
-
#total_discount_amounts ⇒ Object
readonly
The aggregate amounts calculated per discount across all line items.
-
#total_excluding_tax ⇒ Object
readonly
The integer amount in cents (or local equivalent) representing the total amount of the invoice including all discounts but excluding all tax.
-
#total_margin_amounts ⇒ Object
readonly
The aggregate amounts calculated per margin across all line items.
-
#total_pretax_credit_amounts ⇒ Object
readonly
Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this invoice.
-
#total_taxes ⇒ Object
readonly
The aggregate tax information of all line items.
-
#webhooks_delivered_at ⇒ Object
readonly
Invoices are automatically paid or sent 1 hour after webhooks are delivered, or until all webhook delivery attempts have [been exhausted](stripe.com/docs/billing/webhooks#understand).
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.add_lines(invoice, params = {}, opts = {}) ⇒ Object
Adds multiple line items to an invoice.
-
.attach_payment(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.
-
.attach_payment_intent(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent to the invoice, adding it to the list of payments.
-
.create(params = {}, opts = {}) ⇒ Object
This endpoint creates a draft invoice for a given customer.
-
.create_preview(params = {}, opts = {}) ⇒ Object
At any time, you can preview the upcoming invoice for a subscription or subscription schedule.
-
.delete(invoice, params = {}, opts = {}) ⇒ Object
Permanently deletes a one-off invoice draft.
-
.finalize_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically finalizes drafts before sending and attempting payment on invoices.
-
.list(params = {}, opts = {}) ⇒ Object
You can list all invoices, or list the invoices for a specific customer.
-
.mark_uncollectible(invoice, params = {}, opts = {}) ⇒ Object
Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.
- .object_name ⇒ Object
-
.pay(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic).
-
.remove_lines(invoice, params = {}, opts = {}) ⇒ Object
Removes multiple line items from an invoice.
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.send_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic).
-
.update(invoice, params = {}, opts = {}) ⇒ Object
Draft invoices are fully editable.
-
.update_lines(invoice, params = {}, opts = {}) ⇒ Object
Updates multiple line items on an invoice.
-
.void_invoice(invoice, params = {}, opts = {}) ⇒ Object
Mark a finalized invoice as void.
Instance Method Summary collapse
-
#add_lines(params = {}, opts = {}) ⇒ Object
Adds multiple line items to an invoice.
-
#attach_payment(params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.
-
#attach_payment_intent(params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent to the invoice, adding it to the list of payments.
-
#delete(params = {}, opts = {}) ⇒ Object
Permanently deletes a one-off invoice draft.
-
#finalize_invoice(params = {}, opts = {}) ⇒ Object
Stripe automatically finalizes drafts before sending and attempting payment on invoices.
-
#mark_uncollectible(params = {}, opts = {}) ⇒ Object
Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.
-
#pay(params = {}, opts = {}) ⇒ Object
Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic).
-
#remove_lines(params = {}, opts = {}) ⇒ Object
Removes multiple line items from an invoice.
-
#send_invoice(params = {}, opts = {}) ⇒ Object
Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic).
-
#update_lines(params = {}, opts = {}) ⇒ Object
Updates multiple line items on an invoice.
-
#void_invoice(params = {}, opts = {}) ⇒ Object
Mark a finalized invoice as void.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_country ⇒ Object (readonly)
The country of the business associated with this invoice, most often the business creating the invoice.
4166 4167 4168 |
# File 'lib/stripe/resources/invoice.rb', line 4166 def account_country @account_country end |
#account_name ⇒ Object (readonly)
The public name of the business associated with this invoice, most often the business creating the invoice.
4168 4169 4170 |
# File 'lib/stripe/resources/invoice.rb', line 4168 def account_name @account_name end |
#account_tax_ids ⇒ Object (readonly)
The account tax IDs associated with the invoice. Only editable when the invoice is a draft.
4170 4171 4172 |
# File 'lib/stripe/resources/invoice.rb', line 4170 def account_tax_ids @account_tax_ids end |
#amount_due ⇒ Object (readonly)
Final amount due at this time for this invoice. If the invoice’s total is smaller than the minimum charge amount, for example, or if there is account credit that can be applied to the invoice, the ‘amount_due` may be 0. If there is a positive `starting_balance` for the invoice (the customer owes money), the `amount_due` will also take that into account. The charge that gets generated for the invoice will be for the amount specified in `amount_due`.
4172 4173 4174 |
# File 'lib/stripe/resources/invoice.rb', line 4172 def amount_due @amount_due end |
#amount_overpaid ⇒ Object (readonly)
Amount that was overpaid on the invoice. The amount overpaid is credited to the customer’s credit balance.
4174 4175 4176 |
# File 'lib/stripe/resources/invoice.rb', line 4174 def amount_overpaid @amount_overpaid end |
#amount_paid ⇒ Object (readonly)
The amount, in cents (or local equivalent), that was paid.
4176 4177 4178 |
# File 'lib/stripe/resources/invoice.rb', line 4176 def amount_paid @amount_paid end |
#amount_remaining ⇒ Object (readonly)
The difference between amount_due and amount_paid, in cents (or local equivalent).
4178 4179 4180 |
# File 'lib/stripe/resources/invoice.rb', line 4178 def amount_remaining @amount_remaining end |
#amount_shipping ⇒ Object (readonly)
This is the sum of all the shipping amounts.
4180 4181 4182 |
# File 'lib/stripe/resources/invoice.rb', line 4180 def amount_shipping @amount_shipping end |
#amounts_due ⇒ Object (readonly)
List of expected payments and corresponding due dates. This value will be null for invoices where collection_method=charge_automatically.
4182 4183 4184 |
# File 'lib/stripe/resources/invoice.rb', line 4182 def amounts_due @amounts_due end |
#application ⇒ Object (readonly)
ID of the Connect Application that created the invoice.
4184 4185 4186 |
# File 'lib/stripe/resources/invoice.rb', line 4184 def application @application end |
#attempt_count ⇒ Object (readonly)
Number of payment attempts made for this invoice, from the perspective of the payment retry schedule. Any payment attempt counts as the first attempt, and subsequently only automatic retries increment the attempt count. In other words, manual payment attempts after the first attempt do not affect the retry schedule. If a failure is returned with a non-retryable return code, the invoice can no longer be retried unless a new payment method is obtained. Retries will continue to be scheduled, and attempt_count will continue to increment, but retries will only be executed if a new payment method is obtained.
4186 4187 4188 |
# File 'lib/stripe/resources/invoice.rb', line 4186 def attempt_count @attempt_count end |
#attempted ⇒ Object (readonly)
Whether an attempt has been made to pay the invoice. An invoice is not attempted until 1 hour after the ‘invoice.created` webhook, for example, so you might not want to display that invoice as unpaid to your users.
4188 4189 4190 |
# File 'lib/stripe/resources/invoice.rb', line 4188 def attempted @attempted end |
#auto_advance ⇒ Object (readonly)
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action.
4190 4191 4192 |
# File 'lib/stripe/resources/invoice.rb', line 4190 def auto_advance @auto_advance end |
#automatic_tax ⇒ Object (readonly)
Attribute for field automatic_tax
4192 4193 4194 |
# File 'lib/stripe/resources/invoice.rb', line 4192 def automatic_tax @automatic_tax end |
#automatically_finalizes_at ⇒ Object (readonly)
The time when this invoice is currently scheduled to be automatically finalized. The field will be ‘null` if the invoice is not scheduled to finalize in the future. If the invoice is not in the draft state, this field will always be `null` - see `finalized_at` for the time when an already-finalized invoice was finalized.
4194 4195 4196 |
# File 'lib/stripe/resources/invoice.rb', line 4194 def automatically_finalizes_at @automatically_finalizes_at end |
#billing_reason ⇒ Object (readonly)
Indicates the reason why the invoice was created.
-
‘manual`: Unrelated to a subscription, for example, created via the invoice editor.
-
‘subscription`: No longer in use. Applies to subscriptions from before May 2018 where no distinction was made between updates, cycles, and thresholds.
-
‘subscription_create`: A new subscription was created.
-
‘subscription_cycle`: A subscription advanced into a new period.
-
‘subscription_threshold`: A subscription reached a billing threshold.
-
‘subscription_update`: A subscription was updated.
-
‘upcoming`: Reserved for simulated invoices, per the upcoming invoice endpoint.
4204 4205 4206 |
# File 'lib/stripe/resources/invoice.rb', line 4204 def billing_reason @billing_reason end |
#collection_method ⇒ Object (readonly)
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions.
4206 4207 4208 |
# File 'lib/stripe/resources/invoice.rb', line 4206 def collection_method @collection_method end |
#confirmation_secret ⇒ Object (readonly)
The confirmation secret associated with this invoice. Currently, this contains the client_secret of the PaymentIntent that Stripe creates during invoice finalization.
4208 4209 4210 |
# File 'lib/stripe/resources/invoice.rb', line 4208 def confirmation_secret @confirmation_secret end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
4210 4211 4212 |
# File 'lib/stripe/resources/invoice.rb', line 4210 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
4212 4213 4214 |
# File 'lib/stripe/resources/invoice.rb', line 4212 def currency @currency end |
#custom_fields ⇒ Object (readonly)
Custom fields displayed on the invoice.
4214 4215 4216 |
# File 'lib/stripe/resources/invoice.rb', line 4214 def custom_fields @custom_fields end |
#customer ⇒ Object (readonly)
The ID of the customer who will be billed.
4216 4217 4218 |
# File 'lib/stripe/resources/invoice.rb', line 4216 def customer @customer end |
#customer_account ⇒ Object (readonly)
The ID of the account who will be billed.
4218 4219 4220 |
# File 'lib/stripe/resources/invoice.rb', line 4218 def customer_account @customer_account end |
#customer_address ⇒ Object (readonly)
The customer’s address. Until the invoice is finalized, this field will equal ‘customer.address`. Once the invoice is finalized, this field will no longer be updated.
4220 4221 4222 |
# File 'lib/stripe/resources/invoice.rb', line 4220 def customer_address @customer_address end |
#customer_email ⇒ Object (readonly)
The customer’s email. Until the invoice is finalized, this field will equal ‘customer.email`. Once the invoice is finalized, this field will no longer be updated.
4222 4223 4224 |
# File 'lib/stripe/resources/invoice.rb', line 4222 def customer_email @customer_email end |
#customer_name ⇒ Object (readonly)
The customer’s name. Until the invoice is finalized, this field will equal ‘customer.name`. Once the invoice is finalized, this field will no longer be updated.
4224 4225 4226 |
# File 'lib/stripe/resources/invoice.rb', line 4224 def customer_name @customer_name end |
#customer_phone ⇒ Object (readonly)
The customer’s phone number. Until the invoice is finalized, this field will equal ‘customer.phone`. Once the invoice is finalized, this field will no longer be updated.
4226 4227 4228 |
# File 'lib/stripe/resources/invoice.rb', line 4226 def customer_phone @customer_phone end |
#customer_shipping ⇒ Object (readonly)
The customer’s shipping information. Until the invoice is finalized, this field will equal ‘customer.shipping`. Once the invoice is finalized, this field will no longer be updated.
4228 4229 4230 |
# File 'lib/stripe/resources/invoice.rb', line 4228 def customer_shipping @customer_shipping end |
#customer_tax_exempt ⇒ Object (readonly)
The customer’s tax exempt status. Until the invoice is finalized, this field will equal ‘customer.tax_exempt`. Once the invoice is finalized, this field will no longer be updated.
4230 4231 4232 |
# File 'lib/stripe/resources/invoice.rb', line 4230 def customer_tax_exempt @customer_tax_exempt end |
#customer_tax_ids ⇒ Object (readonly)
The customer’s tax IDs. Until the invoice is finalized, this field will contain the same tax IDs as ‘customer.tax_ids`. Once the invoice is finalized, this field will no longer be updated.
4232 4233 4234 |
# File 'lib/stripe/resources/invoice.rb', line 4232 def customer_tax_ids @customer_tax_ids end |
#default_margins ⇒ Object (readonly)
The margins applied to the invoice. Can be overridden by line item ‘margins`. Use `expand[]=default_margins` to expand each margin.
4234 4235 4236 |
# File 'lib/stripe/resources/invoice.rb', line 4234 def default_margins @default_margins end |
#default_payment_method ⇒ Object (readonly)
ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.
4236 4237 4238 |
# File 'lib/stripe/resources/invoice.rb', line 4236 def default_payment_method @default_payment_method end |
#default_source ⇒ Object (readonly)
ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.
4238 4239 4240 |
# File 'lib/stripe/resources/invoice.rb', line 4238 def default_source @default_source end |
#default_tax_rates ⇒ Object (readonly)
The tax rates applied to this invoice, if any.
4240 4241 4242 |
# File 'lib/stripe/resources/invoice.rb', line 4240 def default_tax_rates @default_tax_rates end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
4334 4335 4336 |
# File 'lib/stripe/resources/invoice.rb', line 4334 def deleted @deleted end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.
4242 4243 4244 |
# File 'lib/stripe/resources/invoice.rb', line 4242 def description @description end |
#discounts ⇒ Object (readonly)
The discounts applied to the invoice. Line item discounts are applied before invoice discounts. Use ‘expand[]=discounts` to expand each discount.
4244 4245 4246 |
# File 'lib/stripe/resources/invoice.rb', line 4244 def discounts @discounts end |
#due_date ⇒ Object (readonly)
The date on which payment for this invoice is due. This value will be ‘null` for invoices where `collection_method=charge_automatically`.
4246 4247 4248 |
# File 'lib/stripe/resources/invoice.rb', line 4246 def due_date @due_date end |
#effective_at ⇒ Object (readonly)
The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.
4248 4249 4250 |
# File 'lib/stripe/resources/invoice.rb', line 4248 def effective_at @effective_at end |
#ending_balance ⇒ Object (readonly)
Ending customer balance after the invoice is finalized. Invoices are finalized approximately an hour after successful webhook delivery or when payment collection is attempted for the invoice. If the invoice has not been finalized yet, this will be null.
4250 4251 4252 |
# File 'lib/stripe/resources/invoice.rb', line 4250 def ending_balance @ending_balance end |
#footer ⇒ Object (readonly)
Footer displayed on the invoice.
4252 4253 4254 |
# File 'lib/stripe/resources/invoice.rb', line 4252 def @footer end |
#from_invoice ⇒ Object (readonly)
Details of the invoice that was cloned. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.
4254 4255 4256 |
# File 'lib/stripe/resources/invoice.rb', line 4254 def from_invoice @from_invoice end |
#hosted_invoice_url ⇒ Object (readonly)
The URL for the hosted invoice page, which allows customers to view and pay an invoice. If the invoice has not been finalized yet, this will be null.
4256 4257 4258 |
# File 'lib/stripe/resources/invoice.rb', line 4256 def hosted_invoice_url @hosted_invoice_url end |
#id ⇒ Object (readonly)
Unique identifier for the object. This property is always present unless the invoice is an upcoming invoice. See [Retrieve an upcoming invoice](stripe.com/docs/api/invoices/upcoming) for more details.
4258 4259 4260 |
# File 'lib/stripe/resources/invoice.rb', line 4258 def id @id end |
#invoice_pdf ⇒ Object (readonly)
The link to download the PDF for the invoice. If the invoice has not been finalized yet, this will be null.
4260 4261 4262 |
# File 'lib/stripe/resources/invoice.rb', line 4260 def invoice_pdf @invoice_pdf end |
#issuer ⇒ Object (readonly)
Attribute for field issuer
4262 4263 4264 |
# File 'lib/stripe/resources/invoice.rb', line 4262 def issuer @issuer end |
#last_finalization_error ⇒ Object (readonly)
The error encountered during the previous attempt to finalize the invoice. This field is cleared when the invoice is successfully finalized.
4264 4265 4266 |
# File 'lib/stripe/resources/invoice.rb', line 4264 def last_finalization_error @last_finalization_error end |
#latest_revision ⇒ Object (readonly)
The ID of the most recent non-draft revision of this invoice
4266 4267 4268 |
# File 'lib/stripe/resources/invoice.rb', line 4266 def latest_revision @latest_revision end |
#lines ⇒ Object (readonly)
The individual line items that make up the invoice. ‘lines` is sorted as follows: (1) pending invoice items (including prorations) in reverse chronological order, (2) subscription items in reverse chronological order, and (3) invoice items added after invoice creation in chronological order.
4268 4269 4270 |
# File 'lib/stripe/resources/invoice.rb', line 4268 def lines @lines end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
4270 4271 4272 |
# File 'lib/stripe/resources/invoice.rb', line 4270 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
4272 4273 4274 |
# File 'lib/stripe/resources/invoice.rb', line 4272 def @metadata end |
#next_payment_attempt ⇒ Object (readonly)
The time at which payment will next be attempted. This value will be ‘null` for invoices where `collection_method=send_invoice`.
4274 4275 4276 |
# File 'lib/stripe/resources/invoice.rb', line 4274 def next_payment_attempt @next_payment_attempt end |
#number ⇒ Object (readonly)
A unique, identifying string that appears on emails sent to the customer for this invoice. This starts with the customer’s unique invoice_prefix if it is specified.
4276 4277 4278 |
# File 'lib/stripe/resources/invoice.rb', line 4276 def number @number end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
4278 4279 4280 |
# File 'lib/stripe/resources/invoice.rb', line 4278 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.
4280 4281 4282 |
# File 'lib/stripe/resources/invoice.rb', line 4280 def on_behalf_of @on_behalf_of end |
#parent ⇒ Object (readonly)
The parent that generated this invoice
4282 4283 4284 |
# File 'lib/stripe/resources/invoice.rb', line 4282 def parent @parent end |
#payment_settings ⇒ Object (readonly)
Attribute for field payment_settings
4284 4285 4286 |
# File 'lib/stripe/resources/invoice.rb', line 4284 def payment_settings @payment_settings end |
#payments ⇒ Object (readonly)
Payments for this invoice
4286 4287 4288 |
# File 'lib/stripe/resources/invoice.rb', line 4286 def payments @payments end |
#period_end ⇒ Object (readonly)
End of the usage period during which invoice items were added to this invoice. This looks back one period for a subscription invoice. Use the [line item period](/api/invoices/line_item#invoice_line_item_object-period) to get the service period for each price.
4288 4289 4290 |
# File 'lib/stripe/resources/invoice.rb', line 4288 def period_end @period_end end |
#period_start ⇒ Object (readonly)
Start of the usage period during which invoice items were added to this invoice. This looks back one period for a subscription invoice. Use the [line item period](/api/invoices/line_item#invoice_line_item_object-period) to get the service period for each price.
4290 4291 4292 |
# File 'lib/stripe/resources/invoice.rb', line 4290 def period_start @period_start end |
#post_payment_credit_notes_amount ⇒ Object (readonly)
Total amount of all post-payment credit notes issued for this invoice.
4292 4293 4294 |
# File 'lib/stripe/resources/invoice.rb', line 4292 def post_payment_credit_notes_amount @post_payment_credit_notes_amount end |
#pre_payment_credit_notes_amount ⇒ Object (readonly)
Total amount of all pre-payment credit notes issued for this invoice.
4294 4295 4296 |
# File 'lib/stripe/resources/invoice.rb', line 4294 def pre_payment_credit_notes_amount @pre_payment_credit_notes_amount end |
#receipt_number ⇒ Object (readonly)
This is the transaction number that appears on email receipts sent for this invoice.
4296 4297 4298 |
# File 'lib/stripe/resources/invoice.rb', line 4296 def receipt_number @receipt_number end |
#rendering ⇒ Object (readonly)
The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.
4298 4299 4300 |
# File 'lib/stripe/resources/invoice.rb', line 4298 def rendering @rendering end |
#shipping_cost ⇒ Object (readonly)
The details of the cost of shipping, including the ShippingRate applied on the invoice.
4300 4301 4302 |
# File 'lib/stripe/resources/invoice.rb', line 4300 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object (readonly)
Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.
4302 4303 4304 |
# File 'lib/stripe/resources/invoice.rb', line 4302 def shipping_details @shipping_details end |
#starting_balance ⇒ Object (readonly)
Starting customer balance before the invoice is finalized. If the invoice has not been finalized yet, this will be the current customer balance. For revision invoices, this also includes any customer balance that was applied to the original invoice.
4304 4305 4306 |
# File 'lib/stripe/resources/invoice.rb', line 4304 def starting_balance @starting_balance end |
#statement_descriptor ⇒ Object (readonly)
Extra information about an invoice for the customer’s credit card statement.
4306 4307 4308 |
# File 'lib/stripe/resources/invoice.rb', line 4306 def statement_descriptor @statement_descriptor end |
#status ⇒ Object (readonly)
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)
4308 4309 4310 |
# File 'lib/stripe/resources/invoice.rb', line 4308 def status @status end |
#status_transitions ⇒ Object (readonly)
Attribute for field status_transitions
4310 4311 4312 |
# File 'lib/stripe/resources/invoice.rb', line 4310 def status_transitions @status_transitions end |
#subtotal ⇒ Object (readonly)
Total of all subscriptions, invoice items, and prorations on the invoice before any invoice level discount or exclusive tax is applied. Item discounts are already incorporated
4312 4313 4314 |
# File 'lib/stripe/resources/invoice.rb', line 4312 def subtotal @subtotal end |
#subtotal_excluding_tax ⇒ Object (readonly)
The integer amount in cents (or local equivalent) representing the subtotal of the invoice before any invoice level discount or tax is applied. Item discounts are already incorporated
4314 4315 4316 |
# File 'lib/stripe/resources/invoice.rb', line 4314 def subtotal_excluding_tax @subtotal_excluding_tax end |
#test_clock ⇒ Object (readonly)
ID of the test clock this invoice belongs to.
4316 4317 4318 |
# File 'lib/stripe/resources/invoice.rb', line 4316 def test_clock @test_clock end |
#threshold_reason ⇒ Object (readonly)
Attribute for field threshold_reason
4318 4319 4320 |
# File 'lib/stripe/resources/invoice.rb', line 4318 def threshold_reason @threshold_reason end |
#total ⇒ Object (readonly)
Total after discounts and taxes.
4320 4321 4322 |
# File 'lib/stripe/resources/invoice.rb', line 4320 def total @total end |
#total_discount_amounts ⇒ Object (readonly)
The aggregate amounts calculated per discount across all line items.
4322 4323 4324 |
# File 'lib/stripe/resources/invoice.rb', line 4322 def total_discount_amounts @total_discount_amounts end |
#total_excluding_tax ⇒ Object (readonly)
The integer amount in cents (or local equivalent) representing the total amount of the invoice including all discounts but excluding all tax.
4324 4325 4326 |
# File 'lib/stripe/resources/invoice.rb', line 4324 def total_excluding_tax @total_excluding_tax end |
#total_margin_amounts ⇒ Object (readonly)
The aggregate amounts calculated per margin across all line items.
4326 4327 4328 |
# File 'lib/stripe/resources/invoice.rb', line 4326 def total_margin_amounts @total_margin_amounts end |
#total_pretax_credit_amounts ⇒ Object (readonly)
Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this invoice. This is a combined list of total_pretax_credit_amounts across all invoice line items.
4328 4329 4330 |
# File 'lib/stripe/resources/invoice.rb', line 4328 def total_pretax_credit_amounts @total_pretax_credit_amounts end |
#total_taxes ⇒ Object (readonly)
The aggregate tax information of all line items.
4330 4331 4332 |
# File 'lib/stripe/resources/invoice.rb', line 4330 def total_taxes @total_taxes end |
#webhooks_delivered_at ⇒ Object (readonly)
Invoices are automatically paid or sent 1 hour after webhooks are delivered, or until all webhook delivery attempts have [been exhausted](stripe.com/docs/billing/webhooks#understand). This field tracks the time when webhooks for this invoice were successfully delivered. If the invoice had no webhooks to deliver, this will be set while the invoice is being created.
4332 4333 4334 |
# File 'lib/stripe/resources/invoice.rb', line 4332 def webhooks_delivered_at @webhooks_delivered_at end |
Class Method Details
.add_lines(invoice, params = {}, opts = {}) ⇒ Object
Adds multiple line items to an invoice. This is only possible when an invoice is still a draft.
4347 4348 4349 4350 4351 4352 4353 4354 |
# File 'lib/stripe/resources/invoice.rb', line 4347 def self.add_lines(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/add_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.attach_payment(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.
For Out of Band Payment, the payment is credited to the invoice immediately, increasing the amount_paid of the invoice and subsequently transitioning the status of the invoice to paid if necessary.
For the PaymentIntent, when the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.
If the PaymentIntent’s status is already succeeded when it’s attached, it’s credited to the invoice immediately.
See: [Create an invoice payment](stripe.com/docs/invoicing/payments/create) to learn more.
4391 4392 4393 4394 4395 4396 4397 4398 |
# File 'lib/stripe/resources/invoice.rb', line 4391 def self.attach_payment(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/attach_payment", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.attach_payment_intent(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent to the invoice, adding it to the list of payments. When the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.
If the PaymentIntent’s status is already succeeded when it is attached, it is credited to the invoice immediately.
Related guide: [Create an invoice payment](stripe.com/docs/invoicing/payments/create)
4427 4428 4429 4430 4431 4432 4433 4434 |
# File 'lib/stripe/resources/invoice.rb', line 4427 def self.attach_payment_intent(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/attach_payment_intent", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
This endpoint creates a draft invoice for a given customer. The invoice remains a draft until you [finalize the invoice, which allows you to [pay](#pay_invoice) or <a href=“#send_invoice”>send](stripe.com/docs/api#finalize_invoice) the invoice to your customers.
4437 4438 4439 |
# File 'lib/stripe/resources/invoice.rb', line 4437 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/invoices", params: params, opts: opts) end |
.create_preview(params = {}, opts = {}) ⇒ Object
At any time, you can preview the upcoming invoice for a subscription or subscription schedule. This will show you all the charges that are pending, including subscription renewal charges, invoice item charges, etc. It will also show you any discounts that are applicable to the invoice.
Note that when you are viewing an upcoming invoice, you are simply viewing a preview – the invoice has not yet been created. As such, the upcoming invoice will not show up in invoice listing calls, and you cannot use the API to pay or edit the invoice. If you want to change the amount that your customer will be billed, you can add, remove, or update pending invoice items, or update the customer’s discount.
You can preview the effects of updating a subscription, including a preview of what proration will take place. To ensure that the actual proration is calculated exactly the same as the previewed proration, you should pass the subscription_details.proration_date parameter when doing the actual subscription update. The recommended way to get only the prorations being previewed is to consider only proration line items where period is equal to the subscription_details.proration_date value passed in the request.
Note: Currency conversion calculations use the latest exchange rates. Exchange rates may vary between the time of the preview and the time of the actual invoice creation. [Learn more](docs.stripe.com/currencies/conversions)
4448 4449 4450 4451 4452 4453 4454 4455 |
# File 'lib/stripe/resources/invoice.rb', line 4448 def self.create_preview(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/invoices/create_preview", params: params, opts: opts ) end |
.delete(invoice, params = {}, opts = {}) ⇒ Object
Permanently deletes a one-off invoice draft. This cannot be undone. Attempts to delete invoices that are no longer in a draft state will fail; once an invoice has been finalized or if an invoice is for a subscription, it must be [voided](stripe.com/docs/api#void_invoice).
4458 4459 4460 4461 4462 4463 4464 4465 |
# File 'lib/stripe/resources/invoice.rb', line 4458 def self.delete(invoice, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.finalize_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically finalizes drafts before sending and attempting payment on invoices. However, if you’d like to finalize a draft invoice manually, you can do so using this method.
4488 4489 4490 4491 4492 4493 4494 4495 |
# File 'lib/stripe/resources/invoice.rb', line 4488 def self.finalize_invoice(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/finalize", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
You can list all invoices, or list the invoices for a specific customer. The invoices are returned sorted by creation date, with the most recently created invoices appearing first.
4498 4499 4500 |
# File 'lib/stripe/resources/invoice.rb', line 4498 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/invoices", params: params, opts: opts) end |
.mark_uncollectible(invoice, params = {}, opts = {}) ⇒ Object
Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.
4513 4514 4515 4516 4517 4518 4519 4520 |
# File 'lib/stripe/resources/invoice.rb', line 4513 def self.mark_uncollectible(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/mark_uncollectible", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.object_name ⇒ Object
46 47 48 |
# File 'lib/stripe/resources/invoice.rb', line 46 def self.object_name "invoice" end |
.pay(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to attempt payment on an invoice out of the normal collection schedule or for some other reason, you can do so.
4533 4534 4535 4536 4537 4538 4539 4540 |
# File 'lib/stripe/resources/invoice.rb', line 4533 def self.pay(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/pay", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.remove_lines(invoice, params = {}, opts = {}) ⇒ Object
Removes multiple line items from an invoice. This is only possible when an invoice is still a draft.
4553 4554 4555 4556 4557 4558 4559 4560 |
# File 'lib/stripe/resources/invoice.rb', line 4553 def self.remove_lines(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/remove_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.search(params = {}, opts = {}) ⇒ Object
4562 4563 4564 |
# File 'lib/stripe/resources/invoice.rb', line 4562 def self.search(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/invoices/search", params: params, opts: opts) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
4566 4567 4568 |
# File 'lib/stripe/resources/invoice.rb', line 4566 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.send_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to manually send an invoice to your customer out of the normal schedule, you can do so. When sending invoices that have already been paid, there will be no reference to the payment in the email.
Requests made in test-mode result in no emails being sent, despite sending an invoice.sent event.
4585 4586 4587 4588 4589 4590 4591 4592 |
# File 'lib/stripe/resources/invoice.rb', line 4585 def self.send_invoice(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/send", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.update(invoice, params = {}, opts = {}) ⇒ Object
Draft invoices are fully editable. Once an invoice is [finalized](stripe.com/docs/billing/invoices/workflow#finalized), monetary values, as well as collection_method, become uneditable.
If you would like to stop the Stripe Billing engine from automatically finalizing, reattempting payments on, sending reminders for, or [automatically reconciling](stripe.com/docs/billing/invoices/reconciliation) invoices, pass auto_advance=false.
4600 4601 4602 4603 4604 4605 4606 4607 |
# File 'lib/stripe/resources/invoice.rb', line 4600 def self.update(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.update_lines(invoice, params = {}, opts = {}) ⇒ Object
Updates multiple line items on an invoice. This is only possible when an invoice is still a draft.
4620 4621 4622 4623 4624 4625 4626 4627 |
# File 'lib/stripe/resources/invoice.rb', line 4620 def self.update_lines(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/update_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
.void_invoice(invoice, params = {}, opts = {}) ⇒ Object
Mark a finalized invoice as void. This cannot be undone. Voiding an invoice is similar to [deletion](stripe.com/docs/api#delete_invoice), however it only applies to finalized invoices and maintains a papertrail where the invoice can still be found.
Consult with local regulations to determine whether and how an invoice might be amended, canceled, or voided in the jurisdiction you’re doing business in. You might need to [issue another invoice or <a href=“#create_credit_note”>credit note](stripe.com/docs/api#create_invoice) instead. Stripe recommends that you consult with your legal counsel for advice specific to your business.
4644 4645 4646 4647 4648 4649 4650 4651 |
# File 'lib/stripe/resources/invoice.rb', line 4644 def self.void_invoice(invoice, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/void", { invoice: CGI.escape(invoice) }), params: params, opts: opts ) end |
Instance Method Details
#add_lines(params = {}, opts = {}) ⇒ Object
Adds multiple line items to an invoice. This is only possible when an invoice is still a draft.
4337 4338 4339 4340 4341 4342 4343 4344 |
# File 'lib/stripe/resources/invoice.rb', line 4337 def add_lines(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/add_lines", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#attach_payment(params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.
For Out of Band Payment, the payment is credited to the invoice immediately, increasing the amount_paid of the invoice and subsequently transitioning the status of the invoice to paid if necessary.
For the PaymentIntent, when the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.
If the PaymentIntent’s status is already succeeded when it’s attached, it’s credited to the invoice immediately.
See: [Create an invoice payment](stripe.com/docs/invoicing/payments/create) to learn more.
4369 4370 4371 4372 4373 4374 4375 4376 |
# File 'lib/stripe/resources/invoice.rb', line 4369 def attach_payment(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/attach_payment", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#attach_payment_intent(params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent to the invoice, adding it to the list of payments. When the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.
If the PaymentIntent’s status is already succeeded when it is attached, it is credited to the invoice immediately.
Related guide: [Create an invoice payment](stripe.com/docs/invoicing/payments/create)
4409 4410 4411 4412 4413 4414 4415 4416 |
# File 'lib/stripe/resources/invoice.rb', line 4409 def attach_payment_intent(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/attach_payment_intent", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#delete(params = {}, opts = {}) ⇒ Object
Permanently deletes a one-off invoice draft. This cannot be undone. Attempts to delete invoices that are no longer in a draft state will fail; once an invoice has been finalized or if an invoice is for a subscription, it must be [voided](stripe.com/docs/api#void_invoice).
4468 4469 4470 4471 4472 4473 4474 4475 |
# File 'lib/stripe/resources/invoice.rb', line 4468 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#finalize_invoice(params = {}, opts = {}) ⇒ Object
Stripe automatically finalizes drafts before sending and attempting payment on invoices. However, if you’d like to finalize a draft invoice manually, you can do so using this method.
4478 4479 4480 4481 4482 4483 4484 4485 |
# File 'lib/stripe/resources/invoice.rb', line 4478 def finalize_invoice(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/finalize", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#mark_uncollectible(params = {}, opts = {}) ⇒ Object
Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.
4503 4504 4505 4506 4507 4508 4509 4510 |
# File 'lib/stripe/resources/invoice.rb', line 4503 def mark_uncollectible(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/mark_uncollectible", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#pay(params = {}, opts = {}) ⇒ Object
Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to attempt payment on an invoice out of the normal collection schedule or for some other reason, you can do so.
4523 4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/stripe/resources/invoice.rb', line 4523 def pay(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/pay", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#remove_lines(params = {}, opts = {}) ⇒ Object
Removes multiple line items from an invoice. This is only possible when an invoice is still a draft.
4543 4544 4545 4546 4547 4548 4549 4550 |
# File 'lib/stripe/resources/invoice.rb', line 4543 def remove_lines(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/remove_lines", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#send_invoice(params = {}, opts = {}) ⇒ Object
Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to manually send an invoice to your customer out of the normal schedule, you can do so. When sending invoices that have already been paid, there will be no reference to the payment in the email.
Requests made in test-mode result in no emails being sent, despite sending an invoice.sent event.
4573 4574 4575 4576 4577 4578 4579 4580 |
# File 'lib/stripe/resources/invoice.rb', line 4573 def send_invoice(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/send", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#update_lines(params = {}, opts = {}) ⇒ Object
Updates multiple line items on an invoice. This is only possible when an invoice is still a draft.
4610 4611 4612 4613 4614 4615 4616 4617 |
# File 'lib/stripe/resources/invoice.rb', line 4610 def update_lines(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/update_lines", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#void_invoice(params = {}, opts = {}) ⇒ Object
Mark a finalized invoice as void. This cannot be undone. Voiding an invoice is similar to [deletion](stripe.com/docs/api#delete_invoice), however it only applies to finalized invoices and maintains a papertrail where the invoice can still be found.
Consult with local regulations to determine whether and how an invoice might be amended, canceled, or voided in the jurisdiction you’re doing business in. You might need to [issue another invoice or <a href=“#create_credit_note”>credit note](stripe.com/docs/api#create_invoice) instead. Stripe recommends that you consult with your legal counsel for advice specific to your business.
4632 4633 4634 4635 4636 4637 4638 4639 |
# File 'lib/stripe/resources/invoice.rb', line 4632 def void_invoice(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoices/%<invoice>s/void", { invoice: CGI.escape(self["id"]) }), params: params, opts: opts ) end |