Class: Stripe::Invoice

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/invoice.rb

Overview

Invoices are statements of amounts owed by a customer, and are either generated one-off, or generated periodically from a subscription.

They contain [invoice items](stripe.com/docs/api#invoiceitems), and proration adjustments that may be caused by subscription upgrades/downgrades (if necessary).

If your invoice is configured to be billed through automatic charges, Stripe automatically finalizes your invoice and attempts payment. Note that finalizing the invoice, [when automatic](stripe.com/docs/invoicing/integration/automatic-advancement-collection), does not happen immediately as the invoice is created. Stripe waits until one hour after the last webhook was successfully sent (or the last webhook timed out after failing). If you (and the platforms you may have connected to) have no webhooks configured, Stripe waits one hour after creation to finalize the invoice.

If your invoice is configured to be billed by sending an email, then based on your [email settings](dashboard.stripe.com/account/billing/automatic), Stripe will email the invoice to your customer and await payment. These emails can contain a link to a hosted page to pay the invoice.

Stripe applies any customer credit on the account before determining the amount due for the invoice (i.e., the amount that will be actually charged). If the amount due for the invoice is less than Stripe’s [minimum allowed charge per currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts), the invoice is automatically marked paid, and we add the amount due to the customer’s credit balance which is applied to the next invoice.

More details on the customer’s credit balance are [here](stripe.com/docs/billing/customer/balance).

Related guide: [Send invoices to customers](stripe.com/docs/billing/invoices/sending)

Defined Under Namespace

Classes: AddLinesParams, AmountsDue, AttachPaymentIntentParams, AttachPaymentParams, AutomaticTax, CreateParams, CreatePreviewParams, CustomField, CustomerAddress, CustomerShipping, CustomerTaxId, DeleteParams, FinalizeInvoiceParams, FromInvoice, Issuer, LastFinalizationError, ListParams, ListUpcomingLineItemsParams, MarkUncollectibleParams, PayParams, PaymentSettings, RemoveLinesParams, Rendering, RetrieveParams, SearchParams, SendInvoiceParams, ShippingCost, ShippingDetails, StatusTransitions, SubscriptionDetails, ThresholdReason, TotalDiscountAmount, TotalMarginAmount, TotalPretaxCreditAmount, TotalTaxAmount, TransferData, UpcomingParams, UpdateLinesParams, UpdateParams, VoidInvoiceParams

Constant Summary collapse

OBJECT_NAME =
"invoice"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_countryObject (readonly)

The country of the business associated with this invoice, most often the business creating the invoice.



7862
7863
7864
# File 'lib/stripe/resources/invoice.rb', line 7862

def 
  @account_country
end

#account_nameObject (readonly)

The public name of the business associated with this invoice, most often the business creating the invoice.



7864
7865
7866
# File 'lib/stripe/resources/invoice.rb', line 7864

def 
  @account_name
end

#account_tax_idsObject (readonly)

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



7866
7867
7868
# File 'lib/stripe/resources/invoice.rb', line 7866

def 
  @account_tax_ids
end

#amount_dueObject (readonly)

Final amount due at this time for this invoice. If the invoice’s total is smaller than the minimum charge amount, for example, or if there is account credit that can be applied to the invoice, the ‘amount_due` may be 0. If there is a positive `starting_balance` for the invoice (the customer owes money), the `amount_due` will also take that into account. The charge that gets generated for the invoice will be for the amount specified in `amount_due`.



7868
7869
7870
# File 'lib/stripe/resources/invoice.rb', line 7868

def amount_due
  @amount_due
end

#amount_overpaidObject (readonly)

Amount that was overpaid on the invoice. Overpayments are debited to the customer’s credit balance.



7870
7871
7872
# File 'lib/stripe/resources/invoice.rb', line 7870

def amount_overpaid
  @amount_overpaid
end

#amount_paidObject (readonly)

The amount, in cents (or local equivalent), that was paid.



7872
7873
7874
# File 'lib/stripe/resources/invoice.rb', line 7872

def amount_paid
  @amount_paid
end

#amount_remainingObject (readonly)

The difference between amount_due and amount_paid, in cents (or local equivalent).



7874
7875
7876
# File 'lib/stripe/resources/invoice.rb', line 7874

def amount_remaining
  @amount_remaining
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



7876
7877
7878
# File 'lib/stripe/resources/invoice.rb', line 7876

def amount_shipping
  @amount_shipping
end

#amounts_dueObject (readonly)

List of expected payments and corresponding due dates. This value will be null for invoices where collection_method=charge_automatically.



7878
7879
7880
# File 'lib/stripe/resources/invoice.rb', line 7878

def amounts_due
  @amounts_due
end

#applicationObject (readonly)

ID of the Connect Application that created the invoice.



7880
7881
7882
# File 'lib/stripe/resources/invoice.rb', line 7880

def application
  @application
end

#application_fee_amountObject (readonly)

The fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account when the invoice is paid.



7882
7883
7884
# File 'lib/stripe/resources/invoice.rb', line 7882

def application_fee_amount
  @application_fee_amount
end

#attempt_countObject (readonly)

Number of payment attempts made for this invoice, from the perspective of the payment retry schedule. Any payment attempt counts as the first attempt, and subsequently only automatic retries increment the attempt count. In other words, manual payment attempts after the first attempt do not affect the retry schedule. If a failure is returned with a non-retryable return code, the invoice can no longer be retried unless a new payment method is obtained. Retries will continue to be scheduled, and attempt_count will continue to increment, but retries will only be executed if a new payment method is obtained.



7884
7885
7886
# File 'lib/stripe/resources/invoice.rb', line 7884

def attempt_count
  @attempt_count
end

#attemptedObject (readonly)

Whether an attempt has been made to pay the invoice. An invoice is not attempted until 1 hour after the ‘invoice.created` webhook, for example, so you might not want to display that invoice as unpaid to your users.



7886
7887
7888
# File 'lib/stripe/resources/invoice.rb', line 7886

def attempted
  @attempted
end

#auto_advanceObject (readonly)

Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action.



7888
7889
7890
# File 'lib/stripe/resources/invoice.rb', line 7888

def auto_advance
  @auto_advance
end

#automatic_taxObject (readonly)

Attribute for field automatic_tax



7890
7891
7892
# File 'lib/stripe/resources/invoice.rb', line 7890

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject (readonly)

The time when this invoice is currently scheduled to be automatically finalized. The field will be ‘null` if the invoice is not scheduled to finalize in the future. If the invoice is not in the draft state, this field will always be `null` - see `finalized_at` for the time when an already-finalized invoice was finalized.



7892
7893
7894
# File 'lib/stripe/resources/invoice.rb', line 7892

def automatically_finalizes_at
  @automatically_finalizes_at
end

#billing_reasonObject (readonly)

Indicates the reason why the invoice was created.

  • ‘manual`: Unrelated to a subscription, for example, created via the invoice editor.

  • ‘subscription`: No longer in use. Applies to subscriptions from before May 2018 where no distinction was made between updates, cycles, and thresholds.

  • ‘subscription_create`: A new subscription was created.

  • ‘subscription_cycle`: A subscription advanced into a new period.

  • ‘subscription_threshold`: A subscription reached a billing threshold.

  • ‘subscription_update`: A subscription was updated.

  • ‘upcoming`: Reserved for simulated invoices, per the upcoming invoice endpoint.



7902
7903
7904
# File 'lib/stripe/resources/invoice.rb', line 7902

def billing_reason
  @billing_reason
end

#chargeObject (readonly)

ID of the latest charge generated for this invoice, if any.



7904
7905
7906
# File 'lib/stripe/resources/invoice.rb', line 7904

def charge
  @charge
end

#collection_methodObject (readonly)

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions.



7906
7907
7908
# File 'lib/stripe/resources/invoice.rb', line 7906

def collection_method
  @collection_method
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



7908
7909
7910
# File 'lib/stripe/resources/invoice.rb', line 7908

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



7910
7911
7912
# File 'lib/stripe/resources/invoice.rb', line 7910

def currency
  @currency
end

#custom_fieldsObject (readonly)

Custom fields displayed on the invoice.



7912
7913
7914
# File 'lib/stripe/resources/invoice.rb', line 7912

def custom_fields
  @custom_fields
end

#customerObject (readonly)

The ID of the customer who will be billed.



7914
7915
7916
# File 'lib/stripe/resources/invoice.rb', line 7914

def customer
  @customer
end

#customer_addressObject (readonly)

The customer’s address. Until the invoice is finalized, this field will equal ‘customer.address`. Once the invoice is finalized, this field will no longer be updated.



7916
7917
7918
# File 'lib/stripe/resources/invoice.rb', line 7916

def customer_address
  @customer_address
end

#customer_emailObject (readonly)

The customer’s email. Until the invoice is finalized, this field will equal ‘customer.email`. Once the invoice is finalized, this field will no longer be updated.



7918
7919
7920
# File 'lib/stripe/resources/invoice.rb', line 7918

def customer_email
  @customer_email
end

#customer_nameObject (readonly)

The customer’s name. Until the invoice is finalized, this field will equal ‘customer.name`. Once the invoice is finalized, this field will no longer be updated.



7920
7921
7922
# File 'lib/stripe/resources/invoice.rb', line 7920

def customer_name
  @customer_name
end

#customer_phoneObject (readonly)

The customer’s phone number. Until the invoice is finalized, this field will equal ‘customer.phone`. Once the invoice is finalized, this field will no longer be updated.



7922
7923
7924
# File 'lib/stripe/resources/invoice.rb', line 7922

def customer_phone
  @customer_phone
end

#customer_shippingObject (readonly)

The customer’s shipping information. Until the invoice is finalized, this field will equal ‘customer.shipping`. Once the invoice is finalized, this field will no longer be updated.



7924
7925
7926
# File 'lib/stripe/resources/invoice.rb', line 7924

def customer_shipping
  @customer_shipping
end

#customer_tax_exemptObject (readonly)

The customer’s tax exempt status. Until the invoice is finalized, this field will equal ‘customer.tax_exempt`. Once the invoice is finalized, this field will no longer be updated.



7926
7927
7928
# File 'lib/stripe/resources/invoice.rb', line 7926

def customer_tax_exempt
  @customer_tax_exempt
end

#customer_tax_idsObject (readonly)

The customer’s tax IDs. Until the invoice is finalized, this field will contain the same tax IDs as ‘customer.tax_ids`. Once the invoice is finalized, this field will no longer be updated.



7928
7929
7930
# File 'lib/stripe/resources/invoice.rb', line 7928

def customer_tax_ids
  @customer_tax_ids
end

#default_marginsObject (readonly)

The margins applied to the invoice. Can be overridden by line item ‘margins`. Use `expand[]=default_margins` to expand each margin.



7930
7931
7932
# File 'lib/stripe/resources/invoice.rb', line 7930

def default_margins
  @default_margins
end

#default_payment_methodObject (readonly)

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



7932
7933
7934
# File 'lib/stripe/resources/invoice.rb', line 7932

def default_payment_method
  @default_payment_method
end

#default_sourceObject (readonly)

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



7934
7935
7936
# File 'lib/stripe/resources/invoice.rb', line 7934

def default_source
  @default_source
end

#default_tax_ratesObject (readonly)

The tax rates applied to this invoice, if any.



7936
7937
7938
# File 'lib/stripe/resources/invoice.rb', line 7936

def default_tax_rates
  @default_tax_rates
end

#deletedObject (readonly)

Always true for a deleted object



8048
8049
8050
# File 'lib/stripe/resources/invoice.rb', line 8048

def deleted
  @deleted
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



7938
7939
7940
# File 'lib/stripe/resources/invoice.rb', line 7938

def description
  @description
end

#discountObject (readonly)

Describes the current discount applied to this invoice, if there is one. Not populated if there are multiple discounts.



7940
7941
7942
# File 'lib/stripe/resources/invoice.rb', line 7940

def discount
  @discount
end

#discountsObject (readonly)

The discounts applied to the invoice. Line item discounts are applied before invoice discounts. Use ‘expand[]=discounts` to expand each discount.



7942
7943
7944
# File 'lib/stripe/resources/invoice.rb', line 7942

def discounts
  @discounts
end

#due_dateObject (readonly)

The date on which payment for this invoice is due. This value will be ‘null` for invoices where `collection_method=charge_automatically`.



7944
7945
7946
# File 'lib/stripe/resources/invoice.rb', line 7944

def due_date
  @due_date
end

#effective_atObject (readonly)

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



7946
7947
7948
# File 'lib/stripe/resources/invoice.rb', line 7946

def effective_at
  @effective_at
end

#ending_balanceObject (readonly)

Ending customer balance after the invoice is finalized. Invoices are finalized approximately an hour after successful webhook delivery or when payment collection is attempted for the invoice. If the invoice has not been finalized yet, this will be null.



7948
7949
7950
# File 'lib/stripe/resources/invoice.rb', line 7948

def ending_balance
  @ending_balance
end

Footer displayed on the invoice.



7950
7951
7952
# File 'lib/stripe/resources/invoice.rb', line 7950

def footer
  @footer
end

#from_invoiceObject (readonly)

Details of the invoice that was cloned. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.



7952
7953
7954
# File 'lib/stripe/resources/invoice.rb', line 7952

def from_invoice
  @from_invoice
end

#hosted_invoice_urlObject (readonly)

The URL for the hosted invoice page, which allows customers to view and pay an invoice. If the invoice has not been finalized yet, this will be null.



7954
7955
7956
# File 'lib/stripe/resources/invoice.rb', line 7954

def hosted_invoice_url
  @hosted_invoice_url
end

#idObject (readonly)

Unique identifier for the object. This property is always present unless the invoice is an upcoming invoice. See [Retrieve an upcoming invoice](stripe.com/docs/api/invoices/upcoming) for more details.



7956
7957
7958
# File 'lib/stripe/resources/invoice.rb', line 7956

def id
  @id
end

#invoice_pdfObject (readonly)

The link to download the PDF for the invoice. If the invoice has not been finalized yet, this will be null.



7958
7959
7960
# File 'lib/stripe/resources/invoice.rb', line 7958

def invoice_pdf
  @invoice_pdf
end

#issuerObject (readonly)

Attribute for field issuer



7960
7961
7962
# File 'lib/stripe/resources/invoice.rb', line 7960

def issuer
  @issuer
end

#last_finalization_errorObject (readonly)

The error encountered during the previous attempt to finalize the invoice. This field is cleared when the invoice is successfully finalized.



7962
7963
7964
# File 'lib/stripe/resources/invoice.rb', line 7962

def last_finalization_error
  @last_finalization_error
end

#latest_revisionObject (readonly)

The ID of the most recent non-draft revision of this invoice



7964
7965
7966
# File 'lib/stripe/resources/invoice.rb', line 7964

def latest_revision
  @latest_revision
end

#linesObject (readonly)

The individual line items that make up the invoice. ‘lines` is sorted as follows: (1) pending invoice items (including prorations) in reverse chronological order, (2) subscription items in reverse chronological order, and (3) invoice items added after invoice creation in chronological order.



7966
7967
7968
# File 'lib/stripe/resources/invoice.rb', line 7966

def lines
  @lines
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



7968
7969
7970
# File 'lib/stripe/resources/invoice.rb', line 7968

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



7970
7971
7972
# File 'lib/stripe/resources/invoice.rb', line 7970

def 
  @metadata
end

#next_payment_attemptObject (readonly)

The time at which payment will next be attempted. This value will be ‘null` for invoices where `collection_method=send_invoice`.



7972
7973
7974
# File 'lib/stripe/resources/invoice.rb', line 7972

def next_payment_attempt
  @next_payment_attempt
end

#numberObject (readonly)

A unique, identifying string that appears on emails sent to the customer for this invoice. This starts with the customer’s unique invoice_prefix if it is specified.



7974
7975
7976
# File 'lib/stripe/resources/invoice.rb', line 7974

def number
  @number
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



7976
7977
7978
# File 'lib/stripe/resources/invoice.rb', line 7976

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



7978
7979
7980
# File 'lib/stripe/resources/invoice.rb', line 7978

def on_behalf_of
  @on_behalf_of
end

Whether payment was successfully collected for this invoice. An invoice can be paid (most commonly) with a charge or with credit from the customer’s account balance.



7980
7981
7982
# File 'lib/stripe/resources/invoice.rb', line 7980

def paid
  @paid
end

Returns true if the invoice was manually marked paid, returns false if the invoice hasn’t been paid yet or was paid on Stripe.



7982
7983
7984
# File 'lib/stripe/resources/invoice.rb', line 7982

def paid_out_of_band
  @paid_out_of_band
end

#payment_intentObject (readonly)

The PaymentIntent associated with this invoice. The PaymentIntent is generated when the invoice is finalized, and can then be used to pay the invoice. Note that voiding an invoice will cancel the PaymentIntent.



7984
7985
7986
# File 'lib/stripe/resources/invoice.rb', line 7984

def payment_intent
  @payment_intent
end

#payment_settingsObject (readonly)

Attribute for field payment_settings



7986
7987
7988
# File 'lib/stripe/resources/invoice.rb', line 7986

def payment_settings
  @payment_settings
end

#paymentsObject (readonly)

Payments for this invoice



7988
7989
7990
# File 'lib/stripe/resources/invoice.rb', line 7988

def payments
  @payments
end

#period_endObject (readonly)

End of the usage period during which invoice items were added to this invoice. This looks back one period for a subscription invoice. Use the [line item period](/api/invoices/line_item#invoice_line_item_object-period) to get the service period for each price.



7990
7991
7992
# File 'lib/stripe/resources/invoice.rb', line 7990

def period_end
  @period_end
end

#period_startObject (readonly)

Start of the usage period during which invoice items were added to this invoice. This looks back one period for a subscription invoice. Use the [line item period](/api/invoices/line_item#invoice_line_item_object-period) to get the service period for each price.



7992
7993
7994
# File 'lib/stripe/resources/invoice.rb', line 7992

def period_start
  @period_start
end

#post_payment_credit_notes_amountObject (readonly)

Total amount of all post-payment credit notes issued for this invoice.



7994
7995
7996
# File 'lib/stripe/resources/invoice.rb', line 7994

def post_payment_credit_notes_amount
  @post_payment_credit_notes_amount
end

#pre_payment_credit_notes_amountObject (readonly)

Total amount of all pre-payment credit notes issued for this invoice.



7996
7997
7998
# File 'lib/stripe/resources/invoice.rb', line 7996

def pre_payment_credit_notes_amount
  @pre_payment_credit_notes_amount
end

#quoteObject (readonly)

The quote this invoice was generated from.



7998
7999
8000
# File 'lib/stripe/resources/invoice.rb', line 7998

def quote
  @quote
end

#receipt_numberObject (readonly)

This is the transaction number that appears on email receipts sent for this invoice.



8000
8001
8002
# File 'lib/stripe/resources/invoice.rb', line 8000

def receipt_number
  @receipt_number
end

#renderingObject (readonly)

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



8002
8003
8004
# File 'lib/stripe/resources/invoice.rb', line 8002

def rendering
  @rendering
end

#shipping_costObject (readonly)

The details of the cost of shipping, including the ShippingRate applied on the invoice.



8004
8005
8006
# File 'lib/stripe/resources/invoice.rb', line 8004

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject (readonly)

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



8006
8007
8008
# File 'lib/stripe/resources/invoice.rb', line 8006

def shipping_details
  @shipping_details
end

#starting_balanceObject (readonly)

Starting customer balance before the invoice is finalized. If the invoice has not been finalized yet, this will be the current customer balance. For revision invoices, this also includes any customer balance that was applied to the original invoice.



8008
8009
8010
# File 'lib/stripe/resources/invoice.rb', line 8008

def starting_balance
  @starting_balance
end

#statement_descriptorObject (readonly)

Extra information about an invoice for the customer’s credit card statement.



8010
8011
8012
# File 'lib/stripe/resources/invoice.rb', line 8010

def statement_descriptor
  @statement_descriptor
end

#statusObject (readonly)

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



8012
8013
8014
# File 'lib/stripe/resources/invoice.rb', line 8012

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



8014
8015
8016
# File 'lib/stripe/resources/invoice.rb', line 8014

def status_transitions
  @status_transitions
end

#subscriptionObject (readonly)

The subscription that this invoice was prepared for, if any.



8016
8017
8018
# File 'lib/stripe/resources/invoice.rb', line 8016

def subscription
  @subscription
end

#subscription_detailsObject (readonly)

Details about the subscription that created this invoice.



8018
8019
8020
# File 'lib/stripe/resources/invoice.rb', line 8018

def subscription_details
  @subscription_details
end

#subscription_proration_dateObject (readonly)

Only set for upcoming invoices that preview prorations. The time used to calculate prorations.



8020
8021
8022
# File 'lib/stripe/resources/invoice.rb', line 8020

def subscription_proration_date
  @subscription_proration_date
end

#subtotalObject (readonly)

Total of all subscriptions, invoice items, and prorations on the invoice before any invoice level discount or exclusive tax is applied. Item discounts are already incorporated



8022
8023
8024
# File 'lib/stripe/resources/invoice.rb', line 8022

def subtotal
  @subtotal
end

#subtotal_excluding_taxObject (readonly)

The integer amount in cents (or local equivalent) representing the subtotal of the invoice before any invoice level discount or tax is applied. Item discounts are already incorporated



8024
8025
8026
# File 'lib/stripe/resources/invoice.rb', line 8024

def subtotal_excluding_tax
  @subtotal_excluding_tax
end

#taxObject (readonly)

The amount of tax on this invoice. This is the sum of all the tax amounts on this invoice.



8026
8027
8028
# File 'lib/stripe/resources/invoice.rb', line 8026

def tax
  @tax
end

#test_clockObject (readonly)

ID of the test clock this invoice belongs to.



8028
8029
8030
# File 'lib/stripe/resources/invoice.rb', line 8028

def test_clock
  @test_clock
end

#threshold_reasonObject (readonly)

Attribute for field threshold_reason



8030
8031
8032
# File 'lib/stripe/resources/invoice.rb', line 8030

def threshold_reason
  @threshold_reason
end

#totalObject (readonly)

Total after discounts and taxes.



8032
8033
8034
# File 'lib/stripe/resources/invoice.rb', line 8032

def total
  @total
end

#total_discount_amountsObject (readonly)

The aggregate amounts calculated per discount across all line items.



8034
8035
8036
# File 'lib/stripe/resources/invoice.rb', line 8034

def total_discount_amounts
  @total_discount_amounts
end

#total_excluding_taxObject (readonly)

The integer amount in cents (or local equivalent) representing the total amount of the invoice including all discounts but excluding all tax.



8036
8037
8038
# File 'lib/stripe/resources/invoice.rb', line 8036

def total_excluding_tax
  @total_excluding_tax
end

#total_margin_amountsObject (readonly)

The aggregate amounts calculated per margin across all line items.



8038
8039
8040
# File 'lib/stripe/resources/invoice.rb', line 8038

def total_margin_amounts
  @total_margin_amounts
end

#total_pretax_credit_amountsObject (readonly)

Contains pretax credit amounts (ex: discount, credit grants, etc) that apply to this invoice. This is a combined list of total_pretax_credit_amounts across all invoice line items.



8040
8041
8042
# File 'lib/stripe/resources/invoice.rb', line 8040

def total_pretax_credit_amounts
  @total_pretax_credit_amounts
end

#total_tax_amountsObject (readonly)

The aggregate amounts calculated per tax rate for all line items.



8042
8043
8044
# File 'lib/stripe/resources/invoice.rb', line 8042

def total_tax_amounts
  @total_tax_amounts
end

#transfer_dataObject (readonly)

The account (if any) the payment will be attributed to for tax reporting, and where funds from the payment will be transferred to for the invoice.



8044
8045
8046
# File 'lib/stripe/resources/invoice.rb', line 8044

def transfer_data
  @transfer_data
end

#webhooks_delivered_atObject (readonly)

Invoices are automatically paid or sent 1 hour after webhooks are delivered, or until all webhook delivery attempts have [been exhausted](stripe.com/docs/billing/webhooks#understand). This field tracks the time when webhooks for this invoice were successfully delivered. If the invoice had no webhooks to deliver, this will be set while the invoice is being created.



8046
8047
8048
# File 'lib/stripe/resources/invoice.rb', line 8046

def webhooks_delivered_at
  @webhooks_delivered_at
end

Class Method Details

.add_lines(invoice, params = {}, opts = {}) ⇒ Object

Adds multiple line items to an invoice. This is only possible when an invoice is still a draft.



8061
8062
8063
8064
8065
8066
8067
8068
# File 'lib/stripe/resources/invoice.rb', line 8061

def self.add_lines(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/add_lines", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.attach_payment(invoice, params = {}, opts = {}) ⇒ Object

Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.

For Out of Band Payment, the payment is credited to the invoice immediately, increasing the amount_paid of the invoice and subsequently transitioning the status of the invoice to paid if necessary.

For the PaymentIntent, when the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.

If the PaymentIntent’s status is already succeeded when it’s attached, it’s credited to the invoice immediately.

See: [Create an invoice payment](stripe.com/docs/invoicing/payments/create) to learn more.



8105
8106
8107
8108
8109
8110
8111
8112
# File 'lib/stripe/resources/invoice.rb', line 8105

def self.attach_payment(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/attach_payment", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.attach_payment_intent(invoice, params = {}, opts = {}) ⇒ Object

Attaches a PaymentIntent to the invoice, adding it to the list of payments. When the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.

If the PaymentIntent’s status is already succeeded when it is attached, it is credited to the invoice immediately.

Related guide: [Create an invoice payment](stripe.com/docs/invoicing/payments/create)



8141
8142
8143
8144
8145
8146
8147
8148
# File 'lib/stripe/resources/invoice.rb', line 8141

def self.attach_payment_intent(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/attach_payment_intent", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

This endpoint creates a draft invoice for a given customer. The invoice remains a draft until you [finalize the invoice, which allows you to [pay](#pay_invoice) or <a href=“#send_invoice”>send](stripe.com/docs/api#finalize_invoice) the invoice to your customers.



8151
8152
8153
# File 'lib/stripe/resources/invoice.rb', line 8151

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/invoices", params: params, opts: opts)
end

.create_preview(params = {}, opts = {}) ⇒ Object

At any time, you can preview the upcoming invoice for a customer. This will show you all the charges that are pending, including subscription renewal charges, invoice item charges, etc. It will also show you any discounts that are applicable to the invoice.

Note that when you are viewing an upcoming invoice, you are simply viewing a preview – the invoice has not yet been created. As such, the upcoming invoice will not show up in invoice listing calls, and you cannot use the API to pay or edit the invoice. If you want to change the amount that your customer will be billed, you can add, remove, or update pending invoice items, or update the customer’s discount.

You can preview the effects of updating a subscription, including a preview of what proration will take place. To ensure that the actual proration is calculated exactly the same as the previewed proration, you should pass the subscription_details.proration_date parameter when doing the actual subscription update. The recommended way to get only the prorations being previewed is to consider only proration line items where period is equal to the subscription_details.proration_date value passed in the request.

Note: Currency conversion calculations use the latest exchange rates. Exchange rates may vary between the time of the preview and the time of the actual invoice creation. [Learn more](docs.stripe.com/currencies/conversions)



8162
8163
8164
8165
8166
8167
8168
8169
# File 'lib/stripe/resources/invoice.rb', line 8162

def self.create_preview(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/invoices/create_preview",
    params: params,
    opts: opts
  )
end

.delete(id, params = {}, opts = {}) ⇒ Object

Permanently deletes a one-off invoice draft. This cannot be undone. Attempts to delete invoices that are no longer in a draft state will fail; once an invoice has been finalized or if an invoice is for a subscription, it must be [voided](stripe.com/docs/api#void_invoice).



8172
8173
8174
8175
8176
8177
8178
8179
# File 'lib/stripe/resources/invoice.rb', line 8172

def self.delete(id, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/invoices/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.finalize_invoice(invoice, params = {}, opts = {}) ⇒ Object

Stripe automatically finalizes drafts before sending and attempting payment on invoices. However, if you’d like to finalize a draft invoice manually, you can do so using this method.



8202
8203
8204
8205
8206
8207
8208
8209
# File 'lib/stripe/resources/invoice.rb', line 8202

def self.finalize_invoice(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/finalize", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

You can list all invoices, or list the invoices for a specific customer. The invoices are returned sorted by creation date, with the most recently created invoices appearing first.



8212
8213
8214
# File 'lib/stripe/resources/invoice.rb', line 8212

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/invoices", params: params, opts: opts)
end

.list_upcoming_line_items(params = {}, opts = {}) ⇒ Object

When retrieving an upcoming invoice, you’ll get a lines property containing the total count of line items and the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.



8217
8218
8219
8220
8221
8222
8223
8224
# File 'lib/stripe/resources/invoice.rb', line 8217

def self.list_upcoming_line_items(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/invoices/upcoming/lines",
    params: params,
    opts: opts
  )
end

.mark_uncollectible(invoice, params = {}, opts = {}) ⇒ Object

Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.



8237
8238
8239
8240
8241
8242
8243
8244
# File 'lib/stripe/resources/invoice.rb', line 8237

def self.mark_uncollectible(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/mark_uncollectible", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.object_nameObject



46
47
48
# File 'lib/stripe/resources/invoice.rb', line 46

def self.object_name
  "invoice"
end

.pay(invoice, params = {}, opts = {}) ⇒ Object

Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to attempt payment on an invoice out of the normal collection schedule or for some other reason, you can do so.



8257
8258
8259
8260
8261
8262
8263
8264
# File 'lib/stripe/resources/invoice.rb', line 8257

def self.pay(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/pay", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.remove_lines(invoice, params = {}, opts = {}) ⇒ Object

Removes multiple line items from an invoice. This is only possible when an invoice is still a draft.



8277
8278
8279
8280
8281
8282
8283
8284
# File 'lib/stripe/resources/invoice.rb', line 8277

def self.remove_lines(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/remove_lines", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.search(params = {}, opts = {}) ⇒ Object



8286
8287
8288
# File 'lib/stripe/resources/invoice.rb', line 8286

def self.search(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/invoices/search", params: params, opts: opts)
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



8290
8291
8292
# File 'lib/stripe/resources/invoice.rb', line 8290

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.send_invoice(invoice, params = {}, opts = {}) ⇒ Object

Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to manually send an invoice to your customer out of the normal schedule, you can do so. When sending invoices that have already been paid, there will be no reference to the payment in the email.

Requests made in test-mode result in no emails being sent, despite sending an invoice.sent event.



8309
8310
8311
8312
8313
8314
8315
8316
# File 'lib/stripe/resources/invoice.rb', line 8309

def self.send_invoice(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/send", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.upcoming(params = {}, opts = {}) ⇒ Object

At any time, you can preview the upcoming invoice for a customer. This will show you all the charges that are pending, including subscription renewal charges, invoice item charges, etc. It will also show you any discounts that are applicable to the invoice.

Note that when you are viewing an upcoming invoice, you are simply viewing a preview – the invoice has not yet been created. As such, the upcoming invoice will not show up in invoice listing calls, and you cannot use the API to pay or edit the invoice. If you want to change the amount that your customer will be billed, you can add, remove, or update pending invoice items, or update the customer’s discount.

You can preview the effects of updating a subscription, including a preview of what proration will take place. To ensure that the actual proration is calculated exactly the same as the previewed proration, you should pass the subscription_details.proration_date parameter when doing the actual subscription update. The recommended way to get only the prorations being previewed is to consider only proration line items where period is equal to the subscription_details.proration_date value passed in the request.

Note: Currency conversion calculations use the latest exchange rates. Exchange rates may vary between the time of the preview and the time of the actual invoice creation. [Learn more](docs.stripe.com/currencies/conversions)



8325
8326
8327
# File 'lib/stripe/resources/invoice.rb', line 8325

def self.upcoming(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/invoices/upcoming", params: params, opts: opts)
end

.update(id, params = {}, opts = {}) ⇒ Object

Draft invoices are fully editable. Once an invoice is [finalized](stripe.com/docs/billing/invoices/workflow#finalized), monetary values, as well as collection_method, become uneditable.

If you would like to stop the Stripe Billing engine from automatically finalizing, reattempting payments on, sending reminders for, or [automatically reconciling](stripe.com/docs/billing/invoices/reconciliation) invoices, pass auto_advance=false.



8335
8336
8337
8338
8339
8340
8341
8342
# File 'lib/stripe/resources/invoice.rb', line 8335

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

.update_lines(invoice, params = {}, opts = {}) ⇒ Object

Updates multiple line items on an invoice. This is only possible when an invoice is still a draft.



8355
8356
8357
8358
8359
8360
8361
8362
# File 'lib/stripe/resources/invoice.rb', line 8355

def self.update_lines(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/update_lines", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

.void_invoice(invoice, params = {}, opts = {}) ⇒ Object

Mark a finalized invoice as void. This cannot be undone. Voiding an invoice is similar to [deletion](stripe.com/docs/api#delete_invoice), however it only applies to finalized invoices and maintains a papertrail where the invoice can still be found.

Consult with local regulations to determine whether and how an invoice might be amended, canceled, or voided in the jurisdiction you’re doing business in. You might need to [issue another invoice or <a href=“#create_credit_note”>credit note](stripe.com/docs/api#create_invoice) instead. Stripe recommends that you consult with your legal counsel for advice specific to your business.



8379
8380
8381
8382
8383
8384
8385
8386
# File 'lib/stripe/resources/invoice.rb', line 8379

def self.void_invoice(invoice, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/void", { invoice: CGI.escape(invoice) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#add_lines(params = {}, opts = {}) ⇒ Object

Adds multiple line items to an invoice. This is only possible when an invoice is still a draft.



8051
8052
8053
8054
8055
8056
8057
8058
# File 'lib/stripe/resources/invoice.rb', line 8051

def add_lines(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/add_lines", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#attach_payment(params = {}, opts = {}) ⇒ Object

Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.

For Out of Band Payment, the payment is credited to the invoice immediately, increasing the amount_paid of the invoice and subsequently transitioning the status of the invoice to paid if necessary.

For the PaymentIntent, when the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.

If the PaymentIntent’s status is already succeeded when it’s attached, it’s credited to the invoice immediately.

See: [Create an invoice payment](stripe.com/docs/invoicing/payments/create) to learn more.



8083
8084
8085
8086
8087
8088
8089
8090
# File 'lib/stripe/resources/invoice.rb', line 8083

def attach_payment(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/attach_payment", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#attach_payment_intent(params = {}, opts = {}) ⇒ Object

Attaches a PaymentIntent to the invoice, adding it to the list of payments. When the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.

If the PaymentIntent’s status is already succeeded when it is attached, it is credited to the invoice immediately.

Related guide: [Create an invoice payment](stripe.com/docs/invoicing/payments/create)



8123
8124
8125
8126
8127
8128
8129
8130
# File 'lib/stripe/resources/invoice.rb', line 8123

def attach_payment_intent(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/attach_payment_intent", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#delete(params = {}, opts = {}) ⇒ Object

Permanently deletes a one-off invoice draft. This cannot be undone. Attempts to delete invoices that are no longer in a draft state will fail; once an invoice has been finalized or if an invoice is for a subscription, it must be [voided](stripe.com/docs/api#void_invoice).



8182
8183
8184
8185
8186
8187
8188
8189
# File 'lib/stripe/resources/invoice.rb', line 8182

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#finalize_invoice(params = {}, opts = {}) ⇒ Object

Stripe automatically finalizes drafts before sending and attempting payment on invoices. However, if you’d like to finalize a draft invoice manually, you can do so using this method.



8192
8193
8194
8195
8196
8197
8198
8199
# File 'lib/stripe/resources/invoice.rb', line 8192

def finalize_invoice(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/finalize", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#mark_uncollectible(params = {}, opts = {}) ⇒ Object

Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.



8227
8228
8229
8230
8231
8232
8233
8234
# File 'lib/stripe/resources/invoice.rb', line 8227

def mark_uncollectible(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/mark_uncollectible", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#pay(params = {}, opts = {}) ⇒ Object

Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to attempt payment on an invoice out of the normal collection schedule or for some other reason, you can do so.



8247
8248
8249
8250
8251
8252
8253
8254
# File 'lib/stripe/resources/invoice.rb', line 8247

def pay(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/pay", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#remove_lines(params = {}, opts = {}) ⇒ Object

Removes multiple line items from an invoice. This is only possible when an invoice is still a draft.



8267
8268
8269
8270
8271
8272
8273
8274
# File 'lib/stripe/resources/invoice.rb', line 8267

def remove_lines(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/remove_lines", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#send_invoice(params = {}, opts = {}) ⇒ Object

Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to manually send an invoice to your customer out of the normal schedule, you can do so. When sending invoices that have already been paid, there will be no reference to the payment in the email.

Requests made in test-mode result in no emails being sent, despite sending an invoice.sent event.



8297
8298
8299
8300
8301
8302
8303
8304
# File 'lib/stripe/resources/invoice.rb', line 8297

def send_invoice(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/send", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#update_lines(params = {}, opts = {}) ⇒ Object

Updates multiple line items on an invoice. This is only possible when an invoice is still a draft.



8345
8346
8347
8348
8349
8350
8351
8352
# File 'lib/stripe/resources/invoice.rb', line 8345

def update_lines(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/update_lines", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#void_invoice(params = {}, opts = {}) ⇒ Object

Mark a finalized invoice as void. This cannot be undone. Voiding an invoice is similar to [deletion](stripe.com/docs/api#delete_invoice), however it only applies to finalized invoices and maintains a papertrail where the invoice can still be found.

Consult with local regulations to determine whether and how an invoice might be amended, canceled, or voided in the jurisdiction you’re doing business in. You might need to [issue another invoice or <a href=“#create_credit_note”>credit note](stripe.com/docs/api#create_invoice) instead. Stripe recommends that you consult with your legal counsel for advice specific to your business.



8367
8368
8369
8370
8371
8372
8373
8374
# File 'lib/stripe/resources/invoice.rb', line 8367

def void_invoice(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoices/%<invoice>s/void", { invoice: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end