Class: Stripe::Invoice::AddLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams

Returns a new instance of AddLinesParams.



2118
2119
2120
2121
2122
# File 'lib/stripe/resources/invoice.rb', line 2118

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2112
2113
2114
# File 'lib/stripe/resources/invoice.rb', line 2112

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2114
2115
2116
# File 'lib/stripe/resources/invoice.rb', line 2114

def 
  @invoice_metadata
end

#linesObject

The line items to add.



2116
2117
2118
# File 'lib/stripe/resources/invoice.rb', line 2116

def lines
  @lines
end