Class: Stripe::Invoice::AddLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to add.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams
constructor
A new instance of AddLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams
Returns a new instance of AddLinesParams.
1918 1919 1920 1921 1922 |
# File 'lib/stripe/resources/invoice.rb', line 1918 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1912 1913 1914 |
# File 'lib/stripe/resources/invoice.rb', line 1912 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1914 1915 1916 |
# File 'lib/stripe/resources/invoice.rb', line 1914 def @invoice_metadata end |
#lines ⇒ Object
The line items to add.
1916 1917 1918 |
# File 'lib/stripe/resources/invoice.rb', line 1916 def lines @lines end |