Class: Stripe::Invoice::AddLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams

Returns a new instance of AddLinesParams.



6682
6683
6684
6685
6686
# File 'lib/stripe/resources/invoice.rb', line 6682

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



6674
6675
6676
# File 'lib/stripe/resources/invoice.rb', line 6674

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6677
6678
6679
# File 'lib/stripe/resources/invoice.rb', line 6677

def 
  @invoice_metadata
end

#linesObject

The line items to add.



6680
6681
6682
# File 'lib/stripe/resources/invoice.rb', line 6680

def lines
  @lines
end