Class: Stripe::Invoice::AddLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line

Returns a new instance of Line.



1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
1911
# File 'lib/stripe/resources/invoice.rb', line 1885

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  invoice_item: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @invoice_item = invoice_item
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



1861
1862
1863
# File 'lib/stripe/resources/invoice.rb', line 1861

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



1863
1864
1865
# File 'lib/stripe/resources/invoice.rb', line 1863

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



1865
1866
1867
# File 'lib/stripe/resources/invoice.rb', line 1865

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



1867
1868
1869
# File 'lib/stripe/resources/invoice.rb', line 1867

def discounts
  @discounts
end

#invoice_itemObject

ID of an unassigned invoice item to assign to this invoice. If not provided, a new item will be created.



1869
1870
1871
# File 'lib/stripe/resources/invoice.rb', line 1869

def invoice_item
  @invoice_item
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1871
1872
1873
# File 'lib/stripe/resources/invoice.rb', line 1871

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



1873
1874
1875
# File 'lib/stripe/resources/invoice.rb', line 1873

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1875
1876
1877
# File 'lib/stripe/resources/invoice.rb', line 1875

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



1877
1878
1879
# File 'lib/stripe/resources/invoice.rb', line 1877

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



1879
1880
1881
# File 'lib/stripe/resources/invoice.rb', line 1879

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



1881
1882
1883
# File 'lib/stripe/resources/invoice.rb', line 1881

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



1883
1884
1885
# File 'lib/stripe/resources/invoice.rb', line 1883

def tax_rates
  @tax_rates
end