Class: Stripe::Invoice::AddLinesParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Discount, Period, PriceData, Pricing, TaxAmount
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Controls whether discounts apply to this line item.
-
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item.
-
#invoice_item ⇒ Object
ID of an unassigned invoice item to assign to this invoice.
-
#margins ⇒ Object
The IDs of the margins to apply to the line item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#pricing ⇒ Object
The pricing information for the invoice item.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line
Returns a new instance of Line.
2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 |
# File 'lib/stripe/resources/invoice.rb', line 2093 def initialize( amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil ) @amount = amount @description = description @discountable = discountable @discounts = discounts @invoice_item = invoice_item @margins = margins @metadata = @period = period @price_data = price_data @pricing = pricing @quantity = quantity @tax_amounts = tax_amounts @tax_rates = tax_rates end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.
2067 2068 2069 |
# File 'lib/stripe/resources/invoice.rb', line 2067 def amount @amount end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
2069 2070 2071 |
# File 'lib/stripe/resources/invoice.rb', line 2069 def description @description end |
#discountable ⇒ Object
Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.
2071 2072 2073 |
# File 'lib/stripe/resources/invoice.rb', line 2071 def discountable @discountable end |
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.
2073 2074 2075 |
# File 'lib/stripe/resources/invoice.rb', line 2073 def discounts @discounts end |
#invoice_item ⇒ Object
ID of an unassigned invoice item to assign to this invoice. If not provided, a new item will be created.
2075 2076 2077 |
# File 'lib/stripe/resources/invoice.rb', line 2075 def invoice_item @invoice_item end |
#margins ⇒ Object
The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.
2077 2078 2079 |
# File 'lib/stripe/resources/invoice.rb', line 2077 def margins @margins end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2079 2080 2081 |
# File 'lib/stripe/resources/invoice.rb', line 2079 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
2081 2082 2083 |
# File 'lib/stripe/resources/invoice.rb', line 2081 def period @period end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
2083 2084 2085 |
# File 'lib/stripe/resources/invoice.rb', line 2083 def price_data @price_data end |
#pricing ⇒ Object
The pricing information for the invoice item.
2085 2086 2087 |
# File 'lib/stripe/resources/invoice.rb', line 2085 def pricing @pricing end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the line item.
2087 2088 2089 |
# File 'lib/stripe/resources/invoice.rb', line 2087 def quantity @quantity end |
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.
2089 2090 2091 |
# File 'lib/stripe/resources/invoice.rb', line 2089 def tax_amounts @tax_amounts end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.
2091 2092 2093 |
# File 'lib/stripe/resources/invoice.rb', line 2091 def tax_rates @tax_rates end |