Class: Stripe::Invoice::AddLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, margins: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line

Returns a new instance of Line.



6643
6644
6645
6646
6647
6648
6649
6650
6651
6652
6653
6654
6655
6656
6657
6658
6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
# File 'lib/stripe/resources/invoice.rb', line 6643

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  invoice_item: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @invoice_item = invoice_item
  @margins = margins
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



6605
6606
6607
# File 'lib/stripe/resources/invoice.rb', line 6605

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



6608
6609
6610
# File 'lib/stripe/resources/invoice.rb', line 6608

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



6611
6612
6613
# File 'lib/stripe/resources/invoice.rb', line 6611

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



6614
6615
6616
# File 'lib/stripe/resources/invoice.rb', line 6614

def discounts
  @discounts
end

#invoice_itemObject

ID of an unassigned invoice item to assign to this invoice. If not provided, a new item will be created.



6617
6618
6619
# File 'lib/stripe/resources/invoice.rb', line 6617

def invoice_item
  @invoice_item
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



6620
6621
6622
# File 'lib/stripe/resources/invoice.rb', line 6620

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6623
6624
6625
# File 'lib/stripe/resources/invoice.rb', line 6623

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



6626
6627
6628
# File 'lib/stripe/resources/invoice.rb', line 6626

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



6629
6630
6631
# File 'lib/stripe/resources/invoice.rb', line 6629

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



6632
6633
6634
# File 'lib/stripe/resources/invoice.rb', line 6632

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



6635
6636
6637
# File 'lib/stripe/resources/invoice.rb', line 6635

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



6638
6639
6640
# File 'lib/stripe/resources/invoice.rb', line 6638

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



6641
6642
6643
# File 'lib/stripe/resources/invoice.rb', line 6641

def tax_rates
  @tax_rates
end