Class: Stripe::Invoice::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1908
1909
1910
1911
1912
1913
# File 'lib/stripe/resources/invoice.rb', line 1908

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1900
1901
1902
# File 'lib/stripe/resources/invoice.rb', line 1900

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1902
1903
1904
# File 'lib/stripe/resources/invoice.rb', line 1902

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1904
1905
1906
# File 'lib/stripe/resources/invoice.rb', line 1904

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1906
1907
1908
# File 'lib/stripe/resources/invoice.rb', line 1906

def promotion_code
  @promotion_code
end