Class: Stripe::Invoice::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1919
1920
1921
1922
1923
1924
# File 'lib/stripe/resources/invoice.rb', line 1919

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1911
1912
1913
# File 'lib/stripe/resources/invoice.rb', line 1911

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1913
1914
1915
# File 'lib/stripe/resources/invoice.rb', line 1913

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1915
1916
1917
# File 'lib/stripe/resources/invoice.rb', line 1915

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1917
1918
1919
# File 'lib/stripe/resources/invoice.rb', line 1917

def promotion_code
  @promotion_code
end