Class: Stripe::Invoice::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1715
1716
1717
1718
1719
# File 'lib/stripe/resources/invoice.rb', line 1715

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1709
1710
1711
# File 'lib/stripe/resources/invoice.rb', line 1709

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1711
1712
1713
# File 'lib/stripe/resources/invoice.rb', line 1711

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1713
1714
1715
# File 'lib/stripe/resources/invoice.rb', line 1713

def promotion_code
  @promotion_code
end