Class: Stripe::Invoice::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



6460
6461
6462
6463
6464
6465
# File 'lib/stripe/resources/invoice.rb', line 6460

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



6449
6450
6451
# File 'lib/stripe/resources/invoice.rb', line 6449

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



6452
6453
6454
# File 'lib/stripe/resources/invoice.rb', line 6452

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



6455
6456
6457
# File 'lib/stripe/resources/invoice.rb', line 6455

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



6458
6459
6460
# File 'lib/stripe/resources/invoice.rb', line 6458

def promotion_code
  @promotion_code
end