Class: Stripe::Invoice::AddLinesParams::Line::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1893 1894 1895 1896 1897 |
# File 'lib/stripe/resources/invoice.rb', line 1893 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1887 1888 1889 |
# File 'lib/stripe/resources/invoice.rb', line 1887 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1889 1890 1891 |
# File 'lib/stripe/resources/invoice.rb', line 1889 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1891 1892 1893 |
# File 'lib/stripe/resources/invoice.rb', line 1891 def type @type end |