Class: Stripe::Invoice::AddLinesParams::Line::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::Period
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
6475 6476 6477 6478 |
# File 'lib/stripe/resources/invoice.rb', line 6475 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
6470 6471 6472 |
# File 'lib/stripe/resources/invoice.rb', line 6470 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
6473 6474 6475 |
# File 'lib/stripe/resources/invoice.rb', line 6473 def start @start end |