Class: Stripe::Invoice::AddLinesParams::Line::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::PriceData::ProductData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
1941 1942 1943 1944 1945 1946 1947 |
# File 'lib/stripe/resources/invoice.rb', line 1941 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
1931 1932 1933 |
# File 'lib/stripe/resources/invoice.rb', line 1931 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
1933 1934 1935 |
# File 'lib/stripe/resources/invoice.rb', line 1933 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1935 1936 1937 |
# File 'lib/stripe/resources/invoice.rb', line 1935 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
1937 1938 1939 |
# File 'lib/stripe/resources/invoice.rb', line 1937 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
1939 1940 1941 |
# File 'lib/stripe/resources/invoice.rb', line 1939 def tax_code @tax_code end |