Class: Stripe::Invoice::AddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1740
1741
1742
1743
1744
1745
1746
# File 'lib/stripe/resources/invoice.rb', line 1740

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1730
1731
1732
# File 'lib/stripe/resources/invoice.rb', line 1730

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1732
1733
1734
# File 'lib/stripe/resources/invoice.rb', line 1732

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1734
1735
1736
# File 'lib/stripe/resources/invoice.rb', line 1734

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1736
1737
1738
# File 'lib/stripe/resources/invoice.rb', line 1736

def name
  @name
end

#tax_codeObject



1738
1739
1740
# File 'lib/stripe/resources/invoice.rb', line 1738

def tax_code
  @tax_code
end