Class: Stripe::Invoice::AddLinesParams::Line::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::PriceData::ProductData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
1747 1748 1749 1750 1751 1752 1753 |
# File 'lib/stripe/resources/invoice.rb', line 1747 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
1737 1738 1739 |
# File 'lib/stripe/resources/invoice.rb', line 1737 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
1739 1740 1741 |
# File 'lib/stripe/resources/invoice.rb', line 1739 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1741 1742 1743 |
# File 'lib/stripe/resources/invoice.rb', line 1741 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
1743 1744 1745 |
# File 'lib/stripe/resources/invoice.rb', line 1743 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
1745 1746 1747 |
# File 'lib/stripe/resources/invoice.rb', line 1745 def tax_code @tax_code end |