Class: Stripe::Invoice::AddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1952
1953
1954
1955
1956
1957
1958
# File 'lib/stripe/resources/invoice.rb', line 1952

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1942
1943
1944
# File 'lib/stripe/resources/invoice.rb', line 1942

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1944
1945
1946
# File 'lib/stripe/resources/invoice.rb', line 1944

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1946
1947
1948
# File 'lib/stripe/resources/invoice.rb', line 1946

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1948
1949
1950
# File 'lib/stripe/resources/invoice.rb', line 1948

def name
  @name
end

#tax_codeObject



1950
1951
1952
# File 'lib/stripe/resources/invoice.rb', line 1950

def tax_code
  @tax_code
end