Class: Stripe::Invoice::AddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



6498
6499
6500
6501
6502
6503
6504
# File 'lib/stripe/resources/invoice.rb', line 6498

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



6484
6485
6486
# File 'lib/stripe/resources/invoice.rb', line 6484

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



6487
6488
6489
# File 'lib/stripe/resources/invoice.rb', line 6487

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6490
6491
6492
# File 'lib/stripe/resources/invoice.rb', line 6490

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



6493
6494
6495
# File 'lib/stripe/resources/invoice.rb', line 6493

def name
  @name
end

#tax_codeObject



6496
6497
6498
# File 'lib/stripe/resources/invoice.rb', line 6496

def tax_code
  @tax_code
end