Class: Stripe::Invoice::AddLinesParams::Line::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AddLinesParams::Line::TaxAmount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: TaxRateData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
5731 5732 5733 5734 5735 |
# File 'lib/stripe/resources/invoice.rb', line 5731 def initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) @amount = amount @tax_rate_data = tax_rate_data @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
5723 5724 5725 |
# File 'lib/stripe/resources/invoice.rb', line 5723 def amount @amount end |
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.
5727 5728 5729 |
# File 'lib/stripe/resources/invoice.rb', line 5727 def tax_rate_data @tax_rate_data end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
5729 5730 5731 |
# File 'lib/stripe/resources/invoice.rb', line 5729 def taxable_amount @taxable_amount end |