Class: Stripe::Invoice::AddLinesParams::Line::TaxAmount::TaxRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData

Returns a new instance of TaxRateData.



2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
# File 'lib/stripe/resources/invoice.rb', line 2009

def initialize(
  country: nil,
  description: nil,
  display_name: nil,
  inclusive: nil,
  jurisdiction: nil,
  jurisdiction_level: nil,
  percentage: nil,
  state: nil,
  tax_type: nil
)
  @country = country
  @description = description
  @display_name = display_name
  @inclusive = inclusive
  @jurisdiction = jurisdiction
  @jurisdiction_level = jurisdiction_level
  @percentage = percentage
  @state = state
  @tax_type = tax_type
end

Instance Attribute Details

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1991
1992
1993
# File 'lib/stripe/resources/invoice.rb', line 1991

def country
  @country
end

#descriptionObject

An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.



1993
1994
1995
# File 'lib/stripe/resources/invoice.rb', line 1993

def description
  @description
end

#display_nameObject

The display name of the tax rate, which will be shown to users.



1995
1996
1997
# File 'lib/stripe/resources/invoice.rb', line 1995

def display_name
  @display_name
end

#inclusiveObject

This specifies if the tax rate is inclusive or exclusive.



1997
1998
1999
# File 'lib/stripe/resources/invoice.rb', line 1997

def inclusive
  @inclusive
end

#jurisdictionObject

The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.



1999
2000
2001
# File 'lib/stripe/resources/invoice.rb', line 1999

def jurisdiction
  @jurisdiction
end

#jurisdiction_levelObject

The level of the jurisdiction that imposes this tax rate.



2001
2002
2003
# File 'lib/stripe/resources/invoice.rb', line 2001

def jurisdiction_level
  @jurisdiction_level
end

#percentageObject

The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.



2003
2004
2005
# File 'lib/stripe/resources/invoice.rb', line 2003

def percentage
  @percentage
end

#stateObject

[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.



2005
2006
2007
# File 'lib/stripe/resources/invoice.rb', line 2005

def state
  @state
end

#tax_typeObject

The high-level tax type, such as ‘vat` or `sales_tax`.



2007
2008
2009
# File 'lib/stripe/resources/invoice.rb', line 2007

def tax_type
  @tax_type
end