Class: Stripe::Invoice::AmountsDue

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Incremental amount due for this payment in cents (or local equivalent).



55
56
57
# File 'lib/stripe/resources/invoice.rb', line 55

def amount
  @amount
end

#amount_paidObject (readonly)

The amount in cents (or local equivalent) that was paid for this payment.



57
58
59
# File 'lib/stripe/resources/invoice.rb', line 57

def amount_paid
  @amount_paid
end

#amount_remainingObject (readonly)

The difference between the payment’s amount and amount_paid, in cents (or local equivalent).



59
60
61
# File 'lib/stripe/resources/invoice.rb', line 59

def amount_remaining
  @amount_remaining
end

#days_until_dueObject (readonly)

Number of days from when invoice is finalized until the payment is due.



61
62
63
# File 'lib/stripe/resources/invoice.rb', line 61

def days_until_due
  @days_until_due
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



63
64
65
# File 'lib/stripe/resources/invoice.rb', line 63

def description
  @description
end

#due_dateObject (readonly)

Date on which a payment plan’s payment is due.



65
66
67
# File 'lib/stripe/resources/invoice.rb', line 65

def due_date
  @due_date
end

Timestamp when the payment was paid.



67
68
69
# File 'lib/stripe/resources/invoice.rb', line 67

def paid_at
  @paid_at
end

#statusObject (readonly)

The status of the payment, one of ‘open`, `paid`, or `past_due`



69
70
71
# File 'lib/stripe/resources/invoice.rb', line 69

def status
  @status
end