Class: Stripe::Invoice::AmountsDue
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::AmountsDue
- Defined in:
- lib/stripe/resources/invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Incremental amount due for this payment in cents (or local equivalent).
-
#amount_paid ⇒ Object
readonly
The amount in cents (or local equivalent) that was paid for this payment.
-
#amount_remaining ⇒ Object
readonly
The difference between the payment’s amount and amount_paid, in cents (or local equivalent).
-
#days_until_due ⇒ Object
readonly
Number of days from when invoice is finalized until the payment is due.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#due_date ⇒ Object
readonly
Date on which a payment plan’s payment is due.
-
#paid_at ⇒ Object
readonly
Timestamp when the payment was paid.
-
#status ⇒ Object
readonly
The status of the payment, one of ‘open`, `paid`, or `past_due`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Incremental amount due for this payment in cents (or local equivalent).
55 56 57 |
# File 'lib/stripe/resources/invoice.rb', line 55 def amount @amount end |
#amount_paid ⇒ Object (readonly)
The amount in cents (or local equivalent) that was paid for this payment.
58 59 60 |
# File 'lib/stripe/resources/invoice.rb', line 58 def amount_paid @amount_paid end |
#amount_remaining ⇒ Object (readonly)
The difference between the payment’s amount and amount_paid, in cents (or local equivalent).
61 62 63 |
# File 'lib/stripe/resources/invoice.rb', line 61 def amount_remaining @amount_remaining end |
#days_until_due ⇒ Object (readonly)
Number of days from when invoice is finalized until the payment is due.
64 65 66 |
# File 'lib/stripe/resources/invoice.rb', line 64 def days_until_due @days_until_due end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
67 68 69 |
# File 'lib/stripe/resources/invoice.rb', line 67 def description @description end |
#due_date ⇒ Object (readonly)
Date on which a payment plan’s payment is due.
70 71 72 |
# File 'lib/stripe/resources/invoice.rb', line 70 def due_date @due_date end |
#paid_at ⇒ Object (readonly)
Timestamp when the payment was paid.
73 74 75 |
# File 'lib/stripe/resources/invoice.rb', line 73 def paid_at @paid_at end |
#status ⇒ Object (readonly)
The status of the payment, one of ‘open`, `paid`, or `past_due`
76 77 78 |
# File 'lib/stripe/resources/invoice.rb', line 76 def status @status end |