Class: Stripe::Invoice::AttachPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
# File 'lib/stripe/resources/invoice.rb', line 2251

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



2241
2242
2243
# File 'lib/stripe/resources/invoice.rb', line 2241

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



2243
2244
2245
# File 'lib/stripe/resources/invoice.rb', line 2243

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



2245
2246
2247
# File 'lib/stripe/resources/invoice.rb', line 2245

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to attach to the invoice.



2247
2248
2249
# File 'lib/stripe/resources/invoice.rb', line 2247

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



2249
2250
2251
# File 'lib/stripe/resources/invoice.rb', line 2249

def payment_record_data
  @payment_record_data
end