Class: Stripe::Invoice::AttachPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AttachPaymentParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil) ⇒ AttachPaymentParams
constructor
A new instance of AttachPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_intent: nil) ⇒ AttachPaymentParams
Returns a new instance of AttachPaymentParams.
1926 1927 1928 1929 |
# File 'lib/stripe/resources/invoice.rb', line 1926 def initialize(expand: nil, payment_intent: nil) @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1922 1923 1924 |
# File 'lib/stripe/resources/invoice.rb', line 1922 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
1924 1925 1926 |
# File 'lib/stripe/resources/invoice.rb', line 1924 def payment_intent @payment_intent end |