Class: Stripe::Invoice::AttachPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



2167
2168
2169
2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
# File 'lib/stripe/resources/invoice.rb', line 2167

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



2157
2158
2159
# File 'lib/stripe/resources/invoice.rb', line 2157

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



2159
2160
2161
# File 'lib/stripe/resources/invoice.rb', line 2159

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



2161
2162
2163
# File 'lib/stripe/resources/invoice.rb', line 2161

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to attach to the invoice.



2163
2164
2165
# File 'lib/stripe/resources/invoice.rb', line 2163

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



2165
2166
2167
# File 'lib/stripe/resources/invoice.rb', line 2165

def payment_record_data
  @payment_record_data
end