Class: Stripe::Invoice::AttachPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
# File 'lib/stripe/resources/invoice.rb', line 2179

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



2169
2170
2171
# File 'lib/stripe/resources/invoice.rb', line 2169

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



2171
2172
2173
# File 'lib/stripe/resources/invoice.rb', line 2171

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



2173
2174
2175
# File 'lib/stripe/resources/invoice.rb', line 2173

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to attach to the invoice.



2175
2176
2177
# File 'lib/stripe/resources/invoice.rb', line 2175

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



2177
2178
2179
# File 'lib/stripe/resources/invoice.rb', line 2177

def payment_record_data
  @payment_record_data
end