Class: Stripe::Invoice::AttachPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AttachPaymentParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: PaymentRecordData
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
-
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
-
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams
constructor
A new instance of AttachPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams
Returns a new instance of AttachPaymentParams.
5850 5851 5852 5853 5854 5855 5856 5857 5858 5859 5860 5861 5862 |
# File 'lib/stripe/resources/invoice.rb', line 5850 def initialize( amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil ) @amount_requested = amount_requested @expand = @payment_intent = payment_intent @payment_record = payment_record @payment_record_data = payment_record_data end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.
5840 5841 5842 |
# File 'lib/stripe/resources/invoice.rb', line 5840 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5842 5843 5844 |
# File 'lib/stripe/resources/invoice.rb', line 5842 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
5844 5845 5846 |
# File 'lib/stripe/resources/invoice.rb', line 5844 def payment_intent @payment_intent end |
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
5846 5847 5848 |
# File 'lib/stripe/resources/invoice.rb', line 5846 def payment_record @payment_record end |
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
5848 5849 5850 |
# File 'lib/stripe/resources/invoice.rb', line 5848 def payment_record_data @payment_record_data end |