Class: Stripe::Invoice::AttachPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



6740
6741
6742
6743
6744
6745
6746
6747
6748
6749
6750
6751
6752
# File 'lib/stripe/resources/invoice.rb', line 6740

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



6726
6727
6728
# File 'lib/stripe/resources/invoice.rb', line 6726

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



6729
6730
6731
# File 'lib/stripe/resources/invoice.rb', line 6729

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



6732
6733
6734
# File 'lib/stripe/resources/invoice.rb', line 6732

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to detach from the invoice.



6735
6736
6737
# File 'lib/stripe/resources/invoice.rb', line 6735

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



6738
6739
6740
# File 'lib/stripe/resources/invoice.rb', line 6738

def payment_record_data
  @payment_record_data
end