Class: Stripe::Invoice::AttachPaymentParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



5850
5851
5852
5853
5854
5855
5856
5857
5858
5859
5860
5861
5862
# File 'lib/stripe/resources/invoice.rb', line 5850

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



5840
5841
5842
# File 'lib/stripe/resources/invoice.rb', line 5840

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



5842
5843
5844
# File 'lib/stripe/resources/invoice.rb', line 5842

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



5844
5845
5846
# File 'lib/stripe/resources/invoice.rb', line 5844

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to detach from the invoice.



5846
5847
5848
# File 'lib/stripe/resources/invoice.rb', line 5846

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



5848
5849
5850
# File 'lib/stripe/resources/invoice.rb', line 5848

def payment_record_data
  @payment_record_data
end