Class: Stripe::Invoice::AttachPaymentParams::PaymentRecordData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AttachPaymentParams::PaymentRecordData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that was paid out of band.
-
#currency ⇒ Object
The currency that was paid out of band.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
-
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
-
#payment_reference ⇒ Object
The reference for this out of band payment record.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
constructor
A new instance of PaymentRecordData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
Returns a new instance of PaymentRecordData.
2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 |
# File 'lib/stripe/resources/invoice.rb', line 2224 def initialize( amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil ) @amount = amount @currency = currency @metadata = @money_movement_type = money_movement_type @paid_at = paid_at @payment_reference = payment_reference end |
Instance Attribute Details
#amount ⇒ Object
The amount that was paid out of band.
2212 2213 2214 |
# File 'lib/stripe/resources/invoice.rb', line 2212 def amount @amount end |
#currency ⇒ Object
The currency that was paid out of band.
2214 2215 2216 |
# File 'lib/stripe/resources/invoice.rb', line 2214 def currency @currency end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2216 2217 2218 |
# File 'lib/stripe/resources/invoice.rb', line 2216 def @metadata end |
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
2218 2219 2220 |
# File 'lib/stripe/resources/invoice.rb', line 2218 def money_movement_type @money_movement_type end |
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
2220 2221 2222 |
# File 'lib/stripe/resources/invoice.rb', line 2220 def paid_at @paid_at end |
#payment_reference ⇒ Object
The reference for this out of band payment record.
2222 2223 2224 |
# File 'lib/stripe/resources/invoice.rb', line 2222 def payment_reference @payment_reference end |