Class: Stripe::Invoice::AttachPaymentParams::PaymentRecordData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData

Returns a new instance of PaymentRecordData.



2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
# File 'lib/stripe/resources/invoice.rb', line 2151

def initialize(
  amount: nil,
  currency: nil,
  metadata: nil,
  money_movement_type: nil,
  paid_at: nil,
  payment_reference: nil
)
  @amount = amount
  @currency = currency
  @metadata = 
  @money_movement_type = money_movement_type
  @paid_at = paid_at
  @payment_reference = payment_reference
end

Instance Attribute Details

#amountObject

The amount that was paid out of band.



2139
2140
2141
# File 'lib/stripe/resources/invoice.rb', line 2139

def amount
  @amount
end

#currencyObject

The currency that was paid out of band.



2141
2142
2143
# File 'lib/stripe/resources/invoice.rb', line 2141

def currency
  @currency
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2143
2144
2145
# File 'lib/stripe/resources/invoice.rb', line 2143

def 
  @metadata
end

#money_movement_typeObject

The type of money movement for this out of band payment record.



2145
2146
2147
# File 'lib/stripe/resources/invoice.rb', line 2145

def money_movement_type
  @money_movement_type
end

The timestamp when this out of band payment was paid.



2147
2148
2149
# File 'lib/stripe/resources/invoice.rb', line 2147

def paid_at
  @paid_at
end

#payment_referenceObject

The reference for this out of band payment record.



2149
2150
2151
# File 'lib/stripe/resources/invoice.rb', line 2149

def payment_reference
  @payment_reference
end