Class: Stripe::Invoice::AttachPaymentParams::PaymentRecordData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AttachPaymentParams::PaymentRecordData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that was paid out of band.
-
#currency ⇒ Object
The currency that was paid out of band.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
-
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
-
#payment_reference ⇒ Object
The reference for this out of band payment record.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
constructor
A new instance of PaymentRecordData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
Returns a new instance of PaymentRecordData.
2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 |
# File 'lib/stripe/resources/invoice.rb', line 2152 def initialize( amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil ) @amount = amount @currency = currency @metadata = @money_movement_type = money_movement_type @paid_at = paid_at @payment_reference = payment_reference end |
Instance Attribute Details
#amount ⇒ Object
The amount that was paid out of band.
2140 2141 2142 |
# File 'lib/stripe/resources/invoice.rb', line 2140 def amount @amount end |
#currency ⇒ Object
The currency that was paid out of band.
2142 2143 2144 |
# File 'lib/stripe/resources/invoice.rb', line 2142 def currency @currency end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2144 2145 2146 |
# File 'lib/stripe/resources/invoice.rb', line 2144 def @metadata end |
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
2146 2147 2148 |
# File 'lib/stripe/resources/invoice.rb', line 2146 def money_movement_type @money_movement_type end |
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
2148 2149 2150 |
# File 'lib/stripe/resources/invoice.rb', line 2148 def paid_at @paid_at end |
#payment_reference ⇒ Object
The reference for this out of band payment record.
2150 2151 2152 |
# File 'lib/stripe/resources/invoice.rb', line 2150 def payment_reference @payment_reference end |