Class: Stripe::Invoice::AttachPaymentParams::PaymentRecordData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::AttachPaymentParams::PaymentRecordData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that was paid out of band.
-
#currency ⇒ Object
The currency that was paid out of band.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
-
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
-
#payment_reference ⇒ Object
The reference for this out of band payment record.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
constructor
A new instance of PaymentRecordData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
Returns a new instance of PaymentRecordData.
5823 5824 5825 5826 5827 5828 5829 5830 5831 5832 5833 5834 5835 5836 5837 |
# File 'lib/stripe/resources/invoice.rb', line 5823 def initialize( amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil ) @amount = amount @currency = currency @metadata = @money_movement_type = money_movement_type @paid_at = paid_at @payment_reference = payment_reference end |
Instance Attribute Details
#amount ⇒ Object
The amount that was paid out of band.
5811 5812 5813 |
# File 'lib/stripe/resources/invoice.rb', line 5811 def amount @amount end |
#currency ⇒ Object
The currency that was paid out of band.
5813 5814 5815 |
# File 'lib/stripe/resources/invoice.rb', line 5813 def currency @currency end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
5815 5816 5817 |
# File 'lib/stripe/resources/invoice.rb', line 5815 def @metadata end |
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
5817 5818 5819 |
# File 'lib/stripe/resources/invoice.rb', line 5817 def money_movement_type @money_movement_type end |
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
5819 5820 5821 |
# File 'lib/stripe/resources/invoice.rb', line 5819 def paid_at @paid_at end |
#payment_reference ⇒ Object
The reference for this out of band payment record.
5821 5822 5823 |
# File 'lib/stripe/resources/invoice.rb', line 5821 def payment_reference @payment_reference end |