Class: Stripe::Invoice::AttachPaymentParams::PaymentRecordData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData

Returns a new instance of PaymentRecordData.



6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
6720
6721
6722
6723
# File 'lib/stripe/resources/invoice.rb', line 6709

def initialize(
  amount: nil,
  currency: nil,
  metadata: nil,
  money_movement_type: nil,
  paid_at: nil,
  payment_reference: nil
)
  @amount = amount
  @currency = currency
  @metadata = 
  @money_movement_type = money_movement_type
  @paid_at = paid_at
  @payment_reference = payment_reference
end

Instance Attribute Details

#amountObject

The amount that was paid out of band.



6692
6693
6694
# File 'lib/stripe/resources/invoice.rb', line 6692

def amount
  @amount
end

#currencyObject

The currency that was paid out of band.



6695
6696
6697
# File 'lib/stripe/resources/invoice.rb', line 6695

def currency
  @currency
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6698
6699
6700
# File 'lib/stripe/resources/invoice.rb', line 6698

def 
  @metadata
end

#money_movement_typeObject

The type of money movement for this out of band payment record.



6701
6702
6703
# File 'lib/stripe/resources/invoice.rb', line 6701

def money_movement_type
  @money_movement_type
end

The timestamp when this out of band payment was paid.



6704
6705
6706
# File 'lib/stripe/resources/invoice.rb', line 6704

def paid_at
  @paid_at
end

#payment_referenceObject

The reference for this out of band payment record.



6707
6708
6709
# File 'lib/stripe/resources/invoice.rb', line 6707

def payment_reference
  @payment_reference
end