Class: Stripe::Invoice::AutomaticTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::AutomaticTax
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Liability
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#disabled_reason ⇒ Object
readonly
If Stripe disabled automatic tax, this enum describes why.
-
#enabled ⇒ Object
readonly
Whether Stripe automatically computes tax on this invoice.
-
#liability ⇒ Object
readonly
The account that’s liable for tax.
-
#provider ⇒ Object
readonly
The tax provider powering automatic tax.
-
#status ⇒ Object
readonly
The status of the most recent automated tax calculation for this invoice.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#disabled_reason ⇒ Object (readonly)
If Stripe disabled automatic tax, this enum describes why.
79 80 81 |
# File 'lib/stripe/resources/invoice.rb', line 79 def disabled_reason @disabled_reason end |
#enabled ⇒ Object (readonly)
Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](stripe.com/docs/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.
81 82 83 |
# File 'lib/stripe/resources/invoice.rb', line 81 def enabled @enabled end |
#liability ⇒ Object (readonly)
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
83 84 85 |
# File 'lib/stripe/resources/invoice.rb', line 83 def liability @liability end |
#provider ⇒ Object (readonly)
The tax provider powering automatic tax.
85 86 87 |
# File 'lib/stripe/resources/invoice.rb', line 85 def provider @provider end |
#status ⇒ Object (readonly)
The status of the most recent automated tax calculation for this invoice.
87 88 89 |
# File 'lib/stripe/resources/invoice.rb', line 87 def status @status end |