Class: Stripe::Invoice::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmountsDue, AutomaticTax, CustomField, Discount, FromInvoice, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, customer_account: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
1789
1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
# File 'lib/stripe/resources/invoice.rb', line 1778

def initialize(
  account_tax_ids: nil,
  amounts_due: nil,
  application_fee_amount: nil,
  auto_advance: nil,
  automatic_tax: nil,
  automatically_finalizes_at: nil,
  collection_method: nil,
  currency: nil,
  custom_fields: nil,
  customer: nil,
  customer_account: nil,
  days_until_due: nil,
  default_margins: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  due_date: nil,
  effective_at: nil,
  expand: nil,
  footer: nil,
  from_invoice: nil,
  issuer: nil,
  metadata: nil,
  number: nil,
  on_behalf_of: nil,
  payment_settings: nil,
  pending_invoice_items_behavior: nil,
  rendering: nil,
  shipping_cost: nil,
  shipping_details: nil,
  statement_descriptor: nil,
  subscription: nil,
  transfer_data: nil
)
  @account_tax_ids = 
  @amounts_due = amounts_due
  @application_fee_amount = application_fee_amount
  @auto_advance = auto_advance
  @automatic_tax = automatic_tax
  @automatically_finalizes_at = automatically_finalizes_at
  @collection_method = collection_method
  @currency = currency
  @custom_fields = custom_fields
  @customer = customer
  @customer_account = 
  @days_until_due = days_until_due
  @default_margins = default_margins
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @due_date = due_date
  @effective_at = effective_at
  @expand = expand
  @footer = footer
  @from_invoice = from_invoice
  @issuer = issuer
  @metadata = 
  @number = number
  @on_behalf_of = on_behalf_of
  @payment_settings = payment_settings
  @pending_invoice_items_behavior = pending_invoice_items_behavior
  @rendering = rendering
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @statement_descriptor = statement_descriptor
  @subscription = subscription
  @transfer_data = transfer_data
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



1708
1709
1710
# File 'lib/stripe/resources/invoice.rb', line 1708

def 
  @account_tax_ids
end

#amounts_dueObject

List of expected payments and corresponding due dates. Valid only for invoices where ‘collection_method=send_invoice`.



1710
1711
1712
# File 'lib/stripe/resources/invoice.rb', line 1710

def amounts_due
  @amounts_due
end

#application_fee_amountObject

A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/billing/invoices/connect#collecting-fees).



1712
1713
1714
# File 'lib/stripe/resources/invoice.rb', line 1712

def application_fee_amount
  @application_fee_amount
end

#auto_advanceObject

Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action.



1714
1715
1716
# File 'lib/stripe/resources/invoice.rb', line 1714

def auto_advance
  @auto_advance
end

#automatic_taxObject

Settings for automatic tax lookup for this invoice.



1716
1717
1718
# File 'lib/stripe/resources/invoice.rb', line 1716

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject

The time when this invoice should be scheduled to finalize. The invoice will be finalized at this time if it is still in draft state.



1718
1719
1720
# File 'lib/stripe/resources/invoice.rb', line 1718

def automatically_finalizes_at
  @automatically_finalizes_at
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions. Defaults to `charge_automatically`.



1720
1721
1722
# File 'lib/stripe/resources/invoice.rb', line 1720

def collection_method
  @collection_method
end

#currencyObject

The currency to create this invoice in. Defaults to that of ‘customer` if not specified.



1722
1723
1724
# File 'lib/stripe/resources/invoice.rb', line 1722

def currency
  @currency
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice.



1724
1725
1726
# File 'lib/stripe/resources/invoice.rb', line 1724

def custom_fields
  @custom_fields
end

#customerObject

The ID of the customer who will be billed.



1726
1727
1728
# File 'lib/stripe/resources/invoice.rb', line 1726

def customer
  @customer
end

#customer_accountObject

The ID of the account who will be billed.



1728
1729
1730
# File 'lib/stripe/resources/invoice.rb', line 1728

def 
  @customer_account
end

#days_until_dueObject

The number of days from when the invoice is created until it is due. Valid only for invoices where ‘collection_method=send_invoice`.



1730
1731
1732
# File 'lib/stripe/resources/invoice.rb', line 1730

def days_until_due
  @days_until_due
end

#default_marginsObject

The ids of the margins to apply to the invoice. Can be overridden by line item ‘margins`.



1732
1733
1734
# File 'lib/stripe/resources/invoice.rb', line 1732

def default_margins
  @default_margins
end

#default_payment_methodObject

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



1734
1735
1736
# File 'lib/stripe/resources/invoice.rb', line 1734

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



1736
1737
1738
# File 'lib/stripe/resources/invoice.rb', line 1736

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set.



1738
1739
1740
# File 'lib/stripe/resources/invoice.rb', line 1738

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



1740
1741
1742
# File 'lib/stripe/resources/invoice.rb', line 1740

def description
  @description
end

#discountsObject

The coupons and promotion codes to redeem into discounts for the invoice. If not specified, inherits the discount from the invoice’s customer. Pass an empty string to avoid inheriting any discounts.



1742
1743
1744
# File 'lib/stripe/resources/invoice.rb', line 1742

def discounts
  @discounts
end

#due_dateObject

The date on which payment for this invoice is due. Valid only for invoices where ‘collection_method=send_invoice`.



1744
1745
1746
# File 'lib/stripe/resources/invoice.rb', line 1744

def due_date
  @due_date
end

#effective_atObject

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



1746
1747
1748
# File 'lib/stripe/resources/invoice.rb', line 1746

def effective_at
  @effective_at
end

#expandObject

Specifies which fields in the response should be expanded.



1748
1749
1750
# File 'lib/stripe/resources/invoice.rb', line 1748

def expand
  @expand
end

Footer to be displayed on the invoice.



1750
1751
1752
# File 'lib/stripe/resources/invoice.rb', line 1750

def footer
  @footer
end

#from_invoiceObject

Revise an existing invoice. The new invoice will be created in ‘status=draft`. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.



1752
1753
1754
# File 'lib/stripe/resources/invoice.rb', line 1752

def from_invoice
  @from_invoice
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



1754
1755
1756
# File 'lib/stripe/resources/invoice.rb', line 1754

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1756
1757
1758
# File 'lib/stripe/resources/invoice.rb', line 1756

def 
  @metadata
end

#numberObject

Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.



1758
1759
1760
# File 'lib/stripe/resources/invoice.rb', line 1758

def number
  @number
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



1760
1761
1762
# File 'lib/stripe/resources/invoice.rb', line 1760

def on_behalf_of
  @on_behalf_of
end

#payment_settingsObject

Configuration settings for the PaymentIntent that is generated when the invoice is finalized.



1762
1763
1764
# File 'lib/stripe/resources/invoice.rb', line 1762

def payment_settings
  @payment_settings
end

#pending_invoice_items_behaviorObject

How to handle pending invoice items on invoice creation. Defaults to ‘exclude` if the parameter is omitted.



1764
1765
1766
# File 'lib/stripe/resources/invoice.rb', line 1764

def pending_invoice_items_behavior
  @pending_invoice_items_behavior
end

#renderingObject

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



1766
1767
1768
# File 'lib/stripe/resources/invoice.rb', line 1766

def rendering
  @rendering
end

#shipping_costObject

Settings for the cost of shipping for this invoice.



1768
1769
1770
# File 'lib/stripe/resources/invoice.rb', line 1768

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



1770
1771
1772
# File 'lib/stripe/resources/invoice.rb', line 1770

def shipping_details
  @shipping_details
end

#statement_descriptorObject

Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.



1772
1773
1774
# File 'lib/stripe/resources/invoice.rb', line 1772

def statement_descriptor
  @statement_descriptor
end

#subscriptionObject

The ID of the subscription to invoice, if any. If set, the created invoice will only include pending invoice items for that subscription. The subscription’s billing cycle and regular subscription events won’t be affected.



1774
1775
1776
# File 'lib/stripe/resources/invoice.rb', line 1774

def subscription
  @subscription
end

#transfer_dataObject

If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.



1776
1777
1778
# File 'lib/stripe/resources/invoice.rb', line 1776

def transfer_data
  @transfer_data
end