Class: Stripe::Invoice::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AutomaticTax, CustomField, Discount, FromInvoice, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
-
#application_fee_amount ⇒ Object
A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account.
-
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this invoice.
-
#automatically_finalizes_at ⇒ Object
The time when this invoice should be scheduled to finalize.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#currency ⇒ Object
The currency to create this invoice in.
-
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
-
#customer ⇒ Object
The ID of the customer who will be billed.
-
#days_until_due ⇒ Object
The number of days from when the invoice is created until it is due.
-
#default_payment_method ⇒ Object
ID of the default payment method for the invoice.
-
#default_source ⇒ Object
ID of the default payment source for the invoice.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons and promotion codes to redeem into discounts for the invoice.
-
#due_date ⇒ Object
The date on which payment for this invoice is due.
-
#effective_at ⇒ Object
The date when this invoice is in effect.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#footer ⇒ Object
Footer to be displayed on the invoice.
-
#from_invoice ⇒ Object
Revise an existing invoice.
-
#issuer ⇒ Object
The connected account that issues the invoice.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#number ⇒ Object
Set the number for this invoice.
-
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the invoice payment are intended.
-
#payment_settings ⇒ Object
Configuration settings for the PaymentIntent that is generated when the invoice is finalized.
-
#pending_invoice_items_behavior ⇒ Object
How to handle pending invoice items on invoice creation.
-
#rendering ⇒ Object
The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.
-
#shipping_cost ⇒ Object
Settings for the cost of shipping for this invoice.
-
#shipping_details ⇒ Object
Shipping details for the invoice.
-
#statement_descriptor ⇒ Object
Extra information about a charge for the customer’s credit card statement.
-
#subscription ⇒ Object
The ID of the subscription to invoice, if any.
-
#transfer_data ⇒ Object
If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(account_tax_ids: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 |
# File 'lib/stripe/resources/invoice.rb', line 1611 def initialize( account_tax_ids: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, days_until_due: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil ) @account_tax_ids = account_tax_ids @application_fee_amount = application_fee_amount @auto_advance = auto_advance @automatic_tax = automatic_tax @automatically_finalizes_at = automatically_finalizes_at @collection_method = collection_method @currency = currency @custom_fields = custom_fields @customer = customer @days_until_due = days_until_due @default_payment_method = default_payment_method @default_source = default_source @default_tax_rates = default_tax_rates @description = description @discounts = discounts @due_date = due_date @effective_at = effective_at @expand = @footer = @from_invoice = from_invoice @issuer = issuer @metadata = @number = number @on_behalf_of = on_behalf_of @payment_settings = payment_settings @pending_invoice_items_behavior = pending_invoice_items_behavior @rendering = rendering @shipping_cost = shipping_cost @shipping_details = shipping_details @statement_descriptor = statement_descriptor @subscription = subscription @transfer_data = transfer_data end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice. Only editable when the invoice is a draft.
1547 1548 1549 |
# File 'lib/stripe/resources/invoice.rb', line 1547 def account_tax_ids @account_tax_ids end |
#application_fee_amount ⇒ Object
A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/billing/invoices/connect#collecting-fees).
1549 1550 1551 |
# File 'lib/stripe/resources/invoice.rb', line 1549 def application_fee_amount @application_fee_amount end |
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action.
1551 1552 1553 |
# File 'lib/stripe/resources/invoice.rb', line 1551 def auto_advance @auto_advance end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this invoice.
1553 1554 1555 |
# File 'lib/stripe/resources/invoice.rb', line 1553 def automatic_tax @automatic_tax end |
#automatically_finalizes_at ⇒ Object
The time when this invoice should be scheduled to finalize. The invoice will be finalized at this time if it is still in draft state.
1555 1556 1557 |
# File 'lib/stripe/resources/invoice.rb', line 1555 def automatically_finalizes_at @automatically_finalizes_at end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions. Defaults to `charge_automatically`.
1557 1558 1559 |
# File 'lib/stripe/resources/invoice.rb', line 1557 def collection_method @collection_method end |
#currency ⇒ Object
The currency to create this invoice in. Defaults to that of ‘customer` if not specified.
1559 1560 1561 |
# File 'lib/stripe/resources/invoice.rb', line 1559 def currency @currency end |
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
1561 1562 1563 |
# File 'lib/stripe/resources/invoice.rb', line 1561 def custom_fields @custom_fields end |
#customer ⇒ Object
The ID of the customer who will be billed.
1563 1564 1565 |
# File 'lib/stripe/resources/invoice.rb', line 1563 def customer @customer end |
#days_until_due ⇒ Object
The number of days from when the invoice is created until it is due. Valid only for invoices where ‘collection_method=send_invoice`.
1565 1566 1567 |
# File 'lib/stripe/resources/invoice.rb', line 1565 def days_until_due @days_until_due end |
#default_payment_method ⇒ Object
ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.
1567 1568 1569 |
# File 'lib/stripe/resources/invoice.rb', line 1567 def default_payment_method @default_payment_method end |
#default_source ⇒ Object
ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.
1569 1570 1571 |
# File 'lib/stripe/resources/invoice.rb', line 1569 def default_source @default_source end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
1571 1572 1573 |
# File 'lib/stripe/resources/invoice.rb', line 1571 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.
1573 1574 1575 |
# File 'lib/stripe/resources/invoice.rb', line 1573 def description @description end |
#discounts ⇒ Object
The coupons and promotion codes to redeem into discounts for the invoice. If not specified, inherits the discount from the invoice’s customer. Pass an empty string to avoid inheriting any discounts.
1575 1576 1577 |
# File 'lib/stripe/resources/invoice.rb', line 1575 def discounts @discounts end |
#due_date ⇒ Object
The date on which payment for this invoice is due. Valid only for invoices where ‘collection_method=send_invoice`.
1577 1578 1579 |
# File 'lib/stripe/resources/invoice.rb', line 1577 def due_date @due_date end |
#effective_at ⇒ Object
The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.
1579 1580 1581 |
# File 'lib/stripe/resources/invoice.rb', line 1579 def effective_at @effective_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1581 1582 1583 |
# File 'lib/stripe/resources/invoice.rb', line 1581 def @expand end |
#footer ⇒ Object
Footer to be displayed on the invoice.
1583 1584 1585 |
# File 'lib/stripe/resources/invoice.rb', line 1583 def @footer end |
#from_invoice ⇒ Object
Revise an existing invoice. The new invoice will be created in ‘status=draft`. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.
1585 1586 1587 |
# File 'lib/stripe/resources/invoice.rb', line 1585 def from_invoice @from_invoice end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
1587 1588 1589 |
# File 'lib/stripe/resources/invoice.rb', line 1587 def issuer @issuer end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1589 1590 1591 |
# File 'lib/stripe/resources/invoice.rb', line 1589 def @metadata end |
#number ⇒ Object
Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.
1591 1592 1593 |
# File 'lib/stripe/resources/invoice.rb', line 1591 def number @number end |
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.
1593 1594 1595 |
# File 'lib/stripe/resources/invoice.rb', line 1593 def on_behalf_of @on_behalf_of end |
#payment_settings ⇒ Object
Configuration settings for the PaymentIntent that is generated when the invoice is finalized.
1595 1596 1597 |
# File 'lib/stripe/resources/invoice.rb', line 1595 def payment_settings @payment_settings end |
#pending_invoice_items_behavior ⇒ Object
How to handle pending invoice items on invoice creation. Defaults to ‘exclude` if the parameter is omitted.
1597 1598 1599 |
# File 'lib/stripe/resources/invoice.rb', line 1597 def pending_invoice_items_behavior @pending_invoice_items_behavior end |
#rendering ⇒ Object
The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.
1599 1600 1601 |
# File 'lib/stripe/resources/invoice.rb', line 1599 def rendering @rendering end |
#shipping_cost ⇒ Object
Settings for the cost of shipping for this invoice.
1601 1602 1603 |
# File 'lib/stripe/resources/invoice.rb', line 1601 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.
1603 1604 1605 |
# File 'lib/stripe/resources/invoice.rb', line 1603 def shipping_details @shipping_details end |
#statement_descriptor ⇒ Object
Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.
1605 1606 1607 |
# File 'lib/stripe/resources/invoice.rb', line 1605 def statement_descriptor @statement_descriptor end |
#subscription ⇒ Object
The ID of the subscription to invoice, if any. If set, the created invoice will only include pending invoice items for that subscription. The subscription’s billing cycle and regular subscription events won’t be affected.
1607 1608 1609 |
# File 'lib/stripe/resources/invoice.rb', line 1607 def subscription @subscription end |
#transfer_data ⇒ Object
If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.
1609 1610 1611 |
# File 'lib/stripe/resources/invoice.rb', line 1609 def transfer_data @transfer_data end |