Class: Stripe::Invoice::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AmountsDue, AutomaticTax, CustomField, Discount, FromInvoice, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
-
#amounts_due ⇒ Object
List of expected payments and corresponding due dates.
-
#application_fee_amount ⇒ Object
A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account.
-
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this invoice.
-
#automatically_finalizes_at ⇒ Object
The time when this invoice should be scheduled to finalize.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#currency ⇒ Object
The currency to create this invoice in.
-
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
-
#customer ⇒ Object
The ID of the customer who will be billed.
-
#days_until_due ⇒ Object
The number of days from when the invoice is created until it is due.
-
#default_margins ⇒ Object
The ids of the margins to apply to the invoice.
-
#default_payment_method ⇒ Object
ID of the default payment method for the invoice.
-
#default_source ⇒ Object
ID of the default payment source for the invoice.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons and promotion codes to redeem into discounts for the invoice.
-
#due_date ⇒ Object
The date on which payment for this invoice is due.
-
#effective_at ⇒ Object
The date when this invoice is in effect.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#footer ⇒ Object
Footer to be displayed on the invoice.
-
#from_invoice ⇒ Object
Revise an existing invoice.
-
#issuer ⇒ Object
The connected account that issues the invoice.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#number ⇒ Object
Set the number for this invoice.
-
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the invoice payment are intended.
-
#payment_settings ⇒ Object
Configuration settings for the PaymentIntent that is generated when the invoice is finalized.
-
#pending_invoice_items_behavior ⇒ Object
How to handle pending invoice items on invoice creation.
-
#rendering ⇒ Object
The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.
-
#shipping_cost ⇒ Object
Settings for the cost of shipping for this invoice.
-
#shipping_details ⇒ Object
Shipping details for the invoice.
-
#statement_descriptor ⇒ Object
Extra information about a charge for the customer’s credit card statement.
-
#subscription ⇒ Object
The ID of the subscription to invoice, if any.
-
#transfer_data ⇒ Object
If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 2096 2097 2098 2099 2100 2101 2102 2103 2104 2105 2106 2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 2124 |
# File 'lib/stripe/resources/invoice.rb', line 2054 def initialize( account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil ) @account_tax_ids = account_tax_ids @amounts_due = amounts_due @application_fee_amount = application_fee_amount @auto_advance = auto_advance @automatic_tax = automatic_tax @automatically_finalizes_at = automatically_finalizes_at @collection_method = collection_method @currency = currency @custom_fields = custom_fields @customer = customer @days_until_due = days_until_due @default_margins = default_margins @default_payment_method = default_payment_method @default_source = default_source @default_tax_rates = default_tax_rates @description = description @discounts = discounts @due_date = due_date @effective_at = effective_at @expand = @footer = @from_invoice = from_invoice @issuer = issuer @metadata = @number = number @on_behalf_of = on_behalf_of @payment_settings = payment_settings @pending_invoice_items_behavior = pending_invoice_items_behavior @rendering = rendering @shipping_cost = shipping_cost @shipping_details = shipping_details @statement_descriptor = statement_descriptor @subscription = subscription @transfer_data = transfer_data end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice. Only editable when the invoice is a draft.
1953 1954 1955 |
# File 'lib/stripe/resources/invoice.rb', line 1953 def account_tax_ids @account_tax_ids end |
#amounts_due ⇒ Object
List of expected payments and corresponding due dates. Valid only for invoices where ‘collection_method=send_invoice`.
1956 1957 1958 |
# File 'lib/stripe/resources/invoice.rb', line 1956 def amounts_due @amounts_due end |
#application_fee_amount ⇒ Object
A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/billing/invoices/connect#collecting-fees).
1959 1960 1961 |
# File 'lib/stripe/resources/invoice.rb', line 1959 def application_fee_amount @application_fee_amount end |
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action.
1962 1963 1964 |
# File 'lib/stripe/resources/invoice.rb', line 1962 def auto_advance @auto_advance end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this invoice.
1965 1966 1967 |
# File 'lib/stripe/resources/invoice.rb', line 1965 def automatic_tax @automatic_tax end |
#automatically_finalizes_at ⇒ Object
The time when this invoice should be scheduled to finalize. The invoice will be finalized at this time if it is still in draft state.
1968 1969 1970 |
# File 'lib/stripe/resources/invoice.rb', line 1968 def automatically_finalizes_at @automatically_finalizes_at end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions. Defaults to `charge_automatically`.
1971 1972 1973 |
# File 'lib/stripe/resources/invoice.rb', line 1971 def collection_method @collection_method end |
#currency ⇒ Object
The currency to create this invoice in. Defaults to that of ‘customer` if not specified.
1974 1975 1976 |
# File 'lib/stripe/resources/invoice.rb', line 1974 def currency @currency end |
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
1977 1978 1979 |
# File 'lib/stripe/resources/invoice.rb', line 1977 def custom_fields @custom_fields end |
#customer ⇒ Object
The ID of the customer who will be billed.
1980 1981 1982 |
# File 'lib/stripe/resources/invoice.rb', line 1980 def customer @customer end |
#days_until_due ⇒ Object
The number of days from when the invoice is created until it is due. Valid only for invoices where ‘collection_method=send_invoice`.
1983 1984 1985 |
# File 'lib/stripe/resources/invoice.rb', line 1983 def days_until_due @days_until_due end |
#default_margins ⇒ Object
The ids of the margins to apply to the invoice. Can be overridden by line item ‘margins`.
1986 1987 1988 |
# File 'lib/stripe/resources/invoice.rb', line 1986 def default_margins @default_margins end |
#default_payment_method ⇒ Object
ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.
1989 1990 1991 |
# File 'lib/stripe/resources/invoice.rb', line 1989 def default_payment_method @default_payment_method end |
#default_source ⇒ Object
ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.
1992 1993 1994 |
# File 'lib/stripe/resources/invoice.rb', line 1992 def default_source @default_source end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
1995 1996 1997 |
# File 'lib/stripe/resources/invoice.rb', line 1995 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.
1998 1999 2000 |
# File 'lib/stripe/resources/invoice.rb', line 1998 def description @description end |
#discounts ⇒ Object
The coupons and promotion codes to redeem into discounts for the invoice. If not specified, inherits the discount from the invoice’s customer. Pass an empty string to avoid inheriting any discounts.
2001 2002 2003 |
# File 'lib/stripe/resources/invoice.rb', line 2001 def discounts @discounts end |
#due_date ⇒ Object
The date on which payment for this invoice is due. Valid only for invoices where ‘collection_method=send_invoice`.
2004 2005 2006 |
# File 'lib/stripe/resources/invoice.rb', line 2004 def due_date @due_date end |
#effective_at ⇒ Object
The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.
2007 2008 2009 |
# File 'lib/stripe/resources/invoice.rb', line 2007 def effective_at @effective_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2010 2011 2012 |
# File 'lib/stripe/resources/invoice.rb', line 2010 def @expand end |
#footer ⇒ Object
Footer to be displayed on the invoice.
2013 2014 2015 |
# File 'lib/stripe/resources/invoice.rb', line 2013 def @footer end |
#from_invoice ⇒ Object
Revise an existing invoice. The new invoice will be created in ‘status=draft`. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.
2016 2017 2018 |
# File 'lib/stripe/resources/invoice.rb', line 2016 def from_invoice @from_invoice end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
2019 2020 2021 |
# File 'lib/stripe/resources/invoice.rb', line 2019 def issuer @issuer end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2022 2023 2024 |
# File 'lib/stripe/resources/invoice.rb', line 2022 def @metadata end |
#number ⇒ Object
Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.
2025 2026 2027 |
# File 'lib/stripe/resources/invoice.rb', line 2025 def number @number end |
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.
2028 2029 2030 |
# File 'lib/stripe/resources/invoice.rb', line 2028 def on_behalf_of @on_behalf_of end |
#payment_settings ⇒ Object
Configuration settings for the PaymentIntent that is generated when the invoice is finalized.
2031 2032 2033 |
# File 'lib/stripe/resources/invoice.rb', line 2031 def payment_settings @payment_settings end |
#pending_invoice_items_behavior ⇒ Object
How to handle pending invoice items on invoice creation. Defaults to ‘exclude` if the parameter is omitted.
2034 2035 2036 |
# File 'lib/stripe/resources/invoice.rb', line 2034 def pending_invoice_items_behavior @pending_invoice_items_behavior end |
#rendering ⇒ Object
The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.
2037 2038 2039 |
# File 'lib/stripe/resources/invoice.rb', line 2037 def rendering @rendering end |
#shipping_cost ⇒ Object
Settings for the cost of shipping for this invoice.
2040 2041 2042 |
# File 'lib/stripe/resources/invoice.rb', line 2040 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.
2043 2044 2045 |
# File 'lib/stripe/resources/invoice.rb', line 2043 def shipping_details @shipping_details end |
#statement_descriptor ⇒ Object
Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.
2046 2047 2048 |
# File 'lib/stripe/resources/invoice.rb', line 2046 def statement_descriptor @statement_descriptor end |
#subscription ⇒ Object
The ID of the subscription to invoice, if any. If set, the created invoice will only include pending invoice items for that subscription. The subscription’s billing cycle and regular subscription events won’t be affected.
2049 2050 2051 |
# File 'lib/stripe/resources/invoice.rb', line 2049 def subscription @subscription end |
#transfer_data ⇒ Object
If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.
2052 2053 2054 |
# File 'lib/stripe/resources/invoice.rb', line 2052 def transfer_data @transfer_data end |