Class: Stripe::Invoice::CreateParams::AmountsDue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::AmountsDue
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount in cents (or local equivalent).
-
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
Instance Method Summary collapse
-
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
constructor
A new instance of AmountsDue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
Returns a new instance of AmountsDue.
1398 1399 1400 1401 1402 1403 |
# File 'lib/stripe/resources/invoice.rb', line 1398 def initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) @amount = amount @days_until_due = days_until_due @description = description @due_date = due_date end |
Instance Attribute Details
#amount ⇒ Object
The amount in cents (or local equivalent).
1387 1388 1389 |
# File 'lib/stripe/resources/invoice.rb', line 1387 def amount @amount end |
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
1390 1391 1392 |
# File 'lib/stripe/resources/invoice.rb', line 1390 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1393 1394 1395 |
# File 'lib/stripe/resources/invoice.rb', line 1393 def description @description end |
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
1396 1397 1398 |
# File 'lib/stripe/resources/invoice.rb', line 1396 def due_date @due_date end |