Class: Stripe::Invoice::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1753
1754
1755
1756
1757
1758
# File 'lib/stripe/resources/invoice.rb', line 1753

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1745
1746
1747
# File 'lib/stripe/resources/invoice.rb', line 1745

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1747
1748
1749
# File 'lib/stripe/resources/invoice.rb', line 1747

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1749
1750
1751
# File 'lib/stripe/resources/invoice.rb', line 1749

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1751
1752
1753
# File 'lib/stripe/resources/invoice.rb', line 1751

def promotion_code
  @promotion_code
end