Class: Stripe::Invoice::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1338
1339
1340
1341
1342
1343
# File 'lib/stripe/resources/invoice.rb', line 1338

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1330
1331
1332
# File 'lib/stripe/resources/invoice.rb', line 1330

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1332
1333
1334
# File 'lib/stripe/resources/invoice.rb', line 1332

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1334
1335
1336
# File 'lib/stripe/resources/invoice.rb', line 1334

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1336
1337
1338
# File 'lib/stripe/resources/invoice.rb', line 1336

def promotion_code
  @promotion_code
end