Class: Stripe::Invoice::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1291
1292
1293
1294
1295
1296
# File 'lib/stripe/resources/invoice.rb', line 1291

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1283
1284
1285
# File 'lib/stripe/resources/invoice.rb', line 1283

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1285
1286
1287
# File 'lib/stripe/resources/invoice.rb', line 1285

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1287
1288
1289
# File 'lib/stripe/resources/invoice.rb', line 1287

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1289
1290
1291
# File 'lib/stripe/resources/invoice.rb', line 1289

def promotion_code
  @promotion_code
end