Class: Stripe::Invoice::CreateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1485
1486
1487
1488
1489
1490
# File 'lib/stripe/resources/invoice.rb', line 1485

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1474
1475
1476
# File 'lib/stripe/resources/invoice.rb', line 1474

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1477
1478
1479
# File 'lib/stripe/resources/invoice.rb', line 1477

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1480
1481
1482
# File 'lib/stripe/resources/invoice.rb', line 1480

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1483
1484
1485
# File 'lib/stripe/resources/invoice.rb', line 1483

def promotion_code
  @promotion_code
end