Class: Stripe::Invoice::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1276 1277 1278 1279 1280 |
# File 'lib/stripe/resources/invoice.rb', line 1276 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1270 1271 1272 |
# File 'lib/stripe/resources/invoice.rb', line 1270 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1272 1273 1274 |
# File 'lib/stripe/resources/invoice.rb', line 1272 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1274 1275 1276 |
# File 'lib/stripe/resources/invoice.rb', line 1274 def type @type end |