Class: Stripe::Invoice::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1283 1284 1285 1286 1287 |
# File 'lib/stripe/resources/invoice.rb', line 1283 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1277 1278 1279 |
# File 'lib/stripe/resources/invoice.rb', line 1277 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1279 1280 1281 |
# File 'lib/stripe/resources/invoice.rb', line 1279 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1281 1282 1283 |
# File 'lib/stripe/resources/invoice.rb', line 1281 def type @type end |