Class: Stripe::Invoice::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1467
1468
1469
1470
1471
# File 'lib/stripe/resources/invoice.rb', line 1467

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1459
1460
1461
# File 'lib/stripe/resources/invoice.rb', line 1459

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1462
1463
1464
# File 'lib/stripe/resources/invoice.rb', line 1462

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1465
1466
1467
# File 'lib/stripe/resources/invoice.rb', line 1465

def type
  @type
end