Class: Stripe::Invoice::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1263 1264 1265 1266 1267 |
# File 'lib/stripe/resources/invoice.rb', line 1263 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1257 1258 1259 |
# File 'lib/stripe/resources/invoice.rb', line 1257 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1259 1260 1261 |
# File 'lib/stripe/resources/invoice.rb', line 1259 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1261 1262 1263 |
# File 'lib/stripe/resources/invoice.rb', line 1261 def type @type end |