Class: Stripe::Invoice::CreateParams::FromInvoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::FromInvoice
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
The relation between the new invoice and the original invoice.
-
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
Instance Method Summary collapse
-
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
constructor
A new instance of FromInvoice.
Methods inherited from RequestParams
Constructor Details
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
Returns a new instance of FromInvoice.
1352 1353 1354 1355 |
# File 'lib/stripe/resources/invoice.rb', line 1352 def initialize(action: nil, invoice: nil) @action = action @invoice = invoice end |
Instance Attribute Details
#action ⇒ Object
The relation between the new invoice and the original invoice. Currently, only ‘revision’ is permitted
1348 1349 1350 |
# File 'lib/stripe/resources/invoice.rb', line 1348 def action @action end |
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
1350 1351 1352 |
# File 'lib/stripe/resources/invoice.rb', line 1350 def invoice @invoice end |