Class: Stripe::Invoice::CreateParams::PaymentSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::PaymentSettings
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: PaymentMethodOptions
Instance Attribute Summary collapse
-
#default_mandate ⇒ Object
ID of the mandate to be used for this invoice.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to the invoice’s PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil) ⇒ PaymentSettings
constructor
A new instance of PaymentSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil) ⇒ PaymentSettings
Returns a new instance of PaymentSettings.
1731 1732 1733 1734 1735 |
# File 'lib/stripe/resources/invoice.rb', line 1731 def initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil) @default_mandate = default_mandate @payment_method_options = @payment_method_types = payment_method_types end |
Instance Attribute Details
#default_mandate ⇒ Object
ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the invoice’s default_payment_method or default_source, if set.
1723 1724 1725 |
# File 'lib/stripe/resources/invoice.rb', line 1723 def default_mandate @default_mandate end |
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to the invoice’s PaymentIntent.
1726 1727 1728 |
# File 'lib/stripe/resources/invoice.rb', line 1726 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice). Should not be specified with payment_method_configuration
1729 1730 1731 |
# File 'lib/stripe/resources/invoice.rb', line 1729 def payment_method_types @payment_method_types end |