Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
# File 'lib/stripe/resources/invoice.rb', line 1973

def initialize(
  acss_debit: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



1955
1956
1957
# File 'lib/stripe/resources/invoice.rb', line 1955

def acss_debit
  @acss_debit
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



1957
1958
1959
# File 'lib/stripe/resources/invoice.rb', line 1957

def bancontact
  @bancontact
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



1959
1960
1961
# File 'lib/stripe/resources/invoice.rb', line 1959

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



1961
1962
1963
# File 'lib/stripe/resources/invoice.rb', line 1961

def customer_balance
  @customer_balance
end

#id_bank_transferObject

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



1963
1964
1965
# File 'lib/stripe/resources/invoice.rb', line 1963

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



1965
1966
1967
# File 'lib/stripe/resources/invoice.rb', line 1965

def konbini
  @konbini
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



1967
1968
1969
# File 'lib/stripe/resources/invoice.rb', line 1967

def sepa_debit
  @sepa_debit
end

#upiObject

If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



1969
1970
1971
# File 'lib/stripe/resources/invoice.rb', line 1969

def upi
  @upi
end

#us_bank_accountObject

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



1971
1972
1973
# File 'lib/stripe/resources/invoice.rb', line 1971

def 
  @us_bank_account
end