Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, Konbini, SepaDebit, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
1344
1345
# File 'lib/stripe/resources/invoice.rb', line 1329

def initialize(
  acss_debit: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  konbini: nil,
  sepa_debit: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @konbini = konbini
  @sepa_debit = sepa_debit
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



1315
1316
1317
# File 'lib/stripe/resources/invoice.rb', line 1315

def acss_debit
  @acss_debit
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



1317
1318
1319
# File 'lib/stripe/resources/invoice.rb', line 1317

def bancontact
  @bancontact
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



1319
1320
1321
# File 'lib/stripe/resources/invoice.rb', line 1319

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



1321
1322
1323
# File 'lib/stripe/resources/invoice.rb', line 1321

def customer_balance
  @customer_balance
end

#konbiniObject

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



1323
1324
1325
# File 'lib/stripe/resources/invoice.rb', line 1323

def konbini
  @konbini
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



1325
1326
1327
# File 'lib/stripe/resources/invoice.rb', line 1325

def sepa_debit
  @sepa_debit
end

#us_bank_accountObject

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



1327
1328
1329
# File 'lib/stripe/resources/invoice.rb', line 1327

def 
  @us_bank_account
end