Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this invoice.
-
#plan ⇒ Object
The selected installment plan to use for this invoice.
Instance Method Summary collapse
-
#initialize(enabled: nil, plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, plan: nil) ⇒ Installments
Returns a new instance of Installments.
1839 1840 1841 1842 |
# File 'lib/stripe/resources/invoice.rb', line 1839 def initialize(enabled: nil, plan: nil) @enabled = enabled @plan = plan end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.
1835 1836 1837 |
# File 'lib/stripe/resources/invoice.rb', line 1835 def enabled @enabled end |
#plan ⇒ Object
The selected installment plan to use for this invoice.
1837 1838 1839 |
# File 'lib/stripe/resources/invoice.rb', line 1837 def plan @plan end |