Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



1424
1425
1426
1427
# File 'lib/stripe/resources/invoice.rb', line 1424

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.



1420
1421
1422
# File 'lib/stripe/resources/invoice.rb', line 1420

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this invoice.



1422
1423
1424
# File 'lib/stripe/resources/invoice.rb', line 1422

def plan
  @plan
end