Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



1224
1225
1226
1227
# File 'lib/stripe/resources/invoice.rb', line 1224

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.



1220
1221
1222
# File 'lib/stripe/resources/invoice.rb', line 1220

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this invoice.



1222
1223
1224
# File 'lib/stripe/resources/invoice.rb', line 1222

def plan
  @plan
end