Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this invoice.
-
#plan ⇒ Object
The selected installment plan to use for this invoice.
Instance Method Summary collapse
-
#initialize(enabled: nil, plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, plan: nil) ⇒ Installments
Returns a new instance of Installments.
1384 1385 1386 1387 |
# File 'lib/stripe/resources/invoice.rb', line 1384 def initialize(enabled: nil, plan: nil) @enabled = enabled @plan = plan end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.
1380 1381 1382 |
# File 'lib/stripe/resources/invoice.rb', line 1380 def enabled @enabled end |
#plan ⇒ Object
The selected installment plan to use for this invoice.
1382 1383 1384 |
# File 'lib/stripe/resources/invoice.rb', line 1382 def plan @plan end |