Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



1364
1365
1366
1367
# File 'lib/stripe/resources/invoice.rb', line 1364

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.



1360
1361
1362
# File 'lib/stripe/resources/invoice.rb', line 1360

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this invoice.



1362
1363
1364
# File 'lib/stripe/resources/invoice.rb', line 1362

def plan
  @plan
end