Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1371
1372
1373
1374
1375
# File 'lib/stripe/resources/invoice.rb', line 1371

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1364
1365
1366
# File 'lib/stripe/resources/invoice.rb', line 1364

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1367
1368
1369
# File 'lib/stripe/resources/invoice.rb', line 1367

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



1369
1370
1371
# File 'lib/stripe/resources/invoice.rb', line 1369

def type
  @type
end