Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1352
1353
1354
1355
1356
# File 'lib/stripe/resources/invoice.rb', line 1352

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1345
1346
1347
# File 'lib/stripe/resources/invoice.rb', line 1345

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1348
1349
1350
# File 'lib/stripe/resources/invoice.rb', line 1348

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



1350
1351
1352
# File 'lib/stripe/resources/invoice.rb', line 1350

def type
  @type
end