Class: Stripe::Invoice::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



1564
1565
1566
1567
1568
# File 'lib/stripe/resources/invoice.rb', line 1564

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



1555
1556
1557
# File 'lib/stripe/resources/invoice.rb', line 1555

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



1559
1560
1561
# File 'lib/stripe/resources/invoice.rb', line 1559

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



1562
1563
1564
# File 'lib/stripe/resources/invoice.rb', line 1562

def type
  @type
end