Class: Stripe::Invoice::CreateParams::Rendering

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering

Returns a new instance of Rendering.



1537
1538
1539
1540
1541
1542
# File 'lib/stripe/resources/invoice.rb', line 1537

def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil)
  @amount_tax_display = amount_tax_display
  @pdf = pdf
  @template = template
  @template_version = template_version
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



1529
1530
1531
# File 'lib/stripe/resources/invoice.rb', line 1529

def amount_tax_display
  @amount_tax_display
end

#pdfObject

Invoice pdf rendering options



1531
1532
1533
# File 'lib/stripe/resources/invoice.rb', line 1531

def pdf
  @pdf
end

#templateObject

ID of the invoice rendering template to use for this invoice.



1533
1534
1535
# File 'lib/stripe/resources/invoice.rb', line 1533

def template
  @template
end

#template_versionObject

The specific version of invoice rendering template to use for this invoice.



1535
1536
1537
# File 'lib/stripe/resources/invoice.rb', line 1535

def template_version
  @template_version
end