Class: Stripe::Invoice::CreateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions

Returns a new instance of CurrencyOptions.



1600
1601
1602
1603
# File 'lib/stripe/resources/invoice.rb', line 1600

def initialize(amount: nil, tax_behavior: nil)
  @amount = amount
  @tax_behavior = tax_behavior
end

Instance Attribute Details

#amountObject

A non-negative integer in cents representing how much to charge.



1596
1597
1598
# File 'lib/stripe/resources/invoice.rb', line 1596

def amount
  @amount
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



1598
1599
1600
# File 'lib/stripe/resources/invoice.rb', line 1598

def tax_behavior
  @tax_behavior
end