Class: Stripe::Invoice::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2194
2195
2196
2197
# File 'lib/stripe/resources/invoice.rb', line 2194

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



2190
2191
2192
# File 'lib/stripe/resources/invoice.rb', line 2190

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



2192
2193
2194
# File 'lib/stripe/resources/invoice.rb', line 2192

def destination
  @destination
end