Class: Stripe::Invoice::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::TransferData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
2194 2195 2196 2197 |
# File 'lib/stripe/resources/invoice.rb', line 2194 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.
2190 2191 2192 |
# File 'lib/stripe/resources/invoice.rb', line 2190 def amount @amount end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
2192 2193 2194 |
# File 'lib/stripe/resources/invoice.rb', line 2192 def destination @destination end |