Class: Stripe::Invoice::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1779
1780
1781
1782
# File 'lib/stripe/resources/invoice.rb', line 1779

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



1775
1776
1777
# File 'lib/stripe/resources/invoice.rb', line 1775

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



1777
1778
1779
# File 'lib/stripe/resources/invoice.rb', line 1777

def destination
  @destination
end