Class: Stripe::Invoice::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1541
1542
1543
1544
# File 'lib/stripe/resources/invoice.rb', line 1541

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



1537
1538
1539
# File 'lib/stripe/resources/invoice.rb', line 1537

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



1539
1540
1541
# File 'lib/stripe/resources/invoice.rb', line 1539

def destination
  @destination
end