Class: Stripe::Invoice::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1702
1703
1704
1705
# File 'lib/stripe/resources/invoice.rb', line 1702

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



1698
1699
1700
# File 'lib/stripe/resources/invoice.rb', line 1698

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



1700
1701
1702
# File 'lib/stripe/resources/invoice.rb', line 1700

def destination
  @destination
end