Class: Stripe::Invoice::CreateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1694
1695
1696
1697
# File 'lib/stripe/resources/invoice.rb', line 1694

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



1690
1691
1692
# File 'lib/stripe/resources/invoice.rb', line 1690

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



1692
1693
1694
# File 'lib/stripe/resources/invoice.rb', line 1692

def destination
  @destination
end