Class: Stripe::Invoice::CreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreateParams::TransferData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1947 1948 1949 1950 |
# File 'lib/stripe/resources/invoice.rb', line 1947 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.
1942 1943 1944 |
# File 'lib/stripe/resources/invoice.rb', line 1942 def amount @amount end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1945 1946 1947 |
# File 'lib/stripe/resources/invoice.rb', line 1945 def destination @destination end |