Class: Stripe::Invoice::CreatePreviewParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



2556
2557
2558
2559
# File 'lib/stripe/resources/invoice.rb', line 2556

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](stripe.com/docs/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.



2552
2553
2554
# File 'lib/stripe/resources/invoice.rb', line 2552

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



2554
2555
2556
# File 'lib/stripe/resources/invoice.rb', line 2554

def liability
  @liability
end