Class: Stripe::Invoice::CreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3206
3207
3208
3209
3210
3211
# File 'lib/stripe/resources/invoice.rb', line 3206

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3198
3199
3200
# File 'lib/stripe/resources/invoice.rb', line 3198

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3200
3201
3202
# File 'lib/stripe/resources/invoice.rb', line 3200

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3202
3203
3204
# File 'lib/stripe/resources/invoice.rb', line 3202

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3204
3205
3206
# File 'lib/stripe/resources/invoice.rb', line 3204

def promotion_code
  @promotion_code
end