Class: Stripe::Invoice::CreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2741
2742
2743
2744
2745
2746
# File 'lib/stripe/resources/invoice.rb', line 2741

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2733
2734
2735
# File 'lib/stripe/resources/invoice.rb', line 2733

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2735
2736
2737
# File 'lib/stripe/resources/invoice.rb', line 2735

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2737
2738
2739
# File 'lib/stripe/resources/invoice.rb', line 2737

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2739
2740
2741
# File 'lib/stripe/resources/invoice.rb', line 2739

def promotion_code
  @promotion_code
end