Class: Stripe::Invoice::CreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



7357
7358
7359
7360
7361
7362
# File 'lib/stripe/resources/invoice.rb', line 7357

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



7346
7347
7348
# File 'lib/stripe/resources/invoice.rb', line 7346

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



7349
7350
7351
# File 'lib/stripe/resources/invoice.rb', line 7349

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



7352
7353
7354
# File 'lib/stripe/resources/invoice.rb', line 7352

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



7355
7356
7357
# File 'lib/stripe/resources/invoice.rb', line 7355

def promotion_code
  @promotion_code
end