Class: Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
2783 2784 2785 2786 2787 |
# File 'lib/stripe/resources/invoice.rb', line 2783 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
2777 2778 2779 |
# File 'lib/stripe/resources/invoice.rb', line 2777 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
2779 2780 2781 |
# File 'lib/stripe/resources/invoice.rb', line 2779 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
2781 2782 2783 |
# File 'lib/stripe/resources/invoice.rb', line 2781 def type @type end |