Class: Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
2710 2711 2712 2713 2714 |
# File 'lib/stripe/resources/invoice.rb', line 2710 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
2704 2705 2706 |
# File 'lib/stripe/resources/invoice.rb', line 2704 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
2706 2707 2708 |
# File 'lib/stripe/resources/invoice.rb', line 2706 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
2708 2709 2710 |
# File 'lib/stripe/resources/invoice.rb', line 2708 def type @type end |