Class: Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
6376 6377 6378 6379 6380 |
# File 'lib/stripe/resources/invoice.rb', line 6376 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
6370 6371 6372 |
# File 'lib/stripe/resources/invoice.rb', line 6370 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
6372 6373 6374 |
# File 'lib/stripe/resources/invoice.rb', line 6372 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
6374 6375 6376 |
# File 'lib/stripe/resources/invoice.rb', line 6374 def type @type end |