Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem

Returns a new instance of InvoiceItem.



2921
2922
2923
2924
2925
2926
2927
2928
2929
2930
2931
2932
2933
2934
2935
2936
2937
2938
2939
2940
2941
2942
2943
2944
2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
# File 'lib/stripe/resources/invoice.rb', line 2921

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  invoiceitem: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @discountable = discountable
  @discounts = discounts
  @invoiceitem = invoiceitem
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of previewed invoice item.



2889
2890
2891
# File 'lib/stripe/resources/invoice.rb', line 2889

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Only applicable to new invoice items.



2891
2892
2893
# File 'lib/stripe/resources/invoice.rb', line 2891

def currency
  @currency
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



2893
2894
2895
# File 'lib/stripe/resources/invoice.rb', line 2893

def description
  @description
end

#discountableObject

Explicitly controls whether discounts apply to this invoice item. Defaults to true, except for negative invoice items.



2895
2896
2897
# File 'lib/stripe/resources/invoice.rb', line 2895

def discountable
  @discountable
end

#discountsObject

The coupons to redeem into discounts for the invoice item in the preview.



2897
2898
2899
# File 'lib/stripe/resources/invoice.rb', line 2897

def discounts
  @discounts
end

#invoiceitemObject

The ID of the invoice item to update in preview. If not specified, a new invoice item will be added to the preview of the upcoming invoice.



2899
2900
2901
# File 'lib/stripe/resources/invoice.rb', line 2899

def invoiceitem
  @invoiceitem
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2901
2902
2903
# File 'lib/stripe/resources/invoice.rb', line 2901

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



2903
2904
2905
# File 'lib/stripe/resources/invoice.rb', line 2903

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



2905
2906
2907
# File 'lib/stripe/resources/invoice.rb', line 2905

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



2907
2908
2909
# File 'lib/stripe/resources/invoice.rb', line 2907

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item.



2909
2910
2911
# File 'lib/stripe/resources/invoice.rb', line 2909

def quantity
  @quantity
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



2911
2912
2913
# File 'lib/stripe/resources/invoice.rb', line 2911

def tax_behavior
  @tax_behavior
end

#tax_codeObject



2913
2914
2915
# File 'lib/stripe/resources/invoice.rb', line 2913

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates that apply to the item. When set, any ‘default_tax_rates` do not apply to this item.



2915
2916
2917
# File 'lib/stripe/resources/invoice.rb', line 2915

def tax_rates
  @tax_rates
end

#unit_amountObject

The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This unit_amount will be multiplied by the quantity to get the full amount. If you want to apply a credit to the customer’s account, pass a negative unit_amount.



2917
2918
2919
# File 'lib/stripe/resources/invoice.rb', line 2917

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



2919
2920
2921
# File 'lib/stripe/resources/invoice.rb', line 2919

def unit_amount_decimal
  @unit_amount_decimal
end