Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::InvoiceItem
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of previewed invoice item.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Explicitly controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the invoice item in the preview.
-
#invoiceitem ⇒ Object
The ID of the invoice item to update in preview.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#tax_rates ⇒ Object
The tax rates that apply to the item.
-
#unit_amount ⇒ Object
The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem
constructor
A new instance of InvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem
Returns a new instance of InvoiceItem.
2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/stripe/resources/invoice.rb', line 2499 def initialize( amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil ) @amount = amount @currency = currency @description = description @discountable = discountable @discounts = discounts @invoiceitem = invoiceitem @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_behavior = tax_behavior @tax_code = tax_code @tax_rates = tax_rates @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of previewed invoice item.
2467 2468 2469 |
# File 'lib/stripe/resources/invoice.rb', line 2467 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Only applicable to new invoice items.
2469 2470 2471 |
# File 'lib/stripe/resources/invoice.rb', line 2469 def currency @currency end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
2471 2472 2473 |
# File 'lib/stripe/resources/invoice.rb', line 2471 def description @description end |
#discountable ⇒ Object
Explicitly controls whether discounts apply to this invoice item. Defaults to true, except for negative invoice items.
2473 2474 2475 |
# File 'lib/stripe/resources/invoice.rb', line 2473 def discountable @discountable end |
#discounts ⇒ Object
The coupons to redeem into discounts for the invoice item in the preview.
2475 2476 2477 |
# File 'lib/stripe/resources/invoice.rb', line 2475 def discounts @discounts end |
#invoiceitem ⇒ Object
The ID of the invoice item to update in preview. If not specified, a new invoice item will be added to the preview of the upcoming invoice.
2477 2478 2479 |
# File 'lib/stripe/resources/invoice.rb', line 2477 def invoiceitem @invoiceitem end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2479 2480 2481 |
# File 'lib/stripe/resources/invoice.rb', line 2479 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
2481 2482 2483 |
# File 'lib/stripe/resources/invoice.rb', line 2481 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
2483 2484 2485 |
# File 'lib/stripe/resources/invoice.rb', line 2483 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
2485 2486 2487 |
# File 'lib/stripe/resources/invoice.rb', line 2485 def price_data @price_data end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the invoice item.
2487 2488 2489 |
# File 'lib/stripe/resources/invoice.rb', line 2487 def quantity @quantity end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
2489 2490 2491 |
# File 'lib/stripe/resources/invoice.rb', line 2489 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
2491 2492 2493 |
# File 'lib/stripe/resources/invoice.rb', line 2491 def tax_code @tax_code end |
#tax_rates ⇒ Object
The tax rates that apply to the item. When set, any ‘default_tax_rates` do not apply to this item.
2493 2494 2495 |
# File 'lib/stripe/resources/invoice.rb', line 2493 def tax_rates @tax_rates end |
#unit_amount ⇒ Object
The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This unit_amount will be multiplied by the quantity to get the full amount. If you want to apply a credit to the customer’s account, pass a negative unit_amount.
2495 2496 2497 |
# File 'lib/stripe/resources/invoice.rb', line 2495 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
2497 2498 2499 |
# File 'lib/stripe/resources/invoice.rb', line 2497 def unit_amount_decimal @unit_amount_decimal end |