Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3250
3251
3252
3253
3254
3255
# File 'lib/stripe/resources/invoice.rb', line 3250

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3242
3243
3244
# File 'lib/stripe/resources/invoice.rb', line 3242

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3244
3245
3246
# File 'lib/stripe/resources/invoice.rb', line 3244

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3246
3247
3248
# File 'lib/stripe/resources/invoice.rb', line 3246

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3248
3249
3250
# File 'lib/stripe/resources/invoice.rb', line 3248

def promotion_code
  @promotion_code
end