Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2421
2422
2423
2424
2425
# File 'lib/stripe/resources/invoice.rb', line 2421

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2415
2416
2417
# File 'lib/stripe/resources/invoice.rb', line 2415

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2417
2418
2419
# File 'lib/stripe/resources/invoice.rb', line 2417

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2419
2420
2421
# File 'lib/stripe/resources/invoice.rb', line 2419

def promotion_code
  @promotion_code
end