Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2835
2836
2837
2838
2839
2840
# File 'lib/stripe/resources/invoice.rb', line 2835

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2827
2828
2829
# File 'lib/stripe/resources/invoice.rb', line 2827

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2829
2830
2831
# File 'lib/stripe/resources/invoice.rb', line 2829

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2831
2832
2833
# File 'lib/stripe/resources/invoice.rb', line 2831

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2833
2834
2835
# File 'lib/stripe/resources/invoice.rb', line 2833

def promotion_code
  @promotion_code
end