Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2835 2836 2837 2838 2839 2840 |
# File 'lib/stripe/resources/invoice.rb', line 2835 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2827 2828 2829 |
# File 'lib/stripe/resources/invoice.rb', line 2827 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2829 2830 2831 |
# File 'lib/stripe/resources/invoice.rb', line 2829 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2831 2832 2833 |
# File 'lib/stripe/resources/invoice.rb', line 2831 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2833 2834 2835 |
# File 'lib/stripe/resources/invoice.rb', line 2833 def promotion_code @promotion_code end |