Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2758
2759
2760
2761
2762
2763
# File 'lib/stripe/resources/invoice.rb', line 2758

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2750
2751
2752
# File 'lib/stripe/resources/invoice.rb', line 2750

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2752
2753
2754
# File 'lib/stripe/resources/invoice.rb', line 2752

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2754
2755
2756
# File 'lib/stripe/resources/invoice.rb', line 2754

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2756
2757
2758
# File 'lib/stripe/resources/invoice.rb', line 2756

def promotion_code
  @promotion_code
end