Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2769
2770
2771
2772
2773
2774
# File 'lib/stripe/resources/invoice.rb', line 2769

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2761
2762
2763
# File 'lib/stripe/resources/invoice.rb', line 2761

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2763
2764
2765
# File 'lib/stripe/resources/invoice.rb', line 2763

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2765
2766
2767
# File 'lib/stripe/resources/invoice.rb', line 2765

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2767
2768
2769
# File 'lib/stripe/resources/invoice.rb', line 2767

def promotion_code
  @promotion_code
end