Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2785 2786 2787 2788 2789 2790 |
# File 'lib/stripe/resources/invoice.rb', line 2785 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2777 2778 2779 |
# File 'lib/stripe/resources/invoice.rb', line 2777 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2779 2780 2781 |
# File 'lib/stripe/resources/invoice.rb', line 2779 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2781 2782 2783 |
# File 'lib/stripe/resources/invoice.rb', line 2781 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2783 2784 2785 |
# File 'lib/stripe/resources/invoice.rb', line 2783 def promotion_code @promotion_code end |