Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
6435 6436 6437 6438 6439 6440 |
# File 'lib/stripe/resources/invoice.rb', line 6435 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
6427 6428 6429 |
# File 'lib/stripe/resources/invoice.rb', line 6427 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
6429 6430 6431 |
# File 'lib/stripe/resources/invoice.rb', line 6429 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
6431 6432 6433 |
# File 'lib/stripe/resources/invoice.rb', line 6431 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
6433 6434 6435 |
# File 'lib/stripe/resources/invoice.rb', line 6433 def promotion_code @promotion_code end |