Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



7407
7408
7409
7410
7411
7412
# File 'lib/stripe/resources/invoice.rb', line 7407

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



7396
7397
7398
# File 'lib/stripe/resources/invoice.rb', line 7396

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



7399
7400
7401
# File 'lib/stripe/resources/invoice.rb', line 7399

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



7402
7403
7404
# File 'lib/stripe/resources/invoice.rb', line 7402

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



7405
7406
7407
# File 'lib/stripe/resources/invoice.rb', line 7405

def promotion_code
  @promotion_code
end