Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3235
3236
3237
3238
3239
# File 'lib/stripe/resources/invoice.rb', line 3235

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3229
3230
3231
# File 'lib/stripe/resources/invoice.rb', line 3229

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3231
3232
3233
# File 'lib/stripe/resources/invoice.rb', line 3231

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3233
3234
3235
# File 'lib/stripe/resources/invoice.rb', line 3233

def type
  @type
end