Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2820
2821
2822
2823
2824
# File 'lib/stripe/resources/invoice.rb', line 2820

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2814
2815
2816
# File 'lib/stripe/resources/invoice.rb', line 2814

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2816
2817
2818
# File 'lib/stripe/resources/invoice.rb', line 2816

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2818
2819
2820
# File 'lib/stripe/resources/invoice.rb', line 2818

def type
  @type
end