Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2743
2744
2745
2746
2747
# File 'lib/stripe/resources/invoice.rb', line 2743

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2737
2738
2739
# File 'lib/stripe/resources/invoice.rb', line 2737

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2739
2740
2741
# File 'lib/stripe/resources/invoice.rb', line 2739

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2741
2742
2743
# File 'lib/stripe/resources/invoice.rb', line 2741

def type
  @type
end