Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2754
2755
2756
2757
2758
# File 'lib/stripe/resources/invoice.rb', line 2754

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2748
2749
2750
# File 'lib/stripe/resources/invoice.rb', line 2748

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2750
2751
2752
# File 'lib/stripe/resources/invoice.rb', line 2750

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2752
2753
2754
# File 'lib/stripe/resources/invoice.rb', line 2752

def type
  @type
end