Class: Stripe::Invoice::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



7389
7390
7391
7392
7393
# File 'lib/stripe/resources/invoice.rb', line 7389

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



7381
7382
7383
# File 'lib/stripe/resources/invoice.rb', line 7381

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



7384
7385
7386
# File 'lib/stripe/resources/invoice.rb', line 7384

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



7387
7388
7389
# File 'lib/stripe/resources/invoice.rb', line 7387

def type
  @type
end