Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: BillingMode, Phase
Instance Attribute Summary collapse
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#proration_behavior ⇒ Object
In cases where the ‘schedule_details` params update the currently active phase, specifies if and how to prorate at the time of the request.
Instance Method Summary collapse
-
#initialize(billing_mode: nil, end_behavior: nil, phases: nil, proration_behavior: nil) ⇒ ScheduleDetails
constructor
A new instance of ScheduleDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_mode: nil, end_behavior: nil, phases: nil, proration_behavior: nil) ⇒ ScheduleDetails
Returns a new instance of ScheduleDetails.
2920 2921 2922 2923 2924 2925 |
# File 'lib/stripe/resources/invoice.rb', line 2920 def initialize(billing_mode: nil, end_behavior: nil, phases: nil, proration_behavior: nil) @billing_mode = billing_mode @end_behavior = end_behavior @phases = phases @proration_behavior = proration_behavior end |
Instance Attribute Details
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
2912 2913 2914 |
# File 'lib/stripe/resources/invoice.rb', line 2912 def billing_mode @billing_mode end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
2914 2915 2916 |
# File 'lib/stripe/resources/invoice.rb', line 2914 def end_behavior @end_behavior end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.
2916 2917 2918 |
# File 'lib/stripe/resources/invoice.rb', line 2916 def phases @phases end |
#proration_behavior ⇒ Object
In cases where the ‘schedule_details` params update the currently active phase, specifies if and how to prorate at the time of the request.
2918 2919 2920 |
# File 'lib/stripe/resources/invoice.rb', line 2918 def proration_behavior @proration_behavior end |