Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
3002 3003 3004 3005 3006 3007 |
# File 'lib/stripe/resources/invoice.rb', line 3002 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
2994 2995 2996 |
# File 'lib/stripe/resources/invoice.rb', line 2994 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
2996 2997 2998 |
# File 'lib/stripe/resources/invoice.rb', line 2996 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.
2998 2999 3000 |
# File 'lib/stripe/resources/invoice.rb', line 2998 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
3000 3001 3002 |
# File 'lib/stripe/resources/invoice.rb', line 3000 def type @type end |