Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



2929
2930
2931
2932
2933
2934
# File 'lib/stripe/resources/invoice.rb', line 2929

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



2921
2922
2923
# File 'lib/stripe/resources/invoice.rb', line 2921

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



2923
2924
2925
# File 'lib/stripe/resources/invoice.rb', line 2923

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



2925
2926
2927
# File 'lib/stripe/resources/invoice.rb', line 2925

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



2927
2928
2929
# File 'lib/stripe/resources/invoice.rb', line 2927

def type
  @type
end