Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
2945 2946 2947 2948 2949 2950 |
# File 'lib/stripe/resources/invoice.rb', line 2945 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
2937 2938 2939 |
# File 'lib/stripe/resources/invoice.rb', line 2937 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
2939 2940 2941 |
# File 'lib/stripe/resources/invoice.rb', line 2939 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.
2941 2942 2943 |
# File 'lib/stripe/resources/invoice.rb', line 2941 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
2943 2944 2945 |
# File 'lib/stripe/resources/invoice.rb', line 2943 def type @type end |