Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
6595 6596 6597 6598 6599 6600 |
# File 'lib/stripe/resources/invoice.rb', line 6595 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
6587 6588 6589 |
# File 'lib/stripe/resources/invoice.rb', line 6587 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
6589 6590 6591 |
# File 'lib/stripe/resources/invoice.rb', line 6589 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.
6591 6592 6593 |
# File 'lib/stripe/resources/invoice.rb', line 6591 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
6593 6594 6595 |
# File 'lib/stripe/resources/invoice.rb', line 6593 def type @type end |