Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



7592
7593
7594
7595
7596
7597
# File 'lib/stripe/resources/invoice.rb', line 7592

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



7581
7582
7583
# File 'lib/stripe/resources/invoice.rb', line 7581

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



7584
7585
7586
# File 'lib/stripe/resources/invoice.rb', line 7584

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



7587
7588
7589
# File 'lib/stripe/resources/invoice.rb', line 7587

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



7590
7591
7592
# File 'lib/stripe/resources/invoice.rb', line 7590

def type
  @type
end