Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



3030
3031
3032
3033
3034
3035
# File 'lib/stripe/resources/invoice.rb', line 3030

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



3022
3023
3024
# File 'lib/stripe/resources/invoice.rb', line 3022

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



3024
3025
3026
# File 'lib/stripe/resources/invoice.rb', line 3024

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



3026
3027
3028
# File 'lib/stripe/resources/invoice.rb', line 3026

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



3028
3029
3030
# File 'lib/stripe/resources/invoice.rb', line 3028

def type
  @type
end