Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



2953
2954
2955
2956
2957
2958
# File 'lib/stripe/resources/invoice.rb', line 2953

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



2945
2946
2947
# File 'lib/stripe/resources/invoice.rb', line 2945

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



2947
2948
2949
# File 'lib/stripe/resources/invoice.rb', line 2947

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



2949
2950
2951
# File 'lib/stripe/resources/invoice.rb', line 2949

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



2951
2952
2953
# File 'lib/stripe/resources/invoice.rb', line 2951

def type
  @type
end