Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AmendmentEnd, DiscountEnd
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
constructor
A new instance of AmendmentStart.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart
Returns a new instance of AmendmentStart.
6630 6631 6632 6633 6634 6635 |
# File 'lib/stripe/resources/invoice.rb', line 6630 def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @discount_end = discount_end @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
Details of another amendment in the same array, immediately after which this amendment should begin.
6622 6623 6624 |
# File 'lib/stripe/resources/invoice.rb', line 6622 def amendment_end @amendment_end end |
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
6624 6625 6626 |
# File 'lib/stripe/resources/invoice.rb', line 6624 def discount_end @discount_end end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to start.
6626 6627 6628 |
# File 'lib/stripe/resources/invoice.rb', line 6626 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_start`.
6628 6629 6630 |
# File 'lib/stripe/resources/invoice.rb', line 6628 def type @type end |