Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(index: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



7605
7606
7607
# File 'lib/stripe/resources/invoice.rb', line 7605

def initialize(index: nil)
  @index = index
end

Instance Attribute Details

#indexObject

The position of the previous amendment in the ‘amendments` array after which this amendment should begin. Indexes start from 0 and must be less than the index of the current amendment in the array.



7603
7604
7605
# File 'lib/stripe/resources/invoice.rb', line 7603

def index
  @index
end