Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
3046 3047 3048 3049 3050 3051 |
# File 'lib/stripe/resources/invoice.rb', line 3046 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
3038 3039 3040 |
# File 'lib/stripe/resources/invoice.rb', line 3038 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
3040 3041 3042 |
# File 'lib/stripe/resources/invoice.rb', line 3040 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
3042 3043 3044 |
# File 'lib/stripe/resources/invoice.rb', line 3042 def set @set end |
#type ⇒ Object
Determines the type of discount action.
3044 3045 3046 |
# File 'lib/stripe/resources/invoice.rb', line 3044 def type @type end |