Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



3474
3475
3476
3477
3478
3479
3480
3481
3482
3483
3484
3485
3486
# File 'lib/stripe/resources/invoice.rb', line 3474

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



3464
3465
3466
# File 'lib/stripe/resources/invoice.rb', line 3464

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



3466
3467
3468
# File 'lib/stripe/resources/invoice.rb', line 3466

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3468
3469
3470
# File 'lib/stripe/resources/invoice.rb', line 3468

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



3470
3471
3472
# File 'lib/stripe/resources/invoice.rb', line 3470

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



3472
3473
3474
# File 'lib/stripe/resources/invoice.rb', line 3472

def promotion_code
  @promotion_code
end