Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 |
# File 'lib/stripe/resources/invoice.rb', line 3059 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
3049 3050 3051 |
# File 'lib/stripe/resources/invoice.rb', line 3049 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
3051 3052 3053 |
# File 'lib/stripe/resources/invoice.rb', line 3051 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
3053 3054 3055 |
# File 'lib/stripe/resources/invoice.rb', line 3053 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
3055 3056 3057 |
# File 'lib/stripe/resources/invoice.rb', line 3055 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
3057 3058 3059 |
# File 'lib/stripe/resources/invoice.rb', line 3057 def promotion_code @promotion_code end |