Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
# File 'lib/stripe/resources/invoice.rb', line 2982

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



2972
2973
2974
# File 'lib/stripe/resources/invoice.rb', line 2972

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



2974
2975
2976
# File 'lib/stripe/resources/invoice.rb', line 2974

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2976
2977
2978
# File 'lib/stripe/resources/invoice.rb', line 2976

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



2978
2979
2980
# File 'lib/stripe/resources/invoice.rb', line 2978

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



2980
2981
2982
# File 'lib/stripe/resources/invoice.rb', line 2980

def promotion_code
  @promotion_code
end