Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 |
# File 'lib/stripe/resources/invoice.rb', line 2993 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
2983 2984 2985 |
# File 'lib/stripe/resources/invoice.rb', line 2983 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
2985 2986 2987 |
# File 'lib/stripe/resources/invoice.rb', line 2985 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2987 2988 2989 |
# File 'lib/stripe/resources/invoice.rb', line 2987 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
2989 2990 2991 |
# File 'lib/stripe/resources/invoice.rb', line 2989 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
2991 2992 2993 |
# File 'lib/stripe/resources/invoice.rb', line 2991 def promotion_code @promotion_code end |