Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
6669
6670
6671
# File 'lib/stripe/resources/invoice.rb', line 6659

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



6649
6650
6651
# File 'lib/stripe/resources/invoice.rb', line 6649

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



6651
6652
6653
# File 'lib/stripe/resources/invoice.rb', line 6651

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



6653
6654
6655
# File 'lib/stripe/resources/invoice.rb', line 6653

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



6655
6656
6657
# File 'lib/stripe/resources/invoice.rb', line 6655

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



6657
6658
6659
# File 'lib/stripe/resources/invoice.rb', line 6657

def promotion_code
  @promotion_code
end