Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
7663 7664 7665 7666 7667 7668 7669 7670 7671 7672 7673 7674 7675 |
# File 'lib/stripe/resources/invoice.rb', line 7663 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
7649 7650 7651 |
# File 'lib/stripe/resources/invoice.rb', line 7649 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
7652 7653 7654 |
# File 'lib/stripe/resources/invoice.rb', line 7652 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
7655 7656 7657 |
# File 'lib/stripe/resources/invoice.rb', line 7655 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
7658 7659 7660 |
# File 'lib/stripe/resources/invoice.rb', line 7658 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
7661 7662 7663 |
# File 'lib/stripe/resources/invoice.rb', line 7661 def promotion_code @promotion_code end |