Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



3089
3090
3091
3092
3093
# File 'lib/stripe/resources/invoice.rb', line 3089

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



3083
3084
3085
# File 'lib/stripe/resources/invoice.rb', line 3083

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



3085
3086
3087
# File 'lib/stripe/resources/invoice.rb', line 3085

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



3087
3088
3089
# File 'lib/stripe/resources/invoice.rb', line 3087

def promotion_code
  @promotion_code
end