Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



3005
3006
3007
3008
3009
# File 'lib/stripe/resources/invoice.rb', line 3005

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2999
3000
3001
# File 'lib/stripe/resources/invoice.rb', line 2999

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



3001
3002
3003
# File 'lib/stripe/resources/invoice.rb', line 3001

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



3003
3004
3005
# File 'lib/stripe/resources/invoice.rb', line 3003

def promotion_code
  @promotion_code
end