Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



7688
7689
7690
7691
7692
# File 'lib/stripe/resources/invoice.rb', line 7688

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



7680
7681
7682
# File 'lib/stripe/resources/invoice.rb', line 7680

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



7683
7684
7685
# File 'lib/stripe/resources/invoice.rb', line 7683

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



7686
7687
7688
# File 'lib/stripe/resources/invoice.rb', line 7686

def promotion_code
  @promotion_code
end