Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



3097
3098
3099
3100
3101
# File 'lib/stripe/resources/invoice.rb', line 3097

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



3091
3092
3093
# File 'lib/stripe/resources/invoice.rb', line 3091

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



3093
3094
3095
# File 'lib/stripe/resources/invoice.rb', line 3093

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



3095
3096
3097
# File 'lib/stripe/resources/invoice.rb', line 3095

def promotion_code
  @promotion_code
end