Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



3031
3032
3033
3034
3035
# File 'lib/stripe/resources/invoice.rb', line 3031

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



3025
3026
3027
# File 'lib/stripe/resources/invoice.rb', line 3025

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



3027
3028
3029
# File 'lib/stripe/resources/invoice.rb', line 3027

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



3029
3030
3031
# File 'lib/stripe/resources/invoice.rb', line 3029

def promotion_code
  @promotion_code
end