Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



3047
3048
3049
3050
3051
# File 'lib/stripe/resources/invoice.rb', line 3047

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



3041
3042
3043
# File 'lib/stripe/resources/invoice.rb', line 3041

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



3043
3044
3045
# File 'lib/stripe/resources/invoice.rb', line 3043

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



3045
3046
3047
# File 'lib/stripe/resources/invoice.rb', line 3045

def promotion_code
  @promotion_code
end