Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the subscription item to add.
-
#remove ⇒ Object
Details of the subscription item to remove.
-
#set ⇒ Object
Details of the subscription item to replace the existing items with.
-
#type ⇒ Object
Determines the type of item action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
constructor
A new instance of ItemAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
Returns a new instance of ItemAction.
3308 3309 3310 3311 3312 3313 |
# File 'lib/stripe/resources/invoice.rb', line 3308 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.
3300 3301 3302 |
# File 'lib/stripe/resources/invoice.rb', line 3300 def add @add end |
#remove ⇒ Object
Details of the subscription item to remove.
3302 3303 3304 |
# File 'lib/stripe/resources/invoice.rb', line 3302 def remove @remove end |
#set ⇒ Object
Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.
3304 3305 3306 |
# File 'lib/stripe/resources/invoice.rb', line 3304 def set @set end |
#type ⇒ Object
Determines the type of item action.
3306 3307 3308 |
# File 'lib/stripe/resources/invoice.rb', line 3306 def type @type end |