Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



3242
3243
3244
3245
3246
3247
# File 'lib/stripe/resources/invoice.rb', line 3242

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



3234
3235
3236
# File 'lib/stripe/resources/invoice.rb', line 3234

def add
  @add
end

#removeObject

Details of the subscription item to remove.



3236
3237
3238
# File 'lib/stripe/resources/invoice.rb', line 3236

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



3238
3239
3240
# File 'lib/stripe/resources/invoice.rb', line 3238

def set
  @set
end

#typeObject

Determines the type of item action.



3240
3241
3242
# File 'lib/stripe/resources/invoice.rb', line 3240

def type
  @type
end