Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



3258
3259
3260
3261
3262
3263
# File 'lib/stripe/resources/invoice.rb', line 3258

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



3250
3251
3252
# File 'lib/stripe/resources/invoice.rb', line 3250

def add
  @add
end

#removeObject

Details of the subscription item to remove.



3252
3253
3254
# File 'lib/stripe/resources/invoice.rb', line 3252

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



3254
3255
3256
# File 'lib/stripe/resources/invoice.rb', line 3254

def set
  @set
end

#typeObject

Determines the type of item action.



3256
3257
3258
# File 'lib/stripe/resources/invoice.rb', line 3256

def type
  @type
end