Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



3112
3113
3114
3115
3116
3117
3118
3119
3120
3121
3122
3123
3124
3125
3126
# File 'lib/stripe/resources/invoice.rb', line 3112

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



3100
3101
3102
# File 'lib/stripe/resources/invoice.rb', line 3100

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3102
3103
3104
# File 'lib/stripe/resources/invoice.rb', line 3102

def 
  @metadata
end

#priceObject

The ID of the price object.



3104
3105
3106
# File 'lib/stripe/resources/invoice.rb', line 3104

def price
  @price
end

#quantityObject

Quantity for this item.



3106
3107
3108
# File 'lib/stripe/resources/invoice.rb', line 3106

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



3108
3109
3110
# File 'lib/stripe/resources/invoice.rb', line 3108

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



3110
3111
3112
# File 'lib/stripe/resources/invoice.rb', line 3110

def trial
  @trial
end