Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



6789
6790
6791
6792
6793
6794
6795
6796
6797
6798
6799
6800
6801
6802
6803
# File 'lib/stripe/resources/invoice.rb', line 6789

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



6777
6778
6779
# File 'lib/stripe/resources/invoice.rb', line 6777

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6779
6780
6781
# File 'lib/stripe/resources/invoice.rb', line 6779

def 
  @metadata
end

#priceObject

The ID of the price object.



6781
6782
6783
# File 'lib/stripe/resources/invoice.rb', line 6781

def price
  @price
end

#quantityObject

Quantity for this item.



6783
6784
6785
# File 'lib/stripe/resources/invoice.rb', line 6783

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



6785
6786
6787
# File 'lib/stripe/resources/invoice.rb', line 6785

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



6787
6788
6789
# File 'lib/stripe/resources/invoice.rb', line 6787

def trial
  @trial
end