Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
7812 7813 7814 7815 7816 7817 7818 7819 7820 7821 7822 7823 7824 7825 7826 |
# File 'lib/stripe/resources/invoice.rb', line 7812 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
7795 7796 7797 |
# File 'lib/stripe/resources/invoice.rb', line 7795 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
7798 7799 7800 |
# File 'lib/stripe/resources/invoice.rb', line 7798 def @metadata end |
#price ⇒ Object
The ID of the price object.
7801 7802 7803 |
# File 'lib/stripe/resources/invoice.rb', line 7801 def price @price end |
#quantity ⇒ Object
Quantity for this item.
7804 7805 7806 |
# File 'lib/stripe/resources/invoice.rb', line 7804 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
7807 7808 7809 |
# File 'lib/stripe/resources/invoice.rb', line 7807 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
7810 7811 7812 |
# File 'lib/stripe/resources/invoice.rb', line 7810 def trial @trial end |