Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



6757
6758
6759
6760
6761
6762
# File 'lib/stripe/resources/invoice.rb', line 6757

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



6749
6750
6751
# File 'lib/stripe/resources/invoice.rb', line 6749

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



6751
6752
6753
# File 'lib/stripe/resources/invoice.rb', line 6751

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



6753
6754
6755
# File 'lib/stripe/resources/invoice.rb', line 6753

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



6755
6756
6757
# File 'lib/stripe/resources/invoice.rb', line 6755

def promotion_code
  @promotion_code
end