Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3142
3143
3144
3145
3146
# File 'lib/stripe/resources/invoice.rb', line 3142

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3136
3137
3138
# File 'lib/stripe/resources/invoice.rb', line 3136

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3138
3139
3140
# File 'lib/stripe/resources/invoice.rb', line 3138

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3140
3141
3142
# File 'lib/stripe/resources/invoice.rb', line 3140

def type
  @type
end