Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3065
3066
3067
3068
3069
# File 'lib/stripe/resources/invoice.rb', line 3065

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3059
3060
3061
# File 'lib/stripe/resources/invoice.rb', line 3059

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3061
3062
3063
# File 'lib/stripe/resources/invoice.rb', line 3061

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3063
3064
3065
# File 'lib/stripe/resources/invoice.rb', line 3063

def type
  @type
end