Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



6742
6743
6744
6745
6746
# File 'lib/stripe/resources/invoice.rb', line 6742

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



6736
6737
6738
# File 'lib/stripe/resources/invoice.rb', line 6736

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



6738
6739
6740
# File 'lib/stripe/resources/invoice.rb', line 6738

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



6740
6741
6742
# File 'lib/stripe/resources/invoice.rb', line 6740

def type
  @type
end