Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



7756
7757
7758
7759
7760
# File 'lib/stripe/resources/invoice.rb', line 7756

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



7748
7749
7750
# File 'lib/stripe/resources/invoice.rb', line 7748

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



7751
7752
7753
# File 'lib/stripe/resources/invoice.rb', line 7751

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



7754
7755
7756
# File 'lib/stripe/resources/invoice.rb', line 7754

def type
  @type
end