Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price.
-
#metadata ⇒ Object
If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price.
-
#tax_rates ⇒ Object
If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price.
-
#trial ⇒ Object
If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Set
Returns a new instance of Set.
3283 3284 3285 3286 3287 3288 3289 3290 3291 3292 3293 3294 3295 3296 3297 |
# File 'lib/stripe/resources/invoice.rb', line 3283 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.
3271 3272 3273 |
# File 'lib/stripe/resources/invoice.rb', line 3271 def discounts @discounts end |
#metadata ⇒ Object
If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.
3273 3274 3275 |
# File 'lib/stripe/resources/invoice.rb', line 3273 def @metadata end |
#price ⇒ Object
The ID of the price object.
3275 3276 3277 |
# File 'lib/stripe/resources/invoice.rb', line 3275 def price @price end |
#quantity ⇒ Object
If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.
3277 3278 3279 |
# File 'lib/stripe/resources/invoice.rb', line 3277 def quantity @quantity end |
#tax_rates ⇒ Object
If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.
3279 3280 3281 |
# File 'lib/stripe/resources/invoice.rb', line 3279 def tax_rates @tax_rates end |
#trial ⇒ Object
If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.
3281 3282 3283 |
# File 'lib/stripe/resources/invoice.rb', line 3281 def trial @trial end |