Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3666
3667
3668
3669
3670
3671
# File 'lib/stripe/resources/invoice.rb', line 3666

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3658
3659
3660
# File 'lib/stripe/resources/invoice.rb', line 3658

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3660
3661
3662
# File 'lib/stripe/resources/invoice.rb', line 3660

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3662
3663
3664
# File 'lib/stripe/resources/invoice.rb', line 3662

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3664
3665
3666
# File 'lib/stripe/resources/invoice.rb', line 3664

def promotion_code
  @promotion_code
end