Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



6851
6852
6853
6854
6855
6856
# File 'lib/stripe/resources/invoice.rb', line 6851

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



6843
6844
6845
# File 'lib/stripe/resources/invoice.rb', line 6843

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



6845
6846
6847
# File 'lib/stripe/resources/invoice.rb', line 6845

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



6847
6848
6849
# File 'lib/stripe/resources/invoice.rb', line 6847

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



6849
6850
6851
# File 'lib/stripe/resources/invoice.rb', line 6849

def promotion_code
  @promotion_code
end