Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



7880
7881
7882
7883
7884
7885
# File 'lib/stripe/resources/invoice.rb', line 7880

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



7869
7870
7871
# File 'lib/stripe/resources/invoice.rb', line 7869

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



7872
7873
7874
# File 'lib/stripe/resources/invoice.rb', line 7872

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



7875
7876
7877
# File 'lib/stripe/resources/invoice.rb', line 7875

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



7878
7879
7880
# File 'lib/stripe/resources/invoice.rb', line 7878

def promotion_code
  @promotion_code
end