Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3159
3160
3161
3162
3163
# File 'lib/stripe/resources/invoice.rb', line 3159

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3153
3154
3155
# File 'lib/stripe/resources/invoice.rb', line 3153

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3155
3156
3157
# File 'lib/stripe/resources/invoice.rb', line 3155

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3157
3158
3159
# File 'lib/stripe/resources/invoice.rb', line 3157

def type
  @type
end