Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



6836
6837
6838
6839
6840
# File 'lib/stripe/resources/invoice.rb', line 6836

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



6830
6831
6832
# File 'lib/stripe/resources/invoice.rb', line 6830

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



6832
6833
6834
# File 'lib/stripe/resources/invoice.rb', line 6832

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



6834
6835
6836
# File 'lib/stripe/resources/invoice.rb', line 6834

def type
  @type
end