Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, Discount, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
-
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule.
-
#default_tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
-
#description ⇒ Object
Subscription description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase.
-
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
-
#iterations ⇒ Object
Integer representing the multiplier applied to the price interval.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
-
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused.
-
#proration_behavior ⇒ Object
Whether the subscription schedule will create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase.
-
#start_date ⇒ Object
The date at which this phase of the subscription schedule starts or ‘now`.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
-
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
-
#trial_continuation ⇒ Object
Specify trial behavior when crossing phase boundaries.
-
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil) ⇒ Phase
Returns a new instance of Phase.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 3795 3796 3797 3798 3799 3800 3801 3802 3803 3804 3805 3806 3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 3826 |
# File 'lib/stripe/resources/invoice.rb', line 3776 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @collection_method = collection_method @currency = currency @default_payment_method = default_payment_method @default_tax_rates = default_tax_rates @description = description @discounts = discounts @end_date = end_date @invoice_settings = invoice_settings @items = items @iterations = iterations @metadata = @on_behalf_of = on_behalf_of @pause_collection = pause_collection @proration_behavior = proration_behavior @start_date = start_date @transfer_data = transfer_data @trial = trial @trial_continuation = trial_continuation @trial_end = trial_end @trial_settings = trial_settings end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.
3728 3729 3730 |
# File 'lib/stripe/resources/invoice.rb', line 3728 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
3730 3731 3732 |
# File 'lib/stripe/resources/invoice.rb', line 3730 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
3732 3733 3734 |
# File 'lib/stripe/resources/invoice.rb', line 3732 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).
3734 3735 3736 |
# File 'lib/stripe/resources/invoice.rb', line 3734 def billing_cycle_anchor @billing_cycle_anchor end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.
3736 3737 3738 |
# File 'lib/stripe/resources/invoice.rb', line 3736 def collection_method @collection_method end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3738 3739 3740 |
# File 'lib/stripe/resources/invoice.rb', line 3738 def currency @currency end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.
3740 3741 3742 |
# File 'lib/stripe/resources/invoice.rb', line 3740 def default_payment_method @default_payment_method end |
#default_tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will set the Subscription’s [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates), which means they will be the Invoice’s [‘default_tax_rates`](stripe.com/docs/api/invoices/create#create_invoice-default_tax_rates) for any Invoices issued by the Subscription during this Phase.
3742 3743 3744 |
# File 'lib/stripe/resources/invoice.rb', line 3742 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
3744 3745 3746 |
# File 'lib/stripe/resources/invoice.rb', line 3744 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription’s customer. Pass an empty string to avoid inheriting any discounts.
3746 3747 3748 |
# File 'lib/stripe/resources/invoice.rb', line 3746 def discounts @discounts end |
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends. If set, ‘iterations` must not be set.
3748 3749 3750 |
# File 'lib/stripe/resources/invoice.rb', line 3748 def end_date @end_date end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
3750 3751 3752 |
# File 'lib/stripe/resources/invoice.rb', line 3750 def invoice_settings @invoice_settings end |
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
3752 3753 3754 |
# File 'lib/stripe/resources/invoice.rb', line 3752 def items @items end |
#iterations ⇒ Object
Integer representing the multiplier applied to the price interval. For example, ‘iterations=2` applied to a price with `interval=month` and `interval_count=3` results in a phase of duration `2 * 3 months = 6 months`. If set, `end_date` must not be set.
3754 3755 3756 |
# File 'lib/stripe/resources/invoice.rb', line 3754 def iterations @iterations end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys in the subscription’s ‘metadata`. Individual keys in the subscription’s ‘metadata` can be unset by posting an empty value to them in the phase’s ‘metadata`. To unset all keys in the subscription’s ‘metadata`, update the subscription directly or unset every key individually from the phase’s ‘metadata`.
3756 3757 3758 |
# File 'lib/stripe/resources/invoice.rb', line 3756 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
3758 3759 3760 |
# File 'lib/stripe/resources/invoice.rb', line 3758 def on_behalf_of @on_behalf_of end |
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).
3760 3761 3762 |
# File 'lib/stripe/resources/invoice.rb', line 3760 def pause_collection @pause_collection end |
#proration_behavior ⇒ Object
Whether the subscription schedule will create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase. The default value is ‘create_prorations`. This setting controls prorations when a phase is started asynchronously and it is persisted as a field on the phase. It’s different from the request-level [proration_behavior](stripe.com/docs/api/subscription_schedules/update#update_subscription_schedule-proration_behavior) parameter which controls what happens if the update request affects the billing configuration of the current phase.
3762 3763 3764 |
# File 'lib/stripe/resources/invoice.rb', line 3762 def proration_behavior @proration_behavior end |
#start_date ⇒ Object
The date at which this phase of the subscription schedule starts or ‘now`. Must be set on the first phase.
3764 3765 3766 |
# File 'lib/stripe/resources/invoice.rb', line 3764 def start_date @start_date end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
3766 3767 3768 |
# File 'lib/stripe/resources/invoice.rb', line 3766 def transfer_data @transfer_data end |
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
3768 3769 3770 |
# File 'lib/stripe/resources/invoice.rb', line 3768 def trial @trial end |
#trial_continuation ⇒ Object
Specify trial behavior when crossing phase boundaries
3770 3771 3772 |
# File 'lib/stripe/resources/invoice.rb', line 3770 def trial_continuation @trial_continuation end |
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date. Must be before the phase end date, can not be combined with ‘trial`
3772 3773 3774 |
# File 'lib/stripe/resources/invoice.rb', line 3772 def trial_end @trial_end end |
#trial_settings ⇒ Object
Settings related to subscription trials.
3774 3775 3776 |
# File 'lib/stripe/resources/invoice.rb', line 3774 def trial_settings @trial_settings end |