Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
3568
3569
# File 'lib/stripe/resources/invoice.rb', line 3553

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



3539
3540
3541
# File 'lib/stripe/resources/invoice.rb', line 3539

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3541
3542
3543
# File 'lib/stripe/resources/invoice.rb', line 3541

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.



3543
3544
3545
# File 'lib/stripe/resources/invoice.rb', line 3543

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



3545
3546
3547
# File 'lib/stripe/resources/invoice.rb', line 3545

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3547
3548
3549
# File 'lib/stripe/resources/invoice.rb', line 3547

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



3549
3550
3551
# File 'lib/stripe/resources/invoice.rb', line 3549

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



3551
3552
3553
# File 'lib/stripe/resources/invoice.rb', line 3551

def tax_rates
  @tax_rates
end