Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
2661
2662
2663
2664
2665
2666
2667
# File 'lib/stripe/resources/invoice.rb', line 2651

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



2637
2638
2639
# File 'lib/stripe/resources/invoice.rb', line 2637

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2639
2640
2641
# File 'lib/stripe/resources/invoice.rb', line 2639

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.



2641
2642
2643
# File 'lib/stripe/resources/invoice.rb', line 2641

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



2643
2644
2645
# File 'lib/stripe/resources/invoice.rb', line 2643

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



2645
2646
2647
# File 'lib/stripe/resources/invoice.rb', line 2645

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



2647
2648
2649
# File 'lib/stripe/resources/invoice.rb', line 2647

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



2649
2650
2651
# File 'lib/stripe/resources/invoice.rb', line 2649

def tax_rates
  @tax_rates
end