Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/stripe/resources/invoice.rb', line 3448 def initialize( discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
3438 3439 3440 |
# File 'lib/stripe/resources/invoice.rb', line 3438 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
3440 3441 3442 |
# File 'lib/stripe/resources/invoice.rb', line 3440 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
3442 3443 3444 |
# File 'lib/stripe/resources/invoice.rb', line 3442 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
3444 3445 3446 |
# File 'lib/stripe/resources/invoice.rb', line 3444 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
3446 3447 3448 |
# File 'lib/stripe/resources/invoice.rb', line 3446 def tax_rates @tax_rates end |