Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
8163 8164 8165 8166 8167 8168 8169 8170 8171 8172 8173 8174 8175 |
# File 'lib/stripe/resources/invoice.rb', line 8163 def initialize( discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
8149 8150 8151 |
# File 'lib/stripe/resources/invoice.rb', line 8149 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
8152 8153 8154 |
# File 'lib/stripe/resources/invoice.rb', line 8152 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
8155 8156 8157 |
# File 'lib/stripe/resources/invoice.rb', line 8155 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
8158 8159 8160 |
# File 'lib/stripe/resources/invoice.rb', line 8158 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
8161 8162 8163 |
# File 'lib/stripe/resources/invoice.rb', line 8161 def tax_rates @tax_rates end |