Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3403
3404
3405
3406
3407
3408
# File 'lib/stripe/resources/invoice.rb', line 3403

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3395
3396
3397
# File 'lib/stripe/resources/invoice.rb', line 3395

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3397
3398
3399
# File 'lib/stripe/resources/invoice.rb', line 3397

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3399
3400
3401
# File 'lib/stripe/resources/invoice.rb', line 3399

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3401
3402
3403
# File 'lib/stripe/resources/invoice.rb', line 3401

def promotion_code
  @promotion_code
end