Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



7053
7054
7055
7056
7057
7058
# File 'lib/stripe/resources/invoice.rb', line 7053

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



7045
7046
7047
# File 'lib/stripe/resources/invoice.rb', line 7045

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



7047
7048
7049
# File 'lib/stripe/resources/invoice.rb', line 7047

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



7049
7050
7051
# File 'lib/stripe/resources/invoice.rb', line 7049

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



7051
7052
7053
# File 'lib/stripe/resources/invoice.rb', line 7051

def promotion_code
  @promotion_code
end