Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3862
3863
3864
3865
3866
# File 'lib/stripe/resources/invoice.rb', line 3862

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3856
3857
3858
# File 'lib/stripe/resources/invoice.rb', line 3856

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3858
3859
3860
# File 'lib/stripe/resources/invoice.rb', line 3858

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3860
3861
3862
# File 'lib/stripe/resources/invoice.rb', line 3860

def type
  @type
end