Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



8092
8093
8094
8095
8096
# File 'lib/stripe/resources/invoice.rb', line 8092

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



8084
8085
8086
# File 'lib/stripe/resources/invoice.rb', line 8084

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



8087
8088
8089
# File 'lib/stripe/resources/invoice.rb', line 8087

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



8090
8091
8092
# File 'lib/stripe/resources/invoice.rb', line 8090

def type
  @type
end