Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



2594
2595
2596
2597
# File 'lib/stripe/resources/invoice.rb', line 2594

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



2590
2591
2592
# File 'lib/stripe/resources/invoice.rb', line 2590

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



2592
2593
2594
# File 'lib/stripe/resources/invoice.rb', line 2592

def type
  @type
end