Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



2635
2636
2637
2638
# File 'lib/stripe/resources/invoice.rb', line 2635

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



2631
2632
2633
# File 'lib/stripe/resources/invoice.rb', line 2631

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



2633
2634
2635
# File 'lib/stripe/resources/invoice.rb', line 2633

def liability
  @liability
end