Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3642
3643
3644
3645
3646
3647
# File 'lib/stripe/resources/invoice.rb', line 3642

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3634
3635
3636
# File 'lib/stripe/resources/invoice.rb', line 3634

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3636
3637
3638
# File 'lib/stripe/resources/invoice.rb', line 3636

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3638
3639
3640
# File 'lib/stripe/resources/invoice.rb', line 3638

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3640
3641
3642
# File 'lib/stripe/resources/invoice.rb', line 3640

def promotion_code
  @promotion_code
end