Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2713 2714 2715 2716 2717 |
# File 'lib/stripe/resources/invoice.rb', line 2713 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2707 2708 2709 |
# File 'lib/stripe/resources/invoice.rb', line 2707 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2709 2710 2711 |
# File 'lib/stripe/resources/invoice.rb', line 2709 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2711 2712 2713 |
# File 'lib/stripe/resources/invoice.rb', line 2711 def promotion_code @promotion_code end |