Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3515
3516
3517
3518
3519
3520
# File 'lib/stripe/resources/invoice.rb', line 3515

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3507
3508
3509
# File 'lib/stripe/resources/invoice.rb', line 3507

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3509
3510
3511
# File 'lib/stripe/resources/invoice.rb', line 3509

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3511
3512
3513
# File 'lib/stripe/resources/invoice.rb', line 3511

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3513
3514
3515
# File 'lib/stripe/resources/invoice.rb', line 3513

def promotion_code
  @promotion_code
end