Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2670
2671
2672
2673
2674
# File 'lib/stripe/resources/invoice.rb', line 2670

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2664
2665
2666
# File 'lib/stripe/resources/invoice.rb', line 2664

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2666
2667
2668
# File 'lib/stripe/resources/invoice.rb', line 2666

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2668
2669
2670
# File 'lib/stripe/resources/invoice.rb', line 2668

def promotion_code
  @promotion_code
end