Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3521
3522
3523
3524
3525
3526
# File 'lib/stripe/resources/invoice.rb', line 3521

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3513
3514
3515
# File 'lib/stripe/resources/invoice.rb', line 3513

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3515
3516
3517
# File 'lib/stripe/resources/invoice.rb', line 3515

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3517
3518
3519
# File 'lib/stripe/resources/invoice.rb', line 3517

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3519
3520
3521
# File 'lib/stripe/resources/invoice.rb', line 3519

def promotion_code
  @promotion_code
end