Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2642
2643
2644
2645
2646
# File 'lib/stripe/resources/invoice.rb', line 2642

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2636
2637
2638
# File 'lib/stripe/resources/invoice.rb', line 2636

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2638
2639
2640
# File 'lib/stripe/resources/invoice.rb', line 2638

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2640
2641
2642
# File 'lib/stripe/resources/invoice.rb', line 2640

def promotion_code
  @promotion_code
end