Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



8257
8258
8259
8260
8261
8262
# File 'lib/stripe/resources/invoice.rb', line 8257

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



8246
8247
8248
# File 'lib/stripe/resources/invoice.rb', line 8246

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



8249
8250
8251
# File 'lib/stripe/resources/invoice.rb', line 8249

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



8252
8253
8254
# File 'lib/stripe/resources/invoice.rb', line 8252

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



8255
8256
8257
# File 'lib/stripe/resources/invoice.rb', line 8255

def promotion_code
  @promotion_code
end