Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
3627 3628 3629 3630 3631 |
# File 'lib/stripe/resources/invoice.rb', line 3627 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
3621 3622 3623 |
# File 'lib/stripe/resources/invoice.rb', line 3621 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
3623 3624 3625 |
# File 'lib/stripe/resources/invoice.rb', line 3623 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
3625 3626 3627 |
# File 'lib/stripe/resources/invoice.rb', line 3625 def type @type end |