Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4035
4036
4037
4038
4039
# File 'lib/stripe/resources/invoice.rb', line 4035

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4029
4030
4031
# File 'lib/stripe/resources/invoice.rb', line 4029

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4031
4032
4033
# File 'lib/stripe/resources/invoice.rb', line 4031

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4033
4034
4035
# File 'lib/stripe/resources/invoice.rb', line 4033

def type
  @type
end