Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
3490 3491 3492 3493 3494 |
# File 'lib/stripe/resources/invoice.rb', line 3490 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
3484 3485 3486 |
# File 'lib/stripe/resources/invoice.rb', line 3484 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
3486 3487 3488 |
# File 'lib/stripe/resources/invoice.rb', line 3486 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
3488 3489 3490 |
# File 'lib/stripe/resources/invoice.rb', line 3488 def type @type end |