Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3506
3507
3508
3509
3510
# File 'lib/stripe/resources/invoice.rb', line 3506

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3500
3501
3502
# File 'lib/stripe/resources/invoice.rb', line 3500

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3502
3503
3504
# File 'lib/stripe/resources/invoice.rb', line 3502

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3504
3505
3506
# File 'lib/stripe/resources/invoice.rb', line 3504

def type
  @type
end