Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



7168
7169
7170
7171
7172
# File 'lib/stripe/resources/invoice.rb', line 7168

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



7162
7163
7164
# File 'lib/stripe/resources/invoice.rb', line 7162

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



7164
7165
7166
# File 'lib/stripe/resources/invoice.rb', line 7164

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



7166
7167
7168
# File 'lib/stripe/resources/invoice.rb', line 7166

def type
  @type
end