Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



8239
8240
8241
8242
8243
# File 'lib/stripe/resources/invoice.rb', line 8239

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



8231
8232
8233
# File 'lib/stripe/resources/invoice.rb', line 8231

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



8234
8235
8236
# File 'lib/stripe/resources/invoice.rb', line 8234

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



8237
8238
8239
# File 'lib/stripe/resources/invoice.rb', line 8237

def type
  @type
end