Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::InvoiceSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::InvoiceSettings
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Issuer
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with this phase of the subscription schedule.
-
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule.
-
#issuer ⇒ Object
The connected account that issues the invoice.
Instance Method Summary collapse
-
#initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) ⇒ InvoiceSettings
constructor
A new instance of InvoiceSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) ⇒ InvoiceSettings
Returns a new instance of InvoiceSettings.
8287 8288 8289 8290 8291 |
# File 'lib/stripe/resources/invoice.rb', line 8287 def initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) @account_tax_ids = account_tax_ids @days_until_due = days_until_due @issuer = issuer end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.
8279 8280 8281 |
# File 'lib/stripe/resources/invoice.rb', line 8279 def account_tax_ids @account_tax_ids end |
#days_until_due ⇒ Object
Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `billing=charge_automatically`.
8282 8283 8284 |
# File 'lib/stripe/resources/invoice.rb', line 8282 def days_until_due @days_until_due end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
8285 8286 8287 |
# File 'lib/stripe/resources/invoice.rb', line 8285 def issuer @issuer end |