Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
2786 2787 2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 |
# File 'lib/stripe/resources/invoice.rb', line 2786 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
2770 2771 2772 |
# File 'lib/stripe/resources/invoice.rb', line 2770 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
2772 2773 2774 |
# File 'lib/stripe/resources/invoice.rb', line 2772 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.
2774 2775 2776 |
# File 'lib/stripe/resources/invoice.rb', line 2774 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.
2776 2777 2778 |
# File 'lib/stripe/resources/invoice.rb', line 2776 def plan @plan end |
#price ⇒ Object
The ID of the price object.
2778 2779 2780 |
# File 'lib/stripe/resources/invoice.rb', line 2778 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
2780 2781 2782 |
# File 'lib/stripe/resources/invoice.rb', line 2780 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.
2782 2783 2784 |
# File 'lib/stripe/resources/invoice.rb', line 2782 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
2784 2785 2786 |
# File 'lib/stripe/resources/invoice.rb', line 2784 def tax_rates @tax_rates end |