Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



8440
8441
8442
8443
8444
8445
8446
8447
8448
8449
8450
8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
# File 'lib/stripe/resources/invoice.rb', line 8440

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



8414
8415
8416
# File 'lib/stripe/resources/invoice.rb', line 8414

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



8417
8418
8419
# File 'lib/stripe/resources/invoice.rb', line 8417

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



8420
8421
8422
# File 'lib/stripe/resources/invoice.rb', line 8420

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



8423
8424
8425
# File 'lib/stripe/resources/invoice.rb', line 8423

def plan
  @plan
end

#priceObject

The ID of the price object.



8426
8427
8428
# File 'lib/stripe/resources/invoice.rb', line 8426

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



8429
8430
8431
# File 'lib/stripe/resources/invoice.rb', line 8429

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



8432
8433
8434
# File 'lib/stripe/resources/invoice.rb', line 8432

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



8435
8436
8437
# File 'lib/stripe/resources/invoice.rb', line 8435

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



8438
8439
8440
# File 'lib/stripe/resources/invoice.rb', line 8438

def trial
  @trial
end