Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2721
2722
2723
2724
2725
# File 'lib/stripe/resources/invoice.rb', line 2721

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2715
2716
2717
# File 'lib/stripe/resources/invoice.rb', line 2715

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2717
2718
2719
# File 'lib/stripe/resources/invoice.rb', line 2717

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2719
2720
2721
# File 'lib/stripe/resources/invoice.rb', line 2719

def promotion_code
  @promotion_code
end