Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3575
3576
3577
3578
3579
3580
# File 'lib/stripe/resources/invoice.rb', line 3575

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3567
3568
3569
# File 'lib/stripe/resources/invoice.rb', line 3567

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3569
3570
3571
# File 'lib/stripe/resources/invoice.rb', line 3569

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3571
3572
3573
# File 'lib/stripe/resources/invoice.rb', line 3571

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3573
3574
3575
# File 'lib/stripe/resources/invoice.rb', line 3573

def promotion_code
  @promotion_code
end