Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2684 2685 2686 2687 2688 |
# File 'lib/stripe/resources/invoice.rb', line 2684 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2678 2679 2680 |
# File 'lib/stripe/resources/invoice.rb', line 2678 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2680 2681 2682 |
# File 'lib/stripe/resources/invoice.rb', line 2680 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2682 2683 2684 |
# File 'lib/stripe/resources/invoice.rb', line 2682 def promotion_code @promotion_code end |