Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3591
3592
3593
3594
3595
3596
# File 'lib/stripe/resources/invoice.rb', line 3591

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3583
3584
3585
# File 'lib/stripe/resources/invoice.rb', line 3583

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3585
3586
3587
# File 'lib/stripe/resources/invoice.rb', line 3585

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3587
3588
3589
# File 'lib/stripe/resources/invoice.rb', line 3587

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3589
3590
3591
# File 'lib/stripe/resources/invoice.rb', line 3589

def promotion_code
  @promotion_code
end