Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
3591 3592 3593 3594 3595 3596 |
# File 'lib/stripe/resources/invoice.rb', line 3591 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
3583 3584 3585 |
# File 'lib/stripe/resources/invoice.rb', line 3583 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
3585 3586 3587 |
# File 'lib/stripe/resources/invoice.rb', line 3585 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
3587 3588 3589 |
# File 'lib/stripe/resources/invoice.rb', line 3587 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
3589 3590 3591 |
# File 'lib/stripe/resources/invoice.rb', line 3589 def promotion_code @promotion_code end |