Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4126
4127
4128
4129
4130
# File 'lib/stripe/resources/invoice.rb', line 4126

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4120
4121
4122
# File 'lib/stripe/resources/invoice.rb', line 4120

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4122
4123
4124
# File 'lib/stripe/resources/invoice.rb', line 4122

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4124
4125
4126
# File 'lib/stripe/resources/invoice.rb', line 4124

def type
  @type
end