Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3576
3577
3578
3579
3580
# File 'lib/stripe/resources/invoice.rb', line 3576

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3570
3571
3572
# File 'lib/stripe/resources/invoice.rb', line 3570

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3572
3573
3574
# File 'lib/stripe/resources/invoice.rb', line 3572

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3574
3575
3576
# File 'lib/stripe/resources/invoice.rb', line 3574

def type
  @type
end