Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



8327
8328
8329
8330
8331
# File 'lib/stripe/resources/invoice.rb', line 8327

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



8319
8320
8321
# File 'lib/stripe/resources/invoice.rb', line 8319

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



8322
8323
8324
# File 'lib/stripe/resources/invoice.rb', line 8322

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



8325
8326
8327
# File 'lib/stripe/resources/invoice.rb', line 8325

def type
  @type
end