Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



4259
4260
4261
4262
# File 'lib/stripe/resources/invoice.rb', line 4259

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



4255
4256
4257
# File 'lib/stripe/resources/invoice.rb', line 4255

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



4257
4258
4259
# File 'lib/stripe/resources/invoice.rb', line 4257

def destination
  @destination
end