Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



3801
3802
3803
3804
# File 'lib/stripe/resources/invoice.rb', line 3801

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



3797
3798
3799
# File 'lib/stripe/resources/invoice.rb', line 3797

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



3799
3800
3801
# File 'lib/stripe/resources/invoice.rb', line 3799

def destination
  @destination
end