Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2772
2773
2774
2775
# File 'lib/stripe/resources/invoice.rb', line 2772

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



2768
2769
2770
# File 'lib/stripe/resources/invoice.rb', line 2768

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2770
2771
2772
# File 'lib/stripe/resources/invoice.rb', line 2770

def destination
  @destination
end