Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::TrialSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Phase::TrialSettings
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: EndBehavior
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ TrialSettings
constructor
A new instance of TrialSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ TrialSettings
Returns a new instance of TrialSettings.
4277 4278 4279 |
# File 'lib/stripe/resources/invoice.rb', line 4277 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
4275 4276 4277 |
# File 'lib/stripe/resources/invoice.rb', line 4275 def end_behavior @end_behavior end |