Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: BillUntil
Instance Attribute Summary collapse
-
#bill_until ⇒ Object
The end of the prebilled time period.
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(bill_until: nil, iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_until: nil, iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
3872 3873 3874 3875 |
# File 'lib/stripe/resources/invoice.rb', line 3872 def initialize(bill_until: nil, iterations: nil) @bill_until = bill_until @iterations = iterations end |
Instance Attribute Details
#bill_until ⇒ Object
The end of the prebilled time period.
3868 3869 3870 |
# File 'lib/stripe/resources/invoice.rb', line 3868 def bill_until @bill_until end |
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
3870 3871 3872 |
# File 'lib/stripe/resources/invoice.rb', line 3870 def iterations @iterations end |