Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



4014
4015
4016
4017
4018
4019
# File 'lib/stripe/resources/invoice.rb', line 4014

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



4006
4007
4008
# File 'lib/stripe/resources/invoice.rb', line 4006

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



4008
4009
4010
# File 'lib/stripe/resources/invoice.rb', line 4008

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



4010
4011
4012
# File 'lib/stripe/resources/invoice.rb', line 4010

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



4012
4013
4014
# File 'lib/stripe/resources/invoice.rb', line 4012

def type
  @type
end