Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



3964
3965
3966
3967
3968
3969
# File 'lib/stripe/resources/invoice.rb', line 3964

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



3956
3957
3958
# File 'lib/stripe/resources/invoice.rb', line 3956

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



3958
3959
3960
# File 'lib/stripe/resources/invoice.rb', line 3958

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



3960
3961
3962
# File 'lib/stripe/resources/invoice.rb', line 3960

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



3962
3963
3964
# File 'lib/stripe/resources/invoice.rb', line 3962

def type
  @type
end