Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



3871
3872
3873
3874
3875
3876
# File 'lib/stripe/resources/invoice.rb', line 3871

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



3863
3864
3865
# File 'lib/stripe/resources/invoice.rb', line 3863

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



3865
3866
3867
# File 'lib/stripe/resources/invoice.rb', line 3865

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



3867
3868
3869
# File 'lib/stripe/resources/invoice.rb', line 3867

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



3869
3870
3871
# File 'lib/stripe/resources/invoice.rb', line 3869

def type
  @type
end