Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



3844
3845
3846
3847
3848
3849
# File 'lib/stripe/resources/invoice.rb', line 3844

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



3836
3837
3838
# File 'lib/stripe/resources/invoice.rb', line 3836

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



3838
3839
3840
# File 'lib/stripe/resources/invoice.rb', line 3838

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



3840
3841
3842
# File 'lib/stripe/resources/invoice.rb', line 3840

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



3842
3843
3844
# File 'lib/stripe/resources/invoice.rb', line 3842

def type
  @type
end