Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
7543 7544 7545 7546 7547 7548 |
# File 'lib/stripe/resources/invoice.rb', line 7543 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
7535 7536 7537 |
# File 'lib/stripe/resources/invoice.rb', line 7535 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
7537 7538 7539 |
# File 'lib/stripe/resources/invoice.rb', line 7537 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
7539 7540 7541 |
# File 'lib/stripe/resources/invoice.rb', line 7539 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
7541 7542 7543 |
# File 'lib/stripe/resources/invoice.rb', line 7541 def type @type end |