Class: Stripe::Invoice::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



8671
8672
8673
8674
8675
8676
# File 'lib/stripe/resources/invoice.rb', line 8671

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



8660
8661
8662
# File 'lib/stripe/resources/invoice.rb', line 8660

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



8663
8664
8665
# File 'lib/stripe/resources/invoice.rb', line 8663

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



8666
8667
8668
# File 'lib/stripe/resources/invoice.rb', line 8666

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



8669
8670
8671
# File 'lib/stripe/resources/invoice.rb', line 8669

def type
  @type
end