Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::BillingMode
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::BillingMode
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
Instance Method Summary collapse
-
#initialize(type: nil) ⇒ BillingMode
constructor
A new instance of BillingMode.
Methods inherited from RequestParams
Constructor Details
#initialize(type: nil) ⇒ BillingMode
Returns a new instance of BillingMode.
2992 2993 2994 |
# File 'lib/stripe/resources/invoice.rb', line 2992 def initialize(type: nil) @type = type end |
Instance Attribute Details
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
2990 2991 2992 |
# File 'lib/stripe/resources/invoice.rb', line 2990 def type @type end |