Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#clear_usage ⇒ Object
Delete all usage for a given subscription item.
-
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#id ⇒ Object
Subscription item to update.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
4192 4193 4194 4195 4196 4197 4198 4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 4212 4213 4214 4215 4216 |
# File 'lib/stripe/resources/invoice.rb', line 4192 def initialize( billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @clear_usage = clear_usage @deleted = deleted @discounts = discounts @id = id @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
4170 4171 4172 |
# File 'lib/stripe/resources/invoice.rb', line 4170 def billing_thresholds @billing_thresholds end |
#clear_usage ⇒ Object
Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.
4172 4173 4174 |
# File 'lib/stripe/resources/invoice.rb', line 4172 def clear_usage @clear_usage end |
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
4174 4175 4176 |
# File 'lib/stripe/resources/invoice.rb', line 4174 def deleted @deleted end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
4176 4177 4178 |
# File 'lib/stripe/resources/invoice.rb', line 4176 def discounts @discounts end |
#id ⇒ Object
Subscription item to update.
4178 4179 4180 |
# File 'lib/stripe/resources/invoice.rb', line 4178 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
4180 4181 4182 |
# File 'lib/stripe/resources/invoice.rb', line 4180 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
4182 4183 4184 |
# File 'lib/stripe/resources/invoice.rb', line 4182 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.
4184 4185 4186 |
# File 'lib/stripe/resources/invoice.rb', line 4184 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
4186 4187 4188 |
# File 'lib/stripe/resources/invoice.rb', line 4186 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
4188 4189 4190 |
# File 'lib/stripe/resources/invoice.rb', line 4188 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
4190 4191 4192 |
# File 'lib/stripe/resources/invoice.rb', line 4190 def tax_rates @tax_rates end |