Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



4142
4143
4144
4145
4146
4147
4148
4149
4150
4151
4152
4153
4154
4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
# File 'lib/stripe/resources/invoice.rb', line 4142

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



4120
4121
4122
# File 'lib/stripe/resources/invoice.rb', line 4120

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



4122
4123
4124
# File 'lib/stripe/resources/invoice.rb', line 4122

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



4124
4125
4126
# File 'lib/stripe/resources/invoice.rb', line 4124

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



4126
4127
4128
# File 'lib/stripe/resources/invoice.rb', line 4126

def discounts
  @discounts
end

#idObject

Subscription item to update.



4128
4129
4130
# File 'lib/stripe/resources/invoice.rb', line 4128

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4130
4131
4132
# File 'lib/stripe/resources/invoice.rb', line 4130

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



4132
4133
4134
# File 'lib/stripe/resources/invoice.rb', line 4132

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



4134
4135
4136
# File 'lib/stripe/resources/invoice.rb', line 4134

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



4136
4137
4138
# File 'lib/stripe/resources/invoice.rb', line 4136

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



4138
4139
4140
# File 'lib/stripe/resources/invoice.rb', line 4138

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



4140
4141
4142
# File 'lib/stripe/resources/invoice.rb', line 4140

def tax_rates
  @tax_rates
end