Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



3043
3044
3045
3046
3047
3048
3049
3050
3051
3052
3053
3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
# File 'lib/stripe/resources/invoice.rb', line 3043

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



3021
3022
3023
# File 'lib/stripe/resources/invoice.rb', line 3021

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



3023
3024
3025
# File 'lib/stripe/resources/invoice.rb', line 3023

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



3025
3026
3027
# File 'lib/stripe/resources/invoice.rb', line 3025

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3027
3028
3029
# File 'lib/stripe/resources/invoice.rb', line 3027

def discounts
  @discounts
end

#idObject

Subscription item to update.



3029
3030
3031
# File 'lib/stripe/resources/invoice.rb', line 3029

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3031
3032
3033
# File 'lib/stripe/resources/invoice.rb', line 3031

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



3033
3034
3035
# File 'lib/stripe/resources/invoice.rb', line 3033

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



3035
3036
3037
# File 'lib/stripe/resources/invoice.rb', line 3035

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3037
3038
3039
# File 'lib/stripe/resources/invoice.rb', line 3037

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3039
3040
3041
# File 'lib/stripe/resources/invoice.rb', line 3039

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3041
3042
3043
# File 'lib/stripe/resources/invoice.rb', line 3041

def tax_rates
  @tax_rates
end