Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



4049
4050
4051
4052
4053
4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
4070
4071
4072
4073
# File 'lib/stripe/resources/invoice.rb', line 4049

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



4027
4028
4029
# File 'lib/stripe/resources/invoice.rb', line 4027

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



4029
4030
4031
# File 'lib/stripe/resources/invoice.rb', line 4029

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



4031
4032
4033
# File 'lib/stripe/resources/invoice.rb', line 4031

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



4033
4034
4035
# File 'lib/stripe/resources/invoice.rb', line 4033

def discounts
  @discounts
end

#idObject

Subscription item to update.



4035
4036
4037
# File 'lib/stripe/resources/invoice.rb', line 4035

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4037
4038
4039
# File 'lib/stripe/resources/invoice.rb', line 4037

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



4039
4040
4041
# File 'lib/stripe/resources/invoice.rb', line 4039

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



4041
4042
4043
# File 'lib/stripe/resources/invoice.rb', line 4041

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



4043
4044
4045
# File 'lib/stripe/resources/invoice.rb', line 4043

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



4045
4046
4047
# File 'lib/stripe/resources/invoice.rb', line 4045

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



4047
4048
4049
# File 'lib/stripe/resources/invoice.rb', line 4047

def tax_rates
  @tax_rates
end