Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



3006
3007
3008
3009
3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
3023
3024
3025
3026
3027
3028
3029
3030
# File 'lib/stripe/resources/invoice.rb', line 3006

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



2984
2985
2986
# File 'lib/stripe/resources/invoice.rb', line 2984

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



2986
2987
2988
# File 'lib/stripe/resources/invoice.rb', line 2986

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



2988
2989
2990
# File 'lib/stripe/resources/invoice.rb', line 2988

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



2990
2991
2992
# File 'lib/stripe/resources/invoice.rb', line 2990

def discounts
  @discounts
end

#idObject

Subscription item to update.



2992
2993
2994
# File 'lib/stripe/resources/invoice.rb', line 2992

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2994
2995
2996
# File 'lib/stripe/resources/invoice.rb', line 2994

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



2996
2997
2998
# File 'lib/stripe/resources/invoice.rb', line 2996

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



2998
2999
3000
# File 'lib/stripe/resources/invoice.rb', line 2998

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3000
3001
3002
# File 'lib/stripe/resources/invoice.rb', line 3000

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3002
3003
3004
# File 'lib/stripe/resources/invoice.rb', line 3002

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3004
3005
3006
# File 'lib/stripe/resources/invoice.rb', line 3004

def tax_rates
  @tax_rates
end