Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



3998
3999
4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
# File 'lib/stripe/resources/invoice.rb', line 3998

def initialize(
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



3978
3979
3980
# File 'lib/stripe/resources/invoice.rb', line 3978

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



3980
3981
3982
# File 'lib/stripe/resources/invoice.rb', line 3980

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3982
3983
3984
# File 'lib/stripe/resources/invoice.rb', line 3982

def discounts
  @discounts
end

#idObject

Subscription item to update.



3984
3985
3986
# File 'lib/stripe/resources/invoice.rb', line 3984

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3986
3987
3988
# File 'lib/stripe/resources/invoice.rb', line 3986

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



3988
3989
3990
# File 'lib/stripe/resources/invoice.rb', line 3988

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



3990
3991
3992
# File 'lib/stripe/resources/invoice.rb', line 3990

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3992
3993
3994
# File 'lib/stripe/resources/invoice.rb', line 3992

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3994
3995
3996
# File 'lib/stripe/resources/invoice.rb', line 3994

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3996
3997
3998
# File 'lib/stripe/resources/invoice.rb', line 3996

def tax_rates
  @tax_rates
end