Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
4528 4529 4530 4531 4532 4533 |
# File 'lib/stripe/resources/invoice.rb', line 4528 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
4520 4521 4522 |
# File 'lib/stripe/resources/invoice.rb', line 4520 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
4522 4523 4524 |
# File 'lib/stripe/resources/invoice.rb', line 4522 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
4524 4525 4526 |
# File 'lib/stripe/resources/invoice.rb', line 4524 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
4526 4527 4528 |
# File 'lib/stripe/resources/invoice.rb', line 4526 def promotion_code @promotion_code end |