Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
3977 3978 3979 3980 3981 3982 |
# File 'lib/stripe/resources/invoice.rb', line 3977 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
3969 3970 3971 |
# File 'lib/stripe/resources/invoice.rb', line 3969 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
3971 3972 3973 |
# File 'lib/stripe/resources/invoice.rb', line 3971 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
3973 3974 3975 |
# File 'lib/stripe/resources/invoice.rb', line 3973 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
3975 3976 3977 |
# File 'lib/stripe/resources/invoice.rb', line 3975 def promotion_code @promotion_code end |