Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3959
3960
3961
3962
3963
3964
# File 'lib/stripe/resources/invoice.rb', line 3959

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3951
3952
3953
# File 'lib/stripe/resources/invoice.rb', line 3951

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3953
3954
3955
# File 'lib/stripe/resources/invoice.rb', line 3953

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3955
3956
3957
# File 'lib/stripe/resources/invoice.rb', line 3955

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3957
3958
3959
# File 'lib/stripe/resources/invoice.rb', line 3957

def promotion_code
  @promotion_code
end