Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2935
2936
2937
2938
2939
# File 'lib/stripe/resources/invoice.rb', line 2935

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2929
2930
2931
# File 'lib/stripe/resources/invoice.rb', line 2929

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2931
2932
2933
# File 'lib/stripe/resources/invoice.rb', line 2931

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2933
2934
2935
# File 'lib/stripe/resources/invoice.rb', line 2933

def promotion_code
  @promotion_code
end