Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
8776 8777 8778 8779 8780 8781 |
# File 'lib/stripe/resources/invoice.rb', line 8776 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
8765 8766 8767 |
# File 'lib/stripe/resources/invoice.rb', line 8765 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
8768 8769 8770 |
# File 'lib/stripe/resources/invoice.rb', line 8768 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
8771 8772 8773 |
# File 'lib/stripe/resources/invoice.rb', line 8771 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
8774 8775 8776 |
# File 'lib/stripe/resources/invoice.rb', line 8774 def promotion_code @promotion_code end |