Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4055
4056
4057
4058
4059
# File 'lib/stripe/resources/invoice.rb', line 4055

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4049
4050
4051
# File 'lib/stripe/resources/invoice.rb', line 4049

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4051
4052
4053
# File 'lib/stripe/resources/invoice.rb', line 4051

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4053
4054
4055
# File 'lib/stripe/resources/invoice.rb', line 4053

def type
  @type
end