Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3913
3914
3915
3916
3917
# File 'lib/stripe/resources/invoice.rb', line 3913

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3907
3908
3909
# File 'lib/stripe/resources/invoice.rb', line 3907

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3909
3910
3911
# File 'lib/stripe/resources/invoice.rb', line 3909

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3911
3912
3913
# File 'lib/stripe/resources/invoice.rb', line 3911

def type
  @type
end