Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3929
3930
3931
3932
3933
# File 'lib/stripe/resources/invoice.rb', line 3929

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3923
3924
3925
# File 'lib/stripe/resources/invoice.rb', line 3923

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3925
3926
3927
# File 'lib/stripe/resources/invoice.rb', line 3925

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3927
3928
3929
# File 'lib/stripe/resources/invoice.rb', line 3927

def type
  @type
end