Class: Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
7621 7622 7623 7624 7625 |
# File 'lib/stripe/resources/invoice.rb', line 7621 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
7615 7616 7617 |
# File 'lib/stripe/resources/invoice.rb', line 7615 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
7617 7618 7619 |
# File 'lib/stripe/resources/invoice.rb', line 7617 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
7619 7620 7621 |
# File 'lib/stripe/resources/invoice.rb', line 7619 def type @type end |