Class: Stripe::Invoice::LastFinalizationError

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating [how to proceed with an error](stripe.com/docs/declines#retrying-issuer-declines) if they provide one.



169
170
171
# File 'lib/stripe/resources/invoice.rb', line 169

def advice_code
  @advice_code
end

#chargeObject (readonly)

For card errors, the ID of the failed charge.



171
172
173
# File 'lib/stripe/resources/invoice.rb', line 171

def charge
  @charge
end

#codeObject (readonly)

For some errors that could be handled programmatically, a short string indicating the [error code](stripe.com/docs/error-codes) reported.



173
174
175
# File 'lib/stripe/resources/invoice.rb', line 173

def code
  @code
end

#decline_codeObject (readonly)

For card errors resulting from a card issuer decline, a short string indicating the [card issuer’s reason for the decline](stripe.com/docs/declines#issuer-declines) if they provide one.



175
176
177
# File 'lib/stripe/resources/invoice.rb', line 175

def decline_code
  @decline_code
end

#doc_urlObject (readonly)

A URL to more information about the [error code](stripe.com/docs/error-codes) reported.



177
178
179
# File 'lib/stripe/resources/invoice.rb', line 177

def doc_url
  @doc_url
end

#messageObject (readonly)

A human-readable message providing more details about the error. For card errors, these messages can be shown to your users.



179
180
181
# File 'lib/stripe/resources/invoice.rb', line 179

def message
  @message
end

#network_advice_codeObject (readonly)

For card errors resulting from a card issuer decline, a 2 digit code which indicates the advice given to merchant by the card network on how to proceed with an error.



181
182
183
# File 'lib/stripe/resources/invoice.rb', line 181

def network_advice_code
  @network_advice_code
end

#network_decline_codeObject (readonly)

For card errors resulting from a card issuer decline, a brand specific 2, 3, or 4 digit code which indicates the reason the authorization failed.



183
184
185
# File 'lib/stripe/resources/invoice.rb', line 183

def network_decline_code
  @network_decline_code
end

#paramObject (readonly)

If the error is parameter-specific, the parameter related to the error. For example, you can use this to display a message near the correct form field.



185
186
187
# File 'lib/stripe/resources/invoice.rb', line 185

def param
  @param
end

#payment_intentObject (readonly)

A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.

A PaymentIntent transitions through [multiple statuses](stripe.com/docs/payments/intents#intent-statuses) throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.

Related guide: [Payment Intents API](stripe.com/docs/payments/payment-intents)



197
198
199
# File 'lib/stripe/resources/invoice.rb', line 197

def payment_intent
  @payment_intent
end

#payment_methodObject (readonly)

PaymentMethod objects represent your customer’s payment instruments. You can use them with [PaymentIntents](stripe.com/docs/payments/payment-intents) to collect payments or save them to Customer objects to store instrument details for future payments.

Related guides: [Payment Methods](stripe.com/docs/payments/payment-methods) and [More Payment Scenarios](stripe.com/docs/payments/more-payment-scenarios).



203
204
205
# File 'lib/stripe/resources/invoice.rb', line 203

def payment_method
  @payment_method
end

#payment_method_typeObject (readonly)

If the error is specific to the type of payment method, the payment method type that had a problem. This field is only populated for invoice-related errors.



205
206
207
# File 'lib/stripe/resources/invoice.rb', line 205

def payment_method_type
  @payment_method_type
end

#request_log_urlObject (readonly)

A URL to the request log entry in your dashboard.



207
208
209
# File 'lib/stripe/resources/invoice.rb', line 207

def request_log_url
  @request_log_url
end

#setup_intentObject (readonly)

A SetupIntent guides you through the process of setting up and saving a customer’s payment credentials for future payments. For example, you can use a SetupIntent to set up and save your customer’s card without immediately collecting a payment. Later, you can use [PaymentIntents](stripe.com/docs/api#payment_intents) to drive the payment flow.

Create a SetupIntent when you’re ready to collect your customer’s payment credentials. Don’t maintain long-lived, unconfirmed SetupIntents because they might not be valid. The SetupIntent transitions through multiple [statuses](docs.stripe.com/payments/intents#intent-statuses) as it guides you through the setup process.

Successful SetupIntents result in payment credentials that are optimized for future payments. For example, cardholders in [certain regions](stripe.com/guides/strong-customer-authentication) might need to be run through [Strong Customer Authentication](docs.stripe.com/strong-customer-authentication) during payment method collection to streamline later [off-session payments](docs.stripe.com/payments/setup-intents). If you use the SetupIntent with a [Customer](stripe.com/docs/api#setup_intent_object-customer), it automatically attaches the resulting payment method to that Customer after successful setup. We recommend using SetupIntents or [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) on PaymentIntents to save payment methods to prevent saving invalid or unoptimized payment methods.

By using SetupIntents, you can reduce friction for your customers, even as regulations change over time.

Related guide: [Setup Intents API](docs.stripe.com/payments/setup-intents)



229
230
231
# File 'lib/stripe/resources/invoice.rb', line 229

def setup_intent
  @setup_intent
end

#sourceObject (readonly)

Attribute for field source



231
232
233
# File 'lib/stripe/resources/invoice.rb', line 231

def source
  @source
end

#typeObject (readonly)

The type of error returned. One of ‘api_error`, `card_error`, `idempotency_error`, or `invalid_request_error`



233
234
235
# File 'lib/stripe/resources/invoice.rb', line 233

def type
  @type
end