Class: Stripe::Invoice::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The collection method of the invoice to retrieve.
-
#created ⇒ Object
Only return invoices that were created during the given date interval.
-
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
-
#customer_account ⇒ Object
Only return invoices for the account specified by this account ID.
-
#due_date ⇒ Object
Attribute for param field due_date.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`.
-
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
Instance Method Summary collapse
-
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 |
# File 'lib/stripe/resources/invoice.rb', line 1229 def initialize( collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil ) @collection_method = collection_method @created = created @customer = customer @customer_account = customer_account @due_date = due_date @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#collection_method ⇒ Object
The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.
1207 1208 1209 |
# File 'lib/stripe/resources/invoice.rb', line 1207 def collection_method @collection_method end |
#created ⇒ Object
Only return invoices that were created during the given date interval.
1209 1210 1211 |
# File 'lib/stripe/resources/invoice.rb', line 1209 def created @created end |
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
1211 1212 1213 |
# File 'lib/stripe/resources/invoice.rb', line 1211 def customer @customer end |
#customer_account ⇒ Object
Only return invoices for the account specified by this account ID.
1213 1214 1215 |
# File 'lib/stripe/resources/invoice.rb', line 1213 def customer_account @customer_account end |
#due_date ⇒ Object
Attribute for param field due_date
1215 1216 1217 |
# File 'lib/stripe/resources/invoice.rb', line 1215 def due_date @due_date end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1217 1218 1219 |
# File 'lib/stripe/resources/invoice.rb', line 1217 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1219 1220 1221 |
# File 'lib/stripe/resources/invoice.rb', line 1219 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1221 1222 1223 |
# File 'lib/stripe/resources/invoice.rb', line 1221 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1223 1224 1225 |
# File 'lib/stripe/resources/invoice.rb', line 1223 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)
1225 1226 1227 |
# File 'lib/stripe/resources/invoice.rb', line 1225 def status @status end |
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
1227 1228 1229 |
# File 'lib/stripe/resources/invoice.rb', line 1227 def subscription @subscription end |