Class: Stripe::Invoice::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The collection method of the invoice to retrieve.
-
#created ⇒ Object
Only return invoices that were created during the given date interval.
-
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
-
#customer_account ⇒ Object
Only return invoices for the account specified by this account ID.
-
#due_date ⇒ Object
Attribute for param field due_date.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`.
-
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
Instance Method Summary collapse
-
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1637 1638 1639 1640 1641 1642 1643 1644 1645 1646 1647 1648 1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 |
# File 'lib/stripe/resources/invoice.rb', line 1637 def initialize( collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil ) @collection_method = collection_method @created = created @customer = customer @customer_account = customer_account @due_date = due_date @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#collection_method ⇒ Object
The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.
1615 1616 1617 |
# File 'lib/stripe/resources/invoice.rb', line 1615 def collection_method @collection_method end |
#created ⇒ Object
Only return invoices that were created during the given date interval.
1617 1618 1619 |
# File 'lib/stripe/resources/invoice.rb', line 1617 def created @created end |
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
1619 1620 1621 |
# File 'lib/stripe/resources/invoice.rb', line 1619 def customer @customer end |
#customer_account ⇒ Object
Only return invoices for the account specified by this account ID.
1621 1622 1623 |
# File 'lib/stripe/resources/invoice.rb', line 1621 def customer_account @customer_account end |
#due_date ⇒ Object
Attribute for param field due_date
1623 1624 1625 |
# File 'lib/stripe/resources/invoice.rb', line 1623 def due_date @due_date end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1625 1626 1627 |
# File 'lib/stripe/resources/invoice.rb', line 1625 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1627 1628 1629 |
# File 'lib/stripe/resources/invoice.rb', line 1627 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1629 1630 1631 |
# File 'lib/stripe/resources/invoice.rb', line 1629 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1631 1632 1633 |
# File 'lib/stripe/resources/invoice.rb', line 1631 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)
1633 1634 1635 |
# File 'lib/stripe/resources/invoice.rb', line 1633 def status @status end |
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
1635 1636 1637 |
# File 'lib/stripe/resources/invoice.rb', line 1635 def subscription @subscription end |