Class: Stripe::Invoice::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The collection method of the invoice to retrieve.
-
#created ⇒ Object
Only return invoices that were created during the given date interval.
-
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
-
#customer_account ⇒ Object
Only return invoices for the account specified by this account ID.
-
#due_date ⇒ Object
Attribute for param field due_date.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`.
-
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
Instance Method Summary collapse
-
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/stripe/resources/invoice.rb', line 1222 def initialize( collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil ) @collection_method = collection_method @created = created @customer = customer @customer_account = customer_account @due_date = due_date @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#collection_method ⇒ Object
The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.
1200 1201 1202 |
# File 'lib/stripe/resources/invoice.rb', line 1200 def collection_method @collection_method end |
#created ⇒ Object
Only return invoices that were created during the given date interval.
1202 1203 1204 |
# File 'lib/stripe/resources/invoice.rb', line 1202 def created @created end |
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
1204 1205 1206 |
# File 'lib/stripe/resources/invoice.rb', line 1204 def customer @customer end |
#customer_account ⇒ Object
Only return invoices for the account specified by this account ID.
1206 1207 1208 |
# File 'lib/stripe/resources/invoice.rb', line 1206 def customer_account @customer_account end |
#due_date ⇒ Object
Attribute for param field due_date
1208 1209 1210 |
# File 'lib/stripe/resources/invoice.rb', line 1208 def due_date @due_date end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1210 1211 1212 |
# File 'lib/stripe/resources/invoice.rb', line 1210 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1212 1213 1214 |
# File 'lib/stripe/resources/invoice.rb', line 1212 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1214 1215 1216 |
# File 'lib/stripe/resources/invoice.rb', line 1214 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1216 1217 1218 |
# File 'lib/stripe/resources/invoice.rb', line 1216 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)
1218 1219 1220 |
# File 'lib/stripe/resources/invoice.rb', line 1218 def status @status end |
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
1220 1221 1222 |
# File 'lib/stripe/resources/invoice.rb', line 1220 def subscription @subscription end |