Class: Stripe::Invoice::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Created, DueDate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



1182
1183
1184
1185
1186
1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
# File 'lib/stripe/resources/invoice.rb', line 1182

def initialize(
  collection_method: nil,
  created: nil,
  customer: nil,
  customer_account: nil,
  due_date: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @collection_method = collection_method
  @created = created
  @customer = customer
  @customer_account = 
  @due_date = due_date
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#collection_methodObject

The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.



1160
1161
1162
# File 'lib/stripe/resources/invoice.rb', line 1160

def collection_method
  @collection_method
end

#createdObject

Only return invoices that were created during the given date interval.



1162
1163
1164
# File 'lib/stripe/resources/invoice.rb', line 1162

def created
  @created
end

#customerObject

Only return invoices for the customer specified by this customer ID.



1164
1165
1166
# File 'lib/stripe/resources/invoice.rb', line 1164

def customer
  @customer
end

#customer_accountObject

Only return invoices for the account specified by this account ID.



1166
1167
1168
# File 'lib/stripe/resources/invoice.rb', line 1166

def 
  @customer_account
end

#due_dateObject

Attribute for param field due_date



1168
1169
1170
# File 'lib/stripe/resources/invoice.rb', line 1168

def due_date
  @due_date
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1170
1171
1172
# File 'lib/stripe/resources/invoice.rb', line 1170

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1172
1173
1174
# File 'lib/stripe/resources/invoice.rb', line 1172

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1174
1175
1176
# File 'lib/stripe/resources/invoice.rb', line 1174

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1176
1177
1178
# File 'lib/stripe/resources/invoice.rb', line 1176

def starting_after
  @starting_after
end

#statusObject

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



1178
1179
1180
# File 'lib/stripe/resources/invoice.rb', line 1178

def status
  @status
end

#subscriptionObject

Only return invoices for the subscription specified by this subscription ID.



1180
1181
1182
# File 'lib/stripe/resources/invoice.rb', line 1180

def subscription
  @subscription
end