Class: Stripe::Invoice::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The collection method of the invoice to retrieve.
-
#created ⇒ Object
Only return invoices that were created during the given date interval.
-
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
-
#customer_account ⇒ Object
Attribute for param field customer_account.
-
#due_date ⇒ Object
Attribute for param field due_date.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`.
-
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
Instance Method Summary collapse
-
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 |
# File 'lib/stripe/resources/invoice.rb', line 1182 def initialize( collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil ) @collection_method = collection_method @created = created @customer = customer @customer_account = customer_account @due_date = due_date @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#collection_method ⇒ Object
The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.
1160 1161 1162 |
# File 'lib/stripe/resources/invoice.rb', line 1160 def collection_method @collection_method end |
#created ⇒ Object
Only return invoices that were created during the given date interval.
1162 1163 1164 |
# File 'lib/stripe/resources/invoice.rb', line 1162 def created @created end |
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
1164 1165 1166 |
# File 'lib/stripe/resources/invoice.rb', line 1164 def customer @customer end |
#customer_account ⇒ Object
Attribute for param field customer_account
1166 1167 1168 |
# File 'lib/stripe/resources/invoice.rb', line 1166 def customer_account @customer_account end |
#due_date ⇒ Object
Attribute for param field due_date
1168 1169 1170 |
# File 'lib/stripe/resources/invoice.rb', line 1168 def due_date @due_date end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1170 1171 1172 |
# File 'lib/stripe/resources/invoice.rb', line 1170 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1172 1173 1174 |
# File 'lib/stripe/resources/invoice.rb', line 1172 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1174 1175 1176 |
# File 'lib/stripe/resources/invoice.rb', line 1174 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1176 1177 1178 |
# File 'lib/stripe/resources/invoice.rb', line 1176 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)
1178 1179 1180 |
# File 'lib/stripe/resources/invoice.rb', line 1178 def status @status end |
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
1180 1181 1182 |
# File 'lib/stripe/resources/invoice.rb', line 1180 def subscription @subscription end |