Class: Stripe::Invoice::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Created, DueDate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collection_method: nil, created: nil, customer: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



1164
1165
1166
1167
1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
# File 'lib/stripe/resources/invoice.rb', line 1164

def initialize(
  collection_method: nil,
  created: nil,
  customer: nil,
  due_date: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @collection_method = collection_method
  @created = created
  @customer = customer
  @due_date = due_date
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#collection_methodObject

The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.



1144
1145
1146
# File 'lib/stripe/resources/invoice.rb', line 1144

def collection_method
  @collection_method
end

#createdObject

Only return invoices that were created during the given date interval.



1146
1147
1148
# File 'lib/stripe/resources/invoice.rb', line 1146

def created
  @created
end

#customerObject

Only return invoices for the customer specified by this customer ID.



1148
1149
1150
# File 'lib/stripe/resources/invoice.rb', line 1148

def customer
  @customer
end

#due_dateObject

Attribute for param field due_date



1150
1151
1152
# File 'lib/stripe/resources/invoice.rb', line 1150

def due_date
  @due_date
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



1152
1153
1154
# File 'lib/stripe/resources/invoice.rb', line 1152

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



1154
1155
1156
# File 'lib/stripe/resources/invoice.rb', line 1154

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1156
1157
1158
# File 'lib/stripe/resources/invoice.rb', line 1156

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



1158
1159
1160
# File 'lib/stripe/resources/invoice.rb', line 1158

def starting_after
  @starting_after
end

#statusObject

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



1160
1161
1162
# File 'lib/stripe/resources/invoice.rb', line 1160

def status
  @status
end

#subscriptionObject

Only return invoices for the subscription specified by this subscription ID.



1162
1163
1164
# File 'lib/stripe/resources/invoice.rb', line 1162

def subscription
  @subscription
end