Class: Stripe::Invoice::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The collection method of the invoice to retrieve.
-
#created ⇒ Object
Only return invoices that were created during the given date interval.
-
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
-
#due_date ⇒ Object
Attribute for param field due_date.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`.
-
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
Instance Method Summary collapse
-
#initialize(collection_method: nil, created: nil, customer: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, created: nil, customer: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 |
# File 'lib/stripe/resources/invoice.rb', line 1359 def initialize( collection_method: nil, created: nil, customer: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil ) @collection_method = collection_method @created = created @customer = customer @due_date = due_date @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#collection_method ⇒ Object
The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.
1330 1331 1332 |
# File 'lib/stripe/resources/invoice.rb', line 1330 def collection_method @collection_method end |
#created ⇒ Object
Only return invoices that were created during the given date interval.
1333 1334 1335 |
# File 'lib/stripe/resources/invoice.rb', line 1333 def created @created end |
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
1336 1337 1338 |
# File 'lib/stripe/resources/invoice.rb', line 1336 def customer @customer end |
#due_date ⇒ Object
Attribute for param field due_date
1339 1340 1341 |
# File 'lib/stripe/resources/invoice.rb', line 1339 def due_date @due_date end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
1342 1343 1344 |
# File 'lib/stripe/resources/invoice.rb', line 1342 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1345 1346 1347 |
# File 'lib/stripe/resources/invoice.rb', line 1345 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1348 1349 1350 |
# File 'lib/stripe/resources/invoice.rb', line 1348 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
1351 1352 1353 |
# File 'lib/stripe/resources/invoice.rb', line 1351 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)
1354 1355 1356 |
# File 'lib/stripe/resources/invoice.rb', line 1354 def status @status end |
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
1357 1358 1359 |
# File 'lib/stripe/resources/invoice.rb', line 1357 def subscription @subscription end |