Class: Stripe::Invoice::ListUpcomingLineItemsParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AutomaticTax, CustomerDetails, Discount, InvoiceItem, Issuer, ScheduleDetails, SubscriptionDetails, SubscriptionItem, SubscriptionPrebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, coupon: nil, currency: nil, customer: nil, customer_details: nil, discounts: nil, ending_before: nil, expand: nil, invoice_items: nil, issuer: nil, limit: nil, on_behalf_of: nil, preview_mode: nil, schedule: nil, schedule_details: nil, starting_after: nil, subscription: nil, subscription_billing_cycle_anchor: nil, subscription_cancel_at: nil, subscription_cancel_at_period_end: nil, subscription_cancel_now: nil, subscription_default_tax_rates: nil, subscription_details: nil, subscription_items: nil, subscription_prebilling: nil, subscription_proration_behavior: nil, subscription_proration_date: nil, subscription_resume_at: nil, subscription_start_date: nil, subscription_trial_end: nil, subscription_trial_from_plan: nil) ⇒ ListUpcomingLineItemsParams

Returns a new instance of ListUpcomingLineItemsParams.



6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
6360
6361
6362
6363
6364
6365
6366
6367
6368
6369
6370
6371
6372
6373
6374
6375
6376
6377
6378
6379
6380
6381
6382
6383
6384
6385
6386
6387
6388
6389
6390
6391
6392
6393
6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
6410
6411
6412
6413
6414
# File 'lib/stripe/resources/invoice.rb', line 6350

def initialize(
  automatic_tax: nil,
  coupon: nil,
  currency: nil,
  customer: nil,
  customer_details: nil,
  discounts: nil,
  ending_before: nil,
  expand: nil,
  invoice_items: nil,
  issuer: nil,
  limit: nil,
  on_behalf_of: nil,
  preview_mode: nil,
  schedule: nil,
  schedule_details: nil,
  starting_after: nil,
  subscription: nil,
  subscription_billing_cycle_anchor: nil,
  subscription_cancel_at: nil,
  subscription_cancel_at_period_end: nil,
  subscription_cancel_now: nil,
  subscription_default_tax_rates: nil,
  subscription_details: nil,
  subscription_items: nil,
  subscription_prebilling: nil,
  subscription_proration_behavior: nil,
  subscription_proration_date: nil,
  subscription_resume_at: nil,
  subscription_start_date: nil,
  subscription_trial_end: nil,
  subscription_trial_from_plan: nil
)
  @automatic_tax = automatic_tax
  @coupon = coupon
  @currency = currency
  @customer = customer
  @customer_details = customer_details
  @discounts = discounts
  @ending_before = ending_before
  @expand = expand
  @invoice_items = invoice_items
  @issuer = issuer
  @limit = limit
  @on_behalf_of = on_behalf_of
  @preview_mode = preview_mode
  @schedule = schedule
  @schedule_details = schedule_details
  @starting_after = starting_after
  @subscription = subscription
  @subscription_billing_cycle_anchor = subscription_billing_cycle_anchor
  @subscription_cancel_at = subscription_cancel_at
  @subscription_cancel_at_period_end = subscription_cancel_at_period_end
  @subscription_cancel_now = subscription_cancel_now
  @subscription_default_tax_rates = subscription_default_tax_rates
  @subscription_details = subscription_details
  @subscription_items = subscription_items
  @subscription_prebilling = subscription_prebilling
  @subscription_proration_behavior = subscription_proration_behavior
  @subscription_proration_date = subscription_proration_date
  @subscription_resume_at = subscription_resume_at
  @subscription_start_date = subscription_start_date
  @subscription_trial_end = subscription_trial_end
  @subscription_trial_from_plan = subscription_trial_from_plan
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax lookup for this invoice preview.



6258
6259
6260
# File 'lib/stripe/resources/invoice.rb', line 6258

def automatic_tax
  @automatic_tax
end

#couponObject

The ID of the coupon to apply to this phase of the subscription schedule. This field has been deprecated and will be removed in a future API version. Use ‘discounts` instead.



6261
6262
6263
# File 'lib/stripe/resources/invoice.rb', line 6261

def coupon
  @coupon
end

#currencyObject

The currency to preview this invoice in. Defaults to that of ‘customer` if not specified.



6264
6265
6266
# File 'lib/stripe/resources/invoice.rb', line 6264

def currency
  @currency
end

#customerObject

The identifier of the customer whose upcoming invoice you’d like to retrieve. If ‘automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.



6267
6268
6269
# File 'lib/stripe/resources/invoice.rb', line 6267

def customer
  @customer
end

#customer_detailsObject

Details about the customer you want to invoice or overrides for an existing customer. If ‘automatic_tax` is enabled then one of `customer`, `customer_details`, `subscription`, or `schedule` must be set.



6270
6271
6272
# File 'lib/stripe/resources/invoice.rb', line 6270

def customer_details
  @customer_details
end

#discountsObject

The coupons to redeem into discounts for the invoice preview. If not specified, inherits the discount from the subscription or customer. This works for both coupons directly applied to an invoice and coupons applied to a subscription. Pass an empty string to avoid inheriting any discounts.



6273
6274
6275
# File 'lib/stripe/resources/invoice.rb', line 6273

def discounts
  @discounts
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



6276
6277
6278
# File 'lib/stripe/resources/invoice.rb', line 6276

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



6279
6280
6281
# File 'lib/stripe/resources/invoice.rb', line 6279

def expand
  @expand
end

#invoice_itemsObject

List of invoice items to add or update in the upcoming invoice preview (up to 250).



6282
6283
6284
# File 'lib/stripe/resources/invoice.rb', line 6282

def invoice_items
  @invoice_items
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



6285
6286
6287
# File 'lib/stripe/resources/invoice.rb', line 6285

def issuer
  @issuer
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



6288
6289
6290
# File 'lib/stripe/resources/invoice.rb', line 6288

def limit
  @limit
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



6291
6292
6293
# File 'lib/stripe/resources/invoice.rb', line 6291

def on_behalf_of
  @on_behalf_of
end

#preview_modeObject

Customizes the types of values to include when calculating the invoice. Defaults to ‘next` if unspecified.



6294
6295
6296
# File 'lib/stripe/resources/invoice.rb', line 6294

def preview_mode
  @preview_mode
end

#scheduleObject

The identifier of the schedule whose upcoming invoice you’d like to retrieve. Cannot be used with subscription or subscription fields.



6297
6298
6299
# File 'lib/stripe/resources/invoice.rb', line 6297

def schedule
  @schedule
end

#schedule_detailsObject

The schedule creation or modification params to apply as a preview. Cannot be used with ‘subscription` or `subscription_` prefixed fields.



6300
6301
6302
# File 'lib/stripe/resources/invoice.rb', line 6300

def schedule_details
  @schedule_details
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



6303
6304
6305
# File 'lib/stripe/resources/invoice.rb', line 6303

def starting_after
  @starting_after
end

#subscriptionObject

The identifier of the subscription for which you’d like to retrieve the upcoming invoice. If not provided, but a ‘subscription_details.items` is provided, you will preview creating a subscription with those items. If neither `subscription` nor `subscription_details.items` is provided, you will retrieve the next upcoming invoice from among the customer’s subscriptions.



6306
6307
6308
# File 'lib/stripe/resources/invoice.rb', line 6306

def subscription
  @subscription
end

#subscription_billing_cycle_anchorObject

For new subscriptions, a future timestamp to anchor the subscription’s [billing cycle](stripe.com/docs/subscriptions/billing-cycle). This is used to determine the date of the first full invoice, and, for plans with ‘month` or `year` intervals, the day of the month for subsequent invoices. For existing subscriptions, the value can only be set to `now` or `unchanged`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.billing_cycle_anchor` instead.



6309
6310
6311
# File 'lib/stripe/resources/invoice.rb', line 6309

def subscription_billing_cycle_anchor
  @subscription_billing_cycle_anchor
end

#subscription_cancel_atObject

A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using ‘proration_behavior`. If set during a future period, this will always cause a proration for that period. This field has been deprecated and will be removed in a future API version. Use `subscription_details.cancel_at` instead.



6312
6313
6314
# File 'lib/stripe/resources/invoice.rb', line 6312

def subscription_cancel_at
  @subscription_cancel_at
end

#subscription_cancel_at_period_endObject

Indicate whether this subscription should cancel at the end of the current period (‘current_period_end`). Defaults to `false`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.cancel_at_period_end` instead.



6315
6316
6317
# File 'lib/stripe/resources/invoice.rb', line 6315

def subscription_cancel_at_period_end
  @subscription_cancel_at_period_end
end

#subscription_cancel_nowObject

This simulates the subscription being canceled or expired immediately. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.cancel_now` instead.



6318
6319
6320
# File 'lib/stripe/resources/invoice.rb', line 6318

def subscription_cancel_now
  @subscription_cancel_now
end

#subscription_default_tax_ratesObject

If provided, the invoice returned will preview updating or creating a subscription with these default tax rates. The default tax rates will apply to any line item that does not have ‘tax_rates` set. This field has been deprecated and will be removed in a future API version. Use `subscription_details.default_tax_rates` instead.



6321
6322
6323
# File 'lib/stripe/resources/invoice.rb', line 6321

def subscription_default_tax_rates
  @subscription_default_tax_rates
end

#subscription_detailsObject

The subscription creation or modification params to apply as a preview. Cannot be used with ‘schedule` or `schedule_details` fields.



6324
6325
6326
# File 'lib/stripe/resources/invoice.rb', line 6324

def subscription_details
  @subscription_details
end

#subscription_itemsObject

A list of up to 20 subscription items, each with an attached price. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.items` instead.



6327
6328
6329
# File 'lib/stripe/resources/invoice.rb', line 6327

def subscription_items
  @subscription_items
end

#subscription_prebillingObject

The pre-billing to apply to the subscription as a preview. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.prebilling` instead.



6330
6331
6332
# File 'lib/stripe/resources/invoice.rb', line 6330

def subscription_prebilling
  @subscription_prebilling
end

#subscription_proration_behaviorObject

Determines how to handle [prorations](stripe.com/docs/billing/subscriptions/prorations) when the billing cycle changes (e.g., when switching plans, resetting ‘billing_cycle_anchor=now`, or starting a trial), or if an item’s ‘quantity` changes. The default value is `create_prorations`. This field has been deprecated and will be removed in a future API version. Use `subscription_details.proration_behavior` instead.



6333
6334
6335
# File 'lib/stripe/resources/invoice.rb', line 6333

def subscription_proration_behavior
  @subscription_proration_behavior
end

#subscription_proration_dateObject

If previewing an update to a subscription, and doing proration, ‘subscription_proration_date` forces the proration to be calculated as though the update was done at the specified time. The time given must be within the current subscription period and within the current phase of the schedule backing this subscription, if the schedule exists. If set, `subscription`, and one of `subscription_items`, or `subscription_trial_end` are required. Also, `subscription_proration_behavior` cannot be set to ’none’. This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.proration_date` instead.



6336
6337
6338
# File 'lib/stripe/resources/invoice.rb', line 6336

def subscription_proration_date
  @subscription_proration_date
end

#subscription_resume_atObject

For paused subscriptions, setting ‘subscription_resume_at` to `now` will preview the invoice that will be generated if the subscription is resumed. This field has been deprecated and will be removed in a future API version. Use `subscription_details.resume_at` instead.



6339
6340
6341
# File 'lib/stripe/resources/invoice.rb', line 6339

def subscription_resume_at
  @subscription_resume_at
end

#subscription_start_dateObject

Date a subscription is intended to start (can be future or past). This field has been deprecated and will be removed in a future API version. Use ‘subscription_details.start_date` instead.



6342
6343
6344
# File 'lib/stripe/resources/invoice.rb', line 6342

def subscription_start_date
  @subscription_start_date
end

#subscription_trial_endObject

If provided, the invoice returned will preview updating or creating a subscription with that trial end. If set, one of ‘subscription_items` or `subscription` is required. This field has been deprecated and will be removed in a future API version. Use `subscription_details.trial_end` instead.



6345
6346
6347
# File 'lib/stripe/resources/invoice.rb', line 6345

def subscription_trial_end
  @subscription_trial_end
end

#subscription_trial_from_planObject

Indicates if a plan’s ‘trial_period_days` should be applied to the subscription. Setting `subscription_trial_end` per subscription is preferred, and this defaults to `false`. Setting this flag to `true` together with `subscription_trial_end` is not allowed. See [Using trial periods on subscriptions](stripe.com/docs/billing/subscriptions/trials) to learn more.



6348
6349
6350
# File 'lib/stripe/resources/invoice.rb', line 6348

def subscription_trial_from_plan
  @subscription_trial_from_plan
end