Class: Stripe::Invoice::ListUpcomingLineItemsParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
3872 3873 3874 3875 3876 |
# File 'lib/stripe/resources/invoice.rb', line 3872 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
3866 3867 3868 |
# File 'lib/stripe/resources/invoice.rb', line 3866 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
3868 3869 3870 |
# File 'lib/stripe/resources/invoice.rb', line 3868 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
3870 3871 3872 |
# File 'lib/stripe/resources/invoice.rb', line 3870 def type @type end |