Class: Stripe::Invoice::ListUpcomingLineItemsParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4458
4459
4460
4461
4462
# File 'lib/stripe/resources/invoice.rb', line 4458

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4450
4451
4452
# File 'lib/stripe/resources/invoice.rb', line 4450

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4453
4454
4455
# File 'lib/stripe/resources/invoice.rb', line 4453

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4456
4457
4458
# File 'lib/stripe/resources/invoice.rb', line 4456

def type
  @type
end