Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AmendmentEnd, AmendmentStart, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details to identify the end of the time range modified by the proposed change.
-
#amendment_start ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
-
#billing_cycle_anchor ⇒ Object
For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.
-
#discount_actions ⇒ Object
Changes to the coupons being redeemed or discounts being applied during the amendment time span.
-
#item_actions ⇒ Object
Changes to the subscription items during the amendment time span.
-
#metadata_actions ⇒ Object
Instructions for how to modify phase metadata.
-
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the amendment time span.
-
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
-
#set_schedule_end ⇒ Object
Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment
constructor
A new instance of Amendment.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment
Returns a new instance of Amendment.
5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 5176 5177 5178 5179 5180 5181 5182 5183 |
# File 'lib/stripe/resources/invoice.rb', line 5161 def initialize( amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil ) @amendment_end = amendment_end @amendment_start = amendment_start @billing_cycle_anchor = billing_cycle_anchor @discount_actions = discount_actions @item_actions = item_actions @metadata_actions = @proration_behavior = proration_behavior @set_pause_collection = set_pause_collection @set_schedule_end = set_schedule_end @trial_settings = trial_settings end |
Instance Attribute Details
#amendment_end ⇒ Object
Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.
5132 5133 5134 |
# File 'lib/stripe/resources/invoice.rb', line 5132 def amendment_end @amendment_end end |
#amendment_start ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
5135 5136 5137 |
# File 'lib/stripe/resources/invoice.rb', line 5135 def amendment_start @amendment_start end |
#billing_cycle_anchor ⇒ Object
For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.
5138 5139 5140 |
# File 'lib/stripe/resources/invoice.rb', line 5138 def billing_cycle_anchor @billing_cycle_anchor end |
#discount_actions ⇒ Object
Changes to the coupons being redeemed or discounts being applied during the amendment time span.
5141 5142 5143 |
# File 'lib/stripe/resources/invoice.rb', line 5141 def discount_actions @discount_actions end |
#item_actions ⇒ Object
Changes to the subscription items during the amendment time span.
5144 5145 5146 |
# File 'lib/stripe/resources/invoice.rb', line 5144 def item_actions @item_actions end |
#metadata_actions ⇒ Object
Instructions for how to modify phase metadata
5147 5148 5149 |
# File 'lib/stripe/resources/invoice.rb', line 5147 def @metadata_actions end |
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.
5150 5151 5152 |
# File 'lib/stripe/resources/invoice.rb', line 5150 def proration_behavior @proration_behavior end |
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
5153 5154 5155 |
# File 'lib/stripe/resources/invoice.rb', line 5153 def set_pause_collection @set_pause_collection end |
#set_schedule_end ⇒ Object
Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.
5156 5157 5158 |
# File 'lib/stripe/resources/invoice.rb', line 5156 def set_schedule_end @set_schedule_end end |
#trial_settings ⇒ Object
Settings related to subscription trials.
5159 5160 5161 |
# File 'lib/stripe/resources/invoice.rb', line 5159 def trial_settings @trial_settings end |