Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



4126
4127
4128
4129
4130
4131
# File 'lib/stripe/resources/invoice.rb', line 4126

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



4118
4119
4120
# File 'lib/stripe/resources/invoice.rb', line 4118

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



4120
4121
4122
# File 'lib/stripe/resources/invoice.rb', line 4120

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



4122
4123
4124
# File 'lib/stripe/resources/invoice.rb', line 4122

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



4124
4125
4126
# File 'lib/stripe/resources/invoice.rb', line 4124

def type
  @type
end