Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
4842 4843 4844 4845 4846 4847 |
# File 'lib/stripe/resources/invoice.rb', line 4842 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
4831 4832 4833 |
# File 'lib/stripe/resources/invoice.rb', line 4831 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
4834 4835 4836 |
# File 'lib/stripe/resources/invoice.rb', line 4834 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
4837 4838 4839 |
# File 'lib/stripe/resources/invoice.rb', line 4837 def set @set end |
#type ⇒ Object
Determines the type of discount action.
4840 4841 4842 |
# File 'lib/stripe/resources/invoice.rb', line 4840 def type @type end |