Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
4782 4783 4784 4785 4786 4787 4788 4789 4790 4791 4792 4793 4794 |
# File 'lib/stripe/resources/invoice.rb', line 4782 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
4768 4769 4770 |
# File 'lib/stripe/resources/invoice.rb', line 4768 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
4771 4772 4773 |
# File 'lib/stripe/resources/invoice.rb', line 4771 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
4774 4775 4776 |
# File 'lib/stripe/resources/invoice.rb', line 4774 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
4777 4778 4779 |
# File 'lib/stripe/resources/invoice.rb', line 4777 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
4780 4781 4782 |
# File 'lib/stripe/resources/invoice.rb', line 4780 def promotion_code @promotion_code end |