Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



4155
4156
4157
4158
4159
4160
4161
4162
4163
4164
4165
4166
4167
# File 'lib/stripe/resources/invoice.rb', line 4155

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



4145
4146
4147
# File 'lib/stripe/resources/invoice.rb', line 4145

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



4147
4148
4149
# File 'lib/stripe/resources/invoice.rb', line 4147

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4149
4150
4151
# File 'lib/stripe/resources/invoice.rb', line 4149

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



4151
4152
4153
# File 'lib/stripe/resources/invoice.rb', line 4151

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



4153
4154
4155
# File 'lib/stripe/resources/invoice.rb', line 4153

def promotion_code
  @promotion_code
end