Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



4178
4179
4180
4181
4182
# File 'lib/stripe/resources/invoice.rb', line 4178

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



4172
4173
4174
# File 'lib/stripe/resources/invoice.rb', line 4172

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



4174
4175
4176
# File 'lib/stripe/resources/invoice.rb', line 4174

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



4176
4177
4178
# File 'lib/stripe/resources/invoice.rb', line 4176

def promotion_code
  @promotion_code
end