Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



4931
4932
4933
4934
4935
4936
4937
4938
4939
4940
4941
4942
4943
4944
4945
# File 'lib/stripe/resources/invoice.rb', line 4931

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



4914
4915
4916
# File 'lib/stripe/resources/invoice.rb', line 4914

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4917
4918
4919
# File 'lib/stripe/resources/invoice.rb', line 4917

def 
  @metadata
end

#priceObject

The ID of the price object.



4920
4921
4922
# File 'lib/stripe/resources/invoice.rb', line 4920

def price
  @price
end

#quantityObject

Quantity for this item.



4923
4924
4925
# File 'lib/stripe/resources/invoice.rb', line 4923

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



4926
4927
4928
# File 'lib/stripe/resources/invoice.rb', line 4926

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



4929
4930
4931
# File 'lib/stripe/resources/invoice.rb', line 4929

def trial
  @trial
end