Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Amendment::ItemAction::Set::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4999
5000
5001
5002
5003
5004
# File 'lib/stripe/resources/invoice.rb', line 4999

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4988
4989
4990
# File 'lib/stripe/resources/invoice.rb', line 4988

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4991
4992
4993
# File 'lib/stripe/resources/invoice.rb', line 4991

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4994
4995
4996
# File 'lib/stripe/resources/invoice.rb', line 4994

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4997
4998
4999
# File 'lib/stripe/resources/invoice.rb', line 4997

def promotion_code
  @promotion_code
end