Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4758
4759
4760
4761
4762
4763
# File 'lib/stripe/resources/invoice.rb', line 4758

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4750
4751
4752
# File 'lib/stripe/resources/invoice.rb', line 4750

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4752
4753
4754
# File 'lib/stripe/resources/invoice.rb', line 4752

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4754
4755
4756
# File 'lib/stripe/resources/invoice.rb', line 4754

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4756
4757
4758
# File 'lib/stripe/resources/invoice.rb', line 4756

def promotion_code
  @promotion_code
end