Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



5446
5447
5448
5449
5450
# File 'lib/stripe/resources/invoice.rb', line 5446

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



5438
5439
5440
# File 'lib/stripe/resources/invoice.rb', line 5438

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



5441
5442
5443
# File 'lib/stripe/resources/invoice.rb', line 5441

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



5444
5445
5446
# File 'lib/stripe/resources/invoice.rb', line 5444

def type
  @type
end