Class: Stripe::Invoice::ListUpcomingLineItemsParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



5790
5791
5792
5793
5794
5795
# File 'lib/stripe/resources/invoice.rb', line 5790

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



5779
5780
5781
# File 'lib/stripe/resources/invoice.rb', line 5779

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



5782
5783
5784
# File 'lib/stripe/resources/invoice.rb', line 5782

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



5785
5786
5787
# File 'lib/stripe/resources/invoice.rb', line 5785

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



5788
5789
5790
# File 'lib/stripe/resources/invoice.rb', line 5788

def type
  @type
end