Class: Stripe::Invoice::ListUpcomingLineItemsParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



5117
5118
5119
5120
5121
# File 'lib/stripe/resources/invoice.rb', line 5117

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



5111
5112
5113
# File 'lib/stripe/resources/invoice.rb', line 5111

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



5113
5114
5115
# File 'lib/stripe/resources/invoice.rb', line 5113

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



5115
5116
5117
# File 'lib/stripe/resources/invoice.rb', line 5115

def type
  @type
end