Class: Stripe::Invoice::MarkUncollectibleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::MarkUncollectibleParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ MarkUncollectibleParams
constructor
A new instance of MarkUncollectibleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ MarkUncollectibleParams
Returns a new instance of MarkUncollectibleParams.
1948 1949 1950 |
# File 'lib/stripe/resources/invoice.rb', line 1948 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1946 1947 1948 |
# File 'lib/stripe/resources/invoice.rb', line 1946 def @expand end |