Class: Stripe::Invoice::Parent::SubscriptionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::Parent::SubscriptionDetails
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: PauseCollection
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#metadata ⇒ Object
readonly
Set of key-value pairs defined as subscription metadata when an invoice is created.
-
#pause_collection ⇒ Object
readonly
If specified, payment collection for this subscription will be paused.
-
#subscription ⇒ Object
readonly
The subscription that generated this invoice.
-
#subscription_proration_date ⇒ Object
readonly
Only set for upcoming invoices that preview prorations.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#metadata ⇒ Object (readonly)
Set of key-value pairs defined as subscription metadata when an invoice is created. Becomes an immutable snapshot of the subscription metadata at the time of invoice finalization. Note: This attribute is populated only for invoices created on or after June 29, 2023.
363 364 365 |
# File 'lib/stripe/resources/invoice.rb', line 363 def @metadata end |
#pause_collection ⇒ Object (readonly)
If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to paused. Learn more about pausing collection.
365 366 367 |
# File 'lib/stripe/resources/invoice.rb', line 365 def pause_collection @pause_collection end |
#subscription ⇒ Object (readonly)
The subscription that generated this invoice
367 368 369 |
# File 'lib/stripe/resources/invoice.rb', line 367 def subscription @subscription end |
#subscription_proration_date ⇒ Object (readonly)
Only set for upcoming invoices that preview prorations. The time used to calculate prorations.
369 370 371 |
# File 'lib/stripe/resources/invoice.rb', line 369 def subscription_proration_date @subscription_proration_date end |
Class Method Details
.field_remappings ⇒ Object
375 376 377 |
# File 'lib/stripe/resources/invoice.rb', line 375 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
371 372 373 |
# File 'lib/stripe/resources/invoice.rb', line 371 def self.inner_class_types @inner_class_types = { pause_collection: PauseCollection } end |