Class: Stripe::Invoice::Parent::SubscriptionDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::Parent::SubscriptionDetails
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: PauseCollection
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) defined as subscription metadata when an invoice is created.
-
#pause_collection ⇒ Object
readonly
If specified, payment collection for this subscription will be paused.
-
#subscription ⇒ Object
readonly
The subscription that generated this invoice.
-
#subscription_proration_date ⇒ Object
readonly
Only set for upcoming invoices that preview prorations.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) defined as subscription metadata when an invoice is created. Becomes an immutable snapshot of the subscription metadata at the time of invoice finalization.
*Note: This attribute is populated only for invoices created on or after June 29, 2023.*
256 257 258 |
# File 'lib/stripe/resources/invoice.rb', line 256 def @metadata end |
#pause_collection ⇒ Object (readonly)
If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).
258 259 260 |
# File 'lib/stripe/resources/invoice.rb', line 258 def pause_collection @pause_collection end |
#subscription ⇒ Object (readonly)
The subscription that generated this invoice
260 261 262 |
# File 'lib/stripe/resources/invoice.rb', line 260 def subscription @subscription end |
#subscription_proration_date ⇒ Object (readonly)
Only set for upcoming invoices that preview prorations. The time used to calculate prorations.
262 263 264 |
# File 'lib/stripe/resources/invoice.rb', line 262 def subscription_proration_date @subscription_proration_date end |