Class: Stripe::Invoice::PayParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, forgive: nil, mandate: nil, off_session: nil, paid_out_of_band: nil, payment_method: nil, source: nil) ⇒ PayParams

Returns a new instance of PayParams.



2713
2714
2715
2716
2717
2718
2719
2720
2721
2722
2723
2724
2725
2726
2727
2728
2729
# File 'lib/stripe/resources/invoice.rb', line 2713

def initialize(
  expand: nil,
  forgive: nil,
  mandate: nil,
  off_session: nil,
  paid_out_of_band: nil,
  payment_method: nil,
  source: nil
)
  @expand = expand
  @forgive = forgive
  @mandate = mandate
  @off_session = off_session
  @paid_out_of_band = paid_out_of_band
  @payment_method = payment_method
  @source = source
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2697
2698
2699
# File 'lib/stripe/resources/invoice.rb', line 2697

def expand
  @expand
end

#forgiveObject

In cases where the source used to pay the invoice has insufficient funds, passing ‘forgive=true` controls whether a charge should be attempted for the full amount available on the source, up to the amount to fully pay the invoice. This effectively forgives the difference between the amount available on the source and the amount due.

Passing ‘forgive=false` will fail the charge if the source hasn’t been pre-funded with the right amount. An example for this case is with ACH Credit Transfers and wires: if the amount wired is less than the amount due by a small amount, you might want to forgive the difference. Defaults to ‘false`.



2701
2702
2703
# File 'lib/stripe/resources/invoice.rb', line 2701

def forgive
  @forgive
end

#mandateObject

ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the payment_method param or the invoice’s default_payment_method or default_source, if set.



2703
2704
2705
# File 'lib/stripe/resources/invoice.rb', line 2703

def mandate
  @mandate
end

#off_sessionObject

Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘true` (off-session).



2705
2706
2707
# File 'lib/stripe/resources/invoice.rb', line 2705

def off_session
  @off_session
end

Boolean representing whether an invoice is paid outside of Stripe. This will result in no charge being made. Defaults to ‘false`.



2707
2708
2709
# File 'lib/stripe/resources/invoice.rb', line 2707

def paid_out_of_band
  @paid_out_of_band
end

#payment_methodObject

A PaymentMethod to be charged. The PaymentMethod must be the ID of a PaymentMethod belonging to the customer associated with the invoice being paid.



2709
2710
2711
# File 'lib/stripe/resources/invoice.rb', line 2709

def payment_method
  @payment_method
end

#sourceObject

A payment source to be charged. The source must be the ID of a source belonging to the customer associated with the invoice being paid.



2711
2712
2713
# File 'lib/stripe/resources/invoice.rb', line 2711

def source
  @source
end