Class: Stripe::Invoice::PayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::PayParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#forgive ⇒ Object
In cases where the source used to pay the invoice has insufficient funds, passing ‘forgive=true` controls whether a charge should be attempted for the full amount available on the source, up to the amount to fully pay the invoice.
-
#mandate ⇒ Object
ID of the mandate to be used for this invoice.
-
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted.
-
#paid_out_of_band ⇒ Object
Boolean representing whether an invoice is paid outside of Stripe.
-
#payment_method ⇒ Object
A PaymentMethod to be charged.
-
#source ⇒ Object
A payment source to be charged.
Instance Method Summary collapse
-
#initialize(expand: nil, forgive: nil, mandate: nil, off_session: nil, paid_out_of_band: nil, payment_method: nil, source: nil) ⇒ PayParams
constructor
A new instance of PayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, forgive: nil, mandate: nil, off_session: nil, paid_out_of_band: nil, payment_method: nil, source: nil) ⇒ PayParams
Returns a new instance of PayParams.
2221 2222 2223 2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 |
# File 'lib/stripe/resources/invoice.rb', line 2221 def initialize( expand: nil, forgive: nil, mandate: nil, off_session: nil, paid_out_of_band: nil, payment_method: nil, source: nil ) @expand = @forgive = forgive @mandate = mandate @off_session = off_session @paid_out_of_band = paid_out_of_band @payment_method = payment_method @source = source end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2205 2206 2207 |
# File 'lib/stripe/resources/invoice.rb', line 2205 def @expand end |
#forgive ⇒ Object
In cases where the source used to pay the invoice has insufficient funds, passing ‘forgive=true` controls whether a charge should be attempted for the full amount available on the source, up to the amount to fully pay the invoice. This effectively forgives the difference between the amount available on the source and the amount due.
Passing ‘forgive=false` will fail the charge if the source hasn’t been pre-funded with the right amount. An example for this case is with ACH Credit Transfers and wires: if the amount wired is less than the amount due by a small amount, you might want to forgive the difference. Defaults to ‘false`.
2209 2210 2211 |
# File 'lib/stripe/resources/invoice.rb', line 2209 def forgive @forgive end |
#mandate ⇒ Object
ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the payment_method param or the invoice’s default_payment_method or default_source, if set.
2211 2212 2213 |
# File 'lib/stripe/resources/invoice.rb', line 2211 def mandate @mandate end |
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘true` (off-session).
2213 2214 2215 |
# File 'lib/stripe/resources/invoice.rb', line 2213 def off_session @off_session end |
#paid_out_of_band ⇒ Object
Boolean representing whether an invoice is paid outside of Stripe. This will result in no charge being made. Defaults to ‘false`.
2215 2216 2217 |
# File 'lib/stripe/resources/invoice.rb', line 2215 def paid_out_of_band @paid_out_of_band end |
#payment_method ⇒ Object
A PaymentMethod to be charged. The PaymentMethod must be the ID of a PaymentMethod belonging to the customer associated with the invoice being paid.
2217 2218 2219 |
# File 'lib/stripe/resources/invoice.rb', line 2217 def payment_method @payment_method end |
#source ⇒ Object
A payment source to be charged. The source must be the ID of a source belonging to the customer associated with the invoice being paid.
2219 2220 2221 |
# File 'lib/stripe/resources/invoice.rb', line 2219 def source @source end |