Class: Stripe::Invoice::PaymentSettings::PaymentMethodOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Billie, Bizum, Blik, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount, WechatPay
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
If paying by
acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent. -
#bancontact ⇒ Object
readonly
If paying by
bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent. -
#billie ⇒ Object
readonly
If paying by
billie, this sub-hash contains details about the Billie payment method options to pass to the invoice’s PaymentIntent. -
#bizum ⇒ Object
readonly
If paying by
bizum, this sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent. -
#blik ⇒ Object
readonly
If paying by
blik, this sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent. -
#card ⇒ Object
readonly
If paying by
card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent. -
#check_scan ⇒ Object
readonly
If paying by
check_scan, this sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent. -
#customer_balance ⇒ Object
readonly
If paying by
customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent. -
#id_bank_transfer ⇒ Object
readonly
If paying by
id_bank_transfer, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent. -
#konbini ⇒ Object
readonly
If paying by
konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent. -
#payto ⇒ Object
readonly
If paying by
payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent. -
#pix ⇒ Object
readonly
If paying by
pix, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent. -
#sepa_debit ⇒ Object
readonly
If paying by
sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent. -
#upi ⇒ Object
readonly
If paying by
upi, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent. -
#us_bank_account ⇒ Object
readonly
If paying by
us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent. -
#wechat_pay ⇒ Object
readonly
If paying by
wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the invoice’s PaymentIntent.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
If paying by acss_debit, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
767 768 769 |
# File 'lib/stripe/resources/invoice.rb', line 767 def acss_debit @acss_debit end |
#bancontact ⇒ Object (readonly)
If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
769 770 771 |
# File 'lib/stripe/resources/invoice.rb', line 769 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
If paying by billie, this sub-hash contains details about the Billie payment method options to pass to the invoice’s PaymentIntent.
771 772 773 |
# File 'lib/stripe/resources/invoice.rb', line 771 def billie @billie end |
#bizum ⇒ Object (readonly)
If paying by bizum, this sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.
773 774 775 |
# File 'lib/stripe/resources/invoice.rb', line 773 def bizum @bizum end |
#blik ⇒ Object (readonly)
If paying by blik, this sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.
775 776 777 |
# File 'lib/stripe/resources/invoice.rb', line 775 def blik @blik end |
#card ⇒ Object (readonly)
If paying by card, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
777 778 779 |
# File 'lib/stripe/resources/invoice.rb', line 777 def card @card end |
#check_scan ⇒ Object (readonly)
If paying by check_scan, this sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.
779 780 781 |
# File 'lib/stripe/resources/invoice.rb', line 779 def check_scan @check_scan end |
#customer_balance ⇒ Object (readonly)
If paying by customer_balance, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
781 782 783 |
# File 'lib/stripe/resources/invoice.rb', line 781 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object (readonly)
If paying by id_bank_transfer, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
783 784 785 |
# File 'lib/stripe/resources/invoice.rb', line 783 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object (readonly)
If paying by konbini, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
785 786 787 |
# File 'lib/stripe/resources/invoice.rb', line 785 def konbini @konbini end |
#payto ⇒ Object (readonly)
If paying by payto, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.
787 788 789 |
# File 'lib/stripe/resources/invoice.rb', line 787 def payto @payto end |
#pix ⇒ Object (readonly)
If paying by pix, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
789 790 791 |
# File 'lib/stripe/resources/invoice.rb', line 789 def pix @pix end |
#sepa_debit ⇒ Object (readonly)
If paying by sepa_debit, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
791 792 793 |
# File 'lib/stripe/resources/invoice.rb', line 791 def sepa_debit @sepa_debit end |
#upi ⇒ Object (readonly)
If paying by upi, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
793 794 795 |
# File 'lib/stripe/resources/invoice.rb', line 793 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
If paying by us_bank_account, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
795 796 797 |
# File 'lib/stripe/resources/invoice.rb', line 795 def us_bank_account @us_bank_account end |
#wechat_pay ⇒ Object (readonly)
If paying by wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the invoice’s PaymentIntent.
797 798 799 |
# File 'lib/stripe/resources/invoice.rb', line 797 def wechat_pay @wechat_pay end |
Class Method Details
.field_remappings ⇒ Object
820 821 822 |
# File 'lib/stripe/resources/invoice.rb', line 820 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 |
# File 'lib/stripe/resources/invoice.rb', line 799 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, bancontact: Bancontact, billie: Billie, bizum: Bizum, blik: Blik, card: Card, check_scan: CheckScan, customer_balance: CustomerBalance, id_bank_transfer: IdBankTransfer, konbini: Konbini, payto: Payto, pix: Pix, sepa_debit: SepaDebit, upi: Upi, us_bank_account: UsBankAccount, wechat_pay: WechatPay, } end |