Class: Stripe::Invoice::PaymentSettings::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Blik, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



668
669
670
# File 'lib/stripe/resources/invoice.rb', line 668

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



670
671
672
# File 'lib/stripe/resources/invoice.rb', line 670

def bancontact
  @bancontact
end

#blikObject (readonly)

If paying by ‘blik`, this sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.



672
673
674
# File 'lib/stripe/resources/invoice.rb', line 672

def blik
  @blik
end

#cardObject (readonly)

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



674
675
676
# File 'lib/stripe/resources/invoice.rb', line 674

def card
  @card
end

#customer_balanceObject (readonly)

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



676
677
678
# File 'lib/stripe/resources/invoice.rb', line 676

def customer_balance
  @customer_balance
end

#id_bank_transferObject (readonly)

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



678
679
680
# File 'lib/stripe/resources/invoice.rb', line 678

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject (readonly)

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



680
681
682
# File 'lib/stripe/resources/invoice.rb', line 680

def konbini
  @konbini
end

#paytoObject (readonly)

If paying by ‘payto`, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



682
683
684
# File 'lib/stripe/resources/invoice.rb', line 682

def payto
  @payto
end

#pixObject (readonly)

If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



684
685
686
# File 'lib/stripe/resources/invoice.rb', line 684

def pix
  @pix
end

#sepa_debitObject (readonly)

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



686
687
688
# File 'lib/stripe/resources/invoice.rb', line 686

def sepa_debit
  @sepa_debit
end

#upiObject (readonly)

If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



688
689
690
# File 'lib/stripe/resources/invoice.rb', line 688

def upi
  @upi
end

#us_bank_accountObject (readonly)

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



690
691
692
# File 'lib/stripe/resources/invoice.rb', line 690

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



709
710
711
# File 'lib/stripe/resources/invoice.rb', line 709

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
# File 'lib/stripe/resources/invoice.rb', line 692

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    bancontact: Bancontact,
    blik: Blik,
    card: Card,
    customer_balance: CustomerBalance,
    id_bank_transfer: IdBankTransfer,
    konbini: Konbini,
    payto: Payto,
    pix: Pix,
    sepa_debit: SepaDebit,
    upi: Upi,
    us_bank_account: UsBankAccount,
  }
end