Class: Stripe::Invoice::PaymentSettings::PaymentMethodOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, Upi, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



360
361
362
# File 'lib/stripe/resources/invoice.rb', line 360

def acss_debit
  @acss_debit
end

#bancontactObject (readonly)

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



362
363
364
# File 'lib/stripe/resources/invoice.rb', line 362

def bancontact
  @bancontact
end

#cardObject (readonly)

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



364
365
366
# File 'lib/stripe/resources/invoice.rb', line 364

def card
  @card
end

#customer_balanceObject (readonly)

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



366
367
368
# File 'lib/stripe/resources/invoice.rb', line 366

def customer_balance
  @customer_balance
end

#id_bank_transferObject (readonly)

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



368
369
370
# File 'lib/stripe/resources/invoice.rb', line 368

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject (readonly)

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



370
371
372
# File 'lib/stripe/resources/invoice.rb', line 370

def konbini
  @konbini
end

#sepa_debitObject (readonly)

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



372
373
374
# File 'lib/stripe/resources/invoice.rb', line 372

def sepa_debit
  @sepa_debit
end

#upiObject (readonly)

If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



374
375
376
# File 'lib/stripe/resources/invoice.rb', line 374

def upi
  @upi
end

#us_bank_accountObject (readonly)

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



376
377
378
# File 'lib/stripe/resources/invoice.rb', line 376

def 
  @us_bank_account
end