Class: Stripe::Invoice::PaymentSettings::PaymentMethodOptions
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
readonly
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
readonly
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
readonly
If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
readonly
If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
readonly
If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
readonly
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
readonly
If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
348 349 350 |
# File 'lib/stripe/resources/invoice.rb', line 348 def acss_debit @acss_debit end |
#bancontact ⇒ Object (readonly)
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
351 352 353 |
# File 'lib/stripe/resources/invoice.rb', line 351 def bancontact @bancontact end |
#card ⇒ Object (readonly)
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
354 355 356 |
# File 'lib/stripe/resources/invoice.rb', line 354 def card @card end |
#customer_balance ⇒ Object (readonly)
If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
357 358 359 |
# File 'lib/stripe/resources/invoice.rb', line 357 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object (readonly)
If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
360 361 362 |
# File 'lib/stripe/resources/invoice.rb', line 360 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object (readonly)
If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
363 364 365 |
# File 'lib/stripe/resources/invoice.rb', line 363 def konbini @konbini end |
#sepa_debit ⇒ Object (readonly)
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
366 367 368 |
# File 'lib/stripe/resources/invoice.rb', line 366 def sepa_debit @sepa_debit end |
#us_bank_account ⇒ Object (readonly)
If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
369 370 371 |
# File 'lib/stripe/resources/invoice.rb', line 369 def us_bank_account @us_bank_account end |