Class: Stripe::Invoice::PaymentSettings::PaymentMethodOptions::Billie::CompanyDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::PaymentSettings::PaymentMethodOptions::Billie::CompanyDetails
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: RegisteredAddress
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#registered_address ⇒ Object
readonly
Attribute for field registered_address.
-
#registered_name ⇒ Object
readonly
Company or entity name.
-
#registration_number ⇒ Object
readonly
The official registration number for the given registration type.
-
#registration_type ⇒ Object
readonly
Type of registration the company or entity holds in their registered country.
-
#vat ⇒ Object
readonly
VAT ID number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#registered_address ⇒ Object (readonly)
Attribute for field registered_address
422 423 424 |
# File 'lib/stripe/resources/invoice.rb', line 422 def registered_address @registered_address end |
#registered_name ⇒ Object (readonly)
Company or entity name.
424 425 426 |
# File 'lib/stripe/resources/invoice.rb', line 424 def registered_name @registered_name end |
#registration_number ⇒ Object (readonly)
The official registration number for the given registration type.
426 427 428 |
# File 'lib/stripe/resources/invoice.rb', line 426 def registration_number @registration_number end |
#registration_type ⇒ Object (readonly)
Type of registration the company or entity holds in their registered country.
428 429 430 |
# File 'lib/stripe/resources/invoice.rb', line 428 def registration_type @registration_type end |
#vat ⇒ Object (readonly)
VAT ID number.
430 431 432 |
# File 'lib/stripe/resources/invoice.rb', line 430 def vat @vat end |
Class Method Details
.field_remappings ⇒ Object
436 437 438 |
# File 'lib/stripe/resources/invoice.rb', line 436 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
432 433 434 |
# File 'lib/stripe/resources/invoice.rb', line 432 def self.inner_class_types @inner_class_types = { registered_address: RegisteredAddress } end |