Class: Stripe::Invoice::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



583
584
585
# File 'lib/stripe/resources/invoice.rb', line 583

def amount
  @amount
end

#amount_typeObject (readonly)

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



585
586
587
# File 'lib/stripe/resources/invoice.rb', line 585

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



587
588
589
# File 'lib/stripe/resources/invoice.rb', line 587

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



589
590
591
# File 'lib/stripe/resources/invoice.rb', line 589

def end_date
  @end_date
end

Class Method Details

.field_remappingsObject



595
596
597
# File 'lib/stripe/resources/invoice.rb', line 595

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



591
592
593
# File 'lib/stripe/resources/invoice.rb', line 591

def self.inner_class_types
  @inner_class_types = {}
end