Class: Stripe::Invoice::RemoveLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::RemoveLinesParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to remove.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams
constructor
A new instance of RemoveLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams
Returns a new instance of RemoveLinesParams.
2336 2337 2338 2339 2340 |
# File 'lib/stripe/resources/invoice.rb', line 2336 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2330 2331 2332 |
# File 'lib/stripe/resources/invoice.rb', line 2330 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2332 2333 2334 |
# File 'lib/stripe/resources/invoice.rb', line 2332 def @invoice_metadata end |
#lines ⇒ Object
The line items to remove.
2334 2335 2336 |
# File 'lib/stripe/resources/invoice.rb', line 2334 def lines @lines end |