Class: Stripe::Invoice::RemoveLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams

Returns a new instance of RemoveLinesParams.



2270
2271
2272
2273
2274
# File 'lib/stripe/resources/invoice.rb', line 2270

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2264
2265
2266
# File 'lib/stripe/resources/invoice.rb', line 2264

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2266
2267
2268
# File 'lib/stripe/resources/invoice.rb', line 2266

def 
  @invoice_metadata
end

#linesObject

The line items to remove.



2268
2269
2270
# File 'lib/stripe/resources/invoice.rb', line 2268

def lines
  @lines
end