Class: Stripe::Invoice::RemoveLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams

Returns a new instance of RemoveLinesParams.



2286
2287
2288
2289
2290
# File 'lib/stripe/resources/invoice.rb', line 2286

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2280
2281
2282
# File 'lib/stripe/resources/invoice.rb', line 2280

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2282
2283
2284
# File 'lib/stripe/resources/invoice.rb', line 2282

def 
  @invoice_metadata
end

#linesObject

The line items to remove.



2284
2285
2286
# File 'lib/stripe/resources/invoice.rb', line 2284

def lines
  @lines
end