Class: Stripe::Invoice::RemoveLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::RemoveLinesParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to remove.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams
constructor
A new instance of RemoveLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams
Returns a new instance of RemoveLinesParams.
2286 2287 2288 2289 2290 |
# File 'lib/stripe/resources/invoice.rb', line 2286 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2280 2281 2282 |
# File 'lib/stripe/resources/invoice.rb', line 2280 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2282 2283 2284 |
# File 'lib/stripe/resources/invoice.rb', line 2282 def @invoice_metadata end |
#lines ⇒ Object
The line items to remove.
2284 2285 2286 |
# File 'lib/stripe/resources/invoice.rb', line 2284 def lines @lines end |