Class: Stripe::Invoice::RemoveLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::RemoveLinesParams
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to remove.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams
constructor
A new instance of RemoveLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ RemoveLinesParams
Returns a new instance of RemoveLinesParams.
5957 5958 5959 5960 5961 |
# File 'lib/stripe/resources/invoice.rb', line 5957 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
5951 5952 5953 |
# File 'lib/stripe/resources/invoice.rb', line 5951 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
5953 5954 5955 |
# File 'lib/stripe/resources/invoice.rb', line 5953 def @invoice_metadata end |
#lines ⇒ Object
The line items to remove.
5955 5956 5957 |
# File 'lib/stripe/resources/invoice.rb', line 5955 def lines @lines end |