Class: Stripe::Invoice::RemoveLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, id: nil) ⇒ Line

Returns a new instance of Line.



2739
2740
2741
2742
# File 'lib/stripe/resources/invoice.rb', line 2739

def initialize(behavior: nil, id: nil)
  @behavior = behavior
  @id = id
end

Instance Attribute Details

#behaviorObject

Either ‘delete` or `unassign`. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice.



2735
2736
2737
# File 'lib/stripe/resources/invoice.rb', line 2735

def behavior
  @behavior
end

#idObject

ID of an existing line item to remove from this invoice.



2737
2738
2739
# File 'lib/stripe/resources/invoice.rb', line 2737

def id
  @id
end