Class: Stripe::Invoice::RemoveLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, id: nil) ⇒ Line

Returns a new instance of Line.



2247
2248
2249
2250
# File 'lib/stripe/resources/invoice.rb', line 2247

def initialize(behavior: nil, id: nil)
  @behavior = behavior
  @id = id
end

Instance Attribute Details

#behaviorObject

Either ‘delete` or `unassign`. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice.



2243
2244
2245
# File 'lib/stripe/resources/invoice.rb', line 2243

def behavior
  @behavior
end

#idObject

ID of an existing line item to remove from this invoice.



2245
2246
2247
# File 'lib/stripe/resources/invoice.rb', line 2245

def id
  @id
end