Class: Stripe::Invoice::RemoveLinesParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::RemoveLinesParams::Line
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
Either ‘delete` or `unassign`.
-
#id ⇒ Object
ID of an existing line item to remove from this invoice.
Instance Method Summary collapse
-
#initialize(behavior: nil, id: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil, id: nil) ⇒ Line
Returns a new instance of Line.
1997 1998 1999 2000 |
# File 'lib/stripe/resources/invoice.rb', line 1997 def initialize(behavior: nil, id: nil) @behavior = behavior @id = id end |
Instance Attribute Details
#behavior ⇒ Object
Either ‘delete` or `unassign`. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice.
1993 1994 1995 |
# File 'lib/stripe/resources/invoice.rb', line 1993 def behavior @behavior end |
#id ⇒ Object
ID of an existing line item to remove from this invoice.
1995 1996 1997 |
# File 'lib/stripe/resources/invoice.rb', line 1995 def id @id end |