Class: Stripe::Invoice::RemoveLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, id: nil) ⇒ Line

Returns a new instance of Line.



2258
2259
2260
2261
# File 'lib/stripe/resources/invoice.rb', line 2258

def initialize(behavior: nil, id: nil)
  @behavior = behavior
  @id = id
end

Instance Attribute Details

#behaviorObject

Either ‘delete` or `unassign`. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice.



2254
2255
2256
# File 'lib/stripe/resources/invoice.rb', line 2254

def behavior
  @behavior
end

#idObject

ID of an existing line item to remove from this invoice.



2256
2257
2258
# File 'lib/stripe/resources/invoice.rb', line 2256

def id
  @id
end