Class: Stripe::Invoice::RemoveLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, id: nil) ⇒ Line

Returns a new instance of Line.



6845
6846
6847
6848
# File 'lib/stripe/resources/invoice.rb', line 6845

def initialize(behavior: nil, id: nil)
  @behavior = behavior
  @id = id
end

Instance Attribute Details

#behaviorObject

Either ‘delete` or `unassign`. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice.



6840
6841
6842
# File 'lib/stripe/resources/invoice.rb', line 6840

def behavior
  @behavior
end

#idObject

ID of an existing line item to remove from this invoice.



6843
6844
6845
# File 'lib/stripe/resources/invoice.rb', line 6843

def id
  @id
end