Class: Stripe::Invoice::RemoveLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(behavior: nil, id: nil) ⇒ Line

Returns a new instance of Line.



5945
5946
5947
5948
# File 'lib/stripe/resources/invoice.rb', line 5945

def initialize(behavior: nil, id: nil)
  @behavior = behavior
  @id = id
end

Instance Attribute Details

#behaviorObject

Either ‘delete` or `unassign`. Deleted line items are permanently deleted. Unassigned line items can be reassigned to an invoice.



5941
5942
5943
# File 'lib/stripe/resources/invoice.rb', line 5941

def behavior
  @behavior
end

#idObject

ID of an existing line item to remove from this invoice.



5943
5944
5945
# File 'lib/stripe/resources/invoice.rb', line 5943

def id
  @id
end