Class: Stripe::Invoice::Rendering
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::Rendering
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Pdf
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_tax_display ⇒ Object
readonly
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
-
#pdf ⇒ Object
readonly
Invoice pdf rendering options.
-
#template ⇒ Object
readonly
ID of the rendering template that the invoice is formatted by.
-
#template_version ⇒ Object
readonly
Version of the rendering template that the invoice is using.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_tax_display ⇒ Object (readonly)
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
815 816 817 |
# File 'lib/stripe/resources/invoice.rb', line 815 def amount_tax_display @amount_tax_display end |
#pdf ⇒ Object (readonly)
Invoice pdf rendering options
817 818 819 |
# File 'lib/stripe/resources/invoice.rb', line 817 def pdf @pdf end |
#template ⇒ Object (readonly)
ID of the rendering template that the invoice is formatted by.
819 820 821 |
# File 'lib/stripe/resources/invoice.rb', line 819 def template @template end |
#template_version ⇒ Object (readonly)
Version of the rendering template that the invoice is using.
821 822 823 |
# File 'lib/stripe/resources/invoice.rb', line 821 def template_version @template_version end |
Class Method Details
.field_remappings ⇒ Object
827 828 829 |
# File 'lib/stripe/resources/invoice.rb', line 827 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
823 824 825 |
# File 'lib/stripe/resources/invoice.rb', line 823 def self.inner_class_types @inner_class_types = { pdf: Pdf } end |