Class: Stripe::Invoice::Rendering
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::Rendering
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Pdf
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_tax_display ⇒ Object
readonly
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
-
#pdf ⇒ Object
readonly
Invoice pdf rendering options.
-
#template ⇒ Object
readonly
ID of the rendering template that the invoice is formatted by.
-
#template_version ⇒ Object
readonly
Version of the rendering template that the invoice is using.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_tax_display ⇒ Object (readonly)
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
368 369 370 |
# File 'lib/stripe/resources/invoice.rb', line 368 def amount_tax_display @amount_tax_display end |
#pdf ⇒ Object (readonly)
Invoice pdf rendering options
370 371 372 |
# File 'lib/stripe/resources/invoice.rb', line 370 def pdf @pdf end |
#template ⇒ Object (readonly)
ID of the rendering template that the invoice is formatted by.
372 373 374 |
# File 'lib/stripe/resources/invoice.rb', line 372 def template @template end |
#template_version ⇒ Object (readonly)
Version of the rendering template that the invoice is using.
374 375 376 |
# File 'lib/stripe/resources/invoice.rb', line 374 def template_version @template_version end |