Class: Stripe::Invoice::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::SearchParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
2355 2356 2357 2358 2359 2360 |
# File 'lib/stripe/resources/invoice.rb', line 2355 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2347 2348 2349 |
# File 'lib/stripe/resources/invoice.rb', line 2347 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
2349 2350 2351 |
# File 'lib/stripe/resources/invoice.rb', line 2349 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
2351 2352 2353 |
# File 'lib/stripe/resources/invoice.rb', line 2351 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for invoices](stripe.com/docs/search#query-fields-for-invoices).
2353 2354 2355 |
# File 'lib/stripe/resources/invoice.rb', line 2353 def query @query end |