Class: Stripe::Invoice::SearchParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams

Returns a new instance of SearchParams.



1940
1941
1942
1943
1944
1945
# File 'lib/stripe/resources/invoice.rb', line 1940

def initialize(expand: nil, limit: nil, page: nil, query: nil)
  @expand = expand
  @limit = limit
  @page = page
  @query = query
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1932
1933
1934
# File 'lib/stripe/resources/invoice.rb', line 1932

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



1934
1935
1936
# File 'lib/stripe/resources/invoice.rb', line 1934

def limit
  @limit
end

#pageObject

A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.



1936
1937
1938
# File 'lib/stripe/resources/invoice.rb', line 1936

def page
  @page
end

#queryObject

The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for invoices](stripe.com/docs/search#query-fields-for-invoices).



1938
1939
1940
# File 'lib/stripe/resources/invoice.rb', line 1938

def query
  @query
end