Class: Stripe::Invoice::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::SearchParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
1874 1875 1876 1877 1878 1879 |
# File 'lib/stripe/resources/invoice.rb', line 1874 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1866 1867 1868 |
# File 'lib/stripe/resources/invoice.rb', line 1866 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1868 1869 1870 |
# File 'lib/stripe/resources/invoice.rb', line 1868 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
1870 1871 1872 |
# File 'lib/stripe/resources/invoice.rb', line 1870 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for invoices](stripe.com/docs/search#query-fields-for-invoices).
1872 1873 1874 |
# File 'lib/stripe/resources/invoice.rb', line 1872 def query @query end |