Class: Stripe::Invoice::TotalPretaxCreditAmount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount, in cents (or local equivalent), of the pretax credit amount.



470
471
472
# File 'lib/stripe/resources/invoice.rb', line 470

def amount
  @amount
end

#credit_balance_transactionObject (readonly)

The credit balance transaction that was applied to get this pretax credit amount.



472
473
474
# File 'lib/stripe/resources/invoice.rb', line 472

def credit_balance_transaction
  @credit_balance_transaction
end

#discountObject (readonly)

The discount that was applied to get this pretax credit amount.



474
475
476
# File 'lib/stripe/resources/invoice.rb', line 474

def discount
  @discount
end

#marginObject (readonly)

The margin that was applied to get this pretax credit amount.



476
477
478
# File 'lib/stripe/resources/invoice.rb', line 476

def margin
  @margin
end

#typeObject (readonly)

Type of the pretax credit amount referenced.



478
479
480
# File 'lib/stripe/resources/invoice.rb', line 478

def type
  @type
end