Class: Stripe::Invoice::TotalPretaxCreditAmount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::TotalPretaxCreditAmount
- Defined in:
- lib/stripe/resources/invoice.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount, in cents (or local equivalent), of the pretax credit amount.
-
#credit_balance_transaction ⇒ Object
readonly
The credit balance transaction that was applied to get this pretax credit amount.
-
#discount ⇒ Object
readonly
The discount that was applied to get this pretax credit amount.
-
#margin ⇒ Object
readonly
The margin that was applied to get this pretax credit amount.
-
#type ⇒ Object
readonly
Type of the pretax credit amount referenced.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount, in cents (or local equivalent), of the pretax credit amount.
444 445 446 |
# File 'lib/stripe/resources/invoice.rb', line 444 def amount @amount end |
#credit_balance_transaction ⇒ Object (readonly)
The credit balance transaction that was applied to get this pretax credit amount.
446 447 448 |
# File 'lib/stripe/resources/invoice.rb', line 446 def credit_balance_transaction @credit_balance_transaction end |
#discount ⇒ Object (readonly)
The discount that was applied to get this pretax credit amount.
448 449 450 |
# File 'lib/stripe/resources/invoice.rb', line 448 def discount @discount end |
#margin ⇒ Object (readonly)
The margin that was applied to get this pretax credit amount.
450 451 452 |
# File 'lib/stripe/resources/invoice.rb', line 450 def margin @margin end |
#type ⇒ Object (readonly)
Type of the pretax credit amount referenced.
452 453 454 |
# File 'lib/stripe/resources/invoice.rb', line 452 def type @type end |