Class: Stripe::Invoice::TotalTax

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: TaxRateDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the tax, in cents (or local equivalent).



1042
1043
1044
# File 'lib/stripe/resources/invoice.rb', line 1042

def amount
  @amount
end

#tax_behaviorObject (readonly)

Whether this tax is inclusive or exclusive.



1044
1045
1046
# File 'lib/stripe/resources/invoice.rb', line 1044

def tax_behavior
  @tax_behavior
end

#tax_rate_detailsObject (readonly)

Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.



1046
1047
1048
# File 'lib/stripe/resources/invoice.rb', line 1046

def tax_rate_details
  @tax_rate_details
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



1048
1049
1050
# File 'lib/stripe/resources/invoice.rb', line 1048

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



1050
1051
1052
# File 'lib/stripe/resources/invoice.rb', line 1050

def taxable_amount
  @taxable_amount
end

#typeObject (readonly)

The type of tax information.



1052
1053
1054
# File 'lib/stripe/resources/invoice.rb', line 1052

def type
  @type
end

Class Method Details

.field_remappingsObject



1058
1059
1060
# File 'lib/stripe/resources/invoice.rb', line 1058

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1054
1055
1056
# File 'lib/stripe/resources/invoice.rb', line 1054

def self.inner_class_types
  @inner_class_types = { tax_rate_details: TaxRateDetails }
end