Class: Stripe::Invoice::TotalTax

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: TaxRateDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the tax, in cents (or local equivalent).



1029
1030
1031
# File 'lib/stripe/resources/invoice.rb', line 1029

def amount
  @amount
end

#tax_behaviorObject (readonly)

Whether this tax is inclusive or exclusive.



1031
1032
1033
# File 'lib/stripe/resources/invoice.rb', line 1031

def tax_behavior
  @tax_behavior
end

#tax_rate_detailsObject (readonly)

Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.



1033
1034
1035
# File 'lib/stripe/resources/invoice.rb', line 1033

def tax_rate_details
  @tax_rate_details
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



1035
1036
1037
# File 'lib/stripe/resources/invoice.rb', line 1035

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



1037
1038
1039
# File 'lib/stripe/resources/invoice.rb', line 1037

def taxable_amount
  @taxable_amount
end

#typeObject (readonly)

The type of tax information.



1039
1040
1041
# File 'lib/stripe/resources/invoice.rb', line 1039

def type
  @type
end

Class Method Details

.field_remappingsObject



1045
1046
1047
# File 'lib/stripe/resources/invoice.rb', line 1045

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1041
1042
1043
# File 'lib/stripe/resources/invoice.rb', line 1041

def self.inner_class_types
  @inner_class_types = { tax_rate_details: TaxRateDetails }
end