Class: Stripe::Invoice::TotalTax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Invoice::TotalTax
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: TaxRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the tax, in cents (or local equivalent).
-
#tax_behavior ⇒ Object
readonly
Whether this tax is inclusive or exclusive.
-
#tax_rate_details ⇒ Object
readonly
Additional details about the tax rate.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in cents (or local equivalent).
-
#type ⇒ Object
readonly
The type of tax information.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the tax, in cents (or local equivalent).
910 911 912 |
# File 'lib/stripe/resources/invoice.rb', line 910 def amount @amount end |
#tax_behavior ⇒ Object (readonly)
Whether this tax is inclusive or exclusive.
912 913 914 |
# File 'lib/stripe/resources/invoice.rb', line 912 def tax_behavior @tax_behavior end |
#tax_rate_details ⇒ Object (readonly)
Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.
914 915 916 |
# File 'lib/stripe/resources/invoice.rb', line 914 def tax_rate_details @tax_rate_details end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
916 917 918 |
# File 'lib/stripe/resources/invoice.rb', line 916 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in cents (or local equivalent).
918 919 920 |
# File 'lib/stripe/resources/invoice.rb', line 918 def taxable_amount @taxable_amount end |
#type ⇒ Object (readonly)
The type of tax information.
920 921 922 |
# File 'lib/stripe/resources/invoice.rb', line 920 def type @type end |
Class Method Details
.field_remappings ⇒ Object
926 927 928 |
# File 'lib/stripe/resources/invoice.rb', line 926 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
922 923 924 |
# File 'lib/stripe/resources/invoice.rb', line 922 def self.inner_class_types @inner_class_types = { tax_rate_details: TaxRateDetails } end |