Class: Stripe::Invoice::TotalTax

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: TaxRateDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the tax, in cents (or local equivalent).



486
487
488
# File 'lib/stripe/resources/invoice.rb', line 486

def amount
  @amount
end

#tax_behaviorObject (readonly)

Whether this tax is inclusive or exclusive.



488
489
490
# File 'lib/stripe/resources/invoice.rb', line 488

def tax_behavior
  @tax_behavior
end

#tax_rate_detailsObject (readonly)

Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.



490
491
492
# File 'lib/stripe/resources/invoice.rb', line 490

def tax_rate_details
  @tax_rate_details
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



492
493
494
# File 'lib/stripe/resources/invoice.rb', line 492

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



494
495
496
# File 'lib/stripe/resources/invoice.rb', line 494

def taxable_amount
  @taxable_amount
end

#typeObject (readonly)

The type of tax information.



496
497
498
# File 'lib/stripe/resources/invoice.rb', line 496

def type
  @type
end