Class: Stripe::Invoice::UpcomingParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2035
2036
2037
2038
2039
2040
# File 'lib/stripe/resources/invoice.rb', line 2035

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2027
2028
2029
# File 'lib/stripe/resources/invoice.rb', line 2027

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2029
2030
2031
# File 'lib/stripe/resources/invoice.rb', line 2029

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2031
2032
2033
# File 'lib/stripe/resources/invoice.rb', line 2031

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2033
2034
2035
# File 'lib/stripe/resources/invoice.rb', line 2033

def promotion_code
  @promotion_code
end