Class: Stripe::Invoice::UpcomingParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2349
2350
2351
2352
2353
2354
# File 'lib/stripe/resources/invoice.rb', line 2349

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2338
2339
2340
# File 'lib/stripe/resources/invoice.rb', line 2338

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2341
2342
2343
# File 'lib/stripe/resources/invoice.rb', line 2341

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2344
2345
2346
# File 'lib/stripe/resources/invoice.rb', line 2344

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2347
2348
2349
# File 'lib/stripe/resources/invoice.rb', line 2347

def promotion_code
  @promotion_code
end