Class: Stripe::Invoice::UpcomingParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2349 2350 2351 2352 2353 2354 |
# File 'lib/stripe/resources/invoice.rb', line 2349 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2338 2339 2340 |
# File 'lib/stripe/resources/invoice.rb', line 2338 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2341 2342 2343 |
# File 'lib/stripe/resources/invoice.rb', line 2341 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2344 2345 2346 |
# File 'lib/stripe/resources/invoice.rb', line 2344 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2347 2348 2349 |
# File 'lib/stripe/resources/invoice.rb', line 2347 def promotion_code @promotion_code end |