Class: Stripe::Invoice::UpcomingParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
2020 2021 2022 2023 2024 |
# File 'lib/stripe/resources/invoice.rb', line 2020 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
2014 2015 2016 |
# File 'lib/stripe/resources/invoice.rb', line 2014 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
2016 2017 2018 |
# File 'lib/stripe/resources/invoice.rb', line 2016 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
2018 2019 2020 |
# File 'lib/stripe/resources/invoice.rb', line 2018 def type @type end |