Class: Stripe::Invoice::UpcomingParams::InvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::InvoiceItem
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of previewed invoice item.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Explicitly controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the invoice item in the preview.
-
#invoiceitem ⇒ Object
The ID of the invoice item to update in preview.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#tax_rates ⇒ Object
The tax rates that apply to the item.
-
#unit_amount ⇒ Object
The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem
constructor
A new instance of InvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem
Returns a new instance of InvoiceItem.
2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 2174 2175 2176 2177 2178 2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 |
# File 'lib/stripe/resources/invoice.rb', line 2158 def initialize( amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil ) @amount = amount @currency = currency @description = description @discountable = discountable @discounts = discounts @invoiceitem = invoiceitem @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_behavior = tax_behavior @tax_code = tax_code @tax_rates = tax_rates @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of previewed invoice item.
2126 2127 2128 |
# File 'lib/stripe/resources/invoice.rb', line 2126 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Only applicable to new invoice items.
2128 2129 2130 |
# File 'lib/stripe/resources/invoice.rb', line 2128 def currency @currency end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
2130 2131 2132 |
# File 'lib/stripe/resources/invoice.rb', line 2130 def description @description end |
#discountable ⇒ Object
Explicitly controls whether discounts apply to this invoice item. Defaults to true, except for negative invoice items.
2132 2133 2134 |
# File 'lib/stripe/resources/invoice.rb', line 2132 def discountable @discountable end |
#discounts ⇒ Object
The coupons to redeem into discounts for the invoice item in the preview.
2134 2135 2136 |
# File 'lib/stripe/resources/invoice.rb', line 2134 def discounts @discounts end |
#invoiceitem ⇒ Object
The ID of the invoice item to update in preview. If not specified, a new invoice item will be added to the preview of the upcoming invoice.
2136 2137 2138 |
# File 'lib/stripe/resources/invoice.rb', line 2136 def invoiceitem @invoiceitem end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2138 2139 2140 |
# File 'lib/stripe/resources/invoice.rb', line 2138 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
2140 2141 2142 |
# File 'lib/stripe/resources/invoice.rb', line 2140 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
2142 2143 2144 |
# File 'lib/stripe/resources/invoice.rb', line 2142 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
2144 2145 2146 |
# File 'lib/stripe/resources/invoice.rb', line 2144 def price_data @price_data end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the invoice item.
2146 2147 2148 |
# File 'lib/stripe/resources/invoice.rb', line 2146 def quantity @quantity end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
2148 2149 2150 |
# File 'lib/stripe/resources/invoice.rb', line 2148 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
2150 2151 2152 |
# File 'lib/stripe/resources/invoice.rb', line 2150 def tax_code @tax_code end |
#tax_rates ⇒ Object
The tax rates that apply to the item. When set, any ‘default_tax_rates` do not apply to this item.
2152 2153 2154 |
# File 'lib/stripe/resources/invoice.rb', line 2152 def tax_rates @tax_rates end |
#unit_amount ⇒ Object
The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This unit_amount will be multiplied by the quantity to get the full amount. If you want to apply a credit to the customer’s account, pass a negative unit_amount.
2154 2155 2156 |
# File 'lib/stripe/resources/invoice.rb', line 2154 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
2156 2157 2158 |
# File 'lib/stripe/resources/invoice.rb', line 2156 def unit_amount_decimal @unit_amount_decimal end |