Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AmendmentEnd, AmendmentStart, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details to identify the end of the time range modified by the proposed change.
-
#amendment_start ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
-
#billing_cycle_anchor ⇒ Object
For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.
-
#discount_actions ⇒ Object
Changes to the coupons being redeemed or discounts being applied during the amendment time span.
-
#item_actions ⇒ Object
Changes to the subscription items during the amendment time span.
-
#metadata_actions ⇒ Object
Instructions for how to modify phase metadata.
-
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the amendment time span.
-
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
-
#set_schedule_end ⇒ Object
Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment
constructor
A new instance of Amendment.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment
Returns a new instance of Amendment.
3034 3035 3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 3047 3048 3049 3050 3051 3052 3053 3054 3055 3056 |
# File 'lib/stripe/resources/invoice.rb', line 3034 def initialize( amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil ) @amendment_end = amendment_end @amendment_start = amendment_start @billing_cycle_anchor = billing_cycle_anchor @discount_actions = discount_actions @item_actions = item_actions @metadata_actions = @proration_behavior = proration_behavior @set_pause_collection = set_pause_collection @set_schedule_end = set_schedule_end @trial_settings = trial_settings end |
Instance Attribute Details
#amendment_end ⇒ Object
Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.
3005 3006 3007 |
# File 'lib/stripe/resources/invoice.rb', line 3005 def amendment_end @amendment_end end |
#amendment_start ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
3008 3009 3010 |
# File 'lib/stripe/resources/invoice.rb', line 3008 def amendment_start @amendment_start end |
#billing_cycle_anchor ⇒ Object
For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.
3011 3012 3013 |
# File 'lib/stripe/resources/invoice.rb', line 3011 def billing_cycle_anchor @billing_cycle_anchor end |
#discount_actions ⇒ Object
Changes to the coupons being redeemed or discounts being applied during the amendment time span.
3014 3015 3016 |
# File 'lib/stripe/resources/invoice.rb', line 3014 def discount_actions @discount_actions end |
#item_actions ⇒ Object
Changes to the subscription items during the amendment time span.
3017 3018 3019 |
# File 'lib/stripe/resources/invoice.rb', line 3017 def item_actions @item_actions end |
#metadata_actions ⇒ Object
Instructions for how to modify phase metadata
3020 3021 3022 |
# File 'lib/stripe/resources/invoice.rb', line 3020 def @metadata_actions end |
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.
3023 3024 3025 |
# File 'lib/stripe/resources/invoice.rb', line 3023 def proration_behavior @proration_behavior end |
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
3026 3027 3028 |
# File 'lib/stripe/resources/invoice.rb', line 3026 def set_pause_collection @set_pause_collection end |
#set_schedule_end ⇒ Object
Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.
3029 3030 3031 |
# File 'lib/stripe/resources/invoice.rb', line 3029 def set_schedule_end @set_schedule_end end |
#trial_settings ⇒ Object
Settings related to subscription trials.
3032 3033 3034 |
# File 'lib/stripe/resources/invoice.rb', line 3032 def trial_settings @trial_settings end |