Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



2274
2275
2276
2277
2278
2279
# File 'lib/stripe/resources/invoice.rb', line 2274

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



2266
2267
2268
# File 'lib/stripe/resources/invoice.rb', line 2266

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



2268
2269
2270
# File 'lib/stripe/resources/invoice.rb', line 2268

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



2270
2271
2272
# File 'lib/stripe/resources/invoice.rb', line 2270

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



2272
2273
2274
# File 'lib/stripe/resources/invoice.rb', line 2272

def type
  @type
end