Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 |
# File 'lib/stripe/resources/invoice.rb', line 2655 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
2641 2642 2643 |
# File 'lib/stripe/resources/invoice.rb', line 2641 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
2644 2645 2646 |
# File 'lib/stripe/resources/invoice.rb', line 2644 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2647 2648 2649 |
# File 'lib/stripe/resources/invoice.rb', line 2647 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
2650 2651 2652 |
# File 'lib/stripe/resources/invoice.rb', line 2650 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
2653 2654 2655 |
# File 'lib/stripe/resources/invoice.rb', line 2653 def promotion_code @promotion_code end |