Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



2341
2342
2343
2344
2345
# File 'lib/stripe/resources/invoice.rb', line 2341

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



2335
2336
2337
# File 'lib/stripe/resources/invoice.rb', line 2335

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



2337
2338
2339
# File 'lib/stripe/resources/invoice.rb', line 2337

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



2339
2340
2341
# File 'lib/stripe/resources/invoice.rb', line 2339

def promotion_code
  @promotion_code
end