Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2854
2855
2856
2857
2858
# File 'lib/stripe/resources/invoice.rb', line 2854

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2846
2847
2848
# File 'lib/stripe/resources/invoice.rb', line 2846

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2849
2850
2851
# File 'lib/stripe/resources/invoice.rb', line 2849

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2852
2853
2854
# File 'lib/stripe/resources/invoice.rb', line 2852

def type
  @type
end