Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, coupon: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil) ⇒ Phase

Returns a new instance of Phase.



3571
3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
3590
3591
3592
3593
3594
3595
3596
3597
3598
3599
3600
3601
3602
3603
3604
3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
3623
3624
3625
# File 'lib/stripe/resources/invoice.rb', line 3571

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_thresholds: nil,
  collection_method: nil,
  coupon: nil,
  currency: nil,
  default_payment_method: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  end_date: nil,
  invoice_settings: nil,
  items: nil,
  iterations: nil,
  metadata: nil,
  on_behalf_of: nil,
  pause_collection: nil,
  proration_behavior: nil,
  start_date: nil,
  transfer_data: nil,
  trial: nil,
  trial_continuation: nil,
  trial_end: nil,
  trial_settings: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_thresholds = billing_thresholds
  @collection_method = collection_method
  @coupon = coupon
  @currency = currency
  @default_payment_method = default_payment_method
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @end_date = end_date
  @invoice_settings = invoice_settings
  @items = items
  @iterations = iterations
  @metadata = 
  @on_behalf_of = on_behalf_of
  @pause_collection = pause_collection
  @proration_behavior = proration_behavior
  @start_date = start_date
  @transfer_data = transfer_data
  @trial = trial
  @trial_continuation = trial_continuation
  @trial_end = trial_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.



3494
3495
3496
# File 'lib/stripe/resources/invoice.rb', line 3494

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



3497
3498
3499
# File 'lib/stripe/resources/invoice.rb', line 3497

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this phase.



3500
3501
3502
# File 'lib/stripe/resources/invoice.rb', line 3500

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).



3503
3504
3505
# File 'lib/stripe/resources/invoice.rb', line 3503

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



3506
3507
3508
# File 'lib/stripe/resources/invoice.rb', line 3506

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.



3509
3510
3511
# File 'lib/stripe/resources/invoice.rb', line 3509

def collection_method
  @collection_method
end

#couponObject

The ID of the coupon to apply to this phase of the subscription schedule. This field has been deprecated and will be removed in a future API version. Use ‘discounts` instead.



3512
3513
3514
# File 'lib/stripe/resources/invoice.rb', line 3512

def coupon
  @coupon
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



3515
3516
3517
# File 'lib/stripe/resources/invoice.rb', line 3515

def currency
  @currency
end

#default_payment_methodObject

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



3518
3519
3520
# File 'lib/stripe/resources/invoice.rb', line 3518

def default_payment_method
  @default_payment_method
end

#default_tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will set the Subscription’s [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates), which means they will be the Invoice’s [‘default_tax_rates`](stripe.com/docs/api/invoices/create#create_invoice-default_tax_rates) for any Invoices issued by the Subscription during this Phase.



3521
3522
3523
# File 'lib/stripe/resources/invoice.rb', line 3521

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



3524
3525
3526
# File 'lib/stripe/resources/invoice.rb', line 3524

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription’s customer. Pass an empty string to avoid inheriting any discounts.



3527
3528
3529
# File 'lib/stripe/resources/invoice.rb', line 3527

def discounts
  @discounts
end

#end_dateObject

The date at which this phase of the subscription schedule ends. If set, ‘iterations` must not be set.



3530
3531
3532
# File 'lib/stripe/resources/invoice.rb', line 3530

def end_date
  @end_date
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



3533
3534
3535
# File 'lib/stripe/resources/invoice.rb', line 3533

def invoice_settings
  @invoice_settings
end

#itemsObject

List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.



3536
3537
3538
# File 'lib/stripe/resources/invoice.rb', line 3536

def items
  @items
end

#iterationsObject

Integer representing the multiplier applied to the price interval. For example, ‘iterations=2` applied to a price with `interval=month` and `interval_count=3` results in a phase of duration `2 * 3 months = 6 months`. If set, `end_date` must not be set.



3539
3540
3541
# File 'lib/stripe/resources/invoice.rb', line 3539

def iterations
  @iterations
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys in the subscription’s ‘metadata`. Individual keys in the subscription’s ‘metadata` can be unset by posting an empty value to them in the phase’s ‘metadata`. To unset all keys in the subscription’s ‘metadata`, update the subscription directly or unset every key individually from the phase’s ‘metadata`.



3542
3543
3544
# File 'lib/stripe/resources/invoice.rb', line 3542

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the associated subscription’s invoices.



3545
3546
3547
# File 'lib/stripe/resources/invoice.rb', line 3545

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).



3548
3549
3550
# File 'lib/stripe/resources/invoice.rb', line 3548

def pause_collection
  @pause_collection
end

#proration_behaviorObject

Whether the subscription schedule will create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase. The default value is ‘create_prorations`. This setting controls prorations when a phase is started asynchronously and it is persisted as a field on the phase. It’s different from the request-level [proration_behavior](stripe.com/docs/api/subscription_schedules/update#update_subscription_schedule-proration_behavior) parameter which controls what happens if the update request affects the billing configuration of the current phase.



3551
3552
3553
# File 'lib/stripe/resources/invoice.rb', line 3551

def proration_behavior
  @proration_behavior
end

#start_dateObject

The date at which this phase of the subscription schedule starts or ‘now`. Must be set on the first phase.



3554
3555
3556
# File 'lib/stripe/resources/invoice.rb', line 3554

def start_date
  @start_date
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the associated subscription’s invoices.



3557
3558
3559
# File 'lib/stripe/resources/invoice.rb', line 3557

def transfer_data
  @transfer_data
end

#trialObject

If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.



3560
3561
3562
# File 'lib/stripe/resources/invoice.rb', line 3560

def trial
  @trial
end

#trial_continuationObject

Specify trial behavior when crossing phase boundaries



3563
3564
3565
# File 'lib/stripe/resources/invoice.rb', line 3563

def trial_continuation
  @trial_continuation
end

#trial_endObject

Sets the phase to trialing from the start date to this date. Must be before the phase end date, can not be combined with ‘trial`



3566
3567
3568
# File 'lib/stripe/resources/invoice.rb', line 3566

def trial_end
  @trial_end
end

#trial_settingsObject

Settings related to subscription trials.



3569
3570
3571
# File 'lib/stripe/resources/invoice.rb', line 3569

def trial_settings
  @trial_settings
end