Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Phase::TransferData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
3024 3025 3026 3027 |
# File 'lib/stripe/resources/invoice.rb', line 3024 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
3020 3021 3022 |
# File 'lib/stripe/resources/invoice.rb', line 3020 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
3022 3023 3024 |
# File 'lib/stripe/resources/invoice.rb', line 3022 def destination @destination end |