Class: Stripe::Invoice::UpcomingParams::ScheduleDetails::Prebilling::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::ScheduleDetails::Prebilling::BillUntil
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: AmendmentEnd, Duration
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
-
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
-
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
-
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
3663 3664 3665 3666 3667 3668 |
# File 'lib/stripe/resources/invoice.rb', line 3663 def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) @amendment_end = amendment_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#amendment_end ⇒ Object
End the prebilled period when a specified amendment ends.
3652 3653 3654 |
# File 'lib/stripe/resources/invoice.rb', line 3652 def amendment_end @amendment_end end |
#duration ⇒ Object
Time span for prebilling, starting from ‘bill_from`.
3655 3656 3657 |
# File 'lib/stripe/resources/invoice.rb', line 3655 def duration @duration end |
#timestamp ⇒ Object
End the prebilled period at a precise integer timestamp, starting from the Unix epoch.
3658 3659 3660 |
# File 'lib/stripe/resources/invoice.rb', line 3658 def @timestamp end |
#type ⇒ Object
Select one of several ways to pass the ‘bill_until` value.
3661 3662 3663 |
# File 'lib/stripe/resources/invoice.rb', line 3661 def type @type end |