Class: Stripe::Invoice::UpcomingParams::SubscriptionItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::SubscriptionItem::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
4007 4008 4009 4010 4011 4012 |
# File 'lib/stripe/resources/invoice.rb', line 4007 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
3996 3997 3998 |
# File 'lib/stripe/resources/invoice.rb', line 3996 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
3999 4000 4001 |
# File 'lib/stripe/resources/invoice.rb', line 3999 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
4002 4003 4004 |
# File 'lib/stripe/resources/invoice.rb', line 4002 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
4005 4006 4007 |
# File 'lib/stripe/resources/invoice.rb', line 4005 def promotion_code @promotion_code end |