Class: Stripe::Invoice::UpcomingParams::SubscriptionItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3471
3472
3473
3474
3475
# File 'lib/stripe/resources/invoice.rb', line 3471

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3465
3466
3467
# File 'lib/stripe/resources/invoice.rb', line 3465

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3467
3468
3469
# File 'lib/stripe/resources/invoice.rb', line 3467

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3469
3470
3471
# File 'lib/stripe/resources/invoice.rb', line 3469

def type
  @type
end