Class: Stripe::Invoice::UpcomingParams::SubscriptionPrebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpcomingParams::SubscriptionPrebilling
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(iterations: nil) ⇒ SubscriptionPrebilling
constructor
A new instance of SubscriptionPrebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil) ⇒ SubscriptionPrebilling
Returns a new instance of SubscriptionPrebilling.
3589 3590 3591 |
# File 'lib/stripe/resources/invoice.rb', line 3589 def initialize(iterations: nil) @iterations = iterations end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
3587 3588 3589 |
# File 'lib/stripe/resources/invoice.rb', line 3587 def iterations @iterations end |