Class: Stripe::Invoice::UpdateLinesParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Discount, Period, PriceData, Pricing, TaxAmount
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Controls whether discounts apply to this line item.
-
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item.
-
#id ⇒ Object
ID of an existing line item on the invoice.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#pricing ⇒ Object
The pricing information for the invoice item.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line
Returns a new instance of Line.
2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 2217 2218 2219 2220 2221 2222 2223 2224 |
# File 'lib/stripe/resources/invoice.rb', line 2198 def initialize( amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil ) @amount = amount @description = description @discountable = discountable @discounts = discounts @id = id @metadata = @period = period @price_data = price_data @pricing = pricing @quantity = quantity @tax_amounts = tax_amounts @tax_rates = tax_rates end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.
2174 2175 2176 |
# File 'lib/stripe/resources/invoice.rb', line 2174 def amount @amount end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
2176 2177 2178 |
# File 'lib/stripe/resources/invoice.rb', line 2176 def description @description end |
#discountable ⇒ Object
Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.
2178 2179 2180 |
# File 'lib/stripe/resources/invoice.rb', line 2178 def discountable @discountable end |
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.
2180 2181 2182 |
# File 'lib/stripe/resources/invoice.rb', line 2180 def discounts @discounts end |
#id ⇒ Object
ID of an existing line item on the invoice.
2182 2183 2184 |
# File 'lib/stripe/resources/invoice.rb', line 2182 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.
2184 2185 2186 |
# File 'lib/stripe/resources/invoice.rb', line 2184 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
2186 2187 2188 |
# File 'lib/stripe/resources/invoice.rb', line 2186 def period @period end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
2188 2189 2190 |
# File 'lib/stripe/resources/invoice.rb', line 2188 def price_data @price_data end |
#pricing ⇒ Object
The pricing information for the invoice item.
2190 2191 2192 |
# File 'lib/stripe/resources/invoice.rb', line 2190 def pricing @pricing end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the line item.
2192 2193 2194 |
# File 'lib/stripe/resources/invoice.rb', line 2192 def quantity @quantity end |
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.
2194 2195 2196 |
# File 'lib/stripe/resources/invoice.rb', line 2194 def tax_amounts @tax_amounts end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.
2196 2197 2198 |
# File 'lib/stripe/resources/invoice.rb', line 2196 def tax_rates @tax_rates end |