Class: Stripe::Invoice::UpdateLinesParams::Line

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, margins: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line

Returns a new instance of Line.



6162
6163
6164
6165
6166
6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
# File 'lib/stripe/resources/invoice.rb', line 6162

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  id: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @id = id
  @margins = margins
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



6136
6137
6138
# File 'lib/stripe/resources/invoice.rb', line 6136

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



6138
6139
6140
# File 'lib/stripe/resources/invoice.rb', line 6138

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



6140
6141
6142
# File 'lib/stripe/resources/invoice.rb', line 6140

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



6142
6143
6144
# File 'lib/stripe/resources/invoice.rb', line 6142

def discounts
  @discounts
end

#idObject

ID of an existing line item on the invoice.



6144
6145
6146
# File 'lib/stripe/resources/invoice.rb', line 6144

def id
  @id
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



6146
6147
6148
# File 'lib/stripe/resources/invoice.rb', line 6146

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.



6148
6149
6150
# File 'lib/stripe/resources/invoice.rb', line 6148

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



6150
6151
6152
# File 'lib/stripe/resources/invoice.rb', line 6150

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



6152
6153
6154
# File 'lib/stripe/resources/invoice.rb', line 6152

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



6154
6155
6156
# File 'lib/stripe/resources/invoice.rb', line 6154

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



6156
6157
6158
# File 'lib/stripe/resources/invoice.rb', line 6156

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



6158
6159
6160
# File 'lib/stripe/resources/invoice.rb', line 6158

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



6160
6161
6162
# File 'lib/stripe/resources/invoice.rb', line 6160

def tax_rates
  @tax_rates
end