Class: Stripe::Invoice::UpdateLinesParams::Line::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2312 2313 2314 2315 2316 2317 |
# File 'lib/stripe/resources/invoice.rb', line 2312 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2304 2305 2306 |
# File 'lib/stripe/resources/invoice.rb', line 2304 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2306 2307 2308 |
# File 'lib/stripe/resources/invoice.rb', line 2306 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2308 2309 2310 |
# File 'lib/stripe/resources/invoice.rb', line 2308 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2310 2311 2312 |
# File 'lib/stripe/resources/invoice.rb', line 2310 def promotion_code @promotion_code end |