Class: Stripe::Invoice::UpdateLinesParams::Line::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2030 2031 2032 2033 2034 |
# File 'lib/stripe/resources/invoice.rb', line 2030 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2024 2025 2026 |
# File 'lib/stripe/resources/invoice.rb', line 2024 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2026 2027 2028 |
# File 'lib/stripe/resources/invoice.rb', line 2026 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2028 2029 2030 |
# File 'lib/stripe/resources/invoice.rb', line 2028 def promotion_code @promotion_code end |