Class: Stripe::Invoice::UpdateLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2323
2324
2325
2326
2327
2328
# File 'lib/stripe/resources/invoice.rb', line 2323

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2315
2316
2317
# File 'lib/stripe/resources/invoice.rb', line 2315

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2317
2318
2319
# File 'lib/stripe/resources/invoice.rb', line 2317

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2319
2320
2321
# File 'lib/stripe/resources/invoice.rb', line 2319

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2321
2322
2323
# File 'lib/stripe/resources/invoice.rb', line 2321

def promotion_code
  @promotion_code
end