Class: Stripe::Invoice::UpdateLinesParams::Line::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2339 2340 2341 2342 2343 2344 |
# File 'lib/stripe/resources/invoice.rb', line 2339 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2331 2332 2333 |
# File 'lib/stripe/resources/invoice.rb', line 2331 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2333 2334 2335 |
# File 'lib/stripe/resources/invoice.rb', line 2333 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2335 2336 2337 |
# File 'lib/stripe/resources/invoice.rb', line 2335 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2337 2338 2339 |
# File 'lib/stripe/resources/invoice.rb', line 2337 def promotion_code @promotion_code end |