Class: Stripe::Invoice::UpdateLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



6918
6919
6920
6921
6922
6923
# File 'lib/stripe/resources/invoice.rb', line 6918

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



6907
6908
6909
# File 'lib/stripe/resources/invoice.rb', line 6907

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



6910
6911
6912
# File 'lib/stripe/resources/invoice.rb', line 6910

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



6913
6914
6915
# File 'lib/stripe/resources/invoice.rb', line 6913

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



6916
6917
6918
# File 'lib/stripe/resources/invoice.rb', line 6916

def promotion_code
  @promotion_code
end