Class: Stripe::Invoice::UpdateLinesParams::Line::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



5995
5996
5997
5998
5999
# File 'lib/stripe/resources/invoice.rb', line 5995

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



5989
5990
5991
# File 'lib/stripe/resources/invoice.rb', line 5989

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



5991
5992
5993
# File 'lib/stripe/resources/invoice.rb', line 5991

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



5993
5994
5995
# File 'lib/stripe/resources/invoice.rb', line 5993

def type
  @type
end