Class: Stripe::Invoice::UpdateLinesParams::Line::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



6900
6901
6902
6903
6904
# File 'lib/stripe/resources/invoice.rb', line 6900

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



6892
6893
6894
# File 'lib/stripe/resources/invoice.rb', line 6892

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



6895
6896
6897
# File 'lib/stripe/resources/invoice.rb', line 6895

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



6898
6899
6900
# File 'lib/stripe/resources/invoice.rb', line 6898

def type
  @type
end