Class: Stripe::Invoice::UpdateLinesParams::Line::Discount::DiscountEnd::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::Discount::DiscountEnd::Duration
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
5983 5984 5985 5986 |
# File 'lib/stripe/resources/invoice.rb', line 5983 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
5979 5980 5981 |
# File 'lib/stripe/resources/invoice.rb', line 5979 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
5981 5982 5983 |
# File 'lib/stripe/resources/invoice.rb', line 5981 def interval_count @interval_count end |