Class: Stripe::Invoice::UpdateLinesParams::Line::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::Period
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
2353 2354 2355 2356 |
# File 'lib/stripe/resources/invoice.rb', line 2353 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
2349 2350 2351 |
# File 'lib/stripe/resources/invoice.rb', line 2349 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
2351 2352 2353 |
# File 'lib/stripe/resources/invoice.rb', line 2351 def start @start end |