Class: Stripe::Invoice::UpdateLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



2067
2068
2069
2070
2071
2072
2073
# File 'lib/stripe/resources/invoice.rb', line 2067

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



2057
2058
2059
# File 'lib/stripe/resources/invoice.rb', line 2057

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



2059
2060
2061
# File 'lib/stripe/resources/invoice.rb', line 2059

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2061
2062
2063
# File 'lib/stripe/resources/invoice.rb', line 2061

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



2063
2064
2065
# File 'lib/stripe/resources/invoice.rb', line 2063

def name
  @name
end

#tax_codeObject



2065
2066
2067
# File 'lib/stripe/resources/invoice.rb', line 2065

def tax_code
  @tax_code
end