Class: Stripe::Invoice::UpdateLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



2372
2373
2374
2375
2376
2377
2378
# File 'lib/stripe/resources/invoice.rb', line 2372

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



2362
2363
2364
# File 'lib/stripe/resources/invoice.rb', line 2362

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



2364
2365
2366
# File 'lib/stripe/resources/invoice.rb', line 2364

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2366
2367
2368
# File 'lib/stripe/resources/invoice.rb', line 2366

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



2368
2369
2370
# File 'lib/stripe/resources/invoice.rb', line 2368

def name
  @name
end

#tax_codeObject



2370
2371
2372
# File 'lib/stripe/resources/invoice.rb', line 2370

def tax_code
  @tax_code
end