Class: Stripe::Invoice::UpdateLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



6043
6044
6045
6046
6047
6048
6049
# File 'lib/stripe/resources/invoice.rb', line 6043

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



6033
6034
6035
# File 'lib/stripe/resources/invoice.rb', line 6033

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



6035
6036
6037
# File 'lib/stripe/resources/invoice.rb', line 6035

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6037
6038
6039
# File 'lib/stripe/resources/invoice.rb', line 6037

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



6039
6040
6041
# File 'lib/stripe/resources/invoice.rb', line 6039

def name
  @name
end

#tax_codeObject



6041
6042
6043
# File 'lib/stripe/resources/invoice.rb', line 6041

def tax_code
  @tax_code
end