Class: Stripe::Invoice::UpdateLinesParams::Line::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::PriceData::ProductData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
6956 6957 6958 6959 6960 6961 6962 |
# File 'lib/stripe/resources/invoice.rb', line 6956 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
6942 6943 6944 |
# File 'lib/stripe/resources/invoice.rb', line 6942 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
6945 6946 6947 |
# File 'lib/stripe/resources/invoice.rb', line 6945 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
6948 6949 6950 |
# File 'lib/stripe/resources/invoice.rb', line 6948 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
6951 6952 6953 |
# File 'lib/stripe/resources/invoice.rb', line 6951 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
6954 6955 6956 |
# File 'lib/stripe/resources/invoice.rb', line 6954 def tax_code @tax_code end |