Class: Stripe::Invoice::UpdateLinesParams::Line::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::TaxAmount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: TaxRateData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
-
#taxability_reason ⇒ Object
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
2523 2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/stripe/resources/invoice.rb', line 2523 def initialize( amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil ) @amount = amount @tax_rate_data = tax_rate_data @taxability_reason = taxability_reason @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
2513 2514 2515 |
# File 'lib/stripe/resources/invoice.rb', line 2513 def amount @amount end |
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.
2517 2518 2519 |
# File 'lib/stripe/resources/invoice.rb', line 2517 def tax_rate_data @tax_rate_data end |
#taxability_reason ⇒ Object
The reasoning behind this tax, for example, if the product is tax exempt.
2519 2520 2521 |
# File 'lib/stripe/resources/invoice.rb', line 2519 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
2521 2522 2523 |
# File 'lib/stripe/resources/invoice.rb', line 2521 def taxable_amount @taxable_amount end |