Class: Stripe::Invoice::UpdateLinesParams::Line::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::TaxAmount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: TaxRateData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
7056 7057 7058 7059 7060 |
# File 'lib/stripe/resources/invoice.rb', line 7056 def initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) @amount = amount @tax_rate_data = tax_rate_data @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
7046 7047 7048 |
# File 'lib/stripe/resources/invoice.rb', line 7046 def amount @amount end |
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.
7051 7052 7053 |
# File 'lib/stripe/resources/invoice.rb', line 7051 def tax_rate_data @tax_rate_data end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
7054 7055 7056 |
# File 'lib/stripe/resources/invoice.rb', line 7054 def taxable_amount @taxable_amount end |