Class: Stripe::Invoice::UpdateLinesParams::Line::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::TaxAmount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: TaxRateData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
6129 6130 6131 6132 6133 |
# File 'lib/stripe/resources/invoice.rb', line 6129 def initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) @amount = amount @tax_rate_data = tax_rate_data @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
6121 6122 6123 |
# File 'lib/stripe/resources/invoice.rb', line 6121 def amount @amount end |
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.
6125 6126 6127 |
# File 'lib/stripe/resources/invoice.rb', line 6125 def tax_rate_data @tax_rate_data end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
6127 6128 6129 |
# File 'lib/stripe/resources/invoice.rb', line 6127 def taxable_amount @taxable_amount end |