Class: Stripe::Invoice::UpdateLinesParams::Line::TaxAmount::TaxRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateLinesParams::Line::TaxAmount::TaxRateData
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#jurisdiction_level ⇒ Object
The level of the jurisdiction that imposes this tax rate.
-
#percentage ⇒ Object
The statutory tax rate percent.
-
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
Instance Method Summary collapse
-
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
constructor
A new instance of TaxRateData.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
Returns a new instance of TaxRateData.
2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 |
# File 'lib/stripe/resources/invoice.rb', line 2413 def initialize( country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil ) @country = country @description = description @display_name = display_name @inclusive = inclusive @jurisdiction = jurisdiction @jurisdiction_level = jurisdiction_level @percentage = percentage @state = state @tax_type = tax_type end |
Instance Attribute Details
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
2395 2396 2397 |
# File 'lib/stripe/resources/invoice.rb', line 2395 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
2397 2398 2399 |
# File 'lib/stripe/resources/invoice.rb', line 2397 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
2399 2400 2401 |
# File 'lib/stripe/resources/invoice.rb', line 2399 def display_name @display_name end |
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
2401 2402 2403 |
# File 'lib/stripe/resources/invoice.rb', line 2401 def inclusive @inclusive end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
2403 2404 2405 |
# File 'lib/stripe/resources/invoice.rb', line 2403 def jurisdiction @jurisdiction end |
#jurisdiction_level ⇒ Object
The level of the jurisdiction that imposes this tax rate.
2405 2406 2407 |
# File 'lib/stripe/resources/invoice.rb', line 2405 def jurisdiction_level @jurisdiction_level end |
#percentage ⇒ Object
The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.
2407 2408 2409 |
# File 'lib/stripe/resources/invoice.rb', line 2407 def percentage @percentage end |
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.
2409 2410 2411 |
# File 'lib/stripe/resources/invoice.rb', line 2409 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
2411 2412 2413 |
# File 'lib/stripe/resources/invoice.rb', line 2411 def tax_type @tax_type end |