Class: Stripe::Invoice::UpdateParams::AmountsDue
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateParams::AmountsDue
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount in cents (or local equivalent).
-
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
Instance Method Summary collapse
-
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
constructor
A new instance of AmountsDue.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) ⇒ AmountsDue
Returns a new instance of AmountsDue.
536 537 538 539 540 541 |
# File 'lib/stripe/resources/invoice.rb', line 536 def initialize(amount: nil, days_until_due: nil, description: nil, due_date: nil) @amount = amount @days_until_due = days_until_due @description = description @due_date = due_date end |
Instance Attribute Details
#amount ⇒ Object
The amount in cents (or local equivalent).
528 529 530 |
# File 'lib/stripe/resources/invoice.rb', line 528 def amount @amount end |
#days_until_due ⇒ Object
Number of days from when invoice is finalized until the payment is due.
530 531 532 |
# File 'lib/stripe/resources/invoice.rb', line 530 def days_until_due @days_until_due end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
532 533 534 |
# File 'lib/stripe/resources/invoice.rb', line 532 def description @description end |
#due_date ⇒ Object
Date on which a payment plan’s payment is due.
534 535 536 |
# File 'lib/stripe/resources/invoice.rb', line 534 def due_date @due_date end |