Class: Stripe::Invoice::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



592
593
594
595
596
597
# File 'lib/stripe/resources/invoice.rb', line 592

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



584
585
586
# File 'lib/stripe/resources/invoice.rb', line 584

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



586
587
588
# File 'lib/stripe/resources/invoice.rb', line 586

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



588
589
590
# File 'lib/stripe/resources/invoice.rb', line 588

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



590
591
592
# File 'lib/stripe/resources/invoice.rb', line 590

def promotion_code
  @promotion_code
end