Class: Stripe::Invoice::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



683
684
685
686
687
688
# File 'lib/stripe/resources/invoice.rb', line 683

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



672
673
674
# File 'lib/stripe/resources/invoice.rb', line 672

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



675
676
677
# File 'lib/stripe/resources/invoice.rb', line 675

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



678
679
680
# File 'lib/stripe/resources/invoice.rb', line 678

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



681
682
683
# File 'lib/stripe/resources/invoice.rb', line 681

def promotion_code
  @promotion_code
end