Class: Stripe::Invoice::UpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateParams::Discount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
683 684 685 686 687 688 |
# File 'lib/stripe/resources/invoice.rb', line 683 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
672 673 674 |
# File 'lib/stripe/resources/invoice.rb', line 672 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
675 676 677 |
# File 'lib/stripe/resources/invoice.rb', line 675 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
678 679 680 |
# File 'lib/stripe/resources/invoice.rb', line 678 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
681 682 683 |
# File 'lib/stripe/resources/invoice.rb', line 681 def promotion_code @promotion_code end |