Class: Stripe::Invoice::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



592
593
594
595
596
# File 'lib/stripe/resources/invoice.rb', line 592

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



586
587
588
# File 'lib/stripe/resources/invoice.rb', line 586

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



588
589
590
# File 'lib/stripe/resources/invoice.rb', line 588

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



590
591
592
# File 'lib/stripe/resources/invoice.rb', line 590

def type
  @type
end