Class: Stripe::Invoice::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



665
666
667
668
669
# File 'lib/stripe/resources/invoice.rb', line 665

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



657
658
659
# File 'lib/stripe/resources/invoice.rb', line 657

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



660
661
662
# File 'lib/stripe/resources/invoice.rb', line 660

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



663
664
665
# File 'lib/stripe/resources/invoice.rb', line 663

def type
  @type
end