Class: Stripe::Invoice::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this invoice.
-
#plan ⇒ Object
The selected installment plan to use for this invoice.
Instance Method Summary collapse
-
#initialize(enabled: nil, plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, plan: nil) ⇒ Installments
Returns a new instance of Installments.
1096 1097 1098 1099 |
# File 'lib/stripe/resources/invoice.rb', line 1096 def initialize(enabled: nil, plan: nil) @enabled = enabled @plan = plan end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.
1092 1093 1094 |
# File 'lib/stripe/resources/invoice.rb', line 1092 def enabled @enabled end |
#plan ⇒ Object
The selected installment plan to use for this invoice.
1094 1095 1096 |
# File 'lib/stripe/resources/invoice.rb', line 1094 def plan @plan end |