Class: Stripe::Invoice::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



650
651
652
653
# File 'lib/stripe/resources/invoice.rb', line 650

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.



646
647
648
# File 'lib/stripe/resources/invoice.rb', line 646

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this invoice.



648
649
650
# File 'lib/stripe/resources/invoice.rb', line 648

def plan
  @plan
end