Class: Stripe::Invoice::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required.
-
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
constructor
A new instance of Plan.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil, type: nil) ⇒ Plan
Returns a new instance of Plan.
652 653 654 655 656 |
# File 'lib/stripe/resources/invoice.rb', line 652 def initialize(count: nil, interval: nil, type: nil) @count = count @interval = interval @type = type end |
Instance Attribute Details
#count ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.
645 646 647 |
# File 'lib/stripe/resources/invoice.rb', line 645 def count @count end |
#interval ⇒ Object
For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.
648 649 650 |
# File 'lib/stripe/resources/invoice.rb', line 648 def interval @interval end |
#type ⇒ Object
Type of installment plan, one of ‘fixed_count`.
650 651 652 |
# File 'lib/stripe/resources/invoice.rb', line 650 def type @type end |