Class: Stripe::Invoice::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



653
654
655
656
657
# File 'lib/stripe/resources/invoice.rb', line 653

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



646
647
648
# File 'lib/stripe/resources/invoice.rb', line 646

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



649
650
651
# File 'lib/stripe/resources/invoice.rb', line 649

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



651
652
653
# File 'lib/stripe/resources/invoice.rb', line 651

def type
  @type
end