Class: Stripe::Invoice::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



654
655
656
657
658
# File 'lib/stripe/resources/invoice.rb', line 654

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



647
648
649
# File 'lib/stripe/resources/invoice.rb', line 647

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



650
651
652
# File 'lib/stripe/resources/invoice.rb', line 650

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



652
653
654
# File 'lib/stripe/resources/invoice.rb', line 652

def type
  @type
end