Class: Stripe::Invoice::UpdateParams::Rendering

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering

Returns a new instance of Rendering.



831
832
833
834
835
836
# File 'lib/stripe/resources/invoice.rb', line 831

def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil)
  @amount_tax_display = amount_tax_display
  @pdf = pdf
  @template = template
  @template_version = template_version
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



823
824
825
# File 'lib/stripe/resources/invoice.rb', line 823

def amount_tax_display
  @amount_tax_display
end

#pdfObject

Invoice pdf rendering options



825
826
827
# File 'lib/stripe/resources/invoice.rb', line 825

def pdf
  @pdf
end

#templateObject

ID of the invoice rendering template to use for this invoice.



827
828
829
# File 'lib/stripe/resources/invoice.rb', line 827

def template
  @template
end

#template_versionObject

The specific version of invoice rendering template to use for this invoice.



829
830
831
# File 'lib/stripe/resources/invoice.rb', line 829

def template_version
  @template_version
end