Class: Stripe::Invoice::UpdateParams::ShippingCost::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
# File 'lib/stripe/resources/invoice.rb', line 1043

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



1023
1024
1025
# File 'lib/stripe/resources/invoice.rb', line 1023

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



1026
1027
1028
# File 'lib/stripe/resources/invoice.rb', line 1026

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



1029
1030
1031
# File 'lib/stripe/resources/invoice.rb', line 1029

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1032
1033
1034
# File 'lib/stripe/resources/invoice.rb', line 1032

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



1035
1036
1037
# File 'lib/stripe/resources/invoice.rb', line 1035

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A [tax code](stripe.com/docs/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.



1038
1039
1040
# File 'lib/stripe/resources/invoice.rb', line 1038

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



1041
1042
1043
# File 'lib/stripe/resources/invoice.rb', line 1041

def type
  @type
end