Class: Stripe::Invoice::UpdateParams::ShippingCost::ShippingRateData::FixedAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::UpdateParams::ShippingCost::ShippingRateData::FixedAmount
- Defined in:
- lib/stripe/resources/invoice.rb
Defined Under Namespace
Classes: CurrencyOptions
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#currency_options ⇒ Object
Shipping rates defined in each available currency option.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
constructor
A new instance of FixedAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, currency_options: nil) ⇒ FixedAmount
Returns a new instance of FixedAmount.
935 936 937 938 939 |
# File 'lib/stripe/resources/invoice.rb', line 935 def initialize(amount: nil, currency: nil, currency_options: nil) @amount = amount @currency = currency @currency_options = end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
929 930 931 |
# File 'lib/stripe/resources/invoice.rb', line 929 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
931 932 933 |
# File 'lib/stripe/resources/invoice.rb', line 931 def currency @currency end |
#currency_options ⇒ Object
Shipping rates defined in each available currency option. Each key must be a three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html) and a [supported currency](stripe.com/docs/currencies).
933 934 935 |
# File 'lib/stripe/resources/invoice.rb', line 933 def @currency_options end |