Class: Stripe::Invoice::UpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



995
996
997
998
# File 'lib/stripe/resources/invoice.rb', line 995

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



991
992
993
# File 'lib/stripe/resources/invoice.rb', line 991

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



993
994
995
# File 'lib/stripe/resources/invoice.rb', line 993

def destination
  @destination
end