Class: Stripe::Invoice::UpdateParams::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1132
1133
1134
1135
# File 'lib/stripe/resources/invoice.rb', line 1132

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



1127
1128
1129
# File 'lib/stripe/resources/invoice.rb', line 1127

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



1130
1131
1132
# File 'lib/stripe/resources/invoice.rb', line 1130

def destination
  @destination
end