Class: Stripe::Invoice::VoidInvoiceParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Invoice::VoidInvoiceParams
- Defined in:
- lib/stripe/resources/invoice.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ VoidInvoiceParams
constructor
A new instance of VoidInvoiceParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ VoidInvoiceParams
Returns a new instance of VoidInvoiceParams.
2533 2534 2535 |
# File 'lib/stripe/resources/invoice.rb', line 2533 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2531 2532 2533 |
# File 'lib/stripe/resources/invoice.rb', line 2531 def @expand end |