Class: Stripe::InvoiceAddLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_add_lines_params.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ InvoiceAddLinesParams

Returns a new instance of InvoiceAddLinesParams.



272
273
274
275
276
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 272

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



266
267
268
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 266

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



268
269
270
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 268

def 
  @invoice_metadata
end

#linesObject

The line items to add.



270
271
272
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 270

def lines
  @lines
end