Class: Stripe::InvoiceAddLinesParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_add_lines_params.rb

Defined Under Namespace

Classes: Line

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ InvoiceAddLinesParams

Returns a new instance of InvoiceAddLinesParams.



257
258
259
260
261
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 257

def initialize(expand: nil, invoice_metadata: nil, lines: nil)
  @expand = expand
  @invoice_metadata = 
  @lines = lines
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



251
252
253
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 251

def expand
  @expand
end

#invoice_metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



253
254
255
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 253

def 
  @invoice_metadata
end

#linesObject

The line items to add.



255
256
257
# File 'lib/stripe/params/invoice_add_lines_params.rb', line 255

def lines
  @lines
end