Class: Stripe::InvoiceAttachPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceAttachPaymentParams
- Defined in:
- lib/stripe/params/invoice_attach_payment_params.rb
Defined Under Namespace
Classes: PaymentRecordData
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
-
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
-
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ InvoiceAttachPaymentParams
constructor
A new instance of InvoiceAttachPaymentParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ InvoiceAttachPaymentParams
Returns a new instance of InvoiceAttachPaymentParams.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 47 def initialize( amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil ) @amount_requested = amount_requested @expand = @payment_intent = payment_intent @payment_record = payment_record @payment_record_data = payment_record_data end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.
37 38 39 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 37 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
39 40 41 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 39 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
41 42 43 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 41 def payment_intent @payment_intent end |
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
43 44 45 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 43 def payment_record @payment_record end |
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
45 46 47 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 45 def payment_record_data @payment_record_data end |