Class: Stripe::InvoiceAttachPaymentParams::PaymentRecordData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceAttachPaymentParams::PaymentRecordData
- Defined in:
- lib/stripe/params/invoice_attach_payment_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that was paid out of band.
-
#currency ⇒ Object
The currency that was paid out of band.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
-
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
-
#payment_reference ⇒ Object
The reference for this out of band payment record.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
constructor
A new instance of PaymentRecordData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
Returns a new instance of PaymentRecordData.
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 20 def initialize( amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil ) @amount = amount @currency = currency @metadata = @money_movement_type = money_movement_type @paid_at = paid_at @payment_reference = payment_reference end |
Instance Attribute Details
#amount ⇒ Object
The amount that was paid out of band.
8 9 10 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 8 def amount @amount end |
#currency ⇒ Object
The currency that was paid out of band.
10 11 12 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 10 def currency @currency end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
12 13 14 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 12 def @metadata end |
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
14 15 16 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 14 def money_movement_type @money_movement_type end |
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
16 17 18 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 16 def paid_at @paid_at end |
#payment_reference ⇒ Object
The reference for this out of band payment record.
18 19 20 |
# File 'lib/stripe/params/invoice_attach_payment_params.rb', line 18 def payment_reference @payment_reference end |