Class: Stripe::InvoiceCreateParams::PaymentSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Defined Under Namespace

Classes: PaymentMethodOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil) ⇒ PaymentSettings

Returns a new instance of PaymentSettings.



438
439
440
441
442
# File 'lib/stripe/params/invoice_create_params.rb', line 438

def initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil)
  @default_mandate = default_mandate
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
end

Instance Attribute Details

#default_mandateObject

ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the invoice’s default_payment_method or default_source, if set.



432
433
434
# File 'lib/stripe/params/invoice_create_params.rb', line 432

def default_mandate
  @default_mandate
end

#payment_method_optionsObject

Payment-method-specific configuration to provide to the invoice’s PaymentIntent.



434
435
436
# File 'lib/stripe/params/invoice_create_params.rb', line 434

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice).



436
437
438
# File 'lib/stripe/params/invoice_create_params.rb', line 436

def payment_method_types
  @payment_method_types
end