Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Defined Under Namespace
Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, Pix, SepaDebit, Upi, UsBankAccount
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
-
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
-
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
-
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#id_bank_transfer ⇒ Object
If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
-
#konbini ⇒ Object
If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
-
#pix ⇒ Object
If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
-
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
-
#upi ⇒ Object
If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
-
#us_bank_account ⇒ Object
If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/stripe/params/invoice_create_params.rb', line 326 def initialize( acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil ) @acss_debit = acss_debit @bancontact = bancontact @card = card @customer_balance = customer_balance @id_bank_transfer = id_bank_transfer @konbini = konbini @pix = pix @sepa_debit = sepa_debit @upi = upi @us_bank_account = us_bank_account end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.
306 307 308 |
# File 'lib/stripe/params/invoice_create_params.rb', line 306 def acss_debit @acss_debit end |
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.
308 309 310 |
# File 'lib/stripe/params/invoice_create_params.rb', line 308 def bancontact @bancontact end |
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.
310 311 312 |
# File 'lib/stripe/params/invoice_create_params.rb', line 310 def card @card end |
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.
312 313 314 |
# File 'lib/stripe/params/invoice_create_params.rb', line 312 def customer_balance @customer_balance end |
#id_bank_transfer ⇒ Object
If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.
314 315 316 |
# File 'lib/stripe/params/invoice_create_params.rb', line 314 def id_bank_transfer @id_bank_transfer end |
#konbini ⇒ Object
If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.
316 317 318 |
# File 'lib/stripe/params/invoice_create_params.rb', line 316 def konbini @konbini end |
#pix ⇒ Object
If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.
318 319 320 |
# File 'lib/stripe/params/invoice_create_params.rb', line 318 def pix @pix end |
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.
320 321 322 |
# File 'lib/stripe/params/invoice_create_params.rb', line 320 def sepa_debit @sepa_debit end |
#upi ⇒ Object
If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.
322 323 324 |
# File 'lib/stripe/params/invoice_create_params.rb', line 322 def upi @upi end |
#us_bank_account ⇒ Object
If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.
324 325 326 |
# File 'lib/stripe/params/invoice_create_params.rb', line 324 def us_bank_account @us_bank_account end |