Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The maximum amount that can be collected in a single invoice.
-
#purpose ⇒ Object
The purpose for which payments are made.
Instance Method Summary collapse
-
#initialize(amount: nil, purpose: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, purpose: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
241 242 243 244 |
# File 'lib/stripe/params/invoice_create_params.rb', line 241 def initialize(amount: nil, purpose: nil) @amount = amount @purpose = purpose end |
Instance Attribute Details
#amount ⇒ Object
The maximum amount that can be collected in a single invoice. If you don’t specify a maximum, then there is no limit.
237 238 239 |
# File 'lib/stripe/params/invoice_create_params.rb', line 237 def amount @amount end |
#purpose ⇒ Object
The purpose for which payments are made. Has a default value based on your merchant category code.
239 240 241 |
# File 'lib/stripe/params/invoice_create_params.rb', line 239 def purpose @purpose end |