Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



279
280
281
282
283
284
# File 'lib/stripe/params/invoice_create_params.rb', line 279

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



271
272
273
# File 'lib/stripe/params/invoice_create_params.rb', line 271

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



273
274
275
# File 'lib/stripe/params/invoice_create_params.rb', line 273

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



275
276
277
# File 'lib/stripe/params/invoice_create_params.rb', line 275

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



277
278
279
# File 'lib/stripe/params/invoice_create_params.rb', line 277

def end_date
  @end_date
end