Class: Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::WechatPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::PaymentSettings::PaymentMethodOptions::WechatPay
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
The app ID registered with WeChat Pay.
-
#client ⇒ Object
The client type that the end customer will pay from.
Instance Method Summary collapse
-
#initialize(app_id: nil, client: nil) ⇒ WechatPay
constructor
A new instance of WechatPay.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(app_id: nil, client: nil) ⇒ WechatPay
Returns a new instance of WechatPay.
340 341 342 343 |
# File 'lib/stripe/params/invoice_create_params.rb', line 340 def initialize(app_id: nil, client: nil) @app_id = app_id @client = client end |
Instance Attribute Details
#app_id ⇒ Object
The app ID registered with WeChat Pay. Only required when client is ‘ios` or `android`.
336 337 338 |
# File 'lib/stripe/params/invoice_create_params.rb', line 336 def app_id @app_id end |
#client ⇒ Object
The client type that the end customer will pay from.
338 339 340 |
# File 'lib/stripe/params/invoice_create_params.rb', line 338 def client @client end |