Class: Stripe::InvoiceCreateParams::TransferData

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



582
583
584
585
# File 'lib/stripe/params/invoice_create_params.rb', line 582

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.



578
579
580
# File 'lib/stripe/params/invoice_create_params.rb', line 578

def amount
  @amount
end

#destinationObject

ID of an existing, connected Stripe account.



580
581
582
# File 'lib/stripe/params/invoice_create_params.rb', line 580

def destination
  @destination
end