Class: Stripe::InvoiceCreateParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreateParams::TransferData
- Defined in:
- lib/stripe/params/invoice_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
582 583 584 585 |
# File 'lib/stripe/params/invoice_create_params.rb', line 582 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the invoice is paid. If no amount is set, the full amount is transferred.
578 579 580 |
# File 'lib/stripe/params/invoice_create_params.rb', line 578 def amount @amount end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
580 581 582 |
# File 'lib/stripe/params/invoice_create_params.rb', line 580 def destination @destination end |