Class: Stripe::InvoiceCreatePreviewParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::Discount
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 226 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
216 217 218 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 216 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
218 219 220 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 218 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
220 221 222 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 220 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
222 223 224 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 222 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
224 225 226 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 224 def settings @settings end |