Class: Stripe::InvoiceCreatePreviewParams::InvoiceItem::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(currency: nil, product: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 257

def initialize(
  currency: nil,
  product: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



247
248
249
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 247

def currency
  @currency
end

#productObject

The ID of the Product that this Price will belong to.



249
250
251
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 249

def product
  @product
end

#tax_behaviorObject

Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



251
252
253
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 251

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



253
254
255
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 253

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.



255
256
257
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 255

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



271
272
273
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 271

def self.field_encodings
  @field_encodings = { unit_amount_decimal: :decimal_string }
end