Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Amendment, BillingMode, BillingSchedule, Phase, Prebilling

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendments: nil, billing_behavior: nil, billing_mode: nil, end_behavior: nil, phases: nil, prebilling: nil, proration_behavior: nil, billing_schedules: nil) ⇒ ScheduleDetails

Returns a new instance of ScheduleDetails.



1517
1518
1519
1520
1521
1522
1523
1524
1525
1526
1527
1528
1529
1530
1531
1532
1533
1534
1535
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1517

def initialize(
  amendments: nil,
  billing_behavior: nil,
  billing_mode: nil,
  end_behavior: nil,
  phases: nil,
  prebilling: nil,
  proration_behavior: nil,
  billing_schedules: nil
)
  @amendments = amendments
  @billing_behavior = billing_behavior
  @billing_mode = billing_mode
  @end_behavior = end_behavior
  @phases = phases
  @prebilling = prebilling
  @proration_behavior = proration_behavior
  @billing_schedules = billing_schedules
end

Instance Attribute Details

#amendmentsObject

Changes to apply to the phases of the subscription schedule, in the order provided.



1501
1502
1503
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1501

def amendments
  @amendments
end

#billing_behaviorObject

Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.



1503
1504
1505
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1503

def billing_behavior
  @billing_behavior
end

#billing_modeObject

Controls how prorations and invoices for subscriptions are calculated and orchestrated.



1505
1506
1507
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1505

def billing_mode
  @billing_mode
end

#billing_schedulesObject

Sets the billing schedules for the subscription schedule.



1515
1516
1517
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1515

def billing_schedules
  @billing_schedules
end

#end_behaviorObject

Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.



1507
1508
1509
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1507

def end_behavior
  @end_behavior
end

#phasesObject

List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.



1509
1510
1511
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1509

def phases
  @phases
end

#prebillingObject

Provide any time periods to bill in advance.



1511
1512
1513
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1511

def prebilling
  @prebilling
end

#proration_behaviorObject

In cases where the ‘schedule_details` params update the currently active phase, specifies if and how to prorate at the time of the request.



1513
1514
1515
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1513

def proration_behavior
  @proration_behavior
end