Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, AmendmentStart, BillingSchedulesAction, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, billing_schedules_actions: nil, discount_actions: nil, effective_at: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment

Returns a new instance of Amendment.



816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 816

def initialize(
  amendment_end: nil,
  amendment_start: nil,
  billing_cycle_anchor: nil,
  billing_schedules_actions: nil,
  discount_actions: nil,
  effective_at: nil,
  item_actions: nil,
  metadata_actions: nil,
  proration_behavior: nil,
  set_pause_collection: nil,
  set_schedule_end: nil,
  trial_settings: nil
)
  @amendment_end = amendment_end
  @amendment_start = amendment_start
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_schedules_actions = billing_schedules_actions
  @discount_actions = discount_actions
  @effective_at = effective_at
  @item_actions = item_actions
  @metadata_actions = 
  @proration_behavior = proration_behavior
  @set_pause_collection = set_pause_collection
  @set_schedule_end = set_schedule_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#amendment_endObject

Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.



792
793
794
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 792

def amendment_end
  @amendment_end
end

#amendment_startObject

Details to identify the earliest timestamp where the proposed change should take effect.



794
795
796
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 794

def amendment_start
  @amendment_start
end

#billing_cycle_anchorObject

For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.



796
797
798
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 796

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_schedules_actionsObject

Actions to apply to the billing schedules.



798
799
800
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 798

def billing_schedules_actions
  @billing_schedules_actions
end

#discount_actionsObject

Changes to the coupons being redeemed or discounts being applied during the amendment time span.



800
801
802
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 800

def discount_actions
  @discount_actions
end

#effective_atObject

Configures how the subscription schedule handles billing for phase transitions.



802
803
804
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 802

def effective_at
  @effective_at
end

#item_actionsObject

Changes to the subscription items during the amendment time span.



804
805
806
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 804

def item_actions
  @item_actions
end

#metadata_actionsObject

Instructions for how to modify phase metadata



806
807
808
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 806

def 
  @metadata_actions
end

#proration_behaviorObject

Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.



808
809
810
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 808

def proration_behavior
  @proration_behavior
end

#set_pause_collectionObject

Defines how to pause collection for the underlying subscription throughout the duration of the amendment.



810
811
812
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 810

def set_pause_collection
  @set_pause_collection
end

#set_schedule_endObject

Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.



812
813
814
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 812

def set_schedule_end
  @set_schedule_end
end

#trial_settingsObject

Settings related to subscription trials.



814
815
816
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 814

def trial_settings
  @trial_settings
end