Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



437
438
439
440
441
442
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 437

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



429
430
431
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 429

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



431
432
433
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 431

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



433
434
435
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 433

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



435
436
437
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 435

def type
  @type
end