Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



385
386
387
388
389
390
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 385

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



377
378
379
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 377

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



379
380
381
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 379

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



381
382
383
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 381

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



383
384
385
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 383

def type
  @type
end