Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



436
437
438
439
440
441
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 436

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



428
429
430
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 428

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



430
431
432
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 430

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



432
433
434
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 432

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



434
435
436
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 434

def type
  @type
end