Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



472
473
474
475
476
477
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 472

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



464
465
466
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 464

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



466
467
468
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 466

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



468
469
470
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 468

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



470
471
472
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 470

def type
  @type
end