Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



420
421
422
423
424
425
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 420

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



412
413
414
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 412

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



414
415
416
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 414

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



416
417
418
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 416

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



418
419
420
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 418

def type
  @type
end