Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart::AmendmentEnd
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#index ⇒ Object
The position of the previous amendment in the ‘amendments` array after which this amendment should begin.
Instance Method Summary collapse
-
#initialize(index: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(index: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
414 415 416 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 414 def initialize(index: nil) @index = index end |
Instance Attribute Details
#index ⇒ Object
The position of the previous amendment in the ‘amendments` array after which this amendment should begin. Indexes start from 0 and must be less than the index of the current amendment in the array.
412 413 414 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 412 def index @index end |