Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
525 526 527 528 529 530 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 525 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
517 518 519 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 517 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
519 520 521 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 519 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
521 522 523 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 521 def set @set end |
#type ⇒ Object
Determines the type of discount action.
523 524 525 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 523 def type @type end |