Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
465 466 467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 465 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
455 456 457 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 455 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
457 458 459 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 457 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
459 460 461 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 459 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
461 462 463 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 461 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
463 464 465 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 463 def promotion_code @promotion_code end |