Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ Add

Returns a new instance of Add.



585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 585

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



573
574
575
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 573

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



575
576
577
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 575

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



577
578
579
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 577

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



579
580
581
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 579

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



581
582
583
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 581

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



583
584
585
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 583

def settings
  @settings
end