Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil, settings: nil) ⇒ Add

Returns a new instance of Add.



569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 569

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



557
558
559
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 557

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



559
560
561
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 559

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



561
562
563
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 561

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



563
564
565
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 563

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



565
566
567
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 565

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



567
568
569
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 567

def settings
  @settings
end