Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 472 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
462 463 464 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 462 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
464 465 466 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 464 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
466 467 468 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 466 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
468 469 470 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 468 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
470 471 472 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 470 def promotion_code @promotion_code end |