Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 449

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



439
440
441
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 439

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



441
442
443
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 441

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



443
444
445
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 443

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



445
446
447
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 445

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



447
448
449
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 447

def promotion_code
  @promotion_code
end