Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



488
489
490
491
492
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 488

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



482
483
484
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 482

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



484
485
486
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 484

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



486
487
488
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 486

def promotion_code
  @promotion_code
end