Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



594
595
596
597
598
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 594

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



588
589
590
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 588

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



590
591
592
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 590

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



592
593
594
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 592

def promotion_code
  @promotion_code
end