Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



495
496
497
498
499
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 495

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



489
490
491
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 489

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



491
492
493
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 491

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



493
494
495
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 493

def promotion_code
  @promotion_code
end