Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



472
473
474
475
476
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 472

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



466
467
468
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 466

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



468
469
470
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 468

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



470
471
472
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 470

def promotion_code
  @promotion_code
end