Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
-
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
-
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) ⇒ Set
Returns a new instance of Set.
653 654 655 656 657 658 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 653 def initialize(coupon: nil, discount: nil, promotion_code: nil, settings: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to replace the ‘discounts` array with.
645 646 647 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 645 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount to replace the ‘discounts` array with.
647 648 649 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 647 def discount @discount end |
#promotion_code ⇒ Object
An ID of an existing promotion code to replace the ‘discounts` array with.
649 650 651 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 649 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
651 652 653 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 651 def settings @settings end |