Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



510
511
512
513
514
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 510

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



504
505
506
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 504

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



506
507
508
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 506

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



508
509
510
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 508

def promotion_code
  @promotion_code
end