Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Set

Returns a new instance of Set.



487
488
489
490
491
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 487

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to replace the ‘discounts` array with.



481
482
483
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 481

def coupon
  @coupon
end

#discountObject

An ID of an existing discount to replace the ‘discounts` array with.



483
484
485
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 483

def discount
  @discount
end

#promotion_codeObject

An ID of an existing promotion code to replace the ‘discounts` array with.



485
486
487
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 485

def promotion_code
  @promotion_code
end