Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Set::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



616
617
618
619
620
621
622
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 616

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



606
607
608
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 606

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



608
609
610
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 608

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



610
611
612
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 610

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



612
613
614
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 612

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



614
615
616
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 614

def second
  @second
end