Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



722
723
724
725
726
727
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 722

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same price exists, it will be replaced by this new item. Otherwise, it adds the new item.



714
715
716
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 714

def add
  @add
end

#removeObject

Details of the subscription item to remove.



716
717
718
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 716

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the set[price] already exists, the items array is not cleared. Instead, all of the other set properties that are passed in this request will replace the existing values for the configuration item.



718
719
720
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 718

def set
  @set
end

#typeObject

Determines the type of item action.



720
721
722
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 720

def type
  @type
end