Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the subscription item to add.
-
#remove ⇒ Object
Details of the subscription item to remove.
-
#set ⇒ Object
Details of the subscription item to replace the existing items with.
-
#type ⇒ Object
Determines the type of item action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
constructor
A new instance of ItemAction.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction
Returns a new instance of ItemAction.
722 723 724 725 726 727 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 722 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the subscription item to add. If an item with the same price exists, it will be replaced by this new item. Otherwise, it adds the new item.
714 715 716 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 714 def add @add end |
#remove ⇒ Object
Details of the subscription item to remove.
716 717 718 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 716 def remove @remove end |
#set ⇒ Object
Details of the subscription item to replace the existing items with. If an item with the set[price] already exists, the items array is not cleared. Instead, all of the other set properties that are passed in this request will replace the existing values for the configuration item.
718 719 720 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 718 def set @set end |
#type ⇒ Object
Determines the type of item action.
720 721 722 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 720 def type @type end |