Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



989
990
991
992
993
994
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 989

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



981
982
983
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 981

def add
  @add
end

#removeObject

Details of the subscription item to remove.



983
984
985
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 983

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



985
986
987
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 985

def set
  @set
end

#typeObject

Determines the type of item action.



987
988
989
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 987

def type
  @type
end