Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



729
730
731
732
733
734
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 729

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



721
722
723
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 721

def add
  @add
end

#removeObject

Details of the subscription item to remove.



723
724
725
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 723

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



725
726
727
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 725

def set
  @set
end

#typeObject

Determines the type of item action.



727
728
729
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 727

def type
  @type
end