Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



721
722
723
724
725
726
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 721

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



713
714
715
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 713

def add
  @add
end

#removeObject

Details of the subscription item to remove.



715
716
717
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 715

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



717
718
719
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 717

def set
  @set
end

#typeObject

Determines the type of item action.



719
720
721
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 719

def type
  @type
end