Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



698
699
700
701
702
703
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 698

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



690
691
692
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 690

def add
  @add
end

#removeObject

Details of the subscription item to remove.



692
693
694
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 692

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



694
695
696
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 694

def set
  @set
end

#typeObject

Determines the type of item action.



696
697
698
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 696

def type
  @type
end