Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add
Returns a new instance of Add.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 597 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
583 584 585 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 583 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
585 586 587 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 585 def @metadata end |
#price ⇒ Object
The ID of the price object.
587 588 589 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 587 def price @price end |
#quantity ⇒ Object
Quantity for this item.
589 590 591 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 589 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
591 592 593 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 591 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
593 594 595 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 593 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
595 596 597 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 595 def trial_offer @trial_offer end |