Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add

Returns a new instance of Add.



822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 822

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



808
809
810
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 808

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



810
811
812
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 810

def 
  @metadata
end

#priceObject

The ID of the price object.



812
813
814
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 812

def price
  @price
end

#quantityObject

Quantity for this item.



814
815
816
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 814

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



816
817
818
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 816

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



818
819
820
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 818

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



820
821
822
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 820

def trial_offer
  @trial_offer
end