Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Add
Returns a new instance of Add.
806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 806 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
792 793 794 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 792 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
794 795 796 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 794 def @metadata end |
#price ⇒ Object
The ID of the price object.
796 797 798 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 796 def price @price end |
#quantity ⇒ Object
Quantity for this item.
798 799 800 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 798 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
800 801 802 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 800 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
802 803 804 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 802 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
804 805 806 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 804 def trial_offer @trial_offer end |