Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 602

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



590
591
592
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 590

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



592
593
594
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 592

def 
  @metadata
end

#priceObject

The ID of the price object.



594
595
596
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 594

def price
  @price
end

#quantityObject

Quantity for this item.



596
597
598
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 596

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



598
599
600
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 598

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



600
601
602
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 600

def trial
  @trial
end