Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 579 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
567 568 569 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 567 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
569 570 571 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 569 def @metadata end |
#price ⇒ Object
The ID of the price object.
571 572 573 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 571 def price @price end |
#quantity ⇒ Object
Quantity for this item.
573 574 575 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 573 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
575 576 577 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 575 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
577 578 579 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 577 def trial @trial end |