Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



563
564
565
566
567
568
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 563

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



555
556
557
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 555

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



557
558
559
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 557

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



559
560
561
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 559

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



561
562
563
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 561

def promotion_code
  @promotion_code
end