Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
765 766 767 768 769 770 771 772 773 774 775 776 777 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 765 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
755 756 757 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 755 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
757 758 759 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 757 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
759 760 761 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 759 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
761 762 763 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 761 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
763 764 765 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 763 def settings @settings end |