Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



547
548
549
550
551
552
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 547

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



539
540
541
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 539

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



541
542
543
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 541

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



543
544
545
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 543

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



545
546
547
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 545

def promotion_code
  @promotion_code
end