Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



699
700
701
702
703
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 699

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



693
694
695
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 693

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



695
696
697
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 695

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



697
698
699
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 697

def type
  @type
end