Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



532
533
534
535
536
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 532

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



526
527
528
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 526

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



528
529
530
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 528

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



530
531
532
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 530

def type
  @type
end