Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



720
721
722
723
724
725
726
727
728
729
730
731
732
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 720

def initialize(
  day_of_month: nil,
  hour: nil,
  minute: nil,
  month: nil,
  second: nil
)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



710
711
712
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 710

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



712
713
714
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 712

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



714
715
716
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 714

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



716
717
718
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 716

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



718
719
720
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 718

def second
  @second
end