Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Set

Returns a new instance of Set.



695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 695

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

If an item with the price already exists, passing this will override the discounts array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied discounts.



681
682
683
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 681

def discounts
  @discounts
end

#metadataObject

If an item with the price already exists, passing this will override the metadata on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied metadata.



683
684
685
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 683

def 
  @metadata
end

#priceObject

The ID of the price object.



685
686
687
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 685

def price
  @price
end

#quantityObject

If an item with the price already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied quantity.



687
688
689
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 687

def quantity
  @quantity
end

#tax_ratesObject

If an item with the price already exists, passing this will override the tax_rates array on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied tax_rates.



689
690
691
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 689

def tax_rates
  @tax_rates
end

#trialObject

If an item with the price already exists, passing this will override the trial configuration on the subscription item that matches that price. Otherwise, the items array is cleared and a single new item is added with the supplied trial.



691
692
693
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 691

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



693
694
695
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 693

def trial_offer
  @trial_offer
end