Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Set

Returns a new instance of Set.



962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 962

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.



948
949
950
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 948

def discounts
  @discounts
end

#metadataObject

If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.



950
951
952
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 950

def 
  @metadata
end

#priceObject

The ID of the price object.



952
953
954
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 952

def price
  @price
end

#quantityObject

If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.



954
955
956
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 954

def quantity
  @quantity
end

#tax_ratesObject

If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.



956
957
958
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 956

def tax_rates
  @tax_rates
end

#trialObject

If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.



958
959
960
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 958

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



960
961
962
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 960

def trial_offer
  @trial_offer
end