Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Set

Returns a new instance of Set.



702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 702

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#discountsObject

If an item with the ‘price` already exists, passing this will override the `discounts` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `discounts`.



688
689
690
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 688

def discounts
  @discounts
end

#metadataObject

If an item with the ‘price` already exists, passing this will override the `metadata` on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `metadata`.



690
691
692
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 690

def 
  @metadata
end

#priceObject

The ID of the price object.



692
693
694
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 692

def price
  @price
end

#quantityObject

If an item with the ‘price` already exists, passing this will override the quantity on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `quantity`.



694
695
696
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 694

def quantity
  @quantity
end

#tax_ratesObject

If an item with the ‘price` already exists, passing this will override the `tax_rates` array on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `tax_rates`.



696
697
698
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 696

def tax_rates
  @tax_rates
end

#trialObject

If an item with the ‘price` already exists, passing this will override the `trial` configuration on the subscription item that matches that price. Otherwise, the `items` array is cleared and a single new item is added with the supplied `trial`.



698
699
700
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 698

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



700
701
702
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 700

def trial_offer
  @trial_offer
end