Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
661 662 663 664 665 666 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 661 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
653 654 655 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 653 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
655 656 657 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 655 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
657 658 659 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 657 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
659 660 661 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 659 def promotion_code @promotion_code end |