Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



646
647
648
649
650
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 646

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



640
641
642
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 640

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



642
643
644
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 642

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



644
645
646
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 644

def type
  @type
end