Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



626
627
628
629
630
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 626

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



620
621
622
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 620

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



622
623
624
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 622

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



624
625
626
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 624

def type
  @type
end