Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::Settings::ServicePeriodAnchorConfig::Custom
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#day_of_month ⇒ Object
The day of the month the anchor should be.
-
#hour ⇒ Object
The hour of the day the anchor should be.
-
#minute ⇒ Object
The minute of the hour the anchor should be.
-
#month ⇒ Object
The month to start full cycle periods.
-
#second ⇒ Object
The second of the minute the anchor should be.
Instance Method Summary collapse
-
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
constructor
A new instance of Custom.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom
Returns a new instance of Custom.
892 893 894 895 896 897 898 899 900 901 902 903 904 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 892 def initialize( day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil ) @day_of_month = day_of_month @hour = hour @minute = minute @month = month @second = second end |
Instance Attribute Details
#day_of_month ⇒ Object
The day of the month the anchor should be. Ranges from 1 to 31.
882 883 884 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 882 def day_of_month @day_of_month end |
#hour ⇒ Object
The hour of the day the anchor should be. Ranges from 0 to 23.
884 885 886 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 884 def hour @hour end |
#minute ⇒ Object
The minute of the hour the anchor should be. Ranges from 0 to 59.
886 887 888 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 886 def minute @minute end |
#month ⇒ Object
The month to start full cycle periods. Ranges from 1 to 12.
888 889 890 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 888 def month @month end |
#second ⇒ Object
The second of the minute the anchor should be. Ranges from 0 to 59.
890 891 892 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 890 def second @second end |