Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



876
877
878
879
880
881
882
883
884
885
886
887
888
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 876

def initialize(
  day_of_month: nil,
  hour: nil,
  minute: nil,
  month: nil,
  second: nil
)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



866
867
868
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 866

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



868
869
870
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 868

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



870
871
872
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 870

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



872
873
874
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 872

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



874
875
876
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 874

def second
  @second
end