Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::SetPauseCollection::Set
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Amendment::SetPauseCollection::Set
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ Set
constructor
A new instance of Set.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil) ⇒ Set
Returns a new instance of Set.
752 753 754 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 752 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.
750 751 752 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 750 def behavior @behavior end |