Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::BillingMode
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::BillingMode
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Flexible
Instance Attribute Summary collapse
-
#flexible ⇒ Object
Configure behavior for flexible billing mode.
-
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
Instance Method Summary collapse
-
#initialize(flexible: nil, type: nil) ⇒ BillingMode
constructor
A new instance of BillingMode.
Methods inherited from RequestParams
Constructor Details
#initialize(flexible: nil, type: nil) ⇒ BillingMode
Returns a new instance of BillingMode.
859 860 861 862 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 859 def initialize(flexible: nil, type: nil) @flexible = flexible @type = type end |
Instance Attribute Details
#flexible ⇒ Object
Configure behavior for flexible billing mode.
855 856 857 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 855 def flexible @flexible end |
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is ‘flexible`.
857 858 859 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 857 def type @type end |