Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode

Returns a new instance of BillingMode.



847
848
849
850
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 847

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



843
844
845
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 843

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is ‘flexible`.



845
846
847
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 845

def type
  @type
end