Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::BillingMode
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::BillingMode
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Flexible
Instance Attribute Summary collapse
-
#flexible ⇒ Object
Configure behavior for flexible billing mode.
-
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions.
Instance Method Summary collapse
-
#initialize(flexible: nil, type: nil) ⇒ BillingMode
constructor
A new instance of BillingMode.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(flexible: nil, type: nil) ⇒ BillingMode
Returns a new instance of BillingMode.
328 329 330 331 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 328 def initialize(flexible: nil, type: nil) @flexible = flexible @type = type end |
Instance Attribute Details
#flexible ⇒ Object
Configure behavior for flexible billing mode.
324 325 326 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 324 def flexible @flexible end |
#type ⇒ Object
Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is flexible.
326 327 328 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 326 def type @type end |