Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, Duration, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, duration: nil, end_date: nil, invoice_settings: nil, items: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil) ⇒ Phase

Returns a new instance of Phase.



1366
1367
1368
1369
1370
1371
1372
1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
1394
1395
1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1366

def initialize(
  add_invoice_items: nil,
  application_fee_percent: nil,
  automatic_tax: nil,
  billing_cycle_anchor: nil,
  billing_thresholds: nil,
  collection_method: nil,
  currency: nil,
  default_payment_method: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  duration: nil,
  end_date: nil,
  invoice_settings: nil,
  items: nil,
  metadata: nil,
  on_behalf_of: nil,
  pause_collection: nil,
  proration_behavior: nil,
  start_date: nil,
  transfer_data: nil,
  trial: nil,
  trial_continuation: nil,
  trial_end: nil,
  trial_settings: nil
)
  @add_invoice_items = add_invoice_items
  @application_fee_percent = application_fee_percent
  @automatic_tax = automatic_tax
  @billing_cycle_anchor = billing_cycle_anchor
  @billing_thresholds = billing_thresholds
  @collection_method = collection_method
  @currency = currency
  @default_payment_method = default_payment_method
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @duration = duration
  @end_date = end_date
  @invoice_settings = invoice_settings
  @items = items
  @metadata = 
  @on_behalf_of = on_behalf_of
  @pause_collection = pause_collection
  @proration_behavior = proration_behavior
  @start_date = start_date
  @transfer_data = transfer_data
  @trial = trial
  @trial_continuation = trial_continuation
  @trial_end = trial_end
  @trial_settings = trial_settings
end

Instance Attribute Details

#add_invoice_itemsObject

A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.



1316
1317
1318
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1316

def add_invoice_items
  @add_invoice_items
end

#application_fee_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).



1318
1319
1320
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1318

def application_fee_percent
  @application_fee_percent
end

#automatic_taxObject

Automatic tax settings for this phase.



1320
1321
1322
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1320

def automatic_tax
  @automatic_tax
end

#billing_cycle_anchorObject

Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](docs.stripe.com/billing/subscriptions/billing-cycle).



1322
1323
1324
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1322

def billing_cycle_anchor
  @billing_cycle_anchor
end

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1324
1325
1326
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1324

def billing_thresholds
  @billing_thresholds
end

#collection_methodObject

Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.



1326
1327
1328
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1326

def collection_method
  @collection_method
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1328
1329
1330
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1328

def currency
  @currency
end

#default_payment_methodObject

ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.



1330
1331
1332
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1330

def default_payment_method
  @default_payment_method
end

#default_tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will set the Subscription’s [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates), which means they will be the Invoice’s [‘default_tax_rates`](docs.stripe.com/api/invoices/create#create_invoice-default_tax_rates) for any Invoices issued by the Subscription during this Phase.



1332
1333
1334
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1332

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.



1334
1335
1336
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1334

def description
  @description
end

#discountsObject

The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription’s customer. Pass an empty string to avoid inheriting any discounts.



1336
1337
1338
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1336

def discounts
  @discounts
end

#durationObject

The number of intervals the phase should last. If set, ‘end_date` must not be set.



1338
1339
1340
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1338

def duration
  @duration
end

#end_dateObject

The date at which this phase of the subscription schedule ends. If set, ‘duration` must not be set.



1340
1341
1342
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1340

def end_date
  @end_date
end

#invoice_settingsObject

All invoices will be billed using the specified settings.



1342
1343
1344
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1342

def invoice_settings
  @invoice_settings
end

#itemsObject

List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.



1344
1345
1346
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1344

def items
  @items
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys in the subscription’s ‘metadata`. Individual keys in the subscription’s ‘metadata` can be unset by posting an empty value to them in the phase’s ‘metadata`. To unset all keys in the subscription’s ‘metadata`, update the subscription directly or unset every key individually from the phase’s ‘metadata`.



1346
1347
1348
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1346

def 
  @metadata
end

#on_behalf_ofObject

The account on behalf of which to charge, for each of the associated subscription’s invoices.



1348
1349
1350
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1348

def on_behalf_of
  @on_behalf_of
end

#pause_collectionObject

If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](docs.stripe.com/billing/subscriptions/pause-payment).



1350
1351
1352
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1350

def pause_collection
  @pause_collection
end

#proration_behaviorObject

Controls whether the subscription schedule should create [prorations](docs.stripe.com/billing/subscriptions/prorations) when transitioning to this phase if there is a difference in billing configuration. It’s different from the request-level [proration_behavior](docs.stripe.com/api/subscription_schedules/update#update_subscription_schedule-proration_behavior) parameter which controls what happens if the update request affects the billing configuration (item price, quantity, etc.) of the current phase.



1352
1353
1354
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1352

def proration_behavior
  @proration_behavior
end

#start_dateObject

The date at which this phase of the subscription schedule starts or ‘now`. Must be set on the first phase.



1354
1355
1356
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1354

def start_date
  @start_date
end

#transfer_dataObject

The data with which to automatically create a Transfer for each of the associated subscription’s invoices.



1356
1357
1358
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1356

def transfer_data
  @transfer_data
end

#trialObject

If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.



1358
1359
1360
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1358

def trial
  @trial
end

#trial_continuationObject

Specify trial behavior when crossing phase boundaries



1360
1361
1362
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1360

def trial_continuation
  @trial_continuation
end

#trial_endObject

Sets the phase to trialing from the start date to this date. Must be before the phase end date, can not be combined with ‘trial`



1362
1363
1364
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1362

def trial_end
  @trial_end
end

#trial_settingsObject

Settings related to subscription trials.



1364
1365
1366
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1364

def trial_settings
  @trial_settings
end

Class Method Details

.field_encodingsObject



1420
1421
1422
1423
1424
1425
1426
1427
1428
1429
1430
1431
1432
1433
1434
1435
1436
1437
1438
1439
1440
1441
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1420

def self.field_encodings
  @field_encodings = {
    add_invoice_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: {
          price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
        },
      },
    },
    items: {
      kind: :array,
      element: {
        kind: :object,
        fields: {
          price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
        },
      },
    },
  }
end