Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
1342
1343
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1327

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



1313
1314
1315
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1313

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1315
1316
1317
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1315

def 
  @metadata
end

#periodObject

The period associated with this invoice item. If not set, ‘period.start.type` defaults to `max_item_period_start` and `period.end.type` defaults to `min_item_period_end`.



1317
1318
1319
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1317

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



1319
1320
1321
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1319

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



1321
1322
1323
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1321

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



1323
1324
1325
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1323

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



1325
1326
1327
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1325

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



1345
1346
1347
1348
1349
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1345

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end