Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1038 def initialize( discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
1024 1025 1026 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1024 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1026 1027 1028 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1026 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. If not set, ‘period.start.type` defaults to `max_item_period_start` and `period.end.type` defaults to `min_item_period_end`.
1028 1029 1030 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1028 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
1030 1031 1032 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1030 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.
1032 1033 1034 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1032 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
1034 1035 1036 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1034 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
1036 1037 1038 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1036 def tax_rates @tax_rates end |