Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1026

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



1012
1013
1014
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1012

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1014
1015
1016
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1014

def 
  @metadata
end

#periodObject

The period associated with this invoice item. If not set, ‘period.start.type` defaults to `max_item_period_start` and `period.end.type` defaults to `min_item_period_end`.



1016
1017
1018
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1016

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



1018
1019
1020
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1018

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1020
1021
1022
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1020

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



1022
1023
1024
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1022

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



1024
1025
1026
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1024

def tax_rates
  @tax_rates
end