Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



887
888
889
890
891
892
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 887

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



879
880
881
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 879

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



881
882
883
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 881

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



883
884
885
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 883

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



885
886
887
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 885

def promotion_code
  @promotion_code
end