Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



863
864
865
866
867
868
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 863

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



855
856
857
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 855

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



857
858
859
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 857

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



859
860
861
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 859

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



861
862
863
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 861

def promotion_code
  @promotion_code
end