Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1199
1200
1201
1202
1203
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1199

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1193
1194
1195
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1193

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1195
1196
1197
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1195

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1197
1198
1199
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1197

def type
  @type
end