Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



927
928
929
930
931
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 927

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



921
922
923
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 921

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



923
924
925
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 923

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



925
926
927
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 925

def type
  @type
end