Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



848
849
850
851
852
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 848

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



842
843
844
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 842

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



844
845
846
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 844

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



846
847
848
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 846

def type
  @type
end