Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::End
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::End
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period.
-
#type ⇒ Object
Select how to calculate the end of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ End
constructor
A new instance of End.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ End
Returns a new instance of End.
1229 1230 1231 1232 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1229 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.
1225 1226 1227 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1225 def @timestamp end |
#type ⇒ Object
Select how to calculate the end of the invoice item period.
1227 1228 1229 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1227 def type @type end |