Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



914
915
916
917
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 914

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



910
911
912
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 910

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



912
913
914
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 912

def type
  @type
end