Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ Start

Returns a new instance of Start.



1250
1251
1252
1253
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1250

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.



1246
1247
1248
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1246

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the start of the invoice item period.



1248
1249
1250
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1248

def type
  @type
end