Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1441 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1431 1432 1433 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1431 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1433 1434 1435 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1433 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1435 1436 1437 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1435 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1437 1438 1439 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1437 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
1439 1440 1441 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1439 def settings @settings end |