Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1115 1116 1117 1118 1119 1120 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1115 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1107 1108 1109 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1107 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1109 1110 1111 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1109 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1111 1112 1113 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1111 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1113 1114 1115 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1113 def promotion_code @promotion_code end |