Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1036
1037
1038
1039
1040
1041
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1036

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1028
1029
1030
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1028

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1030
1031
1032
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1030

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1032
1033
1034
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1032

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1034
1035
1036
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1034

def promotion_code
  @promotion_code
end