Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1372 1373 1374 1375 1376 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1372 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1366 1367 1368 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1366 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1368 1369 1370 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1368 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1370 1371 1372 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1370 def type @type end |