Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1100
1101
1102
1103
1104
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1100

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1094
1095
1096
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1094

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1096
1097
1098
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1096

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1098
1099
1100
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1098

def type
  @type
end