Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1021 1022 1023 1024 1025 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1021 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1015 1016 1017 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1015 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1017 1018 1019 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1017 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1019 1020 1021 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1019 def type @type end |