Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



1393
1394
1395
1396
1397
1398
1399
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1393

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



1383
1384
1385
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1383

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



1385
1386
1387
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1385

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



1387
1388
1389
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1387

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



1389
1390
1391
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1389

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



1391
1392
1393
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1391

def second
  @second
end