Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



1402
1403
1404
1405
1406
1407
1408
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1402

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



1392
1393
1394
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1392

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



1394
1395
1396
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1394

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



1396
1397
1398
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1396

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



1398
1399
1400
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1398

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



1400
1401
1402
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1400

def second
  @second
end