Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of Tax Rate ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
Returns a new instance of Item.
1707 1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 1720 1721 1722 1723 1724 1725 1726 1727 1728 1729 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1707 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
1687 1688 1689 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1687 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
1689 1690 1691 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1689 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item's metadata when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item's metadata can be unset by posting an empty value to them in the configuration item's metadata. To unset all keys in the subscription item's metadata, update the subscription item directly or unset every key individually from the configuration item's metadata.
1691 1692 1693 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1691 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in plan and price.
1693 1694 1695 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1693 def plan @plan end |
#price ⇒ Object
The ID of the price object.
1695 1696 1697 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1695 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
1697 1698 1699 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1697 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price's usage_type is licensed and not metered.
1699 1700 1701 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1699 def quantity @quantity end |
#tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
1701 1702 1703 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1701 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1703 1704 1705 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1703 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
1705 1706 1707 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1705 def trial_offer @trial_offer end |
Class Method Details
.field_encodings ⇒ Object
1731 1732 1733 1734 1735 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1731 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |