Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of Tax Rate ids.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 635 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
619 620 621 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 619 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
621 622 623 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 621 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item's metadata when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item's metadata can be unset by posting an empty value to them in the configuration item's metadata. To unset all keys in the subscription item's metadata, update the subscription item directly or unset every key individually from the configuration item's metadata.
623 624 625 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 623 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in plan and price.
625 626 627 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 625 def plan @plan end |
#price ⇒ Object
The ID of the price object.
627 628 629 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 627 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
629 630 631 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 629 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price's usage_type is licensed and not metered.
631 632 633 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 631 def quantity @quantity end |
#tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
633 634 635 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 633 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
655 656 657 658 659 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 655 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |