Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of Tax Rate ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item
Returns a new instance of Item.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1251 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial @trial_offer = trial_offer end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
1231 1232 1233 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1231 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
1233 1234 1235 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1233 def discounts @discounts end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item's metadata when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item's metadata can be unset by posting an empty value to them in the configuration item's metadata. To unset all keys in the subscription item's metadata, update the subscription item directly or unset every key individually from the configuration item's metadata.
1235 1236 1237 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1235 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in plan and price.
1237 1238 1239 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1237 def plan @plan end |
#price ⇒ Object
The ID of the price object.
1239 1240 1241 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1239 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
1241 1242 1243 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1241 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price's usage_type is licensed and not metered.
1243 1244 1245 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1243 def quantity @quantity end |
#tax_rates ⇒ Object
A list of Tax Rate ids. These Tax Rates will override the default_tax_rates on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
1245 1246 1247 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1245 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
1247 1248 1249 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1247 def trial @trial end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the configuration item.
1249 1250 1251 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1249 def trial_offer @trial_offer end |
Class Method Details
.field_encodings ⇒ Object
1275 1276 1277 1278 1279 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1275 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |