Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item

Returns a new instance of Item.



1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1664

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1644
1645
1646
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1644

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1646
1647
1648
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1646

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



1648
1649
1650
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1648

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



1650
1651
1652
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1650

def plan
  @plan
end

#priceObject

The ID of the price object.



1652
1653
1654
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1652

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



1654
1655
1656
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1654

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



1656
1657
1658
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1656

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1658
1659
1660
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1658

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1660
1661
1662
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1660

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



1662
1663
1664
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1662

def trial_offer
  @trial_offer
end