Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil, trial_offer: nil) ⇒ Item

Returns a new instance of Item.



1300
1301
1302
1303
1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
1316
1317
1318
1319
1320
1321
1322
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1300

def initialize(
  billing_thresholds: nil,
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil,
  trial_offer: nil
)
  @billing_thresholds = billing_thresholds
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
  @trial_offer = trial_offer
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1280
1281
1282
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1280

def billing_thresholds
  @billing_thresholds
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1282
1283
1284
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1282

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



1284
1285
1286
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1284

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



1286
1287
1288
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1286

def plan
  @plan
end

#priceObject

The ID of the price object.



1288
1289
1290
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1288

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



1290
1291
1292
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1290

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



1292
1293
1294
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1292

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1294
1295
1296
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1294

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



1296
1297
1298
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1296

def trial
  @trial
end

#trial_offerObject

The ID of the trial offer to apply to the configuration item.



1298
1299
1300
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1298

def trial_offer
  @trial_offer
end