Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1161
1162
1163
1164
1165
1166
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1161

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1153
1154
1155
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1153

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1155
1156
1157
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1155

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1157
1158
1159
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1157

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1159
1160
1161
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1159

def promotion_code
  @promotion_code
end