Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1584 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1574 1575 1576 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1574 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1576 1577 1578 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1576 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1578 1579 1580 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1578 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1580 1581 1582 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1580 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
1582 1583 1584 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1582 def settings @settings end |