Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1206
1207
1208
1209
1210
1211
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1206

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1198
1199
1200
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1198

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1200
1201
1202
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1200

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1202
1203
1204
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1202

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1204
1205
1206
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1204

def promotion_code
  @promotion_code
end