Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1550
1551
1552
1553
1554
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1550

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1544
1545
1546
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1544

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1546
1547
1548
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1546

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1548
1549
1550
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1548

def type
  @type
end