Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1146
1147
1148
1149
1150
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1146

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1140
1141
1142
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1140

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1142
1143
1144
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1142

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1144
1145
1146
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1144

def type
  @type
end