Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1524
1525
1526
1527
1528
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1524

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1518
1519
1520
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1518

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1520
1521
1522
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1520

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1522
1523
1524
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1522

def type
  @type
end