Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1515
1516
1517
1518
1519
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1515

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1509
1510
1511
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1509

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1511
1512
1513
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1511

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1513
1514
1515
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1513

def type
  @type
end