Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



1191
1192
1193
1194
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1191

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



1187
1188
1189
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1187

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



1189
1190
1191
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1189

def interval_count
  @interval_count
end