Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



1571
1572
1573
1574
1575
1576
1577
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1571

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



1561
1562
1563
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1561

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



1563
1564
1565
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1563

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



1565
1566
1567
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1565

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



1567
1568
1569
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1567

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



1569
1570
1571
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1569

def second
  @second
end