Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



1545
1546
1547
1548
1549
1550
1551
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1545

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



1535
1536
1537
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1535

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



1537
1538
1539
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1537

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



1539
1540
1541
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1539

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



1541
1542
1543
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1541

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



1543
1544
1545
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1543

def second
  @second
end