Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Recurring

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 598

def initialize(
  currency: nil,
  product: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



586
587
588
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 586

def currency
  @currency
end

#productObject

The ID of the Product that this Price will belong to.



588
589
590
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 588

def product
  @product
end

#recurringObject

The recurring components of a price such as interval and interval_count.



590
591
592
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 590

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



592
593
594
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 592

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



594
595
596
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 594

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.



596
597
598
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 596

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



614
615
616
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 614

def self.field_encodings
  @field_encodings = { unit_amount_decimal: :decimal_string }
end