Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::Item::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Recurring

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1198

def initialize(
  currency: nil,
  product: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



1186
1187
1188
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1186

def currency
  @currency
end

#productObject

The ID of the Product that this Price will belong to.



1188
1189
1190
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1188

def product
  @product
end

#recurringObject

The recurring components of a price such as interval and interval_count.



1190
1191
1192
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1190

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



1192
1193
1194
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1192

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



1194
1195
1196
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1194

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.



1196
1197
1198
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1196

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



1214
1215
1216
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1214

def self.field_encodings
  @field_encodings = { unit_amount_decimal: :decimal_string }
end