Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::PauseCollection
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::PauseCollection
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#behavior ⇒ Object
The payment collection behavior for this subscription while paused.
Instance Method Summary collapse
-
#initialize(behavior: nil) ⇒ PauseCollection
constructor
A new instance of PauseCollection.
Methods inherited from RequestParams
Constructor Details
#initialize(behavior: nil) ⇒ PauseCollection
Returns a new instance of PauseCollection.
1693 1694 1695 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1693 def initialize(behavior: nil) @behavior = behavior end |
Instance Attribute Details
#behavior ⇒ Object
The payment collection behavior for this subscription while paused. One of ‘keep_as_draft`, `mark_uncollectible`, or `void`.
1691 1692 1693 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1691 def behavior @behavior end |