Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::TransferData
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#destination ⇒ Object
ID of an existing, connected Stripe account.
Instance Method Summary collapse
-
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_percent: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1297 1298 1299 1300 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1297 def initialize(amount_percent: nil, destination: nil) @amount_percent = amount_percent @destination = destination end |
Instance Attribute Details
#amount_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.
1293 1294 1295 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1293 def amount_percent @amount_percent end |
#destination ⇒ Object
ID of an existing, connected Stripe account.
1295 1296 1297 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1295 def destination @destination end |