Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1704
1705
1706
1707
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1704

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1700
1701
1702
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1700

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1702
1703
1704
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1702

def destination
  @destination
end