Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1324
1325
1326
1327
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1324

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1320
1321
1322
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1320

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1322
1323
1324
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1322

def destination
  @destination
end