Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1245
1246
1247
1248
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1245

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1241
1242
1243
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1241

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1243
1244
1245
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1243

def destination
  @destination
end