Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1475
1476
1477
1478
1479
1480
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1475

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1467
1468
1469
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1467

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1469
1470
1471
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1469

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1471
1472
1473
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1471

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1473
1474
1475
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1473

def type
  @type
end