Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1404
1405
1406
1407
1408
1409
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1404

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1396
1397
1398
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1396

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1398
1399
1400
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1398

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1400
1401
1402
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1400

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1402
1403
1404
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1402

def type
  @type
end