Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1867
1868
1869
1870
1871
1872
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1867

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1859
1860
1861
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1859

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1861
1862
1863
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1861

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1863
1864
1865
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1863

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1865
1866
1867
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1865

def type
  @type
end