Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1483
1484
1485
1486
1487
1488
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1483

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1475
1476
1477
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1475

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1477
1478
1479
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1477

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1479
1480
1481
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1479

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1481
1482
1483
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1481

def type
  @type
end