Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



1503
1504
1505
1506
1507
1508
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1503

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



1495
1496
1497
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1495

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



1497
1498
1499
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1497

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



1499
1500
1501
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1499

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



1501
1502
1503
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1501

def type
  @type
end