Class: Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::ScheduleDetails::Prebilling::BillUntil::Duration
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
1489 1490 1491 1492 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1489 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
1485 1486 1487 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1485 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
1487 1488 1489 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1487 def interval_count @interval_count end |