Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: BillingMode, BillingSchedule, Item, Pause, Prebilling
Instance Attribute Summary collapse
-
#billing_cycle_anchor ⇒ Object
For new subscriptions, a future timestamp to anchor the subscription's billing cycle.
-
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
-
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription.
-
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel.
-
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (
current_period_end). -
#cancel_now ⇒ Object
This simulates the subscription being canceled or expired immediately.
-
#default_tax_rates ⇒ Object
If provided, the invoice returned will preview updating or creating a subscription with these default tax rates.
-
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#pause ⇒ Object
Previews the invoice that would be generated when pausing the subscription.
-
#prebilling ⇒ Object
The pre-billing to apply to the subscription as a preview.
-
#proration_behavior ⇒ Object
Determines how to handle prorations when the billing cycle changes (e.g., when switching plans, resetting
billing_cycle_anchor=now, or starting a trial), or if an item'squantitychanges. -
#proration_date ⇒ Object
If previewing an update to a subscription, and doing proration,
subscription_details.proration_dateforces the proration to be calculated as though the update was done at the specified time. -
#resume_at ⇒ Object
For paused subscriptions, setting
subscription_details.resume_attonowwill preview the invoice that will be generated if the subscription is resumed. -
#start_date ⇒ Object
Date a subscription is intended to start (can be future or past).
-
#trial_end ⇒ Object
If provided, the invoice returned will preview updating or creating a subscription with that trial end.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_cycle_anchor: nil, billing_mode: nil, billing_schedules: nil, cancel_at: nil, cancel_at_period_end: nil, cancel_now: nil, default_tax_rates: nil, items: nil, metadata: nil, pause: nil, prebilling: nil, proration_behavior: nil, proration_date: nil, resume_at: nil, start_date: nil, trial_end: nil) ⇒ SubscriptionDetails
constructor
A new instance of SubscriptionDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_cycle_anchor: nil, billing_mode: nil, billing_schedules: nil, cancel_at: nil, cancel_at_period_end: nil, cancel_now: nil, default_tax_rates: nil, items: nil, metadata: nil, pause: nil, prebilling: nil, proration_behavior: nil, proration_date: nil, resume_at: nil, start_date: nil, trial_end: nil) ⇒ SubscriptionDetails
Returns a new instance of SubscriptionDetails.
1892 1893 1894 1895 1896 1897 1898 1899 1900 1901 1902 1903 1904 1905 1906 1907 1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 1925 1926 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1892 def initialize( billing_cycle_anchor: nil, billing_mode: nil, billing_schedules: nil, cancel_at: nil, cancel_at_period_end: nil, cancel_now: nil, default_tax_rates: nil, items: nil, metadata: nil, pause: nil, prebilling: nil, proration_behavior: nil, proration_date: nil, resume_at: nil, start_date: nil, trial_end: nil ) @billing_cycle_anchor = billing_cycle_anchor @billing_mode = billing_mode @billing_schedules = billing_schedules @cancel_at = cancel_at @cancel_at_period_end = cancel_at_period_end @cancel_now = cancel_now @default_tax_rates = default_tax_rates @items = items @metadata = @pause = pause @prebilling = prebilling @proration_behavior = proration_behavior @proration_date = proration_date @resume_at = resume_at @start_date = start_date @trial_end = trial_end end |
Instance Attribute Details
#billing_cycle_anchor ⇒ Object
For new subscriptions, a future timestamp to anchor the subscription's billing cycle. This is used to determine the date of the first full invoice, and, for plans with month or year intervals, the day of the month for subsequent invoices. For existing subscriptions, the value can only be set to now or unchanged.
1856 1857 1858 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1856 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_mode ⇒ Object
Controls how prorations and invoices for subscriptions are calculated and orchestrated.
1858 1859 1860 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1858 def billing_mode @billing_mode end |
#billing_schedules ⇒ Object
Sets the billing schedules for the subscription.
1860 1861 1862 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1860 def billing_schedules @billing_schedules end |
#cancel_at ⇒ Object
A timestamp at which the subscription should cancel. If set to a date before the current period ends, this will cause a proration if prorations have been enabled using proration_behavior. If set during a future period, this will always cause a proration for that period.
1862 1863 1864 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1862 def cancel_at @cancel_at end |
#cancel_at_period_end ⇒ Object
Indicate whether this subscription should cancel at the end of the current period (current_period_end). Defaults to false.
1864 1865 1866 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1864 def cancel_at_period_end @cancel_at_period_end end |
#cancel_now ⇒ Object
This simulates the subscription being canceled or expired immediately.
1866 1867 1868 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1866 def cancel_now @cancel_now end |
#default_tax_rates ⇒ Object
If provided, the invoice returned will preview updating or creating a subscription with these default tax rates. The default tax rates will apply to any line item that does not have tax_rates set.
1868 1869 1870 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1868 def default_tax_rates @default_tax_rates end |
#items ⇒ Object
A list of up to 20 subscription items, each with an attached price.
1870 1871 1872 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1870 def items @items end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
1872 1873 1874 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1872 def @metadata end |
#pause ⇒ Object
Previews the invoice that would be generated when pausing the subscription. Passing an empty hash won't preview pausing and instead returns the next invoice.
To receive a preview invoice, set invoicing_behavior to invoice. A preview isn't available if the bill_for options produce no billable amounts.
pending_invoice_item never has a preview available because pausing wouldn't generate an invoice, and paused subscriptions don't generate invoices either.
1878 1879 1880 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1878 def pause @pause end |
#prebilling ⇒ Object
The pre-billing to apply to the subscription as a preview.
1880 1881 1882 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1880 def prebilling @prebilling end |
#proration_behavior ⇒ Object
Determines how to handle prorations when the billing cycle changes (e.g., when switching plans, resetting billing_cycle_anchor=now, or starting a trial), or if an item's quantity changes. The default value is create_prorations.
1882 1883 1884 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1882 def proration_behavior @proration_behavior end |
#proration_date ⇒ Object
If previewing an update to a subscription, and doing proration, subscription_details.proration_date forces the proration to be calculated as though the update was done at the specified time. The time given must be within the current subscription period and within the current phase of the schedule backing this subscription, if the schedule exists. If set, subscription, and one of subscription_details.items, or subscription_details.trial_end are required. Also, subscription_details.proration_behavior cannot be set to 'none'.
1884 1885 1886 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1884 def proration_date @proration_date end |
#resume_at ⇒ Object
For paused subscriptions, setting subscription_details.resume_at to now will preview the invoice that will be generated if the subscription is resumed.
1886 1887 1888 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1886 def resume_at @resume_at end |
#start_date ⇒ Object
Date a subscription is intended to start (can be future or past).
1888 1889 1890 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1888 def start_date @start_date end |
#trial_end ⇒ Object
If provided, the invoice returned will preview updating or creating a subscription with that trial end. If set, one of subscription_details.items or subscription is required.
1890 1891 1892 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1890 def trial_end @trial_end end |
Class Method Details
.field_encodings ⇒ Object
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1928 def self.field_encodings @field_encodings = { items: { kind: :array, element: { kind: :object, fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } }, }, }, } end |