Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode

Returns a new instance of BillingMode.



1572
1573
1574
1575
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1572

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



1568
1569
1570
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1568

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is ‘flexible`.



1570
1571
1572
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1570

def type
  @type
end