Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingMode

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Flexible

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(flexible: nil, type: nil) ⇒ BillingMode

Returns a new instance of BillingMode.



1937
1938
1939
1940
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1937

def initialize(flexible: nil, type: nil)
  @flexible = flexible
  @type = type
end

Instance Attribute Details

#flexibleObject

Configure behavior for flexible billing mode.



1933
1934
1935
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1933

def flexible
  @flexible
end

#typeObject

Controls the calculation and orchestration of prorations and invoices for subscriptions. If no value is passed, the default is ‘flexible`.



1935
1936
1937
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1935

def type
  @type
end