Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
-
#bill_until ⇒ Object
The end date for the billing schedule.
-
#key ⇒ Object
Specify a key for the billing schedule.
Instance Method Summary collapse
-
#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
constructor
A new instance of BillingSchedule.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
Returns a new instance of BillingSchedule.
1623 1624 1625 1626 1627 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1623 def initialize(applies_to: nil, bill_until: nil, key: nil) @applies_to = applies_to @bill_until = bill_until @key = key end |
Instance Attribute Details
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
1617 1618 1619 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1617 def applies_to @applies_to end |
#bill_until ⇒ Object
The end date for the billing schedule.
1619 1620 1621 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1619 def bill_until @bill_until end |
#key ⇒ Object
Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.
1621 1622 1623 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1621 def key @key end |