Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AppliesTo, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



2001
2002
2003
2004
2005
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2001

def initialize(applies_to: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



1995
1996
1997
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1995

def applies_to
  @applies_to
end

#bill_untilObject

The end date for the billing schedule.



1997
1998
1999
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1997

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



1999
2000
2001
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1999

def key
  @key
end