Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
-
#bill_until ⇒ Object
The end date for the billing schedule.
-
#key ⇒ Object
Specify a key for the billing schedule.
Instance Method Summary collapse
-
#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
constructor
A new instance of BillingSchedule.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
Returns a new instance of BillingSchedule.
2001 2002 2003 2004 2005 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2001 def initialize(applies_to: nil, bill_until: nil, key: nil) @applies_to = applies_to @bill_until = bill_until @key = key end |
Instance Attribute Details
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
1995 1996 1997 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1995 def applies_to @applies_to end |
#bill_until ⇒ Object
The end date for the billing schedule.
1997 1998 1999 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1997 def bill_until @bill_until end |
#key ⇒ Object
Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.
1999 2000 2001 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1999 def key @key end |