Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: AppliesTo, BillUntil

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule

Returns a new instance of BillingSchedule.



1624
1625
1626
1627
1628
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1624

def initialize(applies_to: nil, bill_until: nil, key: nil)
  @applies_to = applies_to
  @bill_until = bill_until
  @key = key
end

Instance Attribute Details

#applies_toObject

Configure billing schedule differently for individual subscription items.



1618
1619
1620
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1618

def applies_to
  @applies_to
end

#bill_untilObject

The end date for the billing schedule.



1620
1621
1622
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1620

def bill_until
  @bill_until
end

#keyObject

Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.



1622
1623
1624
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1622

def key
  @key
end