Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
-
#bill_until ⇒ Object
The end date for the billing schedule.
-
#key ⇒ Object
Specify a key for the billing schedule.
Instance Method Summary collapse
-
#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
constructor
A new instance of BillingSchedule.
Methods inherited from RequestParams
Constructor Details
#initialize(applies_to: nil, bill_until: nil, key: nil) ⇒ BillingSchedule
Returns a new instance of BillingSchedule.
1604 1605 1606 1607 1608 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1604 def initialize(applies_to: nil, bill_until: nil, key: nil) @applies_to = applies_to @bill_until = bill_until @key = key end |
Instance Attribute Details
#applies_to ⇒ Object
Configure billing schedule differently for individual subscription items.
1598 1599 1600 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1598 def applies_to @applies_to end |
#bill_until ⇒ Object
The end date for the billing schedule.
1600 1601 1602 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1600 def bill_until @bill_until end |
#key ⇒ Object
Specify a key for the billing schedule. Must be unique to this field, alphanumeric, and up to 200 characters. If not provided, a unique key will be generated.
1602 1603 1604 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1602 def key @key end |