Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::AppliesTo
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::AppliesTo
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#price ⇒ Object
The ID of the price object.
-
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
Instance Method Summary collapse
-
#initialize(price: nil, type: nil) ⇒ AppliesTo
constructor
A new instance of AppliesTo.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(price: nil, type: nil) ⇒ AppliesTo
Returns a new instance of AppliesTo.
1585 1586 1587 1588 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1585 def initialize(price: nil, type: nil) @price = price @type = type end |
Instance Attribute Details
#price ⇒ Object
The ID of the price object.
1581 1582 1583 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1581 def price @price end |
#type ⇒ Object
Controls which subscription items the billing schedule applies to.
1583 1584 1585 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1583 def type @type end |