Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1988 1989 1990 1991 1992 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1988 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
1982 1983 1984 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1982 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
1984 1985 1986 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1984 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
1986 1987 1988 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1986 def type @type end |