Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1975 1976 1977 1978 1979 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1975 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
1969 1970 1971 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1969 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
1971 1972 1973 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1971 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
1973 1974 1975 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1973 def type @type end |