Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1611 1612 1613 1614 1615 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1611 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
1605 1606 1607 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1605 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
1607 1608 1609 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1607 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
1609 1610 1611 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1609 def type @type end |