Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::BillingSchedule::BillUntil
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Specifies the billing period.
-
#timestamp ⇒ Object
The end date of the billing schedule.
-
#type ⇒ Object
Describes how the billing schedule will determine the end date.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
constructor
A new instance of BillUntil.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ BillUntil
Returns a new instance of BillUntil.
1508 1509 1510 1511 1512 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1508 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Specifies the billing period.
1502 1503 1504 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1502 def duration @duration end |
#timestamp ⇒ Object
The end date of the billing schedule.
1504 1505 1506 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1504 def @timestamp end |
#type ⇒ Object
Describes how the billing schedule will determine the end date. Either ‘duration` or `timestamp`.
1506 1507 1508 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1506 def type @type end |