Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
2305
2306
2307
2308
2309
2310
2311
2312
2313
2314
2315
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2289

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  current_trial: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @current_trial = current_trial
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



2265
2266
2267
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2265

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



2267
2268
2269
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2267

def clear_usage
  @clear_usage
end

#current_trialObject

The trial offer to apply to this subscription item.



2269
2270
2271
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2269

def current_trial
  @current_trial
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



2271
2272
2273
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2271

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



2273
2274
2275
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2273

def discounts
  @discounts
end

#idObject

Subscription item to update.



2275
2276
2277
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2275

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2277
2278
2279
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2277

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



2279
2280
2281
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2279

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



2281
2282
2283
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2281

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



2283
2284
2285
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2283

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



2285
2286
2287
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2285

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



2287
2288
2289
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2287

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



2317
2318
2319
2320
2321
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2317

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end