Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1003

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



981
982
983
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 981

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



983
984
985
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 983

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



985
986
987
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 985

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



987
988
989
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 987

def discounts
  @discounts
end

#idObject

Subscription item to update.



989
990
991
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 989

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



991
992
993
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 991

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



993
994
995
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 993

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



995
996
997
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 995

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



997
998
999
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 997

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



999
1000
1001
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 999

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1001
1002
1003
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1001

def tax_rates
  @tax_rates
end

Class Method Details

.field_encodingsObject



1029
1030
1031
1032
1033
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1029

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
  }
end