Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: BillingThresholds, CurrentTrial, Discount, PriceData
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#clear_usage ⇒ Object
Delete all usage for a given subscription item.
-
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
-
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#id ⇒ Object
Subscription item to update.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1765 def initialize( billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @billing_thresholds = billing_thresholds @clear_usage = clear_usage @current_trial = current_trial @deleted = deleted @discounts = discounts @id = id @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
1741 1742 1743 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1741 def billing_thresholds @billing_thresholds end |
#clear_usage ⇒ Object
Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.
1743 1744 1745 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1743 def clear_usage @clear_usage end |
#current_trial ⇒ Object
The trial offer to apply to this subscription item.
1745 1746 1747 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1745 def current_trial @current_trial end |
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
1747 1748 1749 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1747 def deleted @deleted end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
1749 1750 1751 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1749 def discounts @discounts end |
#id ⇒ Object
Subscription item to update.
1751 1752 1753 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1751 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1753 1754 1755 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1753 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
1755 1756 1757 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1755 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.
1757 1758 1759 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1757 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.
1759 1760 1761 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1759 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
1761 1762 1763 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1761 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
1763 1764 1765 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1763 def tax_rates @tax_rates end |
Class Method Details
.field_encodings ⇒ Object
1793 1794 1795 1796 1797 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1793 def self.field_encodings @field_encodings = { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, } end |