Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1645

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1623
1624
1625
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1623

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



1625
1626
1627
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1625

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



1627
1628
1629
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1627

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1629
1630
1631
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1629

def discounts
  @discounts
end

#idObject

Subscription item to update.



1631
1632
1633
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1631

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1633
1634
1635
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1633

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1635
1636
1637
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1635

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



1637
1638
1639
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1637

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



1639
1640
1641
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1639

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1641
1642
1643
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1641

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1643
1644
1645
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1643

def tax_rates
  @tax_rates
end