Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, current_trial: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
2201
2202
2203
2204
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2178

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  current_trial: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @current_trial = current_trial
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



2154
2155
2156
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2154

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



2156
2157
2158
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2156

def clear_usage
  @clear_usage
end

#current_trialObject

The trial offer to apply to this subscription item.



2158
2159
2160
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2158

def current_trial
  @current_trial
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



2160
2161
2162
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2160

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



2162
2163
2164
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2162

def discounts
  @discounts
end

#idObject

Subscription item to update.



2164
2165
2166
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2164

def id
  @id
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2166
2167
2168
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2166

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



2168
2169
2170
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2168

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



2170
2171
2172
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2170

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline. One of ‘price` or `price_data` is required.



2172
2173
2174
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2172

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



2174
2175
2176
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2174

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](docs.stripe.com/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](docs.stripe.com/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



2176
2177
2178
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2176

def tax_rates
  @tax_rates
end