Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1728

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1706
1707
1708
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1706

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



1708
1709
1710
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1708

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



1710
1711
1712
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1710

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1712
1713
1714
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1712

def discounts
  @discounts
end

#idObject

Subscription item to update.



1714
1715
1716
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1714

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1716
1717
1718
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1716

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1718
1719
1720
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1718

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



1720
1721
1722
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1720

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1722
1723
1724
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1722

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1724
1725
1726
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1724

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1726
1727
1728
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1726

def tax_rates
  @tax_rates
end