Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillingThresholds, CurrentTrial, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, current_trial: nil) ⇒ Item

Returns a new instance of Item.



1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
1780
1781
1782
1783
1784
1785
1786
1787
1788
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1762

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  current_trial: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @current_trial = current_trial
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



1738
1739
1740
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1738

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



1740
1741
1742
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1740

def clear_usage
  @clear_usage
end

#current_trialObject

The trial offer to apply to this subscription item.



1760
1761
1762
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1760

def current_trial
  @current_trial
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



1742
1743
1744
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1742

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



1744
1745
1746
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1744

def discounts
  @discounts
end

#idObject

Subscription item to update.



1746
1747
1748
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1746

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1748
1749
1750
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1748

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



1750
1751
1752
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1750

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



1752
1753
1754
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1752

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



1754
1755
1756
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1754

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



1756
1757
1758
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1756

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



1758
1759
1760
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1758

def tax_rates
  @tax_rates
end