Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::CurrentTrial

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial

Returns a new instance of CurrentTrial.



1646
1647
1648
1649
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1646

def initialize(trial_end: nil, trial_offer: nil)
  @trial_end = trial_end
  @trial_offer = trial_offer
end

Instance Attribute Details

#trial_endObject

Unix timestamp representing the end of the trial offer period. Required when the trial offer has ‘duration.type=timestamp`. Cannot be specified when `duration.type=relative`.



1642
1643
1644
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1642

def trial_end
  @trial_end
end

#trial_offerObject

The ID of the trial offer to apply to the subscription item.



1644
1645
1646
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1644

def trial_offer
  @trial_offer
end