Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::CurrentTrial
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::CurrentTrial
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Instance Attribute Summary collapse
-
#trial_end ⇒ Object
Unix timestamp representing the end of the trial offer period.
-
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
Instance Method Summary collapse
-
#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial
constructor
A new instance of CurrentTrial.
Methods inherited from RequestParams
Constructor Details
#initialize(trial_end: nil, trial_offer: nil) ⇒ CurrentTrial
Returns a new instance of CurrentTrial.
2011 2012 2013 2014 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2011 def initialize(trial_end: nil, trial_offer: nil) @trial_end = trial_end @trial_offer = trial_offer end |
Instance Attribute Details
#trial_end ⇒ Object
Unix timestamp representing the end of the trial offer period. Required when the trial offer has ‘duration.type=timestamp`. Cannot be specified when `duration.type=relative`.
2007 2008 2009 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2007 def trial_end @trial_end end |
#trial_offer ⇒ Object
The ID of the trial offer to apply to the subscription item.
2009 2010 2011 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2009 def trial_offer @trial_offer end |