Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: DiscountEnd, Settings
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
-
#settings ⇒ Object
Settings for discount application including service period anchoring.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount
Returns a new instance of Discount.
2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2200 def initialize( coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code @settings = settings end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2190 2191 2192 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2190 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2192 2193 2194 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2192 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
2194 2195 2196 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2194 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2196 2197 2198 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2196 def promotion_code @promotion_code end |
#settings ⇒ Object
Settings for discount application including service period anchoring.
2198 2199 2200 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2198 def settings @settings end |