Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1687
1688
1689
1690
1691
1692
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1687

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1679
1680
1681
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1679

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1681
1682
1683
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1681

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1683
1684
1685
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1683

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1685
1686
1687
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1685

def promotion_code
  @promotion_code
end