Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2110

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2100
2101
2102
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2100

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2102
2103
2104
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2102

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2104
2105
2106
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2104

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2106
2107
2108
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2106

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



2108
2109
2110
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2108

def settings
  @settings
end