Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd, Settings

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil, settings: nil) ⇒ Discount

Returns a new instance of Discount.



2097
2098
2099
2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2097

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  promotion_code: nil,
  settings: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
  @settings = settings
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2087
2088
2089
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2087

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2089
2090
2091
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2089

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2091
2092
2093
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2091

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2093
2094
2095
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2093

def promotion_code
  @promotion_code
end

#settingsObject

Settings for discount application including service period anchoring.



2095
2096
2097
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2095

def settings
  @settings
end