Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1573
1574
1575
1576
1577
1578
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1573

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1565
1566
1567
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1565

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1567
1568
1569
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1567

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1569
1570
1571
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1569

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1571
1572
1573
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1571

def promotion_code
  @promotion_code
end