Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1672
1673
1674
1675
1676
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1672

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1666
1667
1668
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1666

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1668
1669
1670
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1668

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1670
1671
1672
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1670

def type
  @type
end