Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2050
2051
2052
2053
2054
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2050

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2044
2045
2046
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2044

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2046
2047
2048
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2046

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2048
2049
2050
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2048

def type
  @type
end