Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1558 1559 1560 1561 1562 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1558 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1552 1553 1554 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1552 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1554 1555 1556 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1554 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1556 1557 1558 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1556 def type @type end |