Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



2038
2039
2040
2041
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2038

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



2034
2035
2036
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2034

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



2036
2037
2038
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2036

def interval_count
  @interval_count
end