Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



2058
2059
2060
2061
2062
2063
2064
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2058

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



2048
2049
2050
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2048

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



2050
2051
2052
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2050

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



2052
2053
2054
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2052

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



2054
2055
2056
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2054

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



2056
2057
2058
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2056

def second
  @second
end