Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::Discount::Settings::ServicePeriodAnchorConfig::Custom

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil) ⇒ Custom

Returns a new instance of Custom.



2071
2072
2073
2074
2075
2076
2077
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2071

def initialize(day_of_month: nil, hour: nil, minute: nil, month: nil, second: nil)
  @day_of_month = day_of_month
  @hour = hour
  @minute = minute
  @month = month
  @second = second
end

Instance Attribute Details

#day_of_monthObject

The day of the month the anchor should be. Ranges from 1 to 31.



2061
2062
2063
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2061

def day_of_month
  @day_of_month
end

#hourObject

The hour of the day the anchor should be. Ranges from 0 to 23.



2063
2064
2065
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2063

def hour
  @hour
end

#minuteObject

The minute of the hour the anchor should be. Ranges from 0 to 59.



2065
2066
2067
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2065

def minute
  @minute
end

#monthObject

The month to start full cycle periods. Ranges from 1 to 12.



2067
2068
2069
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2067

def month
  @month
end

#secondObject

The second of the minute the anchor should be. Ranges from 0 to 59.



2069
2070
2071
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2069

def second
  @second
end