Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Item::PriceData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: Recurring

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(currency: nil, product: nil, recurring: nil, tax_behavior: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ PriceData

Returns a new instance of PriceData.



1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1724

def initialize(
  currency: nil,
  product: nil,
  recurring: nil,
  tax_behavior: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @currency = currency
  @product = product
  @recurring = recurring
  @tax_behavior = tax_behavior
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#currencyObject

Three-letter ISO currency code, in lowercase. Must be a supported currency.



1712
1713
1714
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1712

def currency
  @currency
end

#productObject

The ID of the Product that this Price will belong to.



1714
1715
1716
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1714

def product
  @product
end

#recurringObject

The recurring components of a price such as interval and interval_count.



1716
1717
1718
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1716

def recurring
  @recurring
end

#tax_behaviorObject

Only required if a default tax behavior was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of inclusive, exclusive, or unspecified. Once specified as either inclusive or exclusive, it cannot be changed.



1718
1719
1720
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1718

def tax_behavior
  @tax_behavior
end

#unit_amountObject

A positive integer in cents (or local equivalent) (or 0 for a free price) representing how much to charge.



1720
1721
1722
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1720

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as unit_amount, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of unit_amount and unit_amount_decimal can be set.



1722
1723
1724
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1722

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



1740
1741
1742
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1740

def self.field_encodings
  @field_encodings = { unit_amount_decimal: :decimal_string }
end