Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: BillFor

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(bill_for: nil, invoicing_behavior: nil, type: nil) ⇒ Pause

Returns a new instance of Pause.



2360
2361
2362
2363
2364
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2360

def initialize(bill_for: nil, invoicing_behavior: nil, type: nil)
  @bill_for = bill_for
  @invoicing_behavior = invoicing_behavior
  @type = type
end

Instance Attribute Details

#bill_forObject

Controls what to bill for when pausing the subscription.



2354
2355
2356
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2354

def bill_for
  @bill_for
end

#invoicing_behaviorObject

Determines how to handle debits and credits when pausing. Defaults to pending_invoice_item.



2356
2357
2358
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2356

def invoicing_behavior
  @invoicing_behavior
end

#typeObject

The type of pause to apply. Defaults to subscription.



2358
2359
2360
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2358

def type
  @type
end