Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: BillFor
Instance Attribute Summary collapse
-
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
-
#invoicing_behavior ⇒ Object
Determines how to handle debits and credits when pausing.
-
#type ⇒ Object
The type of pause to apply.
Instance Method Summary collapse
-
#initialize(bill_for: nil, invoicing_behavior: nil, type: nil) ⇒ Pause
constructor
A new instance of Pause.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(bill_for: nil, invoicing_behavior: nil, type: nil) ⇒ Pause
Returns a new instance of Pause.
1840 1841 1842 1843 1844 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1840 def initialize(bill_for: nil, invoicing_behavior: nil, type: nil) @bill_for = bill_for @invoicing_behavior = invoicing_behavior @type = type end |
Instance Attribute Details
#bill_for ⇒ Object
Controls what to bill for when pausing the subscription.
1834 1835 1836 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1834 def bill_for @bill_for end |
#invoicing_behavior ⇒ Object
Determines how to handle debits and credits when pausing. Defaults to ‘pending_invoice_item`.
1836 1837 1838 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1836 def invoicing_behavior @invoicing_behavior end |
#type ⇒ Object
The type of pause to apply. Defaults to ‘subscription`.
1838 1839 1840 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1838 def type @type end |