Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause::BillFor

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_create_preview_params.rb

Defined Under Namespace

Classes: OutstandingUsageThrough, UnusedTimeFrom

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(outstanding_usage_through: nil, unused_time_from: nil) ⇒ BillFor

Returns a new instance of BillFor.



2348
2349
2350
2351
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2348

def initialize(outstanding_usage_through: nil, unused_time_from: nil)
  @outstanding_usage_through = outstanding_usage_through
  @unused_time_from = unused_time_from
end

Instance Attribute Details

#outstanding_usage_throughObject

Controls when to bill for metered usage in the current period. Defaults to { type: "now" }.



2344
2345
2346
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2344

def outstanding_usage_through
  @outstanding_usage_through
end

#unused_time_fromObject

Controls when to credit for unused time on licensed items. Defaults to { type: "now" }.



2346
2347
2348
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 2346

def unused_time_from
  @unused_time_from
end