Class: Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause::BillFor
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceCreatePreviewParams::SubscriptionDetails::Pause::BillFor
- Defined in:
- lib/stripe/params/invoice_create_preview_params.rb
Defined Under Namespace
Classes: OutstandingUsageThrough, UnusedTimeFrom
Instance Attribute Summary collapse
-
#outstanding_usage_through ⇒ Object
Controls when to bill for metered usage in the current period.
-
#unused_time_from ⇒ Object
Controls when to credit for unused time on licensed items.
Instance Method Summary collapse
-
#initialize(outstanding_usage_through: nil, unused_time_from: nil) ⇒ BillFor
constructor
A new instance of BillFor.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(outstanding_usage_through: nil, unused_time_from: nil) ⇒ BillFor
Returns a new instance of BillFor.
1828 1829 1830 1831 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1828 def initialize(outstanding_usage_through: nil, unused_time_from: nil) @outstanding_usage_through = outstanding_usage_through @unused_time_from = unused_time_from end |
Instance Attribute Details
#outstanding_usage_through ⇒ Object
Controls when to bill for metered usage in the current period. Defaults to ‘{ type: “now” }`.
1824 1825 1826 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1824 def outstanding_usage_through @outstanding_usage_through end |
#unused_time_from ⇒ Object
Controls when to credit for unused time on licensed items. Defaults to ‘{ type: “now” }`.
1826 1827 1828 |
# File 'lib/stripe/params/invoice_create_preview_params.rb', line 1826 def unused_time_from @unused_time_from end |