Class: Stripe::InvoiceItem
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::InvoiceItem
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/invoice_item.rb
Overview
Invoice Items represent the component lines of an [invoice](docs.stripe.com/api/invoices). When you create an invoice item with an ‘invoice` field, it is attached to the specified invoice and included as [an invoice line item](docs.stripe.com/api/invoices/line_item) within [invoice.lines](docs.stripe.com/api/invoices/object#invoice_object-lines).
Invoice Items can be created before you are ready to actually send the invoice. This can be particularly useful when combined with a [subscription](docs.stripe.com/api/subscriptions). Sometimes you want to add a charge or credit to a customer, but actually charge or credit the customer’s card only at the end of a regular billing cycle. This is useful for combining several charges (to minimize per-transaction fees), or for having Stripe tabulate your usage-based billing totals.
Related guides: [Integrate with the Invoicing API](docs.stripe.com/invoicing/integration), [Subscription Invoices](docs.stripe.com/billing/invoices/subscription#adding-upcoming-invoice-items).
Defined Under Namespace
Classes: Parent, Period, Pricing, ProrationDetails
Constant Summary collapse
- OBJECT_NAME =
"invoiceitem"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount (in the ‘currency` specified) of the invoice item.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
The ID of the customer to bill for this invoice item.
-
#customer_account ⇒ Object
readonly
The ID of the account to bill for this invoice item.
-
#date ⇒ Object
readonly
Time at which the object was created.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#discountable ⇒ Object
readonly
If true, discounts will apply to this invoice item.
-
#discounts ⇒ Object
readonly
The discounts which apply to the invoice item.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice ⇒ Object
readonly
The ID of the invoice this invoice item belongs to.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#margins ⇒ Object
readonly
The margins which apply to the invoice item.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#net_amount ⇒ Object
readonly
The amount after discounts, but before credits and taxes.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#parent ⇒ Object
readonly
The parent that generated this invoice item.
-
#period ⇒ Object
readonly
Attribute for field period.
-
#pricing ⇒ Object
readonly
The pricing information of the invoice item.
-
#proration ⇒ Object
readonly
Whether the invoice item was created automatically as a proration adjustment when the customer switched plans.
-
#proration_details ⇒ Object
readonly
Attribute for field proration_details.
-
#quantity ⇒ Object
readonly
Quantity of units for the invoice item in integer format, with any decimal precision truncated.
-
#quantity_decimal ⇒ Object
readonly
Non-negative decimal with at most 12 decimal places.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to the invoice item.
-
#test_clock ⇒ Object
readonly
ID of the test clock this invoice item belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates an item to be added to a draft invoice (up to 250 items per invoice).
-
.delete(invoiceitem, params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice.
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your invoice items.
- .object_name ⇒ Object
-
.update(invoiceitem, params = {}, opts = {}) ⇒ Object
Updates the amount or description of an invoice item on an upcoming invoice.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount (in the ‘currency` specified) of the invoice item. This should always be equal to `unit_amount * quantity`.
163 164 165 |
# File 'lib/stripe/resources/invoice_item.rb', line 163 def amount @amount end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
165 166 167 |
# File 'lib/stripe/resources/invoice_item.rb', line 165 def currency @currency end |
#customer ⇒ Object (readonly)
The ID of the customer to bill for this invoice item.
167 168 169 |
# File 'lib/stripe/resources/invoice_item.rb', line 167 def customer @customer end |
#customer_account ⇒ Object (readonly)
The ID of the account to bill for this invoice item.
169 170 171 |
# File 'lib/stripe/resources/invoice_item.rb', line 169 def customer_account @customer_account end |
#date ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
171 172 173 |
# File 'lib/stripe/resources/invoice_item.rb', line 171 def date @date end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
173 174 175 |
# File 'lib/stripe/resources/invoice_item.rb', line 173 def deleted @deleted end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
175 176 177 |
# File 'lib/stripe/resources/invoice_item.rb', line 175 def description @description end |
#discountable ⇒ Object (readonly)
If true, discounts will apply to this invoice item. Always false for prorations.
177 178 179 |
# File 'lib/stripe/resources/invoice_item.rb', line 177 def discountable @discountable end |
#discounts ⇒ Object (readonly)
The discounts which apply to the invoice item. Item discounts are applied before invoice discounts. Use ‘expand[]=discounts` to expand each discount.
179 180 181 |
# File 'lib/stripe/resources/invoice_item.rb', line 179 def discounts @discounts end |
#id ⇒ Object (readonly)
Unique identifier for the object.
181 182 183 |
# File 'lib/stripe/resources/invoice_item.rb', line 181 def id @id end |
#invoice ⇒ Object (readonly)
The ID of the invoice this invoice item belongs to.
183 184 185 |
# File 'lib/stripe/resources/invoice_item.rb', line 183 def invoice @invoice end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
185 186 187 |
# File 'lib/stripe/resources/invoice_item.rb', line 185 def livemode @livemode end |
#margins ⇒ Object (readonly)
The margins which apply to the invoice item. When set, the ‘default_margins` on the invoice do not apply to this invoice item.
187 188 189 |
# File 'lib/stripe/resources/invoice_item.rb', line 187 def margins @margins end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
189 190 191 |
# File 'lib/stripe/resources/invoice_item.rb', line 189 def @metadata end |
#net_amount ⇒ Object (readonly)
The amount after discounts, but before credits and taxes. This field is ‘null` for `discountable=true` items.
191 192 193 |
# File 'lib/stripe/resources/invoice_item.rb', line 191 def net_amount @net_amount end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
193 194 195 |
# File 'lib/stripe/resources/invoice_item.rb', line 193 def object @object end |
#parent ⇒ Object (readonly)
The parent that generated this invoice item.
195 196 197 |
# File 'lib/stripe/resources/invoice_item.rb', line 195 def parent @parent end |
#period ⇒ Object (readonly)
Attribute for field period
197 198 199 |
# File 'lib/stripe/resources/invoice_item.rb', line 197 def period @period end |
#pricing ⇒ Object (readonly)
The pricing information of the invoice item.
199 200 201 |
# File 'lib/stripe/resources/invoice_item.rb', line 199 def pricing @pricing end |
#proration ⇒ Object (readonly)
Whether the invoice item was created automatically as a proration adjustment when the customer switched plans.
201 202 203 |
# File 'lib/stripe/resources/invoice_item.rb', line 201 def proration @proration end |
#proration_details ⇒ Object (readonly)
Attribute for field proration_details
203 204 205 |
# File 'lib/stripe/resources/invoice_item.rb', line 203 def proration_details @proration_details end |
#quantity ⇒ Object (readonly)
Quantity of units for the invoice item in integer format, with any decimal precision truncated. For the item’s full-precision decimal quantity, use ‘quantity_decimal`. This field will be deprecated in favor of `quantity_decimal` in a future version. If the invoice item is a proration, the quantity of the subscription that the proration was computed for.
205 206 207 |
# File 'lib/stripe/resources/invoice_item.rb', line 205 def quantity @quantity end |
#quantity_decimal ⇒ Object (readonly)
Non-negative decimal with at most 12 decimal places. The quantity of units for the invoice item.
207 208 209 |
# File 'lib/stripe/resources/invoice_item.rb', line 207 def quantity_decimal @quantity_decimal end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item.
209 210 211 |
# File 'lib/stripe/resources/invoice_item.rb', line 209 def tax_rates @tax_rates end |
#test_clock ⇒ Object (readonly)
ID of the test clock this invoice item belongs to.
211 212 213 |
# File 'lib/stripe/resources/invoice_item.rb', line 211 def test_clock @test_clock end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates an item to be added to a draft invoice (up to 250 items per invoice). If no invoice is specified, the item will be on the next invoice created for the customer specified.
214 215 216 |
# File 'lib/stripe/resources/invoice_item.rb', line 214 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/invoiceitems", params: params, opts: opts) end |
.delete(invoiceitem, params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.
219 220 221 222 223 224 225 226 |
# File 'lib/stripe/resources/invoice_item.rb', line 219 def self.delete(invoiceitem, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts ) end |
.field_encodings ⇒ Object
266 267 268 269 270 271 |
# File 'lib/stripe/resources/invoice_item.rb', line 266 def self.field_encodings @field_encodings = { pricing: { kind: :object, fields: { unit_amount_decimal: :decimal_string } }, quantity_decimal: :decimal_string, } end |
.field_remappings ⇒ Object
262 263 264 |
# File 'lib/stripe/resources/invoice_item.rb', line 262 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
253 254 255 256 257 258 259 260 |
# File 'lib/stripe/resources/invoice_item.rb', line 253 def self.inner_class_types @inner_class_types = { parent: Parent, period: Period, pricing: Pricing, proration_details: ProrationDetails, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your invoice items. Invoice items are returned sorted by creation date, with the most recently created invoice items appearing first.
239 240 241 |
# File 'lib/stripe/resources/invoice_item.rb', line 239 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/invoiceitems", params: params, opts: opts) end |
.object_name ⇒ Object
20 21 22 |
# File 'lib/stripe/resources/invoice_item.rb', line 20 def self.object_name "invoiceitem" end |
.update(invoiceitem, params = {}, opts = {}) ⇒ Object
Updates the amount or description of an invoice item on an upcoming invoice. Updating an invoice item is only possible before the invoice it’s attached to is closed.
244 245 246 247 248 249 250 251 |
# File 'lib/stripe/resources/invoice_item.rb', line 244 def self.update(invoiceitem, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.
229 230 231 232 233 234 235 236 |
# File 'lib/stripe/resources/invoice_item.rb', line 229 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(self["id"]) }), params: params, opts: opts ) end |