Class: Stripe::InvoiceItem

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/invoice_item.rb

Overview

Invoice Items represent the component lines of an [invoice](docs.stripe.com/api/invoices). When you create an invoice item with an ‘invoice` field, it is attached to the specified invoice and included as [an invoice line item](docs.stripe.com/api/invoices/line_item) within [invoice.lines](docs.stripe.com/api/invoices/object#invoice_object-lines).

Invoice Items can be created before you are ready to actually send the invoice. This can be particularly useful when combined with a [subscription](docs.stripe.com/api/subscriptions). Sometimes you want to add a charge or credit to a customer, but actually charge or credit the customer’s card only at the end of a regular billing cycle. This is useful for combining several charges (to minimize per-transaction fees), or for having Stripe tabulate your usage-based billing totals.

Related guides: [Integrate with the Invoicing API](docs.stripe.com/invoicing/integration), [Subscription Invoices](docs.stripe.com/billing/invoices/subscription#adding-upcoming-invoice-items).

Defined Under Namespace

Classes: Parent, Period, Pricing, ProrationDetails

Constant Summary collapse

OBJECT_NAME =
"invoiceitem"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount (in the ‘currency` specified) of the invoice item. This should always be equal to `unit_amount * quantity`.



130
131
132
# File 'lib/stripe/resources/invoice_item.rb', line 130

def amount
  @amount
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



132
133
134
# File 'lib/stripe/resources/invoice_item.rb', line 132

def currency
  @currency
end

#customerObject (readonly)

The ID of the customer to bill for this invoice item.



134
135
136
# File 'lib/stripe/resources/invoice_item.rb', line 134

def customer
  @customer
end

#customer_accountObject (readonly)

The ID of the account to bill for this invoice item.



136
137
138
# File 'lib/stripe/resources/invoice_item.rb', line 136

def 
  @customer_account
end

#dateObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



138
139
140
# File 'lib/stripe/resources/invoice_item.rb', line 138

def date
  @date
end

#deletedObject (readonly)

Always true for a deleted object



140
141
142
# File 'lib/stripe/resources/invoice_item.rb', line 140

def deleted
  @deleted
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



142
143
144
# File 'lib/stripe/resources/invoice_item.rb', line 142

def description
  @description
end

#discountableObject (readonly)

If true, discounts will apply to this invoice item. Always false for prorations.



144
145
146
# File 'lib/stripe/resources/invoice_item.rb', line 144

def discountable
  @discountable
end

#discountsObject (readonly)

The discounts which apply to the invoice item. Item discounts are applied before invoice discounts. Use ‘expand[]=discounts` to expand each discount.



146
147
148
# File 'lib/stripe/resources/invoice_item.rb', line 146

def discounts
  @discounts
end

#idObject (readonly)

Unique identifier for the object.



148
149
150
# File 'lib/stripe/resources/invoice_item.rb', line 148

def id
  @id
end

#invoiceObject (readonly)

The ID of the invoice this invoice item belongs to.



150
151
152
# File 'lib/stripe/resources/invoice_item.rb', line 150

def invoice
  @invoice
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



152
153
154
# File 'lib/stripe/resources/invoice_item.rb', line 152

def livemode
  @livemode
end

#marginsObject (readonly)

The margins which apply to the invoice item. When set, the ‘default_margins` on the invoice do not apply to this invoice item.



154
155
156
# File 'lib/stripe/resources/invoice_item.rb', line 154

def margins
  @margins
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



156
157
158
# File 'lib/stripe/resources/invoice_item.rb', line 156

def 
  @metadata
end

#net_amountObject (readonly)

The amount after discounts, but before credits and taxes. This field is ‘null` for `discountable=true` items.



158
159
160
# File 'lib/stripe/resources/invoice_item.rb', line 158

def net_amount
  @net_amount
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



160
161
162
# File 'lib/stripe/resources/invoice_item.rb', line 160

def object
  @object
end

#parentObject (readonly)

The parent that generated this invoice item.



162
163
164
# File 'lib/stripe/resources/invoice_item.rb', line 162

def parent
  @parent
end

#periodObject (readonly)

Attribute for field period



164
165
166
# File 'lib/stripe/resources/invoice_item.rb', line 164

def period
  @period
end

#pricingObject (readonly)

The pricing information of the invoice item.



166
167
168
# File 'lib/stripe/resources/invoice_item.rb', line 166

def pricing
  @pricing
end

#prorationObject (readonly)

Whether the invoice item was created automatically as a proration adjustment when the customer switched plans.



168
169
170
# File 'lib/stripe/resources/invoice_item.rb', line 168

def proration
  @proration
end

#proration_detailsObject (readonly)

Attribute for field proration_details



170
171
172
# File 'lib/stripe/resources/invoice_item.rb', line 170

def proration_details
  @proration_details
end

#quantityObject (readonly)

Quantity of units for the invoice item in integer format, with any decimal precision truncated. For the item’s full-precision decimal quantity, use ‘quantity_decimal`. This field will be deprecated in favor of `quantity_decimal` in a future version. If the invoice item is a proration, the quantity of the subscription that the proration was computed for.



172
173
174
# File 'lib/stripe/resources/invoice_item.rb', line 172

def quantity
  @quantity
end

#quantity_decimalObject (readonly)

Non-negative decimal with at most 12 decimal places. The quantity of units for the invoice item.



174
175
176
# File 'lib/stripe/resources/invoice_item.rb', line 174

def quantity_decimal
  @quantity_decimal
end

#tax_ratesObject (readonly)

The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item.



176
177
178
# File 'lib/stripe/resources/invoice_item.rb', line 176

def tax_rates
  @tax_rates
end

#test_clockObject (readonly)

ID of the test clock this invoice item belongs to.



178
179
180
# File 'lib/stripe/resources/invoice_item.rb', line 178

def test_clock
  @test_clock
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates an item to be added to a draft invoice (up to 250 items per invoice). If no invoice is specified, the item will be on the next invoice created for the customer specified.



181
182
183
# File 'lib/stripe/resources/invoice_item.rb', line 181

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/invoiceitems", params: params, opts: opts)
end

.delete(invoiceitem, params = {}, opts = {}) ⇒ Object

Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.



186
187
188
189
190
191
192
193
# File 'lib/stripe/resources/invoice_item.rb', line 186

def self.delete(invoiceitem, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }),
    params: params,
    opts: opts
  )
end

.field_encodingsObject



233
234
235
236
237
238
# File 'lib/stripe/resources/invoice_item.rb', line 233

def self.field_encodings
  @field_encodings = {
    pricing: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
    quantity_decimal: :decimal_string,
  }
end

.field_remappingsObject



229
230
231
# File 'lib/stripe/resources/invoice_item.rb', line 229

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



220
221
222
223
224
225
226
227
# File 'lib/stripe/resources/invoice_item.rb', line 220

def self.inner_class_types
  @inner_class_types = {
    parent: Parent,
    period: Period,
    pricing: Pricing,
    proration_details: ProrationDetails,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of your invoice items. Invoice items are returned sorted by creation date, with the most recently created invoice items appearing first.



206
207
208
# File 'lib/stripe/resources/invoice_item.rb', line 206

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/invoiceitems", params: params, opts: opts)
end

.object_nameObject



20
21
22
# File 'lib/stripe/resources/invoice_item.rb', line 20

def self.object_name
  "invoiceitem"
end

.update(invoiceitem, params = {}, opts = {}) ⇒ Object

Updates the amount or description of an invoice item on an upcoming invoice. Updating an invoice item is only possible before the invoice it’s attached to is closed.



211
212
213
214
215
216
217
218
# File 'lib/stripe/resources/invoice_item.rb', line 211

def self.update(invoiceitem, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.



196
197
198
199
200
201
202
203
# File 'lib/stripe/resources/invoice_item.rb', line 196

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end