Class: Stripe::InvoiceItem
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::InvoiceItem
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Delete, APIOperations::Save
- Defined in:
- lib/stripe/resources/invoice_item.rb
Overview
Invoice Items represent the component lines of an [invoice](stripe.com/docs/api/invoices). When you create an invoice item with an ‘invoice` field, it is attached to the specified invoice and included as [an invoice line item](stripe.com/docs/api/invoices/line_item) within [invoice.lines](stripe.com/docs/api/invoices/object#invoice_object-lines).
Invoice Items can be created before you are ready to actually send the invoice. This can be particularly useful when combined with a [subscription](stripe.com/docs/api/subscriptions). Sometimes you want to add a charge or credit to a customer, but actually charge or credit the customer’s card only at the end of a regular billing cycle. This is useful for combining several charges (to minimize per-transaction fees), or for having Stripe tabulate your usage-based billing totals.
Related guides: [Integrate with the Invoicing API](stripe.com/docs/invoicing/integration), [Subscription Invoices](stripe.com/docs/billing/invoices/subscription#adding-upcoming-invoice-items).
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, Parent, Period, Pricing, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"invoiceitem"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount (in the ‘currency` specified) of the invoice item.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
The ID of the customer who will be billed when this invoice item is billed.
-
#customer_account ⇒ Object
readonly
The ID of the account who will be billed when this invoice item is billed.
-
#date ⇒ Object
readonly
Time at which the object was created.
-
#deleted ⇒ Object
readonly
Always true for a deleted object.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#discountable ⇒ Object
readonly
If true, discounts will apply to this invoice item.
-
#discounts ⇒ Object
readonly
The discounts which apply to the invoice item.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice ⇒ Object
readonly
The ID of the invoice this invoice item belongs to.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#margins ⇒ Object
readonly
The margins which apply to the invoice item.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#parent ⇒ Object
readonly
The parent that generated this invoice item.
-
#period ⇒ Object
readonly
Attribute for field period.
-
#pricing ⇒ Object
readonly
The pricing information of the invoice item.
-
#proration ⇒ Object
readonly
Whether the invoice item was created automatically as a proration adjustment when the customer switched plans.
-
#quantity ⇒ Object
readonly
Quantity of units for the invoice item.
-
#tax_rates ⇒ Object
readonly
The tax rates which apply to the invoice item.
-
#test_clock ⇒ Object
readonly
ID of the test clock this invoice item belongs to.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates an item to be added to a draft invoice (up to 250 items per invoice).
-
.delete(invoiceitem, params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your invoice items.
- .object_name ⇒ Object
-
.update(invoiceitem, params = {}, opts = {}) ⇒ Object
Updates the amount or description of an invoice item on an upcoming invoice.
Instance Method Summary collapse
-
#delete(params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods included from APIOperations::Delete
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount (in the ‘currency` specified) of the invoice item. This should always be equal to `unit_amount * quantity`.
455 456 457 |
# File 'lib/stripe/resources/invoice_item.rb', line 455 def amount @amount end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
457 458 459 |
# File 'lib/stripe/resources/invoice_item.rb', line 457 def currency @currency end |
#customer ⇒ Object (readonly)
The ID of the customer who will be billed when this invoice item is billed.
459 460 461 |
# File 'lib/stripe/resources/invoice_item.rb', line 459 def customer @customer end |
#customer_account ⇒ Object (readonly)
The ID of the account who will be billed when this invoice item is billed.
461 462 463 |
# File 'lib/stripe/resources/invoice_item.rb', line 461 def customer_account @customer_account end |
#date ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
463 464 465 |
# File 'lib/stripe/resources/invoice_item.rb', line 463 def date @date end |
#deleted ⇒ Object (readonly)
Always true for a deleted object
497 498 499 |
# File 'lib/stripe/resources/invoice_item.rb', line 497 def deleted @deleted end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
465 466 467 |
# File 'lib/stripe/resources/invoice_item.rb', line 465 def description @description end |
#discountable ⇒ Object (readonly)
If true, discounts will apply to this invoice item. Always false for prorations.
467 468 469 |
# File 'lib/stripe/resources/invoice_item.rb', line 467 def discountable @discountable end |
#discounts ⇒ Object (readonly)
The discounts which apply to the invoice item. Item discounts are applied before invoice discounts. Use ‘expand[]=discounts` to expand each discount.
469 470 471 |
# File 'lib/stripe/resources/invoice_item.rb', line 469 def discounts @discounts end |
#id ⇒ Object (readonly)
Unique identifier for the object.
471 472 473 |
# File 'lib/stripe/resources/invoice_item.rb', line 471 def id @id end |
#invoice ⇒ Object (readonly)
The ID of the invoice this invoice item belongs to.
473 474 475 |
# File 'lib/stripe/resources/invoice_item.rb', line 473 def invoice @invoice end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
475 476 477 |
# File 'lib/stripe/resources/invoice_item.rb', line 475 def livemode @livemode end |
#margins ⇒ Object (readonly)
The margins which apply to the invoice item. When set, the ‘default_margins` on the invoice do not apply to this invoice item.
477 478 479 |
# File 'lib/stripe/resources/invoice_item.rb', line 477 def margins @margins end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
479 480 481 |
# File 'lib/stripe/resources/invoice_item.rb', line 479 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
481 482 483 |
# File 'lib/stripe/resources/invoice_item.rb', line 481 def object @object end |
#parent ⇒ Object (readonly)
The parent that generated this invoice item.
483 484 485 |
# File 'lib/stripe/resources/invoice_item.rb', line 483 def parent @parent end |
#period ⇒ Object (readonly)
Attribute for field period
485 486 487 |
# File 'lib/stripe/resources/invoice_item.rb', line 485 def period @period end |
#pricing ⇒ Object (readonly)
The pricing information of the invoice item.
487 488 489 |
# File 'lib/stripe/resources/invoice_item.rb', line 487 def pricing @pricing end |
#proration ⇒ Object (readonly)
Whether the invoice item was created automatically as a proration adjustment when the customer switched plans.
489 490 491 |
# File 'lib/stripe/resources/invoice_item.rb', line 489 def proration @proration end |
#quantity ⇒ Object (readonly)
Quantity of units for the invoice item. If the invoice item is a proration, the quantity of the subscription that the proration was computed for.
491 492 493 |
# File 'lib/stripe/resources/invoice_item.rb', line 491 def quantity @quantity end |
#tax_rates ⇒ Object (readonly)
The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item.
493 494 495 |
# File 'lib/stripe/resources/invoice_item.rb', line 493 def tax_rates @tax_rates end |
#test_clock ⇒ Object (readonly)
ID of the test clock this invoice item belongs to.
495 496 497 |
# File 'lib/stripe/resources/invoice_item.rb', line 495 def test_clock @test_clock end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates an item to be added to a draft invoice (up to 250 items per invoice). If no invoice is specified, the item will be on the next invoice created for the customer specified.
500 501 502 |
# File 'lib/stripe/resources/invoice_item.rb', line 500 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/invoiceitems", params: params, opts: opts) end |
.delete(invoiceitem, params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.
505 506 507 508 509 510 511 512 |
# File 'lib/stripe/resources/invoice_item.rb', line 505 def self.delete(invoiceitem, params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of your invoice items. Invoice items are returned sorted by creation date, with the most recently created invoice items appearing first.
525 526 527 |
# File 'lib/stripe/resources/invoice_item.rb', line 525 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/invoiceitems", params: params, opts: opts) end |
.object_name ⇒ Object
20 21 22 |
# File 'lib/stripe/resources/invoice_item.rb', line 20 def self.object_name "invoiceitem" end |
.update(invoiceitem, params = {}, opts = {}) ⇒ Object
Updates the amount or description of an invoice item on an upcoming invoice. Updating an invoice item is only possible before the invoice it’s attached to is closed.
530 531 532 533 534 535 536 537 |
# File 'lib/stripe/resources/invoice_item.rb', line 530 def self.update(invoiceitem, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts ) end |
Instance Method Details
#delete(params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.
515 516 517 518 519 520 521 522 |
# File 'lib/stripe/resources/invoice_item.rb', line 515 def delete(params = {}, opts = {}) request_stripe_object( method: :delete, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(self["id"]) }), params: params, opts: opts ) end |