Class: Stripe::InvoiceItem

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Delete, APIOperations::Save
Defined in:
lib/stripe/resources/invoice_item.rb

Overview

Invoice Items represent the component lines of an [invoice](stripe.com/docs/api/invoices). When you create an invoice item with an ‘invoice` field, it is attached to the specified invoice and included as [an invoice line item](stripe.com/docs/api/invoices/line_item) within [invoice.lines](stripe.com/docs/api/invoices/object#invoice_object-lines).

Invoice Items can be created before you are ready to actually send the invoice. This can be particularly useful when combined with a [subscription](stripe.com/docs/api/subscriptions). Sometimes you want to add a charge or credit to a customer, but actually charge or credit the customer’s card only at the end of a regular billing cycle. This is useful for combining several charges (to minimize per-transaction fees), or for having Stripe tabulate your usage-based billing totals.

Related guides: [Integrate with the Invoicing API](stripe.com/docs/invoicing/integration), [Subscription Invoices](stripe.com/docs/billing/invoices/subscription#adding-upcoming-invoice-items).

Defined Under Namespace

Classes: CreateParams, DeleteParams, ListParams, Parent, Period, Pricing, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"invoiceitem"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods included from APIOperations::Delete

included

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount (in the ‘currency` specified) of the invoice item. This should always be equal to `unit_amount * quantity`.



383
384
385
# File 'lib/stripe/resources/invoice_item.rb', line 383

def amount
  @amount
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



385
386
387
# File 'lib/stripe/resources/invoice_item.rb', line 385

def currency
  @currency
end

#customerObject (readonly)

The ID of the customer who will be billed when this invoice item is billed.



387
388
389
# File 'lib/stripe/resources/invoice_item.rb', line 387

def customer
  @customer
end

#dateObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



389
390
391
# File 'lib/stripe/resources/invoice_item.rb', line 389

def date
  @date
end

#deletedObject (readonly)

Always true for a deleted object



421
422
423
# File 'lib/stripe/resources/invoice_item.rb', line 421

def deleted
  @deleted
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



391
392
393
# File 'lib/stripe/resources/invoice_item.rb', line 391

def description
  @description
end

#discountableObject (readonly)

If true, discounts will apply to this invoice item. Always false for prorations.



393
394
395
# File 'lib/stripe/resources/invoice_item.rb', line 393

def discountable
  @discountable
end

#discountsObject (readonly)

The discounts which apply to the invoice item. Item discounts are applied before invoice discounts. Use ‘expand[]=discounts` to expand each discount.



395
396
397
# File 'lib/stripe/resources/invoice_item.rb', line 395

def discounts
  @discounts
end

#idObject (readonly)

Unique identifier for the object.



397
398
399
# File 'lib/stripe/resources/invoice_item.rb', line 397

def id
  @id
end

#invoiceObject (readonly)

The ID of the invoice this invoice item belongs to.



399
400
401
# File 'lib/stripe/resources/invoice_item.rb', line 399

def invoice
  @invoice
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



401
402
403
# File 'lib/stripe/resources/invoice_item.rb', line 401

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



403
404
405
# File 'lib/stripe/resources/invoice_item.rb', line 403

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



405
406
407
# File 'lib/stripe/resources/invoice_item.rb', line 405

def object
  @object
end

#parentObject (readonly)

The parent that generated this invoice item.



407
408
409
# File 'lib/stripe/resources/invoice_item.rb', line 407

def parent
  @parent
end

#periodObject (readonly)

Attribute for field period



409
410
411
# File 'lib/stripe/resources/invoice_item.rb', line 409

def period
  @period
end

#pricingObject (readonly)

The pricing information of the invoice item.



411
412
413
# File 'lib/stripe/resources/invoice_item.rb', line 411

def pricing
  @pricing
end

#prorationObject (readonly)

Whether the invoice item was created automatically as a proration adjustment when the customer switched plans.



413
414
415
# File 'lib/stripe/resources/invoice_item.rb', line 413

def proration
  @proration
end

#quantityObject (readonly)

Quantity of units for the invoice item. If the invoice item is a proration, the quantity of the subscription that the proration was computed for.



415
416
417
# File 'lib/stripe/resources/invoice_item.rb', line 415

def quantity
  @quantity
end

#tax_ratesObject (readonly)

The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item.



417
418
419
# File 'lib/stripe/resources/invoice_item.rb', line 417

def tax_rates
  @tax_rates
end

#test_clockObject (readonly)

ID of the test clock this invoice item belongs to.



419
420
421
# File 'lib/stripe/resources/invoice_item.rb', line 419

def test_clock
  @test_clock
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates an item to be added to a draft invoice (up to 250 items per invoice). If no invoice is specified, the item will be on the next invoice created for the customer specified.



424
425
426
# File 'lib/stripe/resources/invoice_item.rb', line 424

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/invoiceitems", params: params, opts: opts)
end

.delete(invoiceitem, params = {}, opts = {}) ⇒ Object

Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.



429
430
431
432
433
434
435
436
# File 'lib/stripe/resources/invoice_item.rb', line 429

def self.delete(invoiceitem, params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of your invoice items. Invoice items are returned sorted by creation date, with the most recently created invoice items appearing first.



449
450
451
# File 'lib/stripe/resources/invoice_item.rb', line 449

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/invoiceitems", params: params, opts: opts)
end

.object_nameObject



20
21
22
# File 'lib/stripe/resources/invoice_item.rb', line 20

def self.object_name
  "invoiceitem"
end

.update(invoiceitem, params = {}, opts = {}) ⇒ Object

Updates the amount or description of an invoice item on an upcoming invoice. Updating an invoice item is only possible before the invoice it’s attached to is closed.



454
455
456
457
458
459
460
461
# File 'lib/stripe/resources/invoice_item.rb', line 454

def self.update(invoiceitem, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#delete(params = {}, opts = {}) ⇒ Object

Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.



439
440
441
442
443
444
445
446
# File 'lib/stripe/resources/invoice_item.rb', line 439

def delete(params = {}, opts = {})
  request_stripe_object(
    method: :delete,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end