Class: Stripe::InvoiceItem::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::CreateParams
- Defined in:
- lib/stripe/resources/invoice_item.rb
Defined Under Namespace
Classes: Discount, Period, PriceData, Pricing
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The ID of the customer who will be billed when this invoice item is billed.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons and promotion codes to redeem into discounts for the invoice item or invoice line item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
The ID of an existing invoice to add this invoice item to.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#pricing ⇒ Object
The pricing information for the invoice item.
-
#quantity ⇒ Object
Non-negative integer.
-
#subscription ⇒ Object
The ID of a subscription to add this invoice item to.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#tax_rates ⇒ Object
The tax rates which apply to the invoice item.
-
#unit_amount_decimal ⇒ Object
The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, customer: nil, description: nil, discountable: nil, discounts: nil, expand: nil, invoice: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, subscription: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, customer: nil, description: nil, discountable: nil, discounts: nil, expand: nil, invoice: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, subscription: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/stripe/resources/invoice_item.rb', line 342 def initialize( amount: nil, currency: nil, customer: nil, description: nil, discountable: nil, discounts: nil, expand: nil, invoice: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, subscription: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil ) @amount = amount @currency = currency @customer = customer @description = description @discountable = discountable @discounts = discounts @expand = @invoice = invoice @metadata = @period = period @price_data = price_data @pricing = pricing @quantity = quantity @subscription = subscription @tax_behavior = tax_behavior @tax_code = tax_code @tax_rates = tax_rates @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. Passing in a negative ‘amount` will reduce the `amount_due` on the invoice.
306 307 308 |
# File 'lib/stripe/resources/invoice_item.rb', line 306 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
308 309 310 |
# File 'lib/stripe/resources/invoice_item.rb', line 308 def currency @currency end |
#customer ⇒ Object
The ID of the customer who will be billed when this invoice item is billed.
310 311 312 |
# File 'lib/stripe/resources/invoice_item.rb', line 310 def customer @customer end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
312 313 314 |
# File 'lib/stripe/resources/invoice_item.rb', line 312 def description @description end |
#discountable ⇒ Object
Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items.
314 315 316 |
# File 'lib/stripe/resources/invoice_item.rb', line 314 def discountable @discountable end |
#discounts ⇒ Object
The coupons and promotion codes to redeem into discounts for the invoice item or invoice line item.
316 317 318 |
# File 'lib/stripe/resources/invoice_item.rb', line 316 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
318 319 320 |
# File 'lib/stripe/resources/invoice_item.rb', line 318 def @expand end |
#invoice ⇒ Object
The ID of an existing invoice to add this invoice item to. When left blank, the invoice item will be added to the next upcoming scheduled invoice. This is useful when adding invoice items in response to an invoice.created webhook. You can only add invoice items to draft invoices and there is a maximum of 250 items per invoice.
320 321 322 |
# File 'lib/stripe/resources/invoice_item.rb', line 320 def invoice @invoice end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
322 323 324 |
# File 'lib/stripe/resources/invoice_item.rb', line 322 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
324 325 326 |
# File 'lib/stripe/resources/invoice_item.rb', line 324 def period @period end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
326 327 328 |
# File 'lib/stripe/resources/invoice_item.rb', line 326 def price_data @price_data end |
#pricing ⇒ Object
The pricing information for the invoice item.
328 329 330 |
# File 'lib/stripe/resources/invoice_item.rb', line 328 def pricing @pricing end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the invoice item.
330 331 332 |
# File 'lib/stripe/resources/invoice_item.rb', line 330 def quantity @quantity end |
#subscription ⇒ Object
The ID of a subscription to add this invoice item to. When left blank, the invoice item is added to the next upcoming scheduled invoice. When set, scheduled invoices for subscriptions other than the specified subscription will ignore the invoice item. Use this when you want to express that an invoice item has been accrued within the context of a particular subscription.
332 333 334 |
# File 'lib/stripe/resources/invoice_item.rb', line 332 def subscription @subscription end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
334 335 336 |
# File 'lib/stripe/resources/invoice_item.rb', line 334 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
336 337 338 |
# File 'lib/stripe/resources/invoice_item.rb', line 336 def tax_code @tax_code end |
#tax_rates ⇒ Object
The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item.
338 339 340 |
# File 'lib/stripe/resources/invoice_item.rb', line 338 def tax_rates @tax_rates end |
#unit_amount_decimal ⇒ Object
The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This ‘unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.
340 341 342 |
# File 'lib/stripe/resources/invoice_item.rb', line 340 def unit_amount_decimal @unit_amount_decimal end |