Class: Stripe::InvoiceItem::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::CreateParams::Discount
- Defined in:
- lib/stripe/resources/invoice_item.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
317 318 319 320 321 322 |
# File 'lib/stripe/resources/invoice_item.rb', line 317 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
309 310 311 |
# File 'lib/stripe/resources/invoice_item.rb', line 309 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
311 312 313 |
# File 'lib/stripe/resources/invoice_item.rb', line 311 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
313 314 315 |
# File 'lib/stripe/resources/invoice_item.rb', line 313 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
315 316 317 |
# File 'lib/stripe/resources/invoice_item.rb', line 315 def promotion_code @promotion_code end |