Class: Stripe::InvoiceItem::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::CreateParams::Discount
- Defined in:
- lib/stripe/resources/invoice_item.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
254 255 256 257 258 |
# File 'lib/stripe/resources/invoice_item.rb', line 254 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
248 249 250 |
# File 'lib/stripe/resources/invoice_item.rb', line 248 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
250 251 252 |
# File 'lib/stripe/resources/invoice_item.rb', line 250 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
252 253 254 |
# File 'lib/stripe/resources/invoice_item.rb', line 252 def promotion_code @promotion_code end |