Class: Stripe::InvoiceItem::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice_item.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
427 428 429 430 431 |
# File 'lib/stripe/resources/invoice_item.rb', line 427 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
421 422 423 |
# File 'lib/stripe/resources/invoice_item.rb', line 421 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
423 424 425 |
# File 'lib/stripe/resources/invoice_item.rb', line 423 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
425 426 427 |
# File 'lib/stripe/resources/invoice_item.rb', line 425 def type @type end |