Class: Stripe::InvoiceItem::CreateParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::CreateParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/resources/invoice_item.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
347 348 349 350 351 |
# File 'lib/stripe/resources/invoice_item.rb', line 347 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
341 342 343 |
# File 'lib/stripe/resources/invoice_item.rb', line 341 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
343 344 345 |
# File 'lib/stripe/resources/invoice_item.rb', line 343 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
345 346 347 |
# File 'lib/stripe/resources/invoice_item.rb', line 345 def type @type end |