Class: Stripe::InvoiceItem::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



275
276
277
278
279
# File 'lib/stripe/resources/invoice_item.rb', line 275

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



269
270
271
# File 'lib/stripe/resources/invoice_item.rb', line 269

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



271
272
273
# File 'lib/stripe/resources/invoice_item.rb', line 271

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



273
274
275
# File 'lib/stripe/resources/invoice_item.rb', line 273

def type
  @type
end