Class: Stripe::InvoiceItem::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



315
316
317
318
319
# File 'lib/stripe/resources/invoice_item.rb', line 315

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



307
308
309
# File 'lib/stripe/resources/invoice_item.rb', line 307

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



310
311
312
# File 'lib/stripe/resources/invoice_item.rb', line 310

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



313
314
315
# File 'lib/stripe/resources/invoice_item.rb', line 313

def type
  @type
end