Class: Stripe::InvoiceItem::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/stripe/resources/invoice_item.rb', line 383

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  pending: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @pending = pending
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return invoice items that were created during the given date interval.



365
366
367
# File 'lib/stripe/resources/invoice_item.rb', line 365

def created
  @created
end

#customerObject

The identifier of the customer whose invoice items to return. If none is provided, all invoice items will be returned.



367
368
369
# File 'lib/stripe/resources/invoice_item.rb', line 367

def customer
  @customer
end

#customer_accountObject

The identifier of the account whose invoice items to return. If none is provided, all invoice items will be returned.



369
370
371
# File 'lib/stripe/resources/invoice_item.rb', line 369

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



371
372
373
# File 'lib/stripe/resources/invoice_item.rb', line 371

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



373
374
375
# File 'lib/stripe/resources/invoice_item.rb', line 373

def expand
  @expand
end

#invoiceObject

Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.



375
376
377
# File 'lib/stripe/resources/invoice_item.rb', line 375

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



377
378
379
# File 'lib/stripe/resources/invoice_item.rb', line 377

def limit
  @limit
end

#pendingObject

Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.



379
380
381
# File 'lib/stripe/resources/invoice_item.rb', line 379

def pending
  @pending
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



381
382
383
# File 'lib/stripe/resources/invoice_item.rb', line 381

def starting_after
  @starting_after
end