Class: Stripe::InvoiceItem::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::ListParams
- Defined in:
- lib/stripe/resources/invoice_item.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return invoice items that were created during the given date interval.
-
#customer ⇒ Object
The identifier of the customer whose invoice items to return.
-
#customer_account ⇒ Object
The identifier of the account whose invoice items to return.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
Only return invoice items belonging to this invoice.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#pending ⇒ Object
Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/stripe/resources/invoice_item.rb', line 303 def initialize( created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil ) @created = created @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @invoice = invoice @limit = limit @pending = pending @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return invoice items that were created during the given date interval.
285 286 287 |
# File 'lib/stripe/resources/invoice_item.rb', line 285 def created @created end |
#customer ⇒ Object
The identifier of the customer whose invoice items to return. If none is provided, all invoice items will be returned.
287 288 289 |
# File 'lib/stripe/resources/invoice_item.rb', line 287 def customer @customer end |
#customer_account ⇒ Object
The identifier of the account whose invoice items to return. If none is provided, all invoice items will be returned.
289 290 291 |
# File 'lib/stripe/resources/invoice_item.rb', line 289 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
291 292 293 |
# File 'lib/stripe/resources/invoice_item.rb', line 291 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
293 294 295 |
# File 'lib/stripe/resources/invoice_item.rb', line 293 def @expand end |
#invoice ⇒ Object
Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.
295 296 297 |
# File 'lib/stripe/resources/invoice_item.rb', line 295 def invoice @invoice end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
297 298 299 |
# File 'lib/stripe/resources/invoice_item.rb', line 297 def limit @limit end |
#pending ⇒ Object
Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.
299 300 301 |
# File 'lib/stripe/resources/invoice_item.rb', line 299 def pending @pending end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
301 302 303 |
# File 'lib/stripe/resources/invoice_item.rb', line 301 def starting_after @starting_after end |