Class: Stripe::InvoiceItem::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/stripe/resources/invoice_item.rb', line 255

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  pending: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @pending = pending
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return invoice items that were created during the given date interval.



237
238
239
# File 'lib/stripe/resources/invoice_item.rb', line 237

def created
  @created
end

#customerObject

The identifier of the customer whose invoice items to return. If none is provided, all invoice items will be returned.



239
240
241
# File 'lib/stripe/resources/invoice_item.rb', line 239

def customer
  @customer
end

#customer_accountObject

The identifier of the account whose invoice items to return. If none is provided, all invoice items will be returned.



241
242
243
# File 'lib/stripe/resources/invoice_item.rb', line 241

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



243
244
245
# File 'lib/stripe/resources/invoice_item.rb', line 243

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



245
246
247
# File 'lib/stripe/resources/invoice_item.rb', line 245

def expand
  @expand
end

#invoiceObject

Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.



247
248
249
# File 'lib/stripe/resources/invoice_item.rb', line 247

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



249
250
251
# File 'lib/stripe/resources/invoice_item.rb', line 249

def limit
  @limit
end

#pendingObject

Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.



251
252
253
# File 'lib/stripe/resources/invoice_item.rb', line 251

def pending
  @pending
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



253
254
255
# File 'lib/stripe/resources/invoice_item.rb', line 253

def starting_after
  @starting_after
end