Class: Stripe::InvoiceItem::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/stripe/resources/invoice_item.rb', line 258

def initialize(
  created: nil,
  customer: nil,
  customer_account: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  pending: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @customer_account = 
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @pending = pending
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return invoice items that were created during the given date interval.



240
241
242
# File 'lib/stripe/resources/invoice_item.rb', line 240

def created
  @created
end

#customerObject

The identifier of the customer whose invoice items to return. If none is provided, all invoice items will be returned.



242
243
244
# File 'lib/stripe/resources/invoice_item.rb', line 242

def customer
  @customer
end

#customer_accountObject

The identifier of the account whose invoice items to return. If none is provided, all invoice items will be returned.



244
245
246
# File 'lib/stripe/resources/invoice_item.rb', line 244

def 
  @customer_account
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



246
247
248
# File 'lib/stripe/resources/invoice_item.rb', line 246

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



248
249
250
# File 'lib/stripe/resources/invoice_item.rb', line 248

def expand
  @expand
end

#invoiceObject

Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.



250
251
252
# File 'lib/stripe/resources/invoice_item.rb', line 250

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



252
253
254
# File 'lib/stripe/resources/invoice_item.rb', line 252

def limit
  @limit
end

#pendingObject

Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.



254
255
256
# File 'lib/stripe/resources/invoice_item.rb', line 254

def pending
  @pending
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



256
257
258
# File 'lib/stripe/resources/invoice_item.rb', line 256

def starting_after
  @starting_after
end