Class: Stripe::InvoiceItem::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::ListParams
- Defined in:
- lib/stripe/resources/invoice_item.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return invoice items that were created during the given date interval.
-
#customer ⇒ Object
The identifier of the customer whose invoice items to return.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
Only return invoice items belonging to this invoice.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#pending ⇒ Object
Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/stripe/resources/invoice_item.rb', line 233 def initialize( created: nil, customer: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil ) @created = created @customer = customer @ending_before = ending_before @expand = @invoice = invoice @limit = limit @pending = pending @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return invoice items that were created during the given date interval.
217 218 219 |
# File 'lib/stripe/resources/invoice_item.rb', line 217 def created @created end |
#customer ⇒ Object
The identifier of the customer whose invoice items to return. If none is provided, all invoice items will be returned.
219 220 221 |
# File 'lib/stripe/resources/invoice_item.rb', line 219 def customer @customer end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
221 222 223 |
# File 'lib/stripe/resources/invoice_item.rb', line 221 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
223 224 225 |
# File 'lib/stripe/resources/invoice_item.rb', line 223 def @expand end |
#invoice ⇒ Object
Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.
225 226 227 |
# File 'lib/stripe/resources/invoice_item.rb', line 225 def invoice @invoice end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
227 228 229 |
# File 'lib/stripe/resources/invoice_item.rb', line 227 def limit @limit end |
#pending ⇒ Object
Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.
229 230 231 |
# File 'lib/stripe/resources/invoice_item.rb', line 229 def pending @pending end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
231 232 233 |
# File 'lib/stripe/resources/invoice_item.rb', line 231 def starting_after @starting_after end |