Class: Stripe::InvoiceItem::Pricing::LicenseFeeDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceItem::Pricing::LicenseFeeDetails
- Defined in:
- lib/stripe/resources/invoice_item.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#license_fee ⇒ Object
readonly
The ID of the license fee this item is associated with.
-
#license_fee_version ⇒ Object
readonly
The version of the license fee this item is associated with.
-
#licensed_item ⇒ Object
readonly
The ID of the licensed item this item is associated with.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#license_fee ⇒ Object (readonly)
The ID of the license fee this item is associated with
133 134 135 |
# File 'lib/stripe/resources/invoice_item.rb', line 133 def license_fee @license_fee end |
#license_fee_version ⇒ Object (readonly)
The version of the license fee this item is associated with
135 136 137 |
# File 'lib/stripe/resources/invoice_item.rb', line 135 def license_fee_version @license_fee_version end |
#licensed_item ⇒ Object (readonly)
The ID of the licensed item this item is associated with
137 138 139 |
# File 'lib/stripe/resources/invoice_item.rb', line 137 def licensed_item @licensed_item end |
Class Method Details
.field_remappings ⇒ Object
143 144 145 |
# File 'lib/stripe/resources/invoice_item.rb', line 143 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
139 140 141 |
# File 'lib/stripe/resources/invoice_item.rb', line 139 def self.inner_class_types @inner_class_types = {} end |