Class: Stripe::InvoiceItem::Pricing::LicenseFeeDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/invoice_item.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#license_feeObject (readonly)

The ID of the license fee this item is associated with



73
74
75
# File 'lib/stripe/resources/invoice_item.rb', line 73

def license_fee
  @license_fee
end

#license_fee_versionObject (readonly)

The version of the license fee this item is associated with



75
76
77
# File 'lib/stripe/resources/invoice_item.rb', line 75

def license_fee_version
  @license_fee_version
end

#licensed_itemObject (readonly)

The ID of the licensed item this item is associated with



77
78
79
# File 'lib/stripe/resources/invoice_item.rb', line 77

def licensed_item
  @licensed_item
end