Class: Stripe::InvoiceItem::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/stripe/resources/invoice_item.rb', line 311

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @margins = margins
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



281
282
283
# File 'lib/stripe/resources/invoice_item.rb', line 281

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



283
284
285
# File 'lib/stripe/resources/invoice_item.rb', line 283

def description
  @description
end

#discountableObject

Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.



285
286
287
# File 'lib/stripe/resources/invoice_item.rb', line 285

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



287
288
289
# File 'lib/stripe/resources/invoice_item.rb', line 287

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



289
290
291
# File 'lib/stripe/resources/invoice_item.rb', line 289

def expand
  @expand
end

#marginsObject

The ids of the margins to apply to the invoice item. When set, the ‘default_margins` on the invoice do not apply to this invoice item.



291
292
293
# File 'lib/stripe/resources/invoice_item.rb', line 291

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



293
294
295
# File 'lib/stripe/resources/invoice_item.rb', line 293

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



295
296
297
# File 'lib/stripe/resources/invoice_item.rb', line 295

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



297
298
299
# File 'lib/stripe/resources/invoice_item.rb', line 297

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



299
300
301
# File 'lib/stripe/resources/invoice_item.rb', line 299

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item.



301
302
303
# File 'lib/stripe/resources/invoice_item.rb', line 301

def quantity
  @quantity
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



303
304
305
# File 'lib/stripe/resources/invoice_item.rb', line 303

def tax_behavior
  @tax_behavior
end

#tax_codeObject



305
306
307
# File 'lib/stripe/resources/invoice_item.rb', line 305

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.



307
308
309
# File 'lib/stripe/resources/invoice_item.rb', line 307

def tax_rates
  @tax_rates
end

#unit_amount_decimalObject

The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This ‘unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.



309
310
311
# File 'lib/stripe/resources/invoice_item.rb', line 309

def unit_amount_decimal
  @unit_amount_decimal
end