Class: Stripe::InvoiceItem::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_item.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/stripe/resources/invoice_item.rb', line 186

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @margins = margins
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



156
157
158
# File 'lib/stripe/resources/invoice_item.rb', line 156

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



158
159
160
# File 'lib/stripe/resources/invoice_item.rb', line 158

def description
  @description
end

#discountableObject

Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.



160
161
162
# File 'lib/stripe/resources/invoice_item.rb', line 160

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



162
163
164
# File 'lib/stripe/resources/invoice_item.rb', line 162

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



164
165
166
# File 'lib/stripe/resources/invoice_item.rb', line 164

def expand
  @expand
end

#marginsObject

The ids of the margins to apply to the invoice item. When set, the ‘default_margins` on the invoice do not apply to this invoice item.



166
167
168
# File 'lib/stripe/resources/invoice_item.rb', line 166

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



168
169
170
# File 'lib/stripe/resources/invoice_item.rb', line 168

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



170
171
172
# File 'lib/stripe/resources/invoice_item.rb', line 170

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



172
173
174
# File 'lib/stripe/resources/invoice_item.rb', line 172

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



174
175
176
# File 'lib/stripe/resources/invoice_item.rb', line 174

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item.



176
177
178
# File 'lib/stripe/resources/invoice_item.rb', line 176

def quantity
  @quantity
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



178
179
180
# File 'lib/stripe/resources/invoice_item.rb', line 178

def tax_behavior
  @tax_behavior
end

#tax_codeObject



180
181
182
# File 'lib/stripe/resources/invoice_item.rb', line 180

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.



182
183
184
# File 'lib/stripe/resources/invoice_item.rb', line 182

def tax_rates
  @tax_rates
end

#unit_amount_decimalObject

The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This ‘unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.



184
185
186
# File 'lib/stripe/resources/invoice_item.rb', line 184

def unit_amount_decimal
  @unit_amount_decimal
end