Class: Stripe::InvoiceItem::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::UpdateParams
- Defined in:
- lib/stripe/resources/invoice_item.rb
Defined Under Namespace
Classes: Discount, Period, PriceData, Pricing
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#pricing ⇒ Object
The pricing information for the invoice item.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#tax_rates ⇒ Object
The tax rates which apply to the invoice item.
-
#unit_amount_decimal ⇒ Object
The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/stripe/resources/invoice_item.rb', line 157 def initialize( amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil ) @amount = amount @description = description @discountable = discountable @discounts = discounts @expand = @metadata = @period = period @price_data = price_data @pricing = pricing @quantity = quantity @tax_behavior = tax_behavior @tax_code = tax_code @tax_rates = tax_rates @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.
129 130 131 |
# File 'lib/stripe/resources/invoice_item.rb', line 129 def amount @amount end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
131 132 133 |
# File 'lib/stripe/resources/invoice_item.rb', line 131 def description @description end |
#discountable ⇒ Object
Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.
133 134 135 |
# File 'lib/stripe/resources/invoice_item.rb', line 133 def discountable @discountable end |
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.
135 136 137 |
# File 'lib/stripe/resources/invoice_item.rb', line 135 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
137 138 139 |
# File 'lib/stripe/resources/invoice_item.rb', line 137 def @expand end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
139 140 141 |
# File 'lib/stripe/resources/invoice_item.rb', line 139 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
141 142 143 |
# File 'lib/stripe/resources/invoice_item.rb', line 141 def period @period end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
143 144 145 |
# File 'lib/stripe/resources/invoice_item.rb', line 143 def price_data @price_data end |
#pricing ⇒ Object
The pricing information for the invoice item.
145 146 147 |
# File 'lib/stripe/resources/invoice_item.rb', line 145 def pricing @pricing end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the invoice item.
147 148 149 |
# File 'lib/stripe/resources/invoice_item.rb', line 147 def quantity @quantity end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
149 150 151 |
# File 'lib/stripe/resources/invoice_item.rb', line 149 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
151 152 153 |
# File 'lib/stripe/resources/invoice_item.rb', line 151 def tax_code @tax_code end |
#tax_rates ⇒ Object
The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.
153 154 155 |
# File 'lib/stripe/resources/invoice_item.rb', line 153 def tax_rates @tax_rates end |
#unit_amount_decimal ⇒ Object
The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This ‘unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.
155 156 157 |
# File 'lib/stripe/resources/invoice_item.rb', line 155 def unit_amount_decimal @unit_amount_decimal end |