Class: Stripe::InvoiceItem::UpdateParams::Period
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItem::UpdateParams::Period
- Defined in:
- lib/stripe/resources/invoice_item.rb
Instance Attribute Summary collapse
-
#end ⇒ Object
The end of the period, which must be greater than or equal to the start.
-
#start ⇒ Object
The start of the period.
Instance Method Summary collapse
-
#initialize(end_: nil, start: nil) ⇒ Period
constructor
A new instance of Period.
Methods inherited from RequestParams
Constructor Details
#initialize(end_: nil, start: nil) ⇒ Period
Returns a new instance of Period.
114 115 116 117 |
# File 'lib/stripe/resources/invoice_item.rb', line 114 def initialize(end_: nil, start: nil) @end = end_ @start = start end |
Instance Attribute Details
#end ⇒ Object
The end of the period, which must be greater than or equal to the start. This value is inclusive.
110 111 112 |
# File 'lib/stripe/resources/invoice_item.rb', line 110 def end @end end |
#start ⇒ Object
The start of the period. This value is inclusive.
112 113 114 |
# File 'lib/stripe/resources/invoice_item.rb', line 112 def start @start end |