Class: Stripe::InvoiceItemService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::InvoiceItemService
- Defined in:
- lib/stripe/services/invoice_item_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates an item to be added to a draft invoice (up to 250 items per invoice).
-
#delete(invoiceitem, params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your invoice items.
-
#retrieve(invoiceitem, params = {}, opts = {}) ⇒ Object
Retrieves the invoice item with the given ID.
-
#update(invoiceitem, params = {}, opts = {}) ⇒ Object
Updates the amount or description of an invoice item on an upcoming invoice.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates an item to be added to a draft invoice (up to 250 items per invoice). If no invoice is specified, the item will be on the next invoice created for the customer specified.
413 414 415 416 417 418 419 420 421 |
# File 'lib/stripe/services/invoice_item_service.rb', line 413 def create(params = {}, opts = {}) request( method: :post, path: "/v1/invoiceitems", params: params, opts: opts, base_address: :api ) end |
#delete(invoiceitem, params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.
424 425 426 427 428 429 430 431 432 |
# File 'lib/stripe/services/invoice_item_service.rb', line 424 def delete(invoiceitem, params = {}, opts = {}) request( method: :delete, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your invoice items. Invoice items are returned sorted by creation date, with the most recently created invoice items appearing first.
435 436 437 438 439 440 441 442 443 |
# File 'lib/stripe/services/invoice_item_service.rb', line 435 def list(params = {}, opts = {}) request( method: :get, path: "/v1/invoiceitems", params: params, opts: opts, base_address: :api ) end |
#retrieve(invoiceitem, params = {}, opts = {}) ⇒ Object
Retrieves the invoice item with the given ID.
446 447 448 449 450 451 452 453 454 |
# File 'lib/stripe/services/invoice_item_service.rb', line 446 def retrieve(invoiceitem, params = {}, opts = {}) request( method: :get, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts, base_address: :api ) end |
#update(invoiceitem, params = {}, opts = {}) ⇒ Object
Updates the amount or description of an invoice item on an upcoming invoice. Updating an invoice item is only possible before the invoice it’s attached to is closed.
457 458 459 460 461 462 463 464 465 |
# File 'lib/stripe/services/invoice_item_service.rb', line 457 def update(invoiceitem, params = {}, opts = {}) request( method: :post, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts, base_address: :api ) end |