Class: Stripe::InvoiceItemService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/invoice_item_service.rb

Defined Under Namespace

Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#create(params = {}, opts = {}) ⇒ Object

Creates an item to be added to a draft invoice (up to 250 items per invoice). If no invoice is specified, the item will be on the next invoice created for the customer specified.



395
396
397
398
399
400
401
402
403
# File 'lib/stripe/services/invoice_item_service.rb', line 395

def create(params = {}, opts = {})
  request(
    method: :post,
    path: "/v1/invoiceitems",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#delete(invoiceitem, params = {}, opts = {}) ⇒ Object

Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.



406
407
408
409
410
411
412
413
414
# File 'lib/stripe/services/invoice_item_service.rb', line 406

def delete(invoiceitem, params = {}, opts = {})
  request(
    method: :delete,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#list(params = {}, opts = {}) ⇒ Object

Returns a list of your invoice items. Invoice items are returned sorted by creation date, with the most recently created invoice items appearing first.



417
418
419
420
421
422
423
424
425
# File 'lib/stripe/services/invoice_item_service.rb', line 417

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/invoiceitems",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(invoiceitem, params = {}, opts = {}) ⇒ Object

Retrieves the invoice item with the given ID.



428
429
430
431
432
433
434
435
436
# File 'lib/stripe/services/invoice_item_service.rb', line 428

def retrieve(invoiceitem, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(invoiceitem, params = {}, opts = {}) ⇒ Object

Updates the amount or description of an invoice item on an upcoming invoice. Updating an invoice item is only possible before the invoice it’s attached to is closed.



439
440
441
442
443
444
445
446
447
# File 'lib/stripe/services/invoice_item_service.rb', line 439

def update(invoiceitem, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end