Class: Stripe::InvoiceItemService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::InvoiceItemService
- Defined in:
- lib/stripe/services/invoice_item_service.rb
Defined Under Namespace
Classes: CreateParams, DeleteParams, ListParams, RetrieveParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates an item to be added to a draft invoice (up to 250 items per invoice).
-
#delete(invoiceitem, params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your invoice items.
-
#retrieve(invoiceitem, params = {}, opts = {}) ⇒ Object
Retrieves the invoice item with the given ID.
-
#update(invoiceitem, params = {}, opts = {}) ⇒ Object
Updates the amount or description of an invoice item on an upcoming invoice.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates an item to be added to a draft invoice (up to 250 items per invoice). If no invoice is specified, the item will be on the next invoice created for the customer specified.
461 462 463 464 465 466 467 468 469 |
# File 'lib/stripe/services/invoice_item_service.rb', line 461 def create(params = {}, opts = {}) request( method: :post, path: "/v1/invoiceitems", params: params, opts: opts, base_address: :api ) end |
#delete(invoiceitem, params = {}, opts = {}) ⇒ Object
Deletes an invoice item, removing it from an invoice. Deleting invoice items is only possible when they’re not attached to invoices, or if it’s attached to a draft invoice.
472 473 474 475 476 477 478 479 480 |
# File 'lib/stripe/services/invoice_item_service.rb', line 472 def delete(invoiceitem, params = {}, opts = {}) request( method: :delete, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your invoice items. Invoice items are returned sorted by creation date, with the most recently created invoice items appearing first.
483 484 485 486 487 488 489 490 491 |
# File 'lib/stripe/services/invoice_item_service.rb', line 483 def list(params = {}, opts = {}) request( method: :get, path: "/v1/invoiceitems", params: params, opts: opts, base_address: :api ) end |
#retrieve(invoiceitem, params = {}, opts = {}) ⇒ Object
Retrieves the invoice item with the given ID.
494 495 496 497 498 499 500 501 502 |
# File 'lib/stripe/services/invoice_item_service.rb', line 494 def retrieve(invoiceitem, params = {}, opts = {}) request( method: :get, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts, base_address: :api ) end |
#update(invoiceitem, params = {}, opts = {}) ⇒ Object
Updates the amount or description of an invoice item on an upcoming invoice. Updating an invoice item is only possible before the invoice it’s attached to is closed.
505 506 507 508 509 510 511 512 513 |
# File 'lib/stripe/services/invoice_item_service.rb', line 505 def update(invoiceitem, params = {}, opts = {}) request( method: :post, path: format("/v1/invoiceitems/%<invoiceitem>s", { invoiceitem: CGI.escape(invoiceitem) }), params: params, opts: opts, base_address: :api ) end |