Class: Stripe::InvoiceItemService::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItemService::CreateParams::Discount
- Defined in:
- lib/stripe/services/invoice_item_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
262 263 264 265 266 267 |
# File 'lib/stripe/services/invoice_item_service.rb', line 262 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
254 255 256 |
# File 'lib/stripe/services/invoice_item_service.rb', line 254 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
256 257 258 |
# File 'lib/stripe/services/invoice_item_service.rb', line 256 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
258 259 260 |
# File 'lib/stripe/services/invoice_item_service.rb', line 258 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
260 261 262 |
# File 'lib/stripe/services/invoice_item_service.rb', line 260 def promotion_code @promotion_code end |