Class: Stripe::InvoiceItemService::CreateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_item_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



247
248
249
250
251
# File 'lib/stripe/services/invoice_item_service.rb', line 247

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



241
242
243
# File 'lib/stripe/services/invoice_item_service.rb', line 241

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



243
244
245
# File 'lib/stripe/services/invoice_item_service.rb', line 243

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



245
246
247
# File 'lib/stripe/services/invoice_item_service.rb', line 245

def type
  @type
end