Class: Stripe::InvoiceItemService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/invoice_item_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/stripe/services/invoice_item_service.rb', line 177

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  pending: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @pending = pending
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return invoice items that were created during the given date interval.



161
162
163
# File 'lib/stripe/services/invoice_item_service.rb', line 161

def created
  @created
end

#customerObject

The identifier of the customer whose invoice items to return. If none is provided, all invoice items will be returned.



163
164
165
# File 'lib/stripe/services/invoice_item_service.rb', line 163

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



165
166
167
# File 'lib/stripe/services/invoice_item_service.rb', line 165

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



167
168
169
# File 'lib/stripe/services/invoice_item_service.rb', line 167

def expand
  @expand
end

#invoiceObject

Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.



169
170
171
# File 'lib/stripe/services/invoice_item_service.rb', line 169

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



171
172
173
# File 'lib/stripe/services/invoice_item_service.rb', line 171

def limit
  @limit
end

#pendingObject

Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.



173
174
175
# File 'lib/stripe/services/invoice_item_service.rb', line 173

def pending
  @pending
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



175
176
177
# File 'lib/stripe/services/invoice_item_service.rb', line 175

def starting_after
  @starting_after
end