Class: Stripe::InvoiceItemService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItemService::ListParams
- Defined in:
- lib/stripe/services/invoice_item_service.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return invoice items that were created during the given date interval.
-
#customer ⇒ Object
The identifier of the customer whose invoice items to return.
-
#customer_account ⇒ Object
The identifier of the account whose invoice items to return.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
Only return invoice items belonging to this invoice.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#pending ⇒ Object
Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices.
-
#starting_after ⇒ Object
A cursor for use in pagination.
Instance Method Summary collapse
-
#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams
Returns a new instance of ListParams.
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/stripe/services/invoice_item_service.rb', line 211 def initialize( created: nil, customer: nil, customer_account: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil ) @created = created @customer = customer @customer_account = customer_account @ending_before = ending_before @expand = @invoice = invoice @limit = limit @pending = pending @starting_after = starting_after end |
Instance Attribute Details
#created ⇒ Object
Only return invoice items that were created during the given date interval.
193 194 195 |
# File 'lib/stripe/services/invoice_item_service.rb', line 193 def created @created end |
#customer ⇒ Object
The identifier of the customer whose invoice items to return. If none is provided, all invoice items will be returned.
195 196 197 |
# File 'lib/stripe/services/invoice_item_service.rb', line 195 def customer @customer end |
#customer_account ⇒ Object
The identifier of the account whose invoice items to return. If none is provided, all invoice items will be returned.
197 198 199 |
# File 'lib/stripe/services/invoice_item_service.rb', line 197 def customer_account @customer_account end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
199 200 201 |
# File 'lib/stripe/services/invoice_item_service.rb', line 199 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
201 202 203 |
# File 'lib/stripe/services/invoice_item_service.rb', line 201 def @expand end |
#invoice ⇒ Object
Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.
203 204 205 |
# File 'lib/stripe/services/invoice_item_service.rb', line 203 def invoice @invoice end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
205 206 207 |
# File 'lib/stripe/services/invoice_item_service.rb', line 205 def limit @limit end |
#pending ⇒ Object
Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.
207 208 209 |
# File 'lib/stripe/services/invoice_item_service.rb', line 207 def pending @pending end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
209 210 211 |
# File 'lib/stripe/services/invoice_item_service.rb', line 209 def starting_after @starting_after end |