Class: Stripe::InvoiceItemService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/invoice_item_service.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, customer: nil, ending_before: nil, expand: nil, invoice: nil, limit: nil, pending: nil, starting_after: nil) ⇒ ListParams

Returns a new instance of ListParams.



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/stripe/services/invoice_item_service.rb', line 205

def initialize(
  created: nil,
  customer: nil,
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  pending: nil,
  starting_after: nil
)
  @created = created
  @customer = customer
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @pending = pending
  @starting_after = starting_after
end

Instance Attribute Details

#createdObject

Only return invoice items that were created during the given date interval.



189
190
191
# File 'lib/stripe/services/invoice_item_service.rb', line 189

def created
  @created
end

#customerObject

The identifier of the customer whose invoice items to return. If none is provided, all invoice items will be returned.



191
192
193
# File 'lib/stripe/services/invoice_item_service.rb', line 191

def customer
  @customer
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



193
194
195
# File 'lib/stripe/services/invoice_item_service.rb', line 193

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



195
196
197
# File 'lib/stripe/services/invoice_item_service.rb', line 195

def expand
  @expand
end

#invoiceObject

Only return invoice items belonging to this invoice. If none is provided, all invoice items will be returned. If specifying an invoice, no customer identifier is needed.



197
198
199
# File 'lib/stripe/services/invoice_item_service.rb', line 197

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



199
200
201
# File 'lib/stripe/services/invoice_item_service.rb', line 199

def limit
  @limit
end

#pendingObject

Set to ‘true` to only show pending invoice items, which are not yet attached to any invoices. Set to `false` to only show invoice items already attached to invoices. If unspecified, no filter is applied.



201
202
203
# File 'lib/stripe/services/invoice_item_service.rb', line 201

def pending
  @pending
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



203
204
205
# File 'lib/stripe/services/invoice_item_service.rb', line 203

def starting_after
  @starting_after
end