Class: Stripe::InvoiceItemService::UpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItemService::UpdateParams::Discount
- Defined in:
- lib/stripe/services/invoice_item_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
26 27 28 29 30 |
# File 'lib/stripe/services/invoice_item_service.rb', line 26 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
20 21 22 |
# File 'lib/stripe/services/invoice_item_service.rb', line 20 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
22 23 24 |
# File 'lib/stripe/services/invoice_item_service.rb', line 22 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
24 25 26 |
# File 'lib/stripe/services/invoice_item_service.rb', line 24 def promotion_code @promotion_code end |