Class: Stripe::InvoiceItemService::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_item_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



60
61
62
63
64
65
# File 'lib/stripe/services/invoice_item_service.rb', line 60

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



49
50
51
# File 'lib/stripe/services/invoice_item_service.rb', line 49

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



52
53
54
# File 'lib/stripe/services/invoice_item_service.rb', line 52

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



55
56
57
# File 'lib/stripe/services/invoice_item_service.rb', line 55

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



58
59
60
# File 'lib/stripe/services/invoice_item_service.rb', line 58

def promotion_code
  @promotion_code
end