Class: Stripe::InvoiceItemUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_item_update_params.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, quantity_decimal: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ InvoiceItemUpdateParams

Returns a new instance of InvoiceItemUpdateParams.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/stripe/params/invoice_item_update_params.rb', line 133

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  quantity_decimal: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @margins = margins
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @quantity_decimal = quantity_decimal
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



101
102
103
# File 'lib/stripe/params/invoice_item_update_params.rb', line 101

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



103
104
105
# File 'lib/stripe/params/invoice_item_update_params.rb', line 103

def description
  @description
end

#discountableObject

Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.



105
106
107
# File 'lib/stripe/params/invoice_item_update_params.rb', line 105

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



107
108
109
# File 'lib/stripe/params/invoice_item_update_params.rb', line 107

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



109
110
111
# File 'lib/stripe/params/invoice_item_update_params.rb', line 109

def expand
  @expand
end

#marginsObject

The ids of the margins to apply to the invoice item. When set, the ‘default_margins` on the invoice do not apply to this invoice item.



111
112
113
# File 'lib/stripe/params/invoice_item_update_params.rb', line 111

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



113
114
115
# File 'lib/stripe/params/invoice_item_update_params.rb', line 113

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](docs.stripe.com/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](docs.stripe.com/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



115
116
117
# File 'lib/stripe/params/invoice_item_update_params.rb', line 115

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.



117
118
119
# File 'lib/stripe/params/invoice_item_update_params.rb', line 117

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



119
120
121
# File 'lib/stripe/params/invoice_item_update_params.rb', line 119

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item. Use ‘quantity_decimal` instead to provide decimal precision. This field will be deprecated in favor of `quantity_decimal` in a future version.



121
122
123
# File 'lib/stripe/params/invoice_item_update_params.rb', line 121

def quantity
  @quantity
end

#quantity_decimalObject

Non-negative decimal with at most 12 decimal places. The quantity of units for the line item.



123
124
125
# File 'lib/stripe/params/invoice_item_update_params.rb', line 123

def quantity_decimal
  @quantity_decimal
end

#tax_behaviorObject

Only required if a [default tax behavior](docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



125
126
127
# File 'lib/stripe/params/invoice_item_update_params.rb', line 125

def tax_behavior
  @tax_behavior
end

#tax_codeObject



127
128
129
# File 'lib/stripe/params/invoice_item_update_params.rb', line 127

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.



129
130
131
# File 'lib/stripe/params/invoice_item_update_params.rb', line 129

def tax_rates
  @tax_rates
end

#unit_amount_decimalObject

The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This ‘unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.



131
132
133
# File 'lib/stripe/params/invoice_item_update_params.rb', line 131

def unit_amount_decimal
  @unit_amount_decimal
end

Class Method Details

.field_encodingsObject



169
170
171
172
173
174
175
# File 'lib/stripe/params/invoice_item_update_params.rb', line 169

def self.field_encodings
  @field_encodings = {
    price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } },
    quantity_decimal: :decimal_string,
    unit_amount_decimal: :decimal_string,
  }
end