Class: Stripe::InvoiceItemUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceItemUpdateParams
- Defined in:
- lib/stripe/params/invoice_item_update_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData, Pricing
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#margins ⇒ Object
The ids of the margins to apply to the invoice item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#pricing ⇒ Object
The pricing information for the invoice item.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
-
#tax_rates ⇒ Object
The tax rates which apply to the invoice item.
-
#unit_amount_decimal ⇒ Object
The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ InvoiceItemUpdateParams
constructor
A new instance of InvoiceItemUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil) ⇒ InvoiceItemUpdateParams
Returns a new instance of InvoiceItemUpdateParams.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 127 def initialize( amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount_decimal: nil ) @amount = amount @description = description @discountable = discountable @discounts = discounts @expand = @margins = margins @metadata = @period = period @price_data = price_data @pricing = pricing @quantity = quantity @tax_behavior = tax_behavior @tax_code = tax_code @tax_rates = tax_rates @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.
97 98 99 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 97 def amount @amount end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
99 100 101 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 99 def description @description end |
#discountable ⇒ Object
Controls whether discounts apply to this invoice item. Defaults to false for prorations or negative invoice items, and true for all other invoice items. Cannot be set to true for prorations.
101 102 103 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 101 def discountable @discountable end |
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the invoice item or invoice line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.
103 104 105 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 103 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
105 106 107 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 105 def @expand end |
#margins ⇒ Object
The ids of the margins to apply to the invoice item. When set, the ‘default_margins` on the invoice do not apply to this invoice item.
107 108 109 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 107 def margins @margins end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
109 110 111 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 109 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](docs.stripe.com/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](docs.stripe.com/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
111 112 113 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 111 def period @period end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
113 114 115 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 113 def price_data @price_data end |
#pricing ⇒ Object
The pricing information for the invoice item.
115 116 117 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 115 def pricing @pricing end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the invoice item.
117 118 119 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 117 def quantity @quantity end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](docs.stripe.com/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
119 120 121 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 119 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
121 122 123 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 121 def tax_code @tax_code end |
#tax_rates ⇒ Object
The tax rates which apply to the invoice item. When set, the ‘default_tax_rates` on the invoice do not apply to this invoice item. Pass an empty string to remove previously-defined tax rates.
123 124 125 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 123 def tax_rates @tax_rates end |
#unit_amount_decimal ⇒ Object
The decimal unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This ‘unit_amount_decimal` will be multiplied by the quantity to get the full amount. Passing in a negative `unit_amount_decimal` will reduce the `amount_due` on the invoice. Accepts at most 12 decimal places.
125 126 127 |
# File 'lib/stripe/params/invoice_item_update_params.rb', line 125 def unit_amount_decimal @unit_amount_decimal end |