Class: Stripe::InvoiceLineItem::Tax

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Defined Under Namespace

Classes: TaxRateDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the tax, in cents (or local equivalent).



381
382
383
# File 'lib/stripe/resources/invoice_line_item.rb', line 381

def amount
  @amount
end

#tax_behaviorObject (readonly)

Whether this tax is inclusive or exclusive.



383
384
385
# File 'lib/stripe/resources/invoice_line_item.rb', line 383

def tax_behavior
  @tax_behavior
end

#tax_rate_detailsObject (readonly)

Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.



385
386
387
# File 'lib/stripe/resources/invoice_line_item.rb', line 385

def tax_rate_details
  @tax_rate_details
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



387
388
389
# File 'lib/stripe/resources/invoice_line_item.rb', line 387

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



389
390
391
# File 'lib/stripe/resources/invoice_line_item.rb', line 389

def taxable_amount
  @taxable_amount
end

#typeObject (readonly)

The type of tax information.



391
392
393
# File 'lib/stripe/resources/invoice_line_item.rb', line 391

def type
  @type
end

Class Method Details

.field_remappingsObject



397
398
399
# File 'lib/stripe/resources/invoice_line_item.rb', line 397

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



393
394
395
# File 'lib/stripe/resources/invoice_line_item.rb', line 393

def self.inner_class_types
  @inner_class_types = { tax_rate_details: TaxRateDetails }
end