Class: Stripe::InvoiceLineItem::Tax
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::InvoiceLineItem::Tax
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Defined Under Namespace
Classes: TaxRateDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount of the tax, in cents (or local equivalent).
-
#tax_behavior ⇒ Object
readonly
Whether this tax is inclusive or exclusive.
-
#tax_rate_details ⇒ Object
readonly
Additional details about the tax rate.
-
#taxability_reason ⇒ Object
readonly
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
readonly
The amount on which tax is calculated, in cents (or local equivalent).
-
#type ⇒ Object
readonly
The type of tax information.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount of the tax, in cents (or local equivalent).
253 254 255 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 253 def amount @amount end |
#tax_behavior ⇒ Object (readonly)
Whether this tax is inclusive or exclusive.
255 256 257 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 255 def tax_behavior @tax_behavior end |
#tax_rate_details ⇒ Object (readonly)
Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.
257 258 259 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 257 def tax_rate_details @tax_rate_details end |
#taxability_reason ⇒ Object (readonly)
The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
259 260 261 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 259 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object (readonly)
The amount on which tax is calculated, in cents (or local equivalent).
261 262 263 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 261 def taxable_amount @taxable_amount end |
#type ⇒ Object (readonly)
The type of tax information.
263 264 265 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 263 def type @type end |
Class Method Details
.field_remappings ⇒ Object
269 270 271 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 269 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
265 266 267 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 265 def self.inner_class_types @inner_class_types = { tax_rate_details: TaxRateDetails } end |