Class: Stripe::InvoiceLineItem::Tax

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Defined Under Namespace

Classes: TaxRateDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The amount of the tax, in cents (or local equivalent).



130
131
132
# File 'lib/stripe/resources/invoice_line_item.rb', line 130

def amount
  @amount
end

#tax_behaviorObject (readonly)

Whether this tax is inclusive or exclusive.



132
133
134
# File 'lib/stripe/resources/invoice_line_item.rb', line 132

def tax_behavior
  @tax_behavior
end

#tax_rate_detailsObject (readonly)

Additional details about the tax rate. Only present when ‘type` is `tax_rate_details`.



134
135
136
# File 'lib/stripe/resources/invoice_line_item.rb', line 134

def tax_rate_details
  @tax_rate_details
end

#taxability_reasonObject (readonly)

The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.



136
137
138
# File 'lib/stripe/resources/invoice_line_item.rb', line 136

def taxability_reason
  @taxability_reason
end

#taxable_amountObject (readonly)

The amount on which tax is calculated, in cents (or local equivalent).



138
139
140
# File 'lib/stripe/resources/invoice_line_item.rb', line 138

def taxable_amount
  @taxable_amount
end

#typeObject (readonly)

The type of tax information.



140
141
142
# File 'lib/stripe/resources/invoice_line_item.rb', line 140

def type
  @type
end