Class: Stripe::InvoiceLineItem::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/stripe/resources/invoice_line_item.rb', line 568

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @margins = margins
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



542
543
544
# File 'lib/stripe/resources/invoice_line_item.rb', line 542

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



544
545
546
# File 'lib/stripe/resources/invoice_line_item.rb', line 544

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



546
547
548
# File 'lib/stripe/resources/invoice_line_item.rb', line 546

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



548
549
550
# File 'lib/stripe/resources/invoice_line_item.rb', line 548

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



550
551
552
# File 'lib/stripe/resources/invoice_line_item.rb', line 550

def expand
  @expand
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



552
553
554
# File 'lib/stripe/resources/invoice_line_item.rb', line 552

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.



554
555
556
# File 'lib/stripe/resources/invoice_line_item.rb', line 554

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



556
557
558
# File 'lib/stripe/resources/invoice_line_item.rb', line 556

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



558
559
560
# File 'lib/stripe/resources/invoice_line_item.rb', line 558

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



560
561
562
# File 'lib/stripe/resources/invoice_line_item.rb', line 560

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



562
563
564
# File 'lib/stripe/resources/invoice_line_item.rb', line 562

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



564
565
566
# File 'lib/stripe/resources/invoice_line_item.rb', line 564

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



566
567
568
# File 'lib/stripe/resources/invoice_line_item.rb', line 566

def tax_rates
  @tax_rates
end