Class: Stripe::InvoiceLineItem::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItem::UpdateParams
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Defined Under Namespace
Classes: Discount, Period, PriceData, Pricing, TaxAmount
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Controls whether discounts apply to this line item.
-
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#margins ⇒ Object
The IDs of the margins to apply to the line item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#pricing ⇒ Object
The pricing information for the invoice item.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 399 def initialize( amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil ) @amount = amount @description = description @discountable = discountable @discounts = discounts @expand = @margins = margins @metadata = @period = period @price_data = price_data @pricing = pricing @quantity = quantity @tax_amounts = tax_amounts @tax_rates = tax_rates end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.
373 374 375 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 373 def amount @amount end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
375 376 377 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 375 def description @description end |
#discountable ⇒ Object
Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.
377 378 379 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 377 def discountable @discountable end |
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.
379 380 381 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 379 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
381 382 383 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 381 def @expand end |
#margins ⇒ Object
The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.
383 384 385 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 383 def margins @margins end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.
385 386 387 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 385 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
387 388 389 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 387 def period @period end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
389 390 391 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 389 def price_data @price_data end |
#pricing ⇒ Object
The pricing information for the invoice item.
391 392 393 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 391 def pricing @pricing end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the line item.
393 394 395 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 393 def quantity @quantity end |
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.
395 396 397 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 395 def tax_amounts @tax_amounts end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.
397 398 399 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 397 def tax_rates @tax_rates end |