Class: Stripe::InvoiceLineItem::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/stripe/resources/invoice_line_item.rb', line 311

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @margins = margins
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



273
274
275
# File 'lib/stripe/resources/invoice_line_item.rb', line 273

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



276
277
278
# File 'lib/stripe/resources/invoice_line_item.rb', line 276

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



279
280
281
# File 'lib/stripe/resources/invoice_line_item.rb', line 279

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



282
283
284
# File 'lib/stripe/resources/invoice_line_item.rb', line 282

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



285
286
287
# File 'lib/stripe/resources/invoice_line_item.rb', line 285

def expand
  @expand
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



288
289
290
# File 'lib/stripe/resources/invoice_line_item.rb', line 288

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.



291
292
293
# File 'lib/stripe/resources/invoice_line_item.rb', line 291

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



294
295
296
# File 'lib/stripe/resources/invoice_line_item.rb', line 294

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



297
298
299
# File 'lib/stripe/resources/invoice_line_item.rb', line 297

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



300
301
302
# File 'lib/stripe/resources/invoice_line_item.rb', line 300

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



303
304
305
# File 'lib/stripe/resources/invoice_line_item.rb', line 303

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



306
307
308
# File 'lib/stripe/resources/invoice_line_item.rb', line 306

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



309
310
311
# File 'lib/stripe/resources/invoice_line_item.rb', line 309

def tax_rates
  @tax_rates
end