Class: Stripe::InvoiceLineItem::UpdateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



110
111
112
113
114
115
# File 'lib/stripe/resources/invoice_line_item.rb', line 110

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



102
103
104
# File 'lib/stripe/resources/invoice_line_item.rb', line 102

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



104
105
106
# File 'lib/stripe/resources/invoice_line_item.rb', line 104

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



106
107
108
# File 'lib/stripe/resources/invoice_line_item.rb', line 106

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



108
109
110
# File 'lib/stripe/resources/invoice_line_item.rb', line 108

def promotion_code
  @promotion_code
end