Class: Stripe::InvoiceLineItem::UpdateParams::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItem::UpdateParams::PriceData::ProductData
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
212 213 214 215 216 217 218 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 212 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
202 203 204 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 202 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
204 205 206 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 204 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
206 207 208 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 206 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
208 209 210 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 208 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
210 211 212 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 210 def tax_code @tax_code end |