Class: Stripe::InvoiceLineItem::UpdateParams::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItem::UpdateParams::PriceData::ProductData
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
143 144 145 146 147 148 149 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 143 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
133 134 135 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 133 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
135 136 137 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 135 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
137 138 139 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 137 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
139 140 141 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 139 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
141 142 143 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 141 def tax_code @tax_code end |