Class: Stripe::InvoiceLineItem::UpdateParams::TaxAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_line_item.rb

Defined Under Namespace

Classes: TaxRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount

Returns a new instance of TaxAmount.



229
230
231
232
233
# File 'lib/stripe/resources/invoice_line_item.rb', line 229

def initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil)
  @amount = amount
  @tax_rate_data = tax_rate_data
  @taxable_amount = taxable_amount
end

Instance Attribute Details

#amountObject

The amount, in cents (or local equivalent), of the tax.



221
222
223
# File 'lib/stripe/resources/invoice_line_item.rb', line 221

def amount
  @amount
end

#tax_rate_dataObject

Data to find or create a TaxRate object.

Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.



225
226
227
# File 'lib/stripe/resources/invoice_line_item.rb', line 225

def tax_rate_data
  @tax_rate_data
end

#taxable_amountObject

The amount on which tax is calculated, in cents (or local equivalent).



227
228
229
# File 'lib/stripe/resources/invoice_line_item.rb', line 227

def taxable_amount
  @taxable_amount
end