Class: Stripe::InvoiceLineItem::UpdateParams::TaxAmount::TaxRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItem::UpdateParams::TaxAmount::TaxRateData
- Defined in:
- lib/stripe/resources/invoice_line_item.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#percentage ⇒ Object
The statutory tax rate percent.
-
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
Instance Method Summary collapse
-
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
constructor
A new instance of TaxRateData.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
Returns a new instance of TaxRateData.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 235 def initialize( country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil ) @country = country @description = description @display_name = display_name @inclusive = inclusive @jurisdiction = jurisdiction @percentage = percentage @state = state @tax_type = tax_type end |
Instance Attribute Details
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
212 213 214 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 212 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
215 216 217 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 215 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
218 219 220 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 218 def display_name @display_name end |
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
221 222 223 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 221 def inclusive @inclusive end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
224 225 226 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 224 def jurisdiction @jurisdiction end |
#percentage ⇒ Object
The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.
227 228 229 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 227 def percentage @percentage end |
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.
230 231 232 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 230 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
233 234 235 |
# File 'lib/stripe/resources/invoice_line_item.rb', line 233 def tax_type @tax_type end |