Class: Stripe::InvoiceLineItemService::UpdateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_line_item_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, expand: nil, margins: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/stripe/services/invoice_line_item_service.rb', line 252

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  expand: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @expand = expand
  @margins = margins
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



214
215
216
# File 'lib/stripe/services/invoice_line_item_service.rb', line 214

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



217
218
219
# File 'lib/stripe/services/invoice_line_item_service.rb', line 217

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



220
221
222
# File 'lib/stripe/services/invoice_line_item_service.rb', line 220

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



223
224
225
# File 'lib/stripe/services/invoice_line_item_service.rb', line 223

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



226
227
228
# File 'lib/stripe/services/invoice_line_item_service.rb', line 226

def expand
  @expand
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



229
230
231
# File 'lib/stripe/services/invoice_line_item_service.rb', line 229

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.



232
233
234
# File 'lib/stripe/services/invoice_line_item_service.rb', line 232

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



235
236
237
# File 'lib/stripe/services/invoice_line_item_service.rb', line 235

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



238
239
240
# File 'lib/stripe/services/invoice_line_item_service.rb', line 238

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



241
242
243
# File 'lib/stripe/services/invoice_line_item_service.rb', line 241

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



244
245
246
# File 'lib/stripe/services/invoice_line_item_service.rb', line 244

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



247
248
249
# File 'lib/stripe/services/invoice_line_item_service.rb', line 247

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



250
251
252
# File 'lib/stripe/services/invoice_line_item_service.rb', line 250

def tax_rates
  @tax_rates
end