Class: Stripe::InvoiceLineItemService::UpdateParams::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItemService::UpdateParams::TaxAmount
- Defined in:
- lib/stripe/services/invoice_line_item_service.rb
Defined Under Namespace
Classes: TaxRateData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
179 180 181 182 183 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 179 def initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) @amount = amount @tax_rate_data = tax_rate_data @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
171 172 173 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 171 def amount @amount end |
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.
175 176 177 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 175 def tax_rate_data @tax_rate_data end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
177 178 179 |
# File 'lib/stripe/services/invoice_line_item_service.rb', line 177 def taxable_amount @taxable_amount end |