Class: Stripe::InvoiceLineItemUpdateParams::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceLineItemUpdateParams::TaxAmount
- Defined in:
- lib/stripe/params/invoice_line_item_update_params.rb
Defined Under Namespace
Classes: TaxRateData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
-
#taxability_reason ⇒ Object
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
204 205 206 207 208 209 |
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 204 def initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) @amount = amount @tax_rate_data = tax_rate_data @taxability_reason = taxability_reason @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
194 195 196 |
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 194 def amount @amount end |
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.
198 199 200 |
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 198 def tax_rate_data @tax_rate_data end |
#taxability_reason ⇒ Object
The reasoning behind this tax, for example, if the product is tax exempt.
200 201 202 |
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 200 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
202 203 204 |
# File 'lib/stripe/params/invoice_line_item_update_params.rb', line 202 def taxable_amount @taxable_amount end |