Class: Stripe::InvoiceListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceListParams
- Defined in:
- lib/stripe/params/invoice_list_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Object
Only return invoices for the cadence specified by this billing cadence ID.
-
#collection_method ⇒ Object
The collection method of the invoice to retrieve.
-
#created ⇒ Object
Only return invoices that were created during the given date interval.
-
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
-
#customer_account ⇒ Object
Only return invoices for the account representing the customer specified by this account ID.
-
#due_date ⇒ Object
Attribute for param field due_date.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`.
-
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
Instance Method Summary collapse
-
#initialize(billing_cadence: nil, collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ InvoiceListParams
constructor
A new instance of InvoiceListParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(billing_cadence: nil, collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ InvoiceListParams
Returns a new instance of InvoiceListParams.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/stripe/params/invoice_list_params.rb', line 66 def initialize( billing_cadence: nil, collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil ) @billing_cadence = billing_cadence @collection_method = collection_method @created = created @customer = customer @customer_account = customer_account @due_date = due_date @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#billing_cadence ⇒ Object
Only return invoices for the cadence specified by this billing cadence ID.
42 43 44 |
# File 'lib/stripe/params/invoice_list_params.rb', line 42 def billing_cadence @billing_cadence end |
#collection_method ⇒ Object
The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.
44 45 46 |
# File 'lib/stripe/params/invoice_list_params.rb', line 44 def collection_method @collection_method end |
#created ⇒ Object
Only return invoices that were created during the given date interval.
46 47 48 |
# File 'lib/stripe/params/invoice_list_params.rb', line 46 def created @created end |
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
48 49 50 |
# File 'lib/stripe/params/invoice_list_params.rb', line 48 def customer @customer end |
#customer_account ⇒ Object
Only return invoices for the account representing the customer specified by this account ID.
50 51 52 |
# File 'lib/stripe/params/invoice_list_params.rb', line 50 def customer_account @customer_account end |
#due_date ⇒ Object
Attribute for param field due_date
52 53 54 |
# File 'lib/stripe/params/invoice_list_params.rb', line 52 def due_date @due_date end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
54 55 56 |
# File 'lib/stripe/params/invoice_list_params.rb', line 54 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
56 57 58 |
# File 'lib/stripe/params/invoice_list_params.rb', line 56 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
58 59 60 |
# File 'lib/stripe/params/invoice_list_params.rb', line 58 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
60 61 62 |
# File 'lib/stripe/params/invoice_list_params.rb', line 60 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](docs.stripe.com/billing/invoices/workflow#workflow-overview)
62 63 64 |
# File 'lib/stripe/params/invoice_list_params.rb', line 62 def status @status end |
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
64 65 66 |
# File 'lib/stripe/params/invoice_list_params.rb', line 64 def subscription @subscription end |