Class: Stripe::InvoicePayment

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/invoice_payment.rb

Overview

Invoice Payments represent payments made against invoices. Invoice Payments can be accessed in two ways:

  1. By expanding the ‘payments` field on the [Invoice](stripe.com/docs/api#invoice) resource.

  2. By using the Invoice Payment retrieve and list endpoints.

Invoice Payments include the mapping between payment objects, such as Payment Intent, and Invoices. This resource and its endpoints allows you to easily track if a payment is associated with a specific invoice and monitor the allocation details of the payments.

Defined Under Namespace

Classes: Payment, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"invoice_payment"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_paidObject (readonly)

Amount that was actually paid for this invoice, in cents (or local equivalent). This field is null until the payment is ‘paid`. This amount can be less than the `amount_requested` if the PaymentIntent’s `amount_received` is not sufficient to pay all of the invoices that it is attached to.



37
38
39
# File 'lib/stripe/resources/invoice_payment.rb', line 37

def amount_paid
  @amount_paid
end

#amount_requestedObject (readonly)

Amount intended to be paid toward this invoice, in cents (or local equivalent)



39
40
41
# File 'lib/stripe/resources/invoice_payment.rb', line 39

def amount_requested
  @amount_requested
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



41
42
43
# File 'lib/stripe/resources/invoice_payment.rb', line 41

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



43
44
45
# File 'lib/stripe/resources/invoice_payment.rb', line 43

def currency
  @currency
end

#idObject (readonly)

Unique identifier for the object.



45
46
47
# File 'lib/stripe/resources/invoice_payment.rb', line 45

def id
  @id
end

#invoiceObject (readonly)

The invoice that was paid.



47
48
49
# File 'lib/stripe/resources/invoice_payment.rb', line 47

def invoice
  @invoice
end

#is_defaultObject (readonly)

Stripe automatically creates a default InvoicePayment when the invoice is finalized, and keeps it synchronized with the invoice’s ‘amount_remaining`. The PaymentIntent associated with the default payment can’t be edited or canceled directly.



49
50
51
# File 'lib/stripe/resources/invoice_payment.rb', line 49

def is_default
  @is_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



51
52
53
# File 'lib/stripe/resources/invoice_payment.rb', line 51

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



53
54
55
# File 'lib/stripe/resources/invoice_payment.rb', line 53

def object
  @object
end

#paymentObject (readonly)

Attribute for field payment



55
56
57
# File 'lib/stripe/resources/invoice_payment.rb', line 55

def payment
  @payment
end

#statusObject (readonly)

The status of the payment, one of ‘open`, `paid`, or `canceled`.



57
58
59
# File 'lib/stripe/resources/invoice_payment.rb', line 57

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



59
60
61
# File 'lib/stripe/resources/invoice_payment.rb', line 59

def status_transitions
  @status_transitions
end

Class Method Details

.object_nameObject



15
16
17
# File 'lib/stripe/resources/invoice_payment.rb', line 15

def self.object_name
  "invoice_payment"
end