Class: Stripe::InvoicePayment

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/invoice_payment.rb

Overview

Invoice Payments represent payments made against invoices. Invoice Payments can be accessed in two ways:

  1. By expanding the ‘payments` field on the [Invoice](stripe.com/docs/api#invoice) resource.

  2. By using the Invoice Payment retrieve and list endpoints.

Invoice Payments include the mapping between payment objects, such as Payment Intent, and Invoices. This resource and its endpoints allows you to easily track if a payment is associated with a specific invoice and monitor the allocation details of the payments.

Defined Under Namespace

Classes: ListParams, Payment, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"invoice_payment"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_paidObject (readonly)

Amount that was actually paid for this invoice, in cents (or local equivalent). This field is null until the payment is ‘paid`. This amount can be less than the `amount_requested` if the PaymentIntent’s `amount_received` is not sufficient to pay all of the invoices that it is attached to.



83
84
85
# File 'lib/stripe/resources/invoice_payment.rb', line 83

def amount_paid
  @amount_paid
end

#amount_requestedObject (readonly)

Amount intended to be paid toward this invoice, in cents (or local equivalent)



85
86
87
# File 'lib/stripe/resources/invoice_payment.rb', line 85

def amount_requested
  @amount_requested
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



87
88
89
# File 'lib/stripe/resources/invoice_payment.rb', line 87

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



89
90
91
# File 'lib/stripe/resources/invoice_payment.rb', line 89

def currency
  @currency
end

#idObject (readonly)

Unique identifier for the object.



91
92
93
# File 'lib/stripe/resources/invoice_payment.rb', line 91

def id
  @id
end

#invoiceObject (readonly)

The invoice that was paid.



93
94
95
# File 'lib/stripe/resources/invoice_payment.rb', line 93

def invoice
  @invoice
end

#is_defaultObject (readonly)

Stripe automatically creates a default InvoicePayment when the invoice is finalized, and keeps it synchronized with the invoice’s ‘amount_remaining`. The PaymentIntent associated with the default payment can’t be edited or canceled directly.



95
96
97
# File 'lib/stripe/resources/invoice_payment.rb', line 95

def is_default
  @is_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



97
98
99
# File 'lib/stripe/resources/invoice_payment.rb', line 97

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



99
100
101
# File 'lib/stripe/resources/invoice_payment.rb', line 99

def object
  @object
end

#paymentObject (readonly)

Attribute for field payment



101
102
103
# File 'lib/stripe/resources/invoice_payment.rb', line 101

def payment
  @payment
end

#statusObject (readonly)

The status of the payment, one of ‘open`, `paid`, or `canceled`.



103
104
105
# File 'lib/stripe/resources/invoice_payment.rb', line 103

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



105
106
107
# File 'lib/stripe/resources/invoice_payment.rb', line 105

def status_transitions
  @status_transitions
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

When retrieving an invoice, there is an includable payments property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of payments.



108
109
110
# File 'lib/stripe/resources/invoice_payment.rb', line 108

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/invoice_payments", params: params, opts: opts)
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/invoice_payment.rb', line 17

def self.object_name
  "invoice_payment"
end