Class: Stripe::InvoicePayment
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::InvoicePayment
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/invoice_payment.rb
Overview
The invoice payment object
Defined Under Namespace
Classes: ListParams, Payment, StatusTransitions
Constant Summary collapse
- OBJECT_NAME =
"invoice_payment"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_paid ⇒ Object
readonly
Amount that was actually paid for this invoice, in cents (or local equivalent).
-
#amount_requested ⇒ Object
readonly
Amount intended to be paid toward this invoice, in cents (or local equivalent).
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#invoice ⇒ Object
readonly
The invoice that was paid.
-
#is_default ⇒ Object
readonly
Stripe automatically creates a default InvoicePayment when the invoice is finalized, and keeps it synchronized with the invoice’s ‘amount_remaining`.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment ⇒ Object
readonly
Attribute for field payment.
-
#status ⇒ Object
readonly
The status of the payment, one of ‘open`, `paid`, or `canceled`.
-
#status_transitions ⇒ Object
readonly
Attribute for field status_transitions.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(params = {}, opts = {}) ⇒ Object
When retrieving an invoice, there is an includable payments property containing the first handful of those items.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_paid ⇒ Object (readonly)
Amount that was actually paid for this invoice, in cents (or local equivalent). This field is null until the payment is ‘paid`. This amount can be less than the `amount_requested` if the PaymentIntent’s `amount_received` is not sufficient to pay all of the invoices that it is attached to.
76 77 78 |
# File 'lib/stripe/resources/invoice_payment.rb', line 76 def amount_paid @amount_paid end |
#amount_requested ⇒ Object (readonly)
Amount intended to be paid toward this invoice, in cents (or local equivalent)
78 79 80 |
# File 'lib/stripe/resources/invoice_payment.rb', line 78 def amount_requested @amount_requested end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
80 81 82 |
# File 'lib/stripe/resources/invoice_payment.rb', line 80 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
82 83 84 |
# File 'lib/stripe/resources/invoice_payment.rb', line 82 def currency @currency end |
#id ⇒ Object (readonly)
Unique identifier for the object.
84 85 86 |
# File 'lib/stripe/resources/invoice_payment.rb', line 84 def id @id end |
#invoice ⇒ Object (readonly)
The invoice that was paid.
86 87 88 |
# File 'lib/stripe/resources/invoice_payment.rb', line 86 def invoice @invoice end |
#is_default ⇒ Object (readonly)
Stripe automatically creates a default InvoicePayment when the invoice is finalized, and keeps it synchronized with the invoice’s ‘amount_remaining`. The PaymentIntent associated with the default payment can’t be edited or canceled directly.
88 89 90 |
# File 'lib/stripe/resources/invoice_payment.rb', line 88 def is_default @is_default end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
90 91 92 |
# File 'lib/stripe/resources/invoice_payment.rb', line 90 def livemode @livemode end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
92 93 94 |
# File 'lib/stripe/resources/invoice_payment.rb', line 92 def object @object end |
#payment ⇒ Object (readonly)
Attribute for field payment
94 95 96 |
# File 'lib/stripe/resources/invoice_payment.rb', line 94 def payment @payment end |
#status ⇒ Object (readonly)
The status of the payment, one of ‘open`, `paid`, or `canceled`.
96 97 98 |
# File 'lib/stripe/resources/invoice_payment.rb', line 96 def status @status end |
#status_transitions ⇒ Object (readonly)
Attribute for field status_transitions
98 99 100 |
# File 'lib/stripe/resources/invoice_payment.rb', line 98 def status_transitions @status_transitions end |
Class Method Details
.list(params = {}, opts = {}) ⇒ Object
When retrieving an invoice, there is an includable payments property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of payments.
101 102 103 |
# File 'lib/stripe/resources/invoice_payment.rb', line 101 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/invoice_payments", params: params, opts: opts) end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/invoice_payment.rb', line 10 def self.object_name "invoice_payment" end |