Class: Stripe::InvoicePayment

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/invoice_payment.rb

Overview

The invoice payment object

Defined Under Namespace

Classes: Payment, StatusTransitions

Constant Summary collapse

OBJECT_NAME =
"invoice_payment"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_overpaidObject (readonly)

Excess payment that was received for this invoice and credited to the customer’s ‘invoice_credit_balance`. This field is null until the payment is `paid`. Overpayment can happen when you attach more than one PaymentIntent to the invoice, and each of them succeeds. To avoid overpayment, cancel any PaymentIntents that you do not need before attaching more.



34
35
36
# File 'lib/stripe/resources/invoice_payment.rb', line 34

def amount_overpaid
  @amount_overpaid
end

#amount_paidObject (readonly)

Amount that was actually paid for this invoice, in cents (or local equivalent). This field is null until the payment is ‘paid`. This amount can be less than the `amount_requested` if the PaymentIntent’s `amount_received` is not sufficient to pay all of the invoices that it is attached to.



37
38
39
# File 'lib/stripe/resources/invoice_payment.rb', line 37

def amount_paid
  @amount_paid
end

#amount_requestedObject (readonly)

Amount intended to be paid toward this invoice, in cents (or local equivalent)



40
41
42
# File 'lib/stripe/resources/invoice_payment.rb', line 40

def amount_requested
  @amount_requested
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



43
44
45
# File 'lib/stripe/resources/invoice_payment.rb', line 43

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



46
47
48
# File 'lib/stripe/resources/invoice_payment.rb', line 46

def currency
  @currency
end

#idObject (readonly)

Unique identifier for the object.



49
50
51
# File 'lib/stripe/resources/invoice_payment.rb', line 49

def id
  @id
end

#invoiceObject (readonly)

The invoice that was paid.



52
53
54
# File 'lib/stripe/resources/invoice_payment.rb', line 52

def invoice
  @invoice
end

#is_defaultObject (readonly)

Stripe automatically creates a default InvoicePayment when the invoice is finalized, and keeps it synchronized with the invoice’s ‘amount_remaining`. The PaymentIntent associated with the default payment can’t be edited or canceled directly.



55
56
57
# File 'lib/stripe/resources/invoice_payment.rb', line 55

def is_default
  @is_default
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



58
59
60
# File 'lib/stripe/resources/invoice_payment.rb', line 58

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



61
62
63
# File 'lib/stripe/resources/invoice_payment.rb', line 61

def object
  @object
end

#paymentObject (readonly)

Attribute for field payment



64
65
66
# File 'lib/stripe/resources/invoice_payment.rb', line 64

def payment
  @payment
end

#statusObject (readonly)

The status of the payment, one of ‘open`, `paid`, or `canceled`.



67
68
69
# File 'lib/stripe/resources/invoice_payment.rb', line 67

def status
  @status
end

#status_transitionsObject (readonly)

Attribute for field status_transitions



70
71
72
# File 'lib/stripe/resources/invoice_payment.rb', line 70

def status_transitions
  @status_transitions
end

Class Method Details

.object_nameObject



8
9
10
# File 'lib/stripe/resources/invoice_payment.rb', line 8

def self.object_name
  "invoice_payment"
end