Class: Stripe::InvoicePayment::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoicePayment::ListParams
- Defined in:
- lib/stripe/resources/invoice_payment.rb
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
The identifier of the invoice whose payments to return.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment ⇒ Object
The payment details of the invoice payments to return.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice payments to return.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, invoice: nil, limit: nil, payment: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, invoice: nil, limit: nil, payment: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/stripe/resources/invoice_payment.rb', line 64 def initialize( ending_before: nil, expand: nil, invoice: nil, limit: nil, payment: nil, starting_after: nil, status: nil ) @ending_before = ending_before @expand = @invoice = invoice @limit = limit @payment = payment @starting_after = starting_after @status = status end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
50 51 52 |
# File 'lib/stripe/resources/invoice_payment.rb', line 50 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
52 53 54 |
# File 'lib/stripe/resources/invoice_payment.rb', line 52 def @expand end |
#invoice ⇒ Object
The identifier of the invoice whose payments to return.
54 55 56 |
# File 'lib/stripe/resources/invoice_payment.rb', line 54 def invoice @invoice end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
56 57 58 |
# File 'lib/stripe/resources/invoice_payment.rb', line 56 def limit @limit end |
#payment ⇒ Object
The payment details of the invoice payments to return.
58 59 60 |
# File 'lib/stripe/resources/invoice_payment.rb', line 58 def payment @payment end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
60 61 62 |
# File 'lib/stripe/resources/invoice_payment.rb', line 60 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice payments to return.
62 63 64 |
# File 'lib/stripe/resources/invoice_payment.rb', line 62 def status @status end |