Class: Stripe::InvoicePayment::ListParams::Payment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_payment.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment_intent: nil, payment_record: nil, type: nil) ⇒ Payment

Returns a new instance of Payment.



48
49
50
51
52
# File 'lib/stripe/resources/invoice_payment.rb', line 48

def initialize(payment_intent: nil, payment_record: nil, type: nil)
  @payment_intent = payment_intent
  @payment_record = payment_record
  @type = type
end

Instance Attribute Details

#payment_intentObject

Only return invoice payments associated by this payment intent ID.



42
43
44
# File 'lib/stripe/resources/invoice_payment.rb', line 42

def payment_intent
  @payment_intent
end

#payment_recordObject

Only return invoice payments associated by this payment record ID.



44
45
46
# File 'lib/stripe/resources/invoice_payment.rb', line 44

def payment_record
  @payment_record
end

#typeObject

Only return invoice payments associated by this payment type.



46
47
48
# File 'lib/stripe/resources/invoice_payment.rb', line 46

def type
  @type
end