Class: Stripe::InvoicePayment::ListParams::Payment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/invoice_payment.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment_intent: nil, type: nil) ⇒ Payment

Returns a new instance of Payment.



44
45
46
47
# File 'lib/stripe/resources/invoice_payment.rb', line 44

def initialize(payment_intent: nil, type: nil)
  @payment_intent = payment_intent
  @type = type
end

Instance Attribute Details

#payment_intentObject

Only return invoice payments associated by this payment intent ID.



40
41
42
# File 'lib/stripe/resources/invoice_payment.rb', line 40

def payment_intent
  @payment_intent
end

#typeObject

Only return invoice payments associated by this payment type.



42
43
44
# File 'lib/stripe/resources/invoice_payment.rb', line 42

def type
  @type
end