Class: Stripe::InvoicePayment::ListParams::Payment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoicePayment::ListParams::Payment
- Defined in:
- lib/stripe/resources/invoice_payment.rb
Instance Attribute Summary collapse
-
#payment_intent ⇒ Object
Only return invoice payments associated by this payment intent ID.
-
#type ⇒ Object
Only return invoice payments associated by this payment type.
Instance Method Summary collapse
-
#initialize(payment_intent: nil, type: nil) ⇒ Payment
constructor
A new instance of Payment.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_intent: nil, type: nil) ⇒ Payment
Returns a new instance of Payment.
37 38 39 40 |
# File 'lib/stripe/resources/invoice_payment.rb', line 37 def initialize(payment_intent: nil, type: nil) @payment_intent = payment_intent @type = type end |
Instance Attribute Details
#payment_intent ⇒ Object
Only return invoice payments associated by this payment intent ID.
33 34 35 |
# File 'lib/stripe/resources/invoice_payment.rb', line 33 def payment_intent @payment_intent end |
#type ⇒ Object
Only return invoice payments associated by this payment type.
35 36 37 |
# File 'lib/stripe/resources/invoice_payment.rb', line 35 def type @type end |