Class: Stripe::InvoicePaymentListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoicePaymentListParams
- Defined in:
- lib/stripe/params/invoice_payment_list_params.rb
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice ⇒ Object
The identifier of the invoice whose payments to return.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment ⇒ Object
The payment details of the invoice payments to return.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice payments to return.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, invoice: nil, limit: nil, payment: nil, starting_after: nil, status: nil) ⇒ InvoicePaymentListParams
constructor
A new instance of InvoicePaymentListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, invoice: nil, limit: nil, payment: nil, starting_after: nil, status: nil) ⇒ InvoicePaymentListParams
Returns a new instance of InvoicePaymentListParams.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 35 def initialize( ending_before: nil, expand: nil, invoice: nil, limit: nil, payment: nil, starting_after: nil, status: nil ) @ending_before = ending_before @expand = @invoice = invoice @limit = limit @payment = payment @starting_after = starting_after @status = status end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
21 22 23 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 21 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
23 24 25 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 23 def @expand end |
#invoice ⇒ Object
The identifier of the invoice whose payments to return.
25 26 27 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 25 def invoice @invoice end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
27 28 29 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 27 def limit @limit end |
#payment ⇒ Object
The payment details of the invoice payments to return.
29 30 31 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 29 def payment @payment end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
31 32 33 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 31 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice payments to return.
33 34 35 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 33 def status @status end |