Class: Stripe::InvoicePaymentListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_payment_list_params.rb

Defined Under Namespace

Classes: Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, invoice: nil, limit: nil, payment: nil, starting_after: nil, status: nil) ⇒ InvoicePaymentListParams

Returns a new instance of InvoicePaymentListParams.



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 32

def initialize(
  ending_before: nil,
  expand: nil,
  invoice: nil,
  limit: nil,
  payment: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @invoice = invoice
  @limit = limit
  @payment = payment
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



18
19
20
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 18

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



20
21
22
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 20

def expand
  @expand
end

#invoiceObject

The identifier of the invoice whose payments to return.



22
23
24
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 22

def invoice
  @invoice
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



24
25
26
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 24

def limit
  @limit
end

#paymentObject

The payment details of the invoice payments to return.



26
27
28
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 26

def payment
  @payment
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



28
29
30
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 28

def starting_after
  @starting_after
end

#statusObject

The status of the invoice payments to return.



30
31
32
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 30

def status
  @status
end