Class: Stripe::InvoicePaymentListParams::Payment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoicePaymentListParams::Payment
- Defined in:
- lib/stripe/params/invoice_payment_list_params.rb
Instance Attribute Summary collapse
-
#payment_intent ⇒ Object
Only return invoice payments associated by this payment intent ID.
-
#payment_record ⇒ Object
Only return invoice payments associated by this payment record ID.
-
#type ⇒ Object
Only return invoice payments associated by this payment type.
Instance Method Summary collapse
-
#initialize(payment_intent: nil, payment_record: nil, type: nil) ⇒ Payment
constructor
A new instance of Payment.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_intent: nil, payment_record: nil, type: nil) ⇒ Payment
Returns a new instance of Payment.
14 15 16 17 18 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 14 def initialize(payment_intent: nil, payment_record: nil, type: nil) @payment_intent = payment_intent @payment_record = payment_record @type = type end |
Instance Attribute Details
#payment_intent ⇒ Object
Only return invoice payments associated by this payment intent ID.
8 9 10 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 8 def payment_intent @payment_intent end |
#payment_record ⇒ Object
Only return invoice payments associated by this payment record ID.
10 11 12 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 10 def payment_record @payment_record end |
#type ⇒ Object
Only return invoice payments associated by this payment type.
12 13 14 |
# File 'lib/stripe/params/invoice_payment_list_params.rb', line 12 def type @type end |