Class: Stripe::InvoicePaymentService::ListParams::Payment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoicePaymentService::ListParams::Payment
- Defined in:
- lib/stripe/services/invoice_payment_service.rb
Instance Attribute Summary collapse
-
#payment_intent ⇒ Object
Only return invoice payments associated by this payment intent ID.
-
#type ⇒ Object
Only return invoice payments associated by this payment type.
Instance Method Summary collapse
-
#initialize(payment_intent: nil, type: nil) ⇒ Payment
constructor
A new instance of Payment.
Methods inherited from RequestParams
Constructor Details
#initialize(payment_intent: nil, type: nil) ⇒ Payment
Returns a new instance of Payment.
13 14 15 16 |
# File 'lib/stripe/services/invoice_payment_service.rb', line 13 def initialize(payment_intent: nil, type: nil) @payment_intent = payment_intent @type = type end |
Instance Attribute Details
#payment_intent ⇒ Object
Only return invoice payments associated by this payment intent ID.
9 10 11 |
# File 'lib/stripe/services/invoice_payment_service.rb', line 9 def payment_intent @payment_intent end |
#type ⇒ Object
Only return invoice payments associated by this payment type.
11 12 13 |
# File 'lib/stripe/services/invoice_payment_service.rb', line 11 def type @type end |