Class: Stripe::InvoicePaymentService::ListParams::Payment

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_payment_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(payment_intent: nil, type: nil) ⇒ Payment

Returns a new instance of Payment.



13
14
15
16
# File 'lib/stripe/services/invoice_payment_service.rb', line 13

def initialize(payment_intent: nil, type: nil)
  @payment_intent = payment_intent
  @type = type
end

Instance Attribute Details

#payment_intentObject

Only return invoice payments associated by this payment intent ID.



9
10
11
# File 'lib/stripe/services/invoice_payment_service.rb', line 9

def payment_intent
  @payment_intent
end

#typeObject

Only return invoice payments associated by this payment type.



11
12
13
# File 'lib/stripe/services/invoice_payment_service.rb', line 11

def type
  @type
end