Class: Stripe::InvoiceService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::InvoiceService
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: AddLinesParams, AttachPaymentParams, CreateParams, CreatePreviewParams, DeleteParams, FinalizeInvoiceParams, ListParams, MarkUncollectibleParams, PayParams, RemoveLinesParams, RetrieveParams, SearchParams, SendInvoiceParams, UpdateLinesParams, UpdateParams, VoidInvoiceParams
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Returns the value of attribute line_items.
Instance Method Summary collapse
-
#add_lines(invoice, params = {}, opts = {}) ⇒ Object
Adds multiple line items to an invoice.
-
#attach_payment(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.
-
#create(params = {}, opts = {}) ⇒ Object
This endpoint creates a draft invoice for a given customer.
-
#create_preview(params = {}, opts = {}) ⇒ Object
At any time, you can preview the upcoming invoice for a subscription or subscription schedule.
-
#delete(invoice, params = {}, opts = {}) ⇒ Object
Permanently deletes a one-off invoice draft.
-
#finalize_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically finalizes drafts before sending and attempting payment on invoices.
-
#initialize(requestor) ⇒ InvoiceService
constructor
A new instance of InvoiceService.
-
#list(params = {}, opts = {}) ⇒ Object
You can list all invoices, or list the invoices for a specific customer.
-
#mark_uncollectible(invoice, params = {}, opts = {}) ⇒ Object
Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.
-
#pay(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic).
-
#remove_lines(invoice, params = {}, opts = {}) ⇒ Object
Removes multiple line items from an invoice.
-
#retrieve(invoice, params = {}, opts = {}) ⇒ Object
Retrieves the invoice with the given ID.
-
#search(params = {}, opts = {}) ⇒ Object
Search for invoices you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language).
-
#send_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic).
-
#update(invoice, params = {}, opts = {}) ⇒ Object
Draft invoices are fully editable.
-
#update_lines(invoice, params = {}, opts = {}) ⇒ Object
Updates multiple line items on an invoice.
-
#void_invoice(invoice, params = {}, opts = {}) ⇒ Object
Mark a finalized invoice as void.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ InvoiceService
Returns a new instance of InvoiceService.
8 9 10 11 |
# File 'lib/stripe/services/invoice_service.rb', line 8 def initialize(requestor) super @line_items = Stripe::InvoiceLineItemService.new(@requestor) end |
Instance Attribute Details
#line_items ⇒ Object (readonly)
Returns the value of attribute line_items.
6 7 8 |
# File 'lib/stripe/services/invoice_service.rb', line 6 def line_items @line_items end |
Instance Method Details
#add_lines(invoice, params = {}, opts = {}) ⇒ Object
Adds multiple line items to an invoice. This is only possible when an invoice is still a draft.
3713 3714 3715 3716 3717 3718 3719 3720 3721 |
# File 'lib/stripe/services/invoice_service.rb', line 3713 def add_lines(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/add_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#attach_payment(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.
For the PaymentIntent, when the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.
If the PaymentIntent’s status is already succeeded when it’s attached, it’s credited to the invoice immediately.
See: [Partial payments](docs.stripe.com/docs/invoicing/partial-payments) to learn more.
3733 3734 3735 3736 3737 3738 3739 3740 3741 |
# File 'lib/stripe/services/invoice_service.rb', line 3733 def attach_payment(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/attach_payment", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
This endpoint creates a draft invoice for a given customer. The invoice remains a draft until you [finalize the invoice, which allows you to [pay](#pay_invoice) or <a href=“#send_invoice”>send](docs.stripe.com/api#finalize_invoice) the invoice to your customers.
3744 3745 3746 |
# File 'lib/stripe/services/invoice_service.rb', line 3744 def create(params = {}, opts = {}) request(method: :post, path: "/v1/invoices", params: params, opts: opts, base_address: :api) end |
#create_preview(params = {}, opts = {}) ⇒ Object
At any time, you can preview the upcoming invoice for a subscription or subscription schedule. This will show you all the charges that are pending, including subscription renewal charges, invoice item charges, etc. It will also show you any discounts that are applicable to the invoice.
You can also preview the effects of creating or updating a subscription or subscription schedule, including a preview of any prorations that will take place. To ensure that the actual proration is calculated exactly the same as the previewed proration, you should pass the subscription_details.proration_date parameter when doing the actual subscription update.
The recommended way to get only the prorations being previewed on the invoice is to consider line items where parent.subscription_item_details.proration is true.
Note that when you are viewing an upcoming invoice, you are simply viewing a preview – the invoice has not yet been created. As such, the upcoming invoice will not show up in invoice listing calls, and you cannot use the API to pay or edit the invoice. If you want to change the amount that your customer will be billed, you can add, remove, or update pending invoice items, or update the customer’s discount.
Note: Currency conversion calculations use the latest exchange rates. Exchange rates may vary between the time of the preview and the time of the actual invoice creation. [Learn more](docs.stripe.com/currencies/conversions)
3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/stripe/services/invoice_service.rb', line 3757 def create_preview(params = {}, opts = {}) request( method: :post, path: "/v1/invoices/create_preview", params: params, opts: opts, base_address: :api ) end |
#delete(invoice, params = {}, opts = {}) ⇒ Object
Permanently deletes a one-off invoice draft. This cannot be undone. Attempts to delete invoices that are no longer in a draft state will fail; once an invoice has been finalized or if an invoice is for a subscription, it must be [voided](docs.stripe.com/api#void_invoice).
3768 3769 3770 3771 3772 3773 3774 3775 3776 |
# File 'lib/stripe/services/invoice_service.rb', line 3768 def delete(invoice, params = {}, opts = {}) request( method: :delete, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#finalize_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically finalizes drafts before sending and attempting payment on invoices. However, if you’d like to finalize a draft invoice manually, you can do so using this method.
3779 3780 3781 3782 3783 3784 3785 3786 3787 |
# File 'lib/stripe/services/invoice_service.rb', line 3779 def finalize_invoice(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/finalize", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
You can list all invoices, or list the invoices for a specific customer. The invoices are returned sorted by creation date, with the most recently created invoices appearing first.
3790 3791 3792 |
# File 'lib/stripe/services/invoice_service.rb', line 3790 def list(params = {}, opts = {}) request(method: :get, path: "/v1/invoices", params: params, opts: opts, base_address: :api) end |
#mark_uncollectible(invoice, params = {}, opts = {}) ⇒ Object
Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.
3795 3796 3797 3798 3799 3800 3801 3802 3803 |
# File 'lib/stripe/services/invoice_service.rb', line 3795 def mark_uncollectible(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/mark_uncollectible", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#pay(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to attempt payment on an invoice out of the normal collection schedule or for some other reason, you can do so.
3806 3807 3808 3809 3810 3811 3812 3813 3814 |
# File 'lib/stripe/services/invoice_service.rb', line 3806 def pay(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/pay", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#remove_lines(invoice, params = {}, opts = {}) ⇒ Object
Removes multiple line items from an invoice. This is only possible when an invoice is still a draft.
3817 3818 3819 3820 3821 3822 3823 3824 3825 |
# File 'lib/stripe/services/invoice_service.rb', line 3817 def remove_lines(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/remove_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(invoice, params = {}, opts = {}) ⇒ Object
Retrieves the invoice with the given ID.
3828 3829 3830 3831 3832 3833 3834 3835 3836 |
# File 'lib/stripe/services/invoice_service.rb', line 3828 def retrieve(invoice, params = {}, opts = {}) request( method: :get, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#search(params = {}, opts = {}) ⇒ Object
Search for invoices you’ve previously created using Stripe’s [Search Query Language](docs.stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.
3842 3843 3844 3845 3846 3847 3848 3849 3850 |
# File 'lib/stripe/services/invoice_service.rb', line 3842 def search(params = {}, opts = {}) request( method: :get, path: "/v1/invoices/search", params: params, opts: opts, base_address: :api ) end |
#send_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to manually send an invoice to your customer out of the normal schedule, you can do so. When sending invoices that have already been paid, there will be no reference to the payment in the email.
Requests made in test-mode result in no emails being sent, despite sending an invoice.sent event.
3855 3856 3857 3858 3859 3860 3861 3862 3863 |
# File 'lib/stripe/services/invoice_service.rb', line 3855 def send_invoice(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/send", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#update(invoice, params = {}, opts = {}) ⇒ Object
Draft invoices are fully editable. Once an invoice is [finalized](docs.stripe.com/docs/billing/invoices/workflow#finalized), monetary values, as well as collection_method, become uneditable.
If you would like to stop the Stripe Billing engine from automatically finalizing, reattempting payments on, sending reminders for, or [automatically reconciling](docs.stripe.com/docs/billing/invoices/reconciliation) invoices, pass auto_advance=false.
3871 3872 3873 3874 3875 3876 3877 3878 3879 |
# File 'lib/stripe/services/invoice_service.rb', line 3871 def update(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#update_lines(invoice, params = {}, opts = {}) ⇒ Object
Updates multiple line items on an invoice. This is only possible when an invoice is still a draft.
3882 3883 3884 3885 3886 3887 3888 3889 3890 |
# File 'lib/stripe/services/invoice_service.rb', line 3882 def update_lines(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/update_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#void_invoice(invoice, params = {}, opts = {}) ⇒ Object
Mark a finalized invoice as void. This cannot be undone. Voiding an invoice is similar to [deletion](docs.stripe.com/api#delete_invoice), however it only applies to finalized invoices and maintains a papertrail where the invoice can still be found.
Consult with local regulations to determine whether and how an invoice might be amended, canceled, or voided in the jurisdiction you’re doing business in. You might need to [issue another invoice or <a href=“#create_credit_note”>credit note](docs.stripe.com/api#create_invoice) instead. Stripe recommends that you consult with your legal counsel for advice specific to your business.
3895 3896 3897 3898 3899 3900 3901 3902 3903 |
# File 'lib/stripe/services/invoice_service.rb', line 3895 def void_invoice(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/void", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |