Class: Stripe::InvoiceService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::InvoiceService
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: AddLinesParams, AttachPaymentIntentParams, AttachPaymentParams, CreateParams, CreatePreviewParams, DeleteParams, FinalizeInvoiceParams, ListParams, MarkUncollectibleParams, PayParams, RemoveLinesParams, RetrieveParams, SearchParams, SendInvoiceParams, UpcomingParams, UpdateLinesParams, UpdateParams, VoidInvoiceParams
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Returns the value of attribute line_items.
-
#payments ⇒ Object
readonly
Returns the value of attribute payments.
-
#upcoming_lines ⇒ Object
readonly
Returns the value of attribute upcoming_lines.
Instance Method Summary collapse
-
#add_lines(invoice, params = {}, opts = {}) ⇒ Object
Adds multiple line items to an invoice.
-
#attach_payment(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.
-
#attach_payment_intent(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent to the invoice, adding it to the list of payments.
-
#create(params = {}, opts = {}) ⇒ Object
This endpoint creates a draft invoice for a given customer.
-
#create_preview(params = {}, opts = {}) ⇒ Object
At any time, you can preview the upcoming invoice for a customer.
-
#delete(invoice, params = {}, opts = {}) ⇒ Object
Permanently deletes a one-off invoice draft.
-
#finalize_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically finalizes drafts before sending and attempting payment on invoices.
-
#initialize(requestor) ⇒ InvoiceService
constructor
A new instance of InvoiceService.
-
#list(params = {}, opts = {}) ⇒ Object
You can list all invoices, or list the invoices for a specific customer.
-
#mark_uncollectible(invoice, params = {}, opts = {}) ⇒ Object
Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.
-
#pay(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic).
-
#remove_lines(invoice, params = {}, opts = {}) ⇒ Object
Removes multiple line items from an invoice.
-
#retrieve(invoice, params = {}, opts = {}) ⇒ Object
Retrieves the invoice with the given ID.
-
#search(params = {}, opts = {}) ⇒ Object
Search for invoices you’ve previously created using Stripe’s [Search Query Language](stripe.com/docs/search#search-query-language).
-
#send_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic).
-
#upcoming(params = {}, opts = {}) ⇒ Object
At any time, you can preview the upcoming invoice for a customer.
-
#update(invoice, params = {}, opts = {}) ⇒ Object
Draft invoices are fully editable.
-
#update_lines(invoice, params = {}, opts = {}) ⇒ Object
Updates multiple line items on an invoice.
-
#void_invoice(invoice, params = {}, opts = {}) ⇒ Object
Mark a finalized invoice as void.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ InvoiceService
Returns a new instance of InvoiceService.
8 9 10 11 12 13 |
# File 'lib/stripe/services/invoice_service.rb', line 8 def initialize(requestor) super(requestor) @payments = Stripe::InvoicePaymentService.new(@requestor) @line_items = Stripe::InvoiceLineItemService.new(@requestor) @upcoming_lines = Stripe::InvoiceUpcomingLinesService.new(@requestor) end |
Instance Attribute Details
#line_items ⇒ Object (readonly)
Returns the value of attribute line_items.
6 7 8 |
# File 'lib/stripe/services/invoice_service.rb', line 6 def line_items @line_items end |
#payments ⇒ Object (readonly)
Returns the value of attribute payments.
6 7 8 |
# File 'lib/stripe/services/invoice_service.rb', line 6 def payments @payments end |
#upcoming_lines ⇒ Object (readonly)
Returns the value of attribute upcoming_lines.
6 7 8 |
# File 'lib/stripe/services/invoice_service.rb', line 6 def upcoming_lines @upcoming_lines end |
Instance Method Details
#add_lines(invoice, params = {}, opts = {}) ⇒ Object
Adds multiple line items to an invoice. This is only possible when an invoice is still a draft.
5539 5540 5541 5542 5543 5544 5545 5546 5547 |
# File 'lib/stripe/services/invoice_service.rb', line 5539 def add_lines(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/add_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#attach_payment(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent or an Out of Band Payment to the invoice, adding it to the list of payments.
For Out of Band Payment, the payment is credited to the invoice immediately, increasing the amount_paid of the invoice and subsequently transitioning the status of the invoice to paid if necessary.
For the PaymentIntent, when the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.
If the PaymentIntent’s status is already succeeded when it’s attached, it’s credited to the invoice immediately.
See: [Create an invoice payment](stripe.com/docs/invoicing/payments/create) to learn more.
5562 5563 5564 5565 5566 5567 5568 5569 5570 |
# File 'lib/stripe/services/invoice_service.rb', line 5562 def attach_payment(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/attach_payment", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#attach_payment_intent(invoice, params = {}, opts = {}) ⇒ Object
Attaches a PaymentIntent to the invoice, adding it to the list of payments. When the PaymentIntent’s status changes to succeeded, the payment is credited to the invoice, increasing its amount_paid. When the invoice is fully paid, the invoice’s status becomes paid.
If the PaymentIntent’s status is already succeeded when it is attached, it is credited to the invoice immediately.
Related guide: [Create an invoice payment](stripe.com/docs/invoicing/payments/create)
5581 5582 5583 5584 5585 5586 5587 5588 5589 |
# File 'lib/stripe/services/invoice_service.rb', line 5581 def attach_payment_intent(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/attach_payment_intent", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
This endpoint creates a draft invoice for a given customer. The invoice remains a draft until you [finalize the invoice, which allows you to [pay](#pay_invoice) or <a href=“#send_invoice”>send](stripe.com/docs/api#finalize_invoice) the invoice to your customers.
5592 5593 5594 |
# File 'lib/stripe/services/invoice_service.rb', line 5592 def create(params = {}, opts = {}) request(method: :post, path: "/v1/invoices", params: params, opts: opts, base_address: :api) end |
#create_preview(params = {}, opts = {}) ⇒ Object
At any time, you can preview the upcoming invoice for a customer. This will show you all the charges that are pending, including subscription renewal charges, invoice item charges, etc. It will also show you any discounts that are applicable to the invoice.
Note that when you are viewing an upcoming invoice, you are simply viewing a preview – the invoice has not yet been created. As such, the upcoming invoice will not show up in invoice listing calls, and you cannot use the API to pay or edit the invoice. If you want to change the amount that your customer will be billed, you can add, remove, or update pending invoice items, or update the customer’s discount.
You can preview the effects of updating a subscription, including a preview of what proration will take place. To ensure that the actual proration is calculated exactly the same as the previewed proration, you should pass the subscription_details.proration_date parameter when doing the actual subscription update. The recommended way to get only the prorations being previewed is to consider only proration line items where period is equal to the subscription_details.proration_date value passed in the request.
Note: Currency conversion calculations use the latest exchange rates. Exchange rates may vary between the time of the preview and the time of the actual invoice creation. [Learn more](docs.stripe.com/currencies/conversions)
5603 5604 5605 5606 5607 5608 5609 5610 5611 |
# File 'lib/stripe/services/invoice_service.rb', line 5603 def create_preview(params = {}, opts = {}) request( method: :post, path: "/v1/invoices/create_preview", params: params, opts: opts, base_address: :api ) end |
#delete(invoice, params = {}, opts = {}) ⇒ Object
Permanently deletes a one-off invoice draft. This cannot be undone. Attempts to delete invoices that are no longer in a draft state will fail; once an invoice has been finalized or if an invoice is for a subscription, it must be [voided](stripe.com/docs/api#void_invoice).
5614 5615 5616 5617 5618 5619 5620 5621 5622 |
# File 'lib/stripe/services/invoice_service.rb', line 5614 def delete(invoice, params = {}, opts = {}) request( method: :delete, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#finalize_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically finalizes drafts before sending and attempting payment on invoices. However, if you’d like to finalize a draft invoice manually, you can do so using this method.
5625 5626 5627 5628 5629 5630 5631 5632 5633 |
# File 'lib/stripe/services/invoice_service.rb', line 5625 def finalize_invoice(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/finalize", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
You can list all invoices, or list the invoices for a specific customer. The invoices are returned sorted by creation date, with the most recently created invoices appearing first.
5636 5637 5638 |
# File 'lib/stripe/services/invoice_service.rb', line 5636 def list(params = {}, opts = {}) request(method: :get, path: "/v1/invoices", params: params, opts: opts, base_address: :api) end |
#mark_uncollectible(invoice, params = {}, opts = {}) ⇒ Object
Marking an invoice as uncollectible is useful for keeping track of bad debts that can be written off for accounting purposes.
5641 5642 5643 5644 5645 5646 5647 5648 5649 |
# File 'lib/stripe/services/invoice_service.rb', line 5641 def mark_uncollectible(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/mark_uncollectible", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#pay(invoice, params = {}, opts = {}) ⇒ Object
Stripe automatically creates and then attempts to collect payment on invoices for customers on subscriptions according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to attempt payment on an invoice out of the normal collection schedule or for some other reason, you can do so.
5652 5653 5654 5655 5656 5657 5658 5659 5660 |
# File 'lib/stripe/services/invoice_service.rb', line 5652 def pay(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/pay", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#remove_lines(invoice, params = {}, opts = {}) ⇒ Object
Removes multiple line items from an invoice. This is only possible when an invoice is still a draft.
5663 5664 5665 5666 5667 5668 5669 5670 5671 |
# File 'lib/stripe/services/invoice_service.rb', line 5663 def remove_lines(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/remove_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(invoice, params = {}, opts = {}) ⇒ Object
Retrieves the invoice with the given ID.
5674 5675 5676 5677 5678 5679 5680 5681 5682 |
# File 'lib/stripe/services/invoice_service.rb', line 5674 def retrieve(invoice, params = {}, opts = {}) request( method: :get, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#search(params = {}, opts = {}) ⇒ Object
Search for invoices you’ve previously created using Stripe’s [Search Query Language](stripe.com/docs/search#search-query-language). Don’t use search in read-after-write flows where strict consistency is necessary. Under normal operating conditions, data is searchable in less than a minute. Occasionally, propagation of new or updated data can be up to an hour behind during outages. Search functionality is not available to merchants in India.
5688 5689 5690 5691 5692 5693 5694 5695 5696 |
# File 'lib/stripe/services/invoice_service.rb', line 5688 def search(params = {}, opts = {}) request( method: :get, path: "/v1/invoices/search", params: params, opts: opts, base_address: :api ) end |
#send_invoice(invoice, params = {}, opts = {}) ⇒ Object
Stripe will automatically send invoices to customers according to your [subscriptions settings](dashboard.stripe.com/account/billing/automatic). However, if you’d like to manually send an invoice to your customer out of the normal schedule, you can do so. When sending invoices that have already been paid, there will be no reference to the payment in the email.
Requests made in test-mode result in no emails being sent, despite sending an invoice.sent event.
5701 5702 5703 5704 5705 5706 5707 5708 5709 |
# File 'lib/stripe/services/invoice_service.rb', line 5701 def send_invoice(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/send", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#upcoming(params = {}, opts = {}) ⇒ Object
At any time, you can preview the upcoming invoice for a customer. This will show you all the charges that are pending, including subscription renewal charges, invoice item charges, etc. It will also show you any discounts that are applicable to the invoice.
Note that when you are viewing an upcoming invoice, you are simply viewing a preview – the invoice has not yet been created. As such, the upcoming invoice will not show up in invoice listing calls, and you cannot use the API to pay or edit the invoice. If you want to change the amount that your customer will be billed, you can add, remove, or update pending invoice items, or update the customer’s discount.
You can preview the effects of updating a subscription, including a preview of what proration will take place. To ensure that the actual proration is calculated exactly the same as the previewed proration, you should pass the subscription_details.proration_date parameter when doing the actual subscription update. The recommended way to get only the prorations being previewed is to consider only proration line items where period is equal to the subscription_details.proration_date value passed in the request.
Note: Currency conversion calculations use the latest exchange rates. Exchange rates may vary between the time of the preview and the time of the actual invoice creation. [Learn more](docs.stripe.com/currencies/conversions)
5718 5719 5720 5721 5722 5723 5724 5725 5726 |
# File 'lib/stripe/services/invoice_service.rb', line 5718 def upcoming(params = {}, opts = {}) request( method: :get, path: "/v1/invoices/upcoming", params: params, opts: opts, base_address: :api ) end |
#update(invoice, params = {}, opts = {}) ⇒ Object
Draft invoices are fully editable. Once an invoice is [finalized](stripe.com/docs/billing/invoices/workflow#finalized), monetary values, as well as collection_method, become uneditable.
If you would like to stop the Stripe Billing engine from automatically finalizing, reattempting payments on, sending reminders for, or [automatically reconciling](stripe.com/docs/billing/invoices/reconciliation) invoices, pass auto_advance=false.
5734 5735 5736 5737 5738 5739 5740 5741 5742 |
# File 'lib/stripe/services/invoice_service.rb', line 5734 def update(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#update_lines(invoice, params = {}, opts = {}) ⇒ Object
Updates multiple line items on an invoice. This is only possible when an invoice is still a draft.
5745 5746 5747 5748 5749 5750 5751 5752 5753 |
# File 'lib/stripe/services/invoice_service.rb', line 5745 def update_lines(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/update_lines", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |
#void_invoice(invoice, params = {}, opts = {}) ⇒ Object
Mark a finalized invoice as void. This cannot be undone. Voiding an invoice is similar to [deletion](stripe.com/docs/api#delete_invoice), however it only applies to finalized invoices and maintains a papertrail where the invoice can still be found.
Consult with local regulations to determine whether and how an invoice might be amended, canceled, or voided in the jurisdiction you’re doing business in. You might need to [issue another invoice or <a href=“#create_credit_note”>credit note](stripe.com/docs/api#create_invoice) instead. Stripe recommends that you consult with your legal counsel for advice specific to your business.
5758 5759 5760 5761 5762 5763 5764 5765 5766 |
# File 'lib/stripe/services/invoice_service.rb', line 5758 def void_invoice(invoice, params = {}, opts = {}) request( method: :post, path: format("/v1/invoices/%<invoice>s/void", { invoice: CGI.escape(invoice) }), params: params, opts: opts, base_address: :api ) end |