Class: Stripe::InvoiceService::AddLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to add.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams
constructor
A new instance of AddLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams
Returns a new instance of AddLinesParams.
1653 1654 1655 1656 1657 |
# File 'lib/stripe/services/invoice_service.rb', line 1653 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1647 1648 1649 |
# File 'lib/stripe/services/invoice_service.rb', line 1647 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1649 1650 1651 |
# File 'lib/stripe/services/invoice_service.rb', line 1649 def @invoice_metadata end |
#lines ⇒ Object
The line items to add.
1651 1652 1653 |
# File 'lib/stripe/services/invoice_service.rb', line 1651 def lines @lines end |