Class: Stripe::InvoiceService::AddLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to add.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams
constructor
A new instance of AddLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ AddLinesParams
Returns a new instance of AddLinesParams.
3477 3478 3479 3480 3481 |
# File 'lib/stripe/services/invoice_service.rb', line 3477 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3471 3472 3473 |
# File 'lib/stripe/services/invoice_service.rb', line 3471 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3473 3474 3475 |
# File 'lib/stripe/services/invoice_service.rb', line 3473 def @invoice_metadata end |
#lines ⇒ Object
The line items to add.
3475 3476 3477 |
# File 'lib/stripe/services/invoice_service.rb', line 3475 def lines @lines end |