Class: Stripe::InvoiceService::AddLinesParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Discount, Period, PriceData, Pricing, TaxAmount
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Controls whether discounts apply to this line item.
-
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item.
-
#invoice_item ⇒ Object
ID of an unassigned invoice item to assign to this invoice.
-
#margins ⇒ Object
The IDs of the margins to apply to the line item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#pricing ⇒ Object
The pricing information for the invoice item.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line
Returns a new instance of Line.
1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 |
# File 'lib/stripe/services/invoice_service.rb', line 1615 def initialize( amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil ) @amount = amount @description = description @discountable = discountable @discounts = discounts @invoice_item = invoice_item @margins = margins @metadata = @period = period @price_data = price_data @pricing = pricing @quantity = quantity @tax_amounts = tax_amounts @tax_rates = tax_rates end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.
1589 1590 1591 |
# File 'lib/stripe/services/invoice_service.rb', line 1589 def amount @amount end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
1591 1592 1593 |
# File 'lib/stripe/services/invoice_service.rb', line 1591 def description @description end |
#discountable ⇒ Object
Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.
1593 1594 1595 |
# File 'lib/stripe/services/invoice_service.rb', line 1593 def discountable @discountable end |
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.
1595 1596 1597 |
# File 'lib/stripe/services/invoice_service.rb', line 1595 def discounts @discounts end |
#invoice_item ⇒ Object
ID of an unassigned invoice item to assign to this invoice. If not provided, a new item will be created.
1597 1598 1599 |
# File 'lib/stripe/services/invoice_service.rb', line 1597 def invoice_item @invoice_item end |
#margins ⇒ Object
The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.
1599 1600 1601 |
# File 'lib/stripe/services/invoice_service.rb', line 1599 def margins @margins end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1601 1602 1603 |
# File 'lib/stripe/services/invoice_service.rb', line 1601 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
1603 1604 1605 |
# File 'lib/stripe/services/invoice_service.rb', line 1603 def period @period end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
1605 1606 1607 |
# File 'lib/stripe/services/invoice_service.rb', line 1605 def price_data @price_data end |
#pricing ⇒ Object
The pricing information for the invoice item.
1607 1608 1609 |
# File 'lib/stripe/services/invoice_service.rb', line 1607 def pricing @pricing end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the line item.
1609 1610 1611 |
# File 'lib/stripe/services/invoice_service.rb', line 1609 def quantity @quantity end |
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.
1611 1612 1613 |
# File 'lib/stripe/services/invoice_service.rb', line 1611 def tax_amounts @tax_amounts end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.
1613 1614 1615 |
# File 'lib/stripe/services/invoice_service.rb', line 1613 def tax_rates @tax_rates end |