Class: Stripe::InvoiceService::AddLinesParams::Line

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, invoice_item: nil, margins: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line

Returns a new instance of Line.



3440
3441
3442
3443
3444
3445
3446
3447
3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/stripe/services/invoice_service.rb', line 3440

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  invoice_item: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @invoice_item = invoice_item
  @margins = margins
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



3414
3415
3416
# File 'lib/stripe/services/invoice_service.rb', line 3414

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



3416
3417
3418
# File 'lib/stripe/services/invoice_service.rb', line 3416

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



3418
3419
3420
# File 'lib/stripe/services/invoice_service.rb', line 3418

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



3420
3421
3422
# File 'lib/stripe/services/invoice_service.rb', line 3420

def discounts
  @discounts
end

#invoice_itemObject

ID of an unassigned invoice item to assign to this invoice. If not provided, a new item will be created.



3422
3423
3424
# File 'lib/stripe/services/invoice_service.rb', line 3422

def invoice_item
  @invoice_item
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



3424
3425
3426
# File 'lib/stripe/services/invoice_service.rb', line 3424

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3426
3427
3428
# File 'lib/stripe/services/invoice_service.rb', line 3426

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



3428
3429
3430
# File 'lib/stripe/services/invoice_service.rb', line 3428

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



3430
3431
3432
# File 'lib/stripe/services/invoice_service.rb', line 3430

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3432
3433
3434
# File 'lib/stripe/services/invoice_service.rb', line 3432

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



3434
3435
3436
# File 'lib/stripe/services/invoice_service.rb', line 3434

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



3436
3437
3438
# File 'lib/stripe/services/invoice_service.rb', line 3436

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



3438
3439
3440
# File 'lib/stripe/services/invoice_service.rb', line 3438

def tax_rates
  @tax_rates
end