Class: Stripe::InvoiceService::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1431
1432
1433
1434
1435
1436
# File 'lib/stripe/services/invoice_service.rb', line 1431

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1423
1424
1425
# File 'lib/stripe/services/invoice_service.rb', line 1423

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1425
1426
1427
# File 'lib/stripe/services/invoice_service.rb', line 1425

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1427
1428
1429
# File 'lib/stripe/services/invoice_service.rb', line 1427

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1429
1430
1431
# File 'lib/stripe/services/invoice_service.rb', line 1429

def promotion_code
  @promotion_code
end