Class: Stripe::InvoiceService::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1272
1273
1274
1275
1276
# File 'lib/stripe/services/invoice_service.rb', line 1272

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1266
1267
1268
# File 'lib/stripe/services/invoice_service.rb', line 1266

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1268
1269
1270
# File 'lib/stripe/services/invoice_service.rb', line 1268

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1270
1271
1272
# File 'lib/stripe/services/invoice_service.rb', line 1270

def promotion_code
  @promotion_code
end