Class: Stripe::InvoiceService::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1279
1280
1281
1282
1283
# File 'lib/stripe/services/invoice_service.rb', line 1279

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1273
1274
1275
# File 'lib/stripe/services/invoice_service.rb', line 1273

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1275
1276
1277
# File 'lib/stripe/services/invoice_service.rb', line 1275

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1277
1278
1279
# File 'lib/stripe/services/invoice_service.rb', line 1277

def promotion_code
  @promotion_code
end