Class: Stripe::InvoiceService::AddLinesParams::Line::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line::Discount
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1442 1443 1444 1445 1446 1447 |
# File 'lib/stripe/services/invoice_service.rb', line 1442 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1434 1435 1436 |
# File 'lib/stripe/services/invoice_service.rb', line 1434 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1436 1437 1438 |
# File 'lib/stripe/services/invoice_service.rb', line 1436 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1438 1439 1440 |
# File 'lib/stripe/services/invoice_service.rb', line 1438 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1440 1441 1442 |
# File 'lib/stripe/services/invoice_service.rb', line 1440 def promotion_code @promotion_code end |