Class: Stripe::InvoiceService::AddLinesParams::Line::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line::Discount
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1279 1280 1281 1282 1283 |
# File 'lib/stripe/services/invoice_service.rb', line 1279 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1273 1274 1275 |
# File 'lib/stripe/services/invoice_service.rb', line 1273 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1275 1276 1277 |
# File 'lib/stripe/services/invoice_service.rb', line 1275 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1277 1278 1279 |
# File 'lib/stripe/services/invoice_service.rb', line 1277 def promotion_code @promotion_code end |