Class: Stripe::InvoiceService::AddLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3763
3764
3765
3766
3767
3768
# File 'lib/stripe/services/invoice_service.rb', line 3763

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3752
3753
3754
# File 'lib/stripe/services/invoice_service.rb', line 3752

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3755
3756
3757
# File 'lib/stripe/services/invoice_service.rb', line 3755

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3758
3759
3760
# File 'lib/stripe/services/invoice_service.rb', line 3758

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3761
3762
3763
# File 'lib/stripe/services/invoice_service.rb', line 3761

def promotion_code
  @promotion_code
end