Class: Stripe::InvoiceService::AddLinesParams::Line::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1416
1417
1418
1419
1420
# File 'lib/stripe/services/invoice_service.rb', line 1416

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1410
1411
1412
# File 'lib/stripe/services/invoice_service.rb', line 1410

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1412
1413
1414
# File 'lib/stripe/services/invoice_service.rb', line 1412

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1414
1415
1416
# File 'lib/stripe/services/invoice_service.rb', line 1414

def type
  @type
end