Class: Stripe::InvoiceService::AddLinesParams::Line::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1427
1428
1429
1430
1431
# File 'lib/stripe/services/invoice_service.rb', line 1427

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1421
1422
1423
# File 'lib/stripe/services/invoice_service.rb', line 1421

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1423
1424
1425
# File 'lib/stripe/services/invoice_service.rb', line 1423

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1425
1426
1427
# File 'lib/stripe/services/invoice_service.rb', line 1425

def type
  @type
end