Class: Stripe::InvoiceService::AddLinesParams::Line::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
1427 1428 1429 1430 1431 |
# File 'lib/stripe/services/invoice_service.rb', line 1427 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
1421 1422 1423 |
# File 'lib/stripe/services/invoice_service.rb', line 1421 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
1423 1424 1425 |
# File 'lib/stripe/services/invoice_service.rb', line 1423 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
1425 1426 1427 |
# File 'lib/stripe/services/invoice_service.rb', line 1425 def type @type end |