Class: Stripe::InvoiceService::AddLinesParams::Line::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
3273 3274 3275 3276 3277 |
# File 'lib/stripe/services/invoice_service.rb', line 3273 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
3267 3268 3269 |
# File 'lib/stripe/services/invoice_service.rb', line 3267 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
3269 3270 3271 |
# File 'lib/stripe/services/invoice_service.rb', line 3269 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
3271 3272 3273 |
# File 'lib/stripe/services/invoice_service.rb', line 3271 def type @type end |