Class: Stripe::InvoiceService::AddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1475
1476
1477
1478
1479
1480
1481
# File 'lib/stripe/services/invoice_service.rb', line 1475

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1465
1466
1467
# File 'lib/stripe/services/invoice_service.rb', line 1465

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1467
1468
1469
# File 'lib/stripe/services/invoice_service.rb', line 1467

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1469
1470
1471
# File 'lib/stripe/services/invoice_service.rb', line 1469

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1471
1472
1473
# File 'lib/stripe/services/invoice_service.rb', line 1471

def name
  @name
end

#tax_codeObject



1473
1474
1475
# File 'lib/stripe/services/invoice_service.rb', line 1473

def tax_code
  @tax_code
end