Class: Stripe::InvoiceService::AddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1311
1312
1313
1314
1315
1316
1317
# File 'lib/stripe/services/invoice_service.rb', line 1311

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1301
1302
1303
# File 'lib/stripe/services/invoice_service.rb', line 1301

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1303
1304
1305
# File 'lib/stripe/services/invoice_service.rb', line 1303

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1305
1306
1307
# File 'lib/stripe/services/invoice_service.rb', line 1305

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1307
1308
1309
# File 'lib/stripe/services/invoice_service.rb', line 1307

def name
  @name
end

#tax_codeObject



1309
1310
1311
# File 'lib/stripe/services/invoice_service.rb', line 1309

def tax_code
  @tax_code
end