Class: Stripe::InvoiceService::AddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



3321
3322
3323
3324
3325
3326
3327
# File 'lib/stripe/services/invoice_service.rb', line 3321

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



3311
3312
3313
# File 'lib/stripe/services/invoice_service.rb', line 3311

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



3313
3314
3315
# File 'lib/stripe/services/invoice_service.rb', line 3313

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3315
3316
3317
# File 'lib/stripe/services/invoice_service.rb', line 3315

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



3317
3318
3319
# File 'lib/stripe/services/invoice_service.rb', line 3317

def name
  @name
end

#tax_codeObject



3319
3320
3321
# File 'lib/stripe/services/invoice_service.rb', line 3319

def tax_code
  @tax_code
end