Class: Stripe::InvoiceService::AddLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



3801
3802
3803
3804
3805
3806
3807
# File 'lib/stripe/services/invoice_service.rb', line 3801

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



3787
3788
3789
# File 'lib/stripe/services/invoice_service.rb', line 3787

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



3790
3791
3792
# File 'lib/stripe/services/invoice_service.rb', line 3790

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3793
3794
3795
# File 'lib/stripe/services/invoice_service.rb', line 3793

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



3796
3797
3798
# File 'lib/stripe/services/invoice_service.rb', line 3796

def name
  @name
end

#tax_codeObject



3799
3800
3801
# File 'lib/stripe/services/invoice_service.rb', line 3799

def tax_code
  @tax_code
end