Class: Stripe::InvoiceService::AddLinesParams::Line::TaxAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: TaxRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil) ⇒ TaxAmount

Returns a new instance of TaxAmount.



3407
3408
3409
3410
3411
# File 'lib/stripe/services/invoice_service.rb', line 3407

def initialize(amount: nil, tax_rate_data: nil, taxable_amount: nil)
  @amount = amount
  @tax_rate_data = tax_rate_data
  @taxable_amount = taxable_amount
end

Instance Attribute Details

#amountObject

The amount, in cents (or local equivalent), of the tax.



3399
3400
3401
# File 'lib/stripe/services/invoice_service.rb', line 3399

def amount
  @amount
end

#tax_rate_dataObject

Data to find or create a TaxRate object.

Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.



3403
3404
3405
# File 'lib/stripe/services/invoice_service.rb', line 3403

def tax_rate_data
  @tax_rate_data
end

#taxable_amountObject

The amount on which tax is calculated, in cents (or local equivalent).



3405
3406
3407
# File 'lib/stripe/services/invoice_service.rb', line 3405

def taxable_amount
  @taxable_amount
end