Class: Stripe::InvoiceService::AddLinesParams::Line::TaxAmount::TaxRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line::TaxAmount::TaxRateData
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#jurisdiction_level ⇒ Object
The level of the jurisdiction that imposes this tax rate.
-
#percentage ⇒ Object
The statutory tax rate percent.
-
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
Instance Method Summary collapse
-
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
constructor
A new instance of TaxRateData.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
Returns a new instance of TaxRateData.
1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 |
# File 'lib/stripe/services/invoice_service.rb', line 1379 def initialize( country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil ) @country = country @description = description @display_name = display_name @inclusive = inclusive @jurisdiction = jurisdiction @jurisdiction_level = jurisdiction_level @percentage = percentage @state = state @tax_type = tax_type end |
Instance Attribute Details
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
1361 1362 1363 |
# File 'lib/stripe/services/invoice_service.rb', line 1361 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
1363 1364 1365 |
# File 'lib/stripe/services/invoice_service.rb', line 1363 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
1365 1366 1367 |
# File 'lib/stripe/services/invoice_service.rb', line 1365 def display_name @display_name end |
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
1367 1368 1369 |
# File 'lib/stripe/services/invoice_service.rb', line 1367 def inclusive @inclusive end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
1369 1370 1371 |
# File 'lib/stripe/services/invoice_service.rb', line 1369 def jurisdiction @jurisdiction end |
#jurisdiction_level ⇒ Object
The level of the jurisdiction that imposes this tax rate.
1371 1372 1373 |
# File 'lib/stripe/services/invoice_service.rb', line 1371 def jurisdiction_level @jurisdiction_level end |
#percentage ⇒ Object
The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.
1373 1374 1375 |
# File 'lib/stripe/services/invoice_service.rb', line 1373 def percentage @percentage end |
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.
1375 1376 1377 |
# File 'lib/stripe/services/invoice_service.rb', line 1375 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
1377 1378 1379 |
# File 'lib/stripe/services/invoice_service.rb', line 1377 def tax_type @tax_type end |