Class: Stripe::InvoiceService::AddLinesParams::Line::TaxAmount::TaxRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData

Returns a new instance of TaxRateData.



1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
# File 'lib/stripe/services/invoice_service.rb', line 1543

def initialize(
  country: nil,
  description: nil,
  display_name: nil,
  inclusive: nil,
  jurisdiction: nil,
  jurisdiction_level: nil,
  percentage: nil,
  state: nil,
  tax_type: nil
)
  @country = country
  @description = description
  @display_name = display_name
  @inclusive = inclusive
  @jurisdiction = jurisdiction
  @jurisdiction_level = jurisdiction_level
  @percentage = percentage
  @state = state
  @tax_type = tax_type
end

Instance Attribute Details

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1525
1526
1527
# File 'lib/stripe/services/invoice_service.rb', line 1525

def country
  @country
end

#descriptionObject

An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.



1527
1528
1529
# File 'lib/stripe/services/invoice_service.rb', line 1527

def description
  @description
end

#display_nameObject

The display name of the tax rate, which will be shown to users.



1529
1530
1531
# File 'lib/stripe/services/invoice_service.rb', line 1529

def display_name
  @display_name
end

#inclusiveObject

This specifies if the tax rate is inclusive or exclusive.



1531
1532
1533
# File 'lib/stripe/services/invoice_service.rb', line 1531

def inclusive
  @inclusive
end

#jurisdictionObject

The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.



1533
1534
1535
# File 'lib/stripe/services/invoice_service.rb', line 1533

def jurisdiction
  @jurisdiction
end

#jurisdiction_levelObject

The level of the jurisdiction that imposes this tax rate.



1535
1536
1537
# File 'lib/stripe/services/invoice_service.rb', line 1535

def jurisdiction_level
  @jurisdiction_level
end

#percentageObject

The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.



1537
1538
1539
# File 'lib/stripe/services/invoice_service.rb', line 1537

def percentage
  @percentage
end

#stateObject

[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.



1539
1540
1541
# File 'lib/stripe/services/invoice_service.rb', line 1539

def state
  @state
end

#tax_typeObject

The high-level tax type, such as ‘vat` or `sales_tax`.



1541
1542
1543
# File 'lib/stripe/services/invoice_service.rb', line 1541

def tax_type
  @tax_type
end