Class: Stripe::InvoiceService::AddLinesParams::Line::TaxAmount::TaxRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AddLinesParams::Line::TaxAmount::TaxRateData
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#percentage ⇒ Object
The statutory tax rate percent.
-
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
Instance Method Summary collapse
-
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
constructor
A new instance of TaxRateData.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
Returns a new instance of TaxRateData.
3870 3871 3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 3884 3885 3886 3887 3888 |
# File 'lib/stripe/services/invoice_service.rb', line 3870 def initialize( country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil ) @country = country @description = description @display_name = display_name @inclusive = inclusive @jurisdiction = jurisdiction @percentage = percentage @state = state @tax_type = tax_type end |
Instance Attribute Details
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
3847 3848 3849 |
# File 'lib/stripe/services/invoice_service.rb', line 3847 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
3850 3851 3852 |
# File 'lib/stripe/services/invoice_service.rb', line 3850 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
3853 3854 3855 |
# File 'lib/stripe/services/invoice_service.rb', line 3853 def display_name @display_name end |
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
3856 3857 3858 |
# File 'lib/stripe/services/invoice_service.rb', line 3856 def inclusive @inclusive end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
3859 3860 3861 |
# File 'lib/stripe/services/invoice_service.rb', line 3859 def jurisdiction @jurisdiction end |
#percentage ⇒ Object
The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.
3862 3863 3864 |
# File 'lib/stripe/services/invoice_service.rb', line 3862 def percentage @percentage end |
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.
3865 3866 3867 |
# File 'lib/stripe/services/invoice_service.rb', line 3865 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
3868 3869 3870 |
# File 'lib/stripe/services/invoice_service.rb', line 3868 def tax_type @tax_type end |