Class: Stripe::InvoiceService::AttachPaymentIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AttachPaymentIntentParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the PaymentIntent’s ‘amount` that should be applied to thisinvoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil) ⇒ AttachPaymentIntentParams
constructor
A new instance of AttachPaymentIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil) ⇒ AttachPaymentIntentParams
Returns a new instance of AttachPaymentIntentParams.
4068 4069 4070 4071 4072 |
# File 'lib/stripe/services/invoice_service.rb', line 4068 def initialize(amount_requested: nil, expand: nil, payment_intent: nil) @amount_requested = amount_requested @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the PaymentIntent’s ‘amount` that should be applied to thisinvoice. Defaults to the entire amount.
4060 4061 4062 |
# File 'lib/stripe/services/invoice_service.rb', line 4060 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
4063 4064 4065 |
# File 'lib/stripe/services/invoice_service.rb', line 4063 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
4066 4067 4068 |
# File 'lib/stripe/services/invoice_service.rb', line 4066 def payment_intent @payment_intent end |