Class: Stripe::InvoiceService::AttachPaymentIntentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AttachPaymentIntentParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the PaymentIntent’s ‘amount` that should be applied to thisinvoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil) ⇒ AttachPaymentIntentParams
constructor
A new instance of AttachPaymentIntentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil) ⇒ AttachPaymentIntentParams
Returns a new instance of AttachPaymentIntentParams.
3549 3550 3551 3552 3553 |
# File 'lib/stripe/services/invoice_service.rb', line 3549 def initialize(amount_requested: nil, expand: nil, payment_intent: nil) @amount_requested = amount_requested @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the PaymentIntent’s ‘amount` that should be applied to thisinvoice. Defaults to the entire amount.
3543 3544 3545 |
# File 'lib/stripe/services/invoice_service.rb', line 3543 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3545 3546 3547 |
# File 'lib/stripe/services/invoice_service.rb', line 3545 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
3547 3548 3549 |
# File 'lib/stripe/services/invoice_service.rb', line 3547 def payment_intent @payment_intent end |