Class: Stripe::InvoiceService::AttachPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AttachPaymentParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: PaymentRecordData
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
-
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
-
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams
constructor
A new instance of AttachPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams
Returns a new instance of AttachPaymentParams.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 |
# File 'lib/stripe/services/invoice_service.rb', line 1750 def initialize( amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil ) @amount_requested = amount_requested @expand = @payment_intent = payment_intent @payment_record = payment_record @payment_record_data = payment_record_data end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.
1740 1741 1742 |
# File 'lib/stripe/services/invoice_service.rb', line 1740 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1742 1743 1744 |
# File 'lib/stripe/services/invoice_service.rb', line 1742 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
1744 1745 1746 |
# File 'lib/stripe/services/invoice_service.rb', line 1744 def payment_intent @payment_intent end |
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
1746 1747 1748 |
# File 'lib/stripe/services/invoice_service.rb', line 1746 def payment_record @payment_record end |
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
1748 1749 1750 |
# File 'lib/stripe/services/invoice_service.rb', line 1748 def payment_record_data @payment_record_data end |