Class: Stripe::InvoiceService::AttachPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
# File 'lib/stripe/services/invoice_service.rb', line 1690

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



1680
1681
1682
# File 'lib/stripe/services/invoice_service.rb', line 1680

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



1682
1683
1684
# File 'lib/stripe/services/invoice_service.rb', line 1682

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



1684
1685
1686
# File 'lib/stripe/services/invoice_service.rb', line 1684

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to attach to the invoice.



1686
1687
1688
# File 'lib/stripe/services/invoice_service.rb', line 1686

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



1688
1689
1690
# File 'lib/stripe/services/invoice_service.rb', line 1688

def payment_record_data
  @payment_record_data
end