Class: Stripe::InvoiceService::AttachPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AttachPaymentParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_intent: nil) ⇒ AttachPaymentParams
constructor
A new instance of AttachPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_intent: nil) ⇒ AttachPaymentParams
Returns a new instance of AttachPaymentParams.
1490 1491 1492 1493 |
# File 'lib/stripe/services/invoice_service.rb', line 1490 def initialize(expand: nil, payment_intent: nil) @expand = @payment_intent = payment_intent end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1486 1487 1488 |
# File 'lib/stripe/services/invoice_service.rb', line 1486 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
1488 1489 1490 |
# File 'lib/stripe/services/invoice_service.rb', line 1488 def payment_intent @payment_intent end |