Class: Stripe::InvoiceService::AttachPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AttachPaymentParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: PaymentRecordData
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
-
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
-
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams
constructor
A new instance of AttachPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams
Returns a new instance of AttachPaymentParams.
1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 1712 1713 1714 |
# File 'lib/stripe/services/invoice_service.rb', line 1702 def initialize( amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil ) @amount_requested = amount_requested @expand = @payment_intent = payment_intent @payment_record = payment_record @payment_record_data = payment_record_data end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.
1692 1693 1694 |
# File 'lib/stripe/services/invoice_service.rb', line 1692 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1694 1695 1696 |
# File 'lib/stripe/services/invoice_service.rb', line 1694 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
1696 1697 1698 |
# File 'lib/stripe/services/invoice_service.rb', line 1696 def payment_intent @payment_intent end |
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
1698 1699 1700 |
# File 'lib/stripe/services/invoice_service.rb', line 1698 def payment_record @payment_record end |
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
1700 1701 1702 |
# File 'lib/stripe/services/invoice_service.rb', line 1700 def payment_record_data @payment_record_data end |