Class: Stripe::InvoiceService::AttachPaymentParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AttachPaymentParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: PaymentRecordData
Instance Attribute Summary collapse
-
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
-
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
-
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
Instance Method Summary collapse
-
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams
constructor
A new instance of AttachPaymentParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams
Returns a new instance of AttachPaymentParams.
3526 3527 3528 3529 3530 3531 3532 3533 3534 3535 3536 3537 3538 |
# File 'lib/stripe/services/invoice_service.rb', line 3526 def initialize( amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil ) @amount_requested = amount_requested @expand = @payment_intent = payment_intent @payment_record = payment_record @payment_record_data = payment_record_data end |
Instance Attribute Details
#amount_requested ⇒ Object
The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.
3516 3517 3518 |
# File 'lib/stripe/services/invoice_service.rb', line 3516 def amount_requested @amount_requested end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3518 3519 3520 |
# File 'lib/stripe/services/invoice_service.rb', line 3518 def @expand end |
#payment_intent ⇒ Object
The ID of the PaymentIntent to attach to the invoice.
3520 3521 3522 |
# File 'lib/stripe/services/invoice_service.rb', line 3520 def payment_intent @payment_intent end |
#payment_record ⇒ Object
The ID of the PaymentRecord to attach to the invoice.
3522 3523 3524 |
# File 'lib/stripe/services/invoice_service.rb', line 3522 def payment_record @payment_record end |
#payment_record_data ⇒ Object
The PaymentRecord data for attaching an out of band payment to the invoice.
3524 3525 3526 |
# File 'lib/stripe/services/invoice_service.rb', line 3524 def payment_record_data @payment_record_data end |