Class: Stripe::InvoiceService::AttachPaymentParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: PaymentRecordData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_requested: nil, expand: nil, payment_intent: nil, payment_record: nil, payment_record_data: nil) ⇒ AttachPaymentParams

Returns a new instance of AttachPaymentParams.



4043
4044
4045
4046
4047
4048
4049
4050
4051
4052
4053
4054
4055
# File 'lib/stripe/services/invoice_service.rb', line 4043

def initialize(
  amount_requested: nil,
  expand: nil,
  payment_intent: nil,
  payment_record: nil,
  payment_record_data: nil
)
  @amount_requested = amount_requested
  @expand = expand
  @payment_intent = payment_intent
  @payment_record = payment_record
  @payment_record_data = payment_record_data
end

Instance Attribute Details

#amount_requestedObject

The portion of the ‘amount` on the PaymentIntent or out of band payment to apply to this invoice. It defaults to the entire amount.



4029
4030
4031
# File 'lib/stripe/services/invoice_service.rb', line 4029

def amount_requested
  @amount_requested
end

#expandObject

Specifies which fields in the response should be expanded.



4032
4033
4034
# File 'lib/stripe/services/invoice_service.rb', line 4032

def expand
  @expand
end

#payment_intentObject

The ID of the PaymentIntent to attach to the invoice.



4035
4036
4037
# File 'lib/stripe/services/invoice_service.rb', line 4035

def payment_intent
  @payment_intent
end

#payment_recordObject

The ID of the PaymentRecord to detach from the invoice.



4038
4039
4040
# File 'lib/stripe/services/invoice_service.rb', line 4038

def payment_record
  @payment_record
end

#payment_record_dataObject

The PaymentRecord data for attaching an out of band payment to the invoice.



4041
4042
4043
# File 'lib/stripe/services/invoice_service.rb', line 4041

def payment_record_data
  @payment_record_data
end