Class: Stripe::InvoiceService::AttachPaymentParams::PaymentRecordData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::AttachPaymentParams::PaymentRecordData
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that was paid out of band.
-
#currency ⇒ Object
The currency that was paid out of band.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
-
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
-
#payment_reference ⇒ Object
The reference for this out of band payment record.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
constructor
A new instance of PaymentRecordData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData
Returns a new instance of PaymentRecordData.
1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 |
# File 'lib/stripe/services/invoice_service.rb', line 1675 def initialize( amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil ) @amount = amount @currency = currency @metadata = @money_movement_type = money_movement_type @paid_at = paid_at @payment_reference = payment_reference end |
Instance Attribute Details
#amount ⇒ Object
The amount that was paid out of band.
1663 1664 1665 |
# File 'lib/stripe/services/invoice_service.rb', line 1663 def amount @amount end |
#currency ⇒ Object
The currency that was paid out of band.
1665 1666 1667 |
# File 'lib/stripe/services/invoice_service.rb', line 1665 def currency @currency end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1667 1668 1669 |
# File 'lib/stripe/services/invoice_service.rb', line 1667 def @metadata end |
#money_movement_type ⇒ Object
The type of money movement for this out of band payment record.
1669 1670 1671 |
# File 'lib/stripe/services/invoice_service.rb', line 1669 def money_movement_type @money_movement_type end |
#paid_at ⇒ Object
The timestamp when this out of band payment was paid.
1671 1672 1673 |
# File 'lib/stripe/services/invoice_service.rb', line 1671 def paid_at @paid_at end |
#payment_reference ⇒ Object
The reference for this out of band payment record.
1673 1674 1675 |
# File 'lib/stripe/services/invoice_service.rb', line 1673 def payment_reference @payment_reference end |