Class: Stripe::InvoiceService::AttachPaymentParams::PaymentRecordData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, metadata: nil, money_movement_type: nil, paid_at: nil, payment_reference: nil) ⇒ PaymentRecordData

Returns a new instance of PaymentRecordData.



4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
# File 'lib/stripe/services/invoice_service.rb', line 4012

def initialize(
  amount: nil,
  currency: nil,
  metadata: nil,
  money_movement_type: nil,
  paid_at: nil,
  payment_reference: nil
)
  @amount = amount
  @currency = currency
  @metadata = 
  @money_movement_type = money_movement_type
  @paid_at = paid_at
  @payment_reference = payment_reference
end

Instance Attribute Details

#amountObject

The amount that was paid out of band.



3995
3996
3997
# File 'lib/stripe/services/invoice_service.rb', line 3995

def amount
  @amount
end

#currencyObject

The currency that was paid out of band.



3998
3999
4000
# File 'lib/stripe/services/invoice_service.rb', line 3998

def currency
  @currency
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4001
4002
4003
# File 'lib/stripe/services/invoice_service.rb', line 4001

def 
  @metadata
end

#money_movement_typeObject

The type of money movement for this out of band payment record.



4004
4005
4006
# File 'lib/stripe/services/invoice_service.rb', line 4004

def money_movement_type
  @money_movement_type
end

The timestamp when this out of band payment was paid.



4007
4008
4009
# File 'lib/stripe/services/invoice_service.rb', line 4007

def paid_at
  @paid_at
end

#payment_referenceObject

The reference for this out of band payment record.



4010
4011
4012
# File 'lib/stripe/services/invoice_service.rb', line 4010

def payment_reference
  @payment_reference
end