Class: Stripe::InvoiceService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreateParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: AmountsDue, AutomaticTax, CustomField, Discount, FromInvoice, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData
Instance Attribute Summary collapse
-
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice.
-
#amounts_due ⇒ Object
List of expected payments and corresponding due dates.
-
#application_fee_amount ⇒ Object
A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account.
-
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice.
-
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this invoice.
-
#automatically_finalizes_at ⇒ Object
The time when this invoice should be scheduled to finalize (up to 5 years in the future).
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#currency ⇒ Object
The currency to create this invoice in.
-
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
-
#customer ⇒ Object
The ID of the customer who will be billed.
-
#customer_account ⇒ Object
The ID of the account who will be billed.
-
#days_until_due ⇒ Object
The number of days from when the invoice is created until it is due.
-
#default_margins ⇒ Object
The ids of the margins to apply to the invoice.
-
#default_payment_method ⇒ Object
ID of the default payment method for the invoice.
-
#default_source ⇒ Object
ID of the default payment source for the invoice.
-
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons and promotion codes to redeem into discounts for the invoice.
-
#due_date ⇒ Object
The date on which payment for this invoice is due.
-
#effective_at ⇒ Object
The date when this invoice is in effect.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#footer ⇒ Object
Footer to be displayed on the invoice.
-
#from_invoice ⇒ Object
Revise an existing invoice.
-
#issuer ⇒ Object
The connected account that issues the invoice.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#number ⇒ Object
Set the number for this invoice.
-
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the invoice payment are intended.
-
#payment_settings ⇒ Object
Configuration settings for the PaymentIntent that is generated when the invoice is finalized.
-
#pending_invoice_items_behavior ⇒ Object
How to handle pending invoice items on invoice creation.
-
#rendering ⇒ Object
The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.
-
#shipping_cost ⇒ Object
Settings for the cost of shipping for this invoice.
-
#shipping_details ⇒ Object
Shipping details for the invoice.
-
#statement_descriptor ⇒ Object
Extra information about a charge for the customer’s credit card statement.
-
#subscription ⇒ Object
The ID of the subscription to invoice, if any.
-
#transfer_data ⇒ Object
If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, customer_account: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 1410 1411 1412 1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/stripe/services/invoice_service.rb', line 1361 def initialize( account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, currency: nil, custom_fields: nil, customer: nil, customer_account: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, from_invoice: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, pending_invoice_items_behavior: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, subscription: nil, transfer_data: nil ) @account_tax_ids = account_tax_ids @amounts_due = amounts_due @application_fee_amount = application_fee_amount @auto_advance = auto_advance @automatic_tax = automatic_tax @automatically_finalizes_at = automatically_finalizes_at @collection_method = collection_method @currency = currency @custom_fields = custom_fields @customer = customer @customer_account = customer_account @days_until_due = days_until_due @default_margins = default_margins @default_payment_method = default_payment_method @default_source = default_source @default_tax_rates = default_tax_rates @description = description @discounts = discounts @due_date = due_date @effective_at = effective_at @expand = @footer = @from_invoice = from_invoice @issuer = issuer @metadata = @number = number @on_behalf_of = on_behalf_of @payment_settings = payment_settings @pending_invoice_items_behavior = pending_invoice_items_behavior @rendering = rendering @shipping_cost = shipping_cost @shipping_details = shipping_details @statement_descriptor = statement_descriptor @subscription = subscription @transfer_data = transfer_data end |
Instance Attribute Details
#account_tax_ids ⇒ Object
The account tax IDs associated with the invoice. Only editable when the invoice is a draft.
1291 1292 1293 |
# File 'lib/stripe/services/invoice_service.rb', line 1291 def account_tax_ids @account_tax_ids end |
#amounts_due ⇒ Object
List of expected payments and corresponding due dates. Valid only for invoices where ‘collection_method=send_invoice`.
1293 1294 1295 |
# File 'lib/stripe/services/invoice_service.rb', line 1293 def amounts_due @amounts_due end |
#application_fee_amount ⇒ Object
A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/billing/invoices/connect#collecting-fees).
1295 1296 1297 |
# File 'lib/stripe/services/invoice_service.rb', line 1295 def application_fee_amount @application_fee_amount end |
#auto_advance ⇒ Object
Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice. If ‘false`, the invoice’s state doesn’t automatically advance without an explicit action. Defaults to false.
1297 1298 1299 |
# File 'lib/stripe/services/invoice_service.rb', line 1297 def auto_advance @auto_advance end |
#automatic_tax ⇒ Object
Settings for automatic tax lookup for this invoice.
1299 1300 1301 |
# File 'lib/stripe/services/invoice_service.rb', line 1299 def automatic_tax @automatic_tax end |
#automatically_finalizes_at ⇒ Object
The time when this invoice should be scheduled to finalize (up to 5 years in the future). The invoice is finalized at this time if it’s still in draft state.
1301 1302 1303 |
# File 'lib/stripe/services/invoice_service.rb', line 1301 def automatically_finalizes_at @automatically_finalizes_at end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay this invoice using the default source attached to the customer. When sending an invoice, Stripe will email this invoice to the customer with payment instructions. Defaults to `charge_automatically`.
1303 1304 1305 |
# File 'lib/stripe/services/invoice_service.rb', line 1303 def collection_method @collection_method end |
#currency ⇒ Object
The currency to create this invoice in. Defaults to that of ‘customer` if not specified.
1305 1306 1307 |
# File 'lib/stripe/services/invoice_service.rb', line 1305 def currency @currency end |
#custom_fields ⇒ Object
A list of up to 4 custom fields to be displayed on the invoice.
1307 1308 1309 |
# File 'lib/stripe/services/invoice_service.rb', line 1307 def custom_fields @custom_fields end |
#customer ⇒ Object
The ID of the customer who will be billed.
1309 1310 1311 |
# File 'lib/stripe/services/invoice_service.rb', line 1309 def customer @customer end |
#customer_account ⇒ Object
The ID of the account who will be billed.
1311 1312 1313 |
# File 'lib/stripe/services/invoice_service.rb', line 1311 def customer_account @customer_account end |
#days_until_due ⇒ Object
The number of days from when the invoice is created until it is due. Valid only for invoices where ‘collection_method=send_invoice`.
1313 1314 1315 |
# File 'lib/stripe/services/invoice_service.rb', line 1313 def days_until_due @days_until_due end |
#default_margins ⇒ Object
The ids of the margins to apply to the invoice. Can be overridden by line item ‘margins`.
1315 1316 1317 |
# File 'lib/stripe/services/invoice_service.rb', line 1315 def default_margins @default_margins end |
#default_payment_method ⇒ Object
ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.
1317 1318 1319 |
# File 'lib/stripe/services/invoice_service.rb', line 1317 def default_payment_method @default_payment_method end |
#default_source ⇒ Object
ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.
1319 1320 1321 |
# File 'lib/stripe/services/invoice_service.rb', line 1319 def default_source @default_source end |
#default_tax_rates ⇒ Object
The tax rates that will apply to any line item that does not have ‘tax_rates` set.
1321 1322 1323 |
# File 'lib/stripe/services/invoice_service.rb', line 1321 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.
1323 1324 1325 |
# File 'lib/stripe/services/invoice_service.rb', line 1323 def description @description end |
#discounts ⇒ Object
The coupons and promotion codes to redeem into discounts for the invoice. If not specified, inherits the discount from the invoice’s customer. Pass an empty string to avoid inheriting any discounts.
1325 1326 1327 |
# File 'lib/stripe/services/invoice_service.rb', line 1325 def discounts @discounts end |
#due_date ⇒ Object
The date on which payment for this invoice is due. Valid only for invoices where ‘collection_method=send_invoice`.
1327 1328 1329 |
# File 'lib/stripe/services/invoice_service.rb', line 1327 def due_date @due_date end |
#effective_at ⇒ Object
The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.
1329 1330 1331 |
# File 'lib/stripe/services/invoice_service.rb', line 1329 def effective_at @effective_at end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1331 1332 1333 |
# File 'lib/stripe/services/invoice_service.rb', line 1331 def @expand end |
#footer ⇒ Object
Footer to be displayed on the invoice.
1333 1334 1335 |
# File 'lib/stripe/services/invoice_service.rb', line 1333 def @footer end |
#from_invoice ⇒ Object
Revise an existing invoice. The new invoice will be created in ‘status=draft`. See the [revision documentation](stripe.com/docs/invoicing/invoice-revisions) for more details.
1335 1336 1337 |
# File 'lib/stripe/services/invoice_service.rb', line 1335 def from_invoice @from_invoice end |
#issuer ⇒ Object
The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.
1337 1338 1339 |
# File 'lib/stripe/services/invoice_service.rb', line 1337 def issuer @issuer end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1339 1340 1341 |
# File 'lib/stripe/services/invoice_service.rb', line 1339 def @metadata end |
#number ⇒ Object
Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.
1341 1342 1343 |
# File 'lib/stripe/services/invoice_service.rb', line 1341 def number @number end |
#on_behalf_of ⇒ Object
The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.
1343 1344 1345 |
# File 'lib/stripe/services/invoice_service.rb', line 1343 def on_behalf_of @on_behalf_of end |
#payment_settings ⇒ Object
Configuration settings for the PaymentIntent that is generated when the invoice is finalized.
1345 1346 1347 |
# File 'lib/stripe/services/invoice_service.rb', line 1345 def payment_settings @payment_settings end |
#pending_invoice_items_behavior ⇒ Object
How to handle pending invoice items on invoice creation. Defaults to ‘exclude` if the parameter is omitted.
1347 1348 1349 |
# File 'lib/stripe/services/invoice_service.rb', line 1347 def pending_invoice_items_behavior @pending_invoice_items_behavior end |
#rendering ⇒ Object
The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.
1349 1350 1351 |
# File 'lib/stripe/services/invoice_service.rb', line 1349 def rendering @rendering end |
#shipping_cost ⇒ Object
Settings for the cost of shipping for this invoice.
1351 1352 1353 |
# File 'lib/stripe/services/invoice_service.rb', line 1351 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.
1353 1354 1355 |
# File 'lib/stripe/services/invoice_service.rb', line 1353 def shipping_details @shipping_details end |
#statement_descriptor ⇒ Object
Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.
1355 1356 1357 |
# File 'lib/stripe/services/invoice_service.rb', line 1355 def statement_descriptor @statement_descriptor end |
#subscription ⇒ Object
The ID of the subscription to invoice, if any. If set, the created invoice will only include pending invoice items for that subscription. The subscription’s billing cycle and regular subscription events won’t be affected.
1357 1358 1359 |
# File 'lib/stripe/services/invoice_service.rb', line 1357 def subscription @subscription end |
#transfer_data ⇒ Object
If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge.
1359 1360 1361 |
# File 'lib/stripe/services/invoice_service.rb', line 1359 def transfer_data @transfer_data end |