Class: Stripe::InvoiceService::CreateParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



821
822
823
824
825
826
# File 'lib/stripe/services/invoice_service.rb', line 821

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



813
814
815
# File 'lib/stripe/services/invoice_service.rb', line 813

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



815
816
817
# File 'lib/stripe/services/invoice_service.rb', line 815

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



817
818
819
# File 'lib/stripe/services/invoice_service.rb', line 817

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



819
820
821
# File 'lib/stripe/services/invoice_service.rb', line 819

def promotion_code
  @promotion_code
end