Class: Stripe::InvoiceService::CreateParams::FromInvoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreateParams::FromInvoice
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
The relation between the new invoice and the original invoice.
-
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
Instance Method Summary collapse
-
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
constructor
A new instance of FromInvoice.
Methods inherited from RequestParams
Constructor Details
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
Returns a new instance of FromInvoice.
716 717 718 719 |
# File 'lib/stripe/services/invoice_service.rb', line 716 def initialize(action: nil, invoice: nil) @action = action @invoice = invoice end |
Instance Attribute Details
#action ⇒ Object
The relation between the new invoice and the original invoice. Currently, only ‘revision’ is permitted
712 713 714 |
# File 'lib/stripe/services/invoice_service.rb', line 712 def action @action end |
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
714 715 716 |
# File 'lib/stripe/services/invoice_service.rb', line 714 def invoice @invoice end |