Class: Stripe::InvoiceService::CreateParams::FromInvoice
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreateParams::FromInvoice
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#action ⇒ Object
The relation between the new invoice and the original invoice.
-
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
Instance Method Summary collapse
-
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
constructor
A new instance of FromInvoice.
Methods inherited from RequestParams
Constructor Details
#initialize(action: nil, invoice: nil) ⇒ FromInvoice
Returns a new instance of FromInvoice.
832 833 834 835 |
# File 'lib/stripe/services/invoice_service.rb', line 832 def initialize(action: nil, invoice: nil) @action = action @invoice = invoice end |
Instance Attribute Details
#action ⇒ Object
The relation between the new invoice and the original invoice. Currently, only ‘revision’ is permitted
828 829 830 |
# File 'lib/stripe/services/invoice_service.rb', line 828 def action @action end |
#invoice ⇒ Object
The ‘id` of the invoice that will be cloned.
830 831 832 |
# File 'lib/stripe/services/invoice_service.rb', line 830 def invoice @invoice end |