Class: Stripe::InvoiceService::CreateParams::PaymentSettings::PaymentMethodOptions::Card::Installments

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, plan: nil) ⇒ Installments

Returns a new instance of Installments.



792
793
794
795
# File 'lib/stripe/services/invoice_service.rb', line 792

def initialize(enabled: nil, plan: nil)
  @enabled = enabled
  @plan = plan
end

Instance Attribute Details

#enabledObject

Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.



788
789
790
# File 'lib/stripe/services/invoice_service.rb', line 788

def enabled
  @enabled
end

#planObject

The selected installment plan to use for this invoice.



790
791
792
# File 'lib/stripe/services/invoice_service.rb', line 790

def plan
  @plan
end