Class: Stripe::InvoiceService::CreateParams::Rendering
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreateParams::Rendering
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Pdf
Instance Attribute Summary collapse
-
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
-
#pdf ⇒ Object
Invoice pdf rendering options.
-
#template ⇒ Object
ID of the invoice rendering template to use for this invoice.
-
#template_version ⇒ Object
The specific version of invoice rendering template to use for this invoice.
Instance Method Summary collapse
-
#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering
constructor
A new instance of Rendering.
Methods inherited from RequestParams
Constructor Details
#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering
Returns a new instance of Rendering.
940 941 942 943 944 945 |
# File 'lib/stripe/services/invoice_service.rb', line 940 def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) @amount_tax_display = amount_tax_display @pdf = pdf @template = template @template_version = template_version end |
Instance Attribute Details
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.
932 933 934 |
# File 'lib/stripe/services/invoice_service.rb', line 932 def amount_tax_display @amount_tax_display end |
#pdf ⇒ Object
Invoice pdf rendering options
934 935 936 |
# File 'lib/stripe/services/invoice_service.rb', line 934 def pdf @pdf end |
#template ⇒ Object
ID of the invoice rendering template to use for this invoice.
936 937 938 |
# File 'lib/stripe/services/invoice_service.rb', line 936 def template @template end |
#template_version ⇒ Object
The specific version of invoice rendering template to use for this invoice.
938 939 940 |
# File 'lib/stripe/services/invoice_service.rb', line 938 def template_version @template_version end |