Class: Stripe::InvoiceService::CreateParams::Rendering

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering

Returns a new instance of Rendering.



1060
1061
1062
1063
1064
1065
# File 'lib/stripe/services/invoice_service.rb', line 1060

def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil)
  @amount_tax_display = amount_tax_display
  @pdf = pdf
  @template = template
  @template_version = template_version
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



1052
1053
1054
# File 'lib/stripe/services/invoice_service.rb', line 1052

def amount_tax_display
  @amount_tax_display
end

#pdfObject

Invoice pdf rendering options



1054
1055
1056
# File 'lib/stripe/services/invoice_service.rb', line 1054

def pdf
  @pdf
end

#templateObject

ID of the invoice rendering template to use for this invoice.



1056
1057
1058
# File 'lib/stripe/services/invoice_service.rb', line 1056

def template
  @template
end

#template_versionObject

The specific version of invoice rendering template to use for this invoice.



1058
1059
1060
# File 'lib/stripe/services/invoice_service.rb', line 1058

def template_version
  @template_version
end