Class: Stripe::InvoiceService::CreateParams::Rendering

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering

Returns a new instance of Rendering.



1206
1207
1208
1209
1210
1211
# File 'lib/stripe/services/invoice_service.rb', line 1206

def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil)
  @amount_tax_display = amount_tax_display
  @pdf = pdf
  @template = template
  @template_version = template_version
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



1195
1196
1197
# File 'lib/stripe/services/invoice_service.rb', line 1195

def amount_tax_display
  @amount_tax_display
end

#pdfObject

Invoice pdf rendering options



1198
1199
1200
# File 'lib/stripe/services/invoice_service.rb', line 1198

def pdf
  @pdf
end

#templateObject

ID of the invoice rendering template to use for this invoice.



1201
1202
1203
# File 'lib/stripe/services/invoice_service.rb', line 1201

def template
  @template
end

#template_versionObject

The specific version of invoice rendering template to use for this invoice.



1204
1205
1206
# File 'lib/stripe/services/invoice_service.rb', line 1204

def template_version
  @template_version
end