Class: Stripe::InvoiceService::CreatePreviewParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::AutomaticTax
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Whether Stripe automatically computes tax on this invoice.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
2079 2080 2081 2082 |
# File 'lib/stripe/services/invoice_service.rb', line 2079 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](stripe.com/docs/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.
2075 2076 2077 |
# File 'lib/stripe/services/invoice_service.rb', line 2075 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
2077 2078 2079 |
# File 'lib/stripe/services/invoice_service.rb', line 2077 def liability @liability end |