Class: Stripe::InvoiceService::CreatePreviewParams::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



3909
3910
3911
3912
# File 'lib/stripe/services/invoice_service.rb', line 3909

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Whether Stripe automatically computes tax on this invoice. Note that incompatible invoice items (invoice items with manually specified [tax rates](stripe.com/docs/api/tax_rates), negative amounts, or ‘tax_behavior=unspecified`) cannot be added to automatic tax invoices.



3905
3906
3907
# File 'lib/stripe/services/invoice_service.rb', line 3905

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



3907
3908
3909
# File 'lib/stripe/services/invoice_service.rb', line 3907

def liability
  @liability
end