Class: Stripe::InvoiceService::CreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2264
2265
2266
2267
2268
2269
# File 'lib/stripe/services/invoice_service.rb', line 2264

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2256
2257
2258
# File 'lib/stripe/services/invoice_service.rb', line 2256

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2258
2259
2260
# File 'lib/stripe/services/invoice_service.rb', line 2258

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2260
2261
2262
# File 'lib/stripe/services/invoice_service.rb', line 2260

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2262
2263
2264
# File 'lib/stripe/services/invoice_service.rb', line 2262

def promotion_code
  @promotion_code
end