Class: Stripe::InvoiceService::CreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2248
2249
2250
2251
2252
2253
# File 'lib/stripe/services/invoice_service.rb', line 2248

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2240
2241
2242
# File 'lib/stripe/services/invoice_service.rb', line 2240

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2242
2243
2244
# File 'lib/stripe/services/invoice_service.rb', line 2242

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2244
2245
2246
# File 'lib/stripe/services/invoice_service.rb', line 2244

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2246
2247
2248
# File 'lib/stripe/services/invoice_service.rb', line 2246

def promotion_code
  @promotion_code
end