Class: Stripe::InvoiceService::CreatePreviewParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4660
4661
4662
4663
4664
4665
# File 'lib/stripe/services/invoice_service.rb', line 4660

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4649
4650
4651
# File 'lib/stripe/services/invoice_service.rb', line 4649

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4652
4653
4654
# File 'lib/stripe/services/invoice_service.rb', line 4652

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4655
4656
4657
# File 'lib/stripe/services/invoice_service.rb', line 4655

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4658
4659
4660
# File 'lib/stripe/services/invoice_service.rb', line 4658

def promotion_code
  @promotion_code
end