Class: Stripe::InvoiceService::CreatePreviewParams::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
4642 4643 4644 4645 4646 |
# File 'lib/stripe/services/invoice_service.rb', line 4642 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
4634 4635 4636 |
# File 'lib/stripe/services/invoice_service.rb', line 4634 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
4637 4638 4639 |
# File 'lib/stripe/services/invoice_service.rb', line 4637 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
4640 4641 4642 |
# File 'lib/stripe/services/invoice_service.rb', line 4640 def type @type end |