Class: Stripe::InvoiceService::CreatePreviewParams::InvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem

Returns a new instance of InvoiceItem.



2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
# File 'lib/stripe/services/invoice_service.rb', line 2058

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  invoiceitem: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @discountable = discountable
  @discounts = discounts
  @invoiceitem = invoiceitem
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of previewed invoice item.



2026
2027
2028
# File 'lib/stripe/services/invoice_service.rb', line 2026

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Only applicable to new invoice items.



2028
2029
2030
# File 'lib/stripe/services/invoice_service.rb', line 2028

def currency
  @currency
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



2030
2031
2032
# File 'lib/stripe/services/invoice_service.rb', line 2030

def description
  @description
end

#discountableObject

Explicitly controls whether discounts apply to this invoice item. Defaults to true, except for negative invoice items.



2032
2033
2034
# File 'lib/stripe/services/invoice_service.rb', line 2032

def discountable
  @discountable
end

#discountsObject

The coupons to redeem into discounts for the invoice item in the preview.



2034
2035
2036
# File 'lib/stripe/services/invoice_service.rb', line 2034

def discounts
  @discounts
end

#invoiceitemObject

The ID of the invoice item to update in preview. If not specified, a new invoice item will be added to the preview of the upcoming invoice.



2036
2037
2038
# File 'lib/stripe/services/invoice_service.rb', line 2036

def invoiceitem
  @invoiceitem
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2038
2039
2040
# File 'lib/stripe/services/invoice_service.rb', line 2038

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



2040
2041
2042
# File 'lib/stripe/services/invoice_service.rb', line 2040

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



2042
2043
2044
# File 'lib/stripe/services/invoice_service.rb', line 2042

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



2044
2045
2046
# File 'lib/stripe/services/invoice_service.rb', line 2044

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item.



2046
2047
2048
# File 'lib/stripe/services/invoice_service.rb', line 2046

def quantity
  @quantity
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



2048
2049
2050
# File 'lib/stripe/services/invoice_service.rb', line 2048

def tax_behavior
  @tax_behavior
end

#tax_codeObject



2050
2051
2052
# File 'lib/stripe/services/invoice_service.rb', line 2050

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates that apply to the item. When set, any ‘default_tax_rates` do not apply to this item.



2052
2053
2054
# File 'lib/stripe/services/invoice_service.rb', line 2052

def tax_rates
  @tax_rates
end

#unit_amountObject

The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This unit_amount will be multiplied by the quantity to get the full amount. If you want to apply a credit to the customer’s account, pass a negative unit_amount.



2054
2055
2056
# File 'lib/stripe/services/invoice_service.rb', line 2054

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



2056
2057
2058
# File 'lib/stripe/services/invoice_service.rb', line 2056

def unit_amount_decimal
  @unit_amount_decimal
end