Class: Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2281
2282
2283
2284
2285
2286
# File 'lib/stripe/services/invoice_service.rb', line 2281

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2273
2274
2275
# File 'lib/stripe/services/invoice_service.rb', line 2273

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2275
2276
2277
# File 'lib/stripe/services/invoice_service.rb', line 2275

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2277
2278
2279
# File 'lib/stripe/services/invoice_service.rb', line 2277

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2279
2280
2281
# File 'lib/stripe/services/invoice_service.rb', line 2279

def promotion_code
  @promotion_code
end