Class: Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2292
2293
2294
2295
2296
2297
# File 'lib/stripe/services/invoice_service.rb', line 2292

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2284
2285
2286
# File 'lib/stripe/services/invoice_service.rb', line 2284

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2286
2287
2288
# File 'lib/stripe/services/invoice_service.rb', line 2286

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2288
2289
2290
# File 'lib/stripe/services/invoice_service.rb', line 2288

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2290
2291
2292
# File 'lib/stripe/services/invoice_service.rb', line 2290

def promotion_code
  @promotion_code
end