Class: Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4111
4112
4113
4114
4115
4116
# File 'lib/stripe/services/invoice_service.rb', line 4111

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4103
4104
4105
# File 'lib/stripe/services/invoice_service.rb', line 4103

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4105
4106
4107
# File 'lib/stripe/services/invoice_service.rb', line 4105

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4107
4108
4109
# File 'lib/stripe/services/invoice_service.rb', line 4107

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4109
4110
4111
# File 'lib/stripe/services/invoice_service.rb', line 4109

def promotion_code
  @promotion_code
end