Class: Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
4096 4097 4098 4099 4100 |
# File 'lib/stripe/services/invoice_service.rb', line 4096 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
4090 4091 4092 |
# File 'lib/stripe/services/invoice_service.rb', line 4090 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
4092 4093 4094 |
# File 'lib/stripe/services/invoice_service.rb', line 4092 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
4094 4095 4096 |
# File 'lib/stripe/services/invoice_service.rb', line 4094 def type @type end |