Class: Stripe::InvoiceService::CreatePreviewParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4096
4097
4098
4099
4100
# File 'lib/stripe/services/invoice_service.rb', line 4096

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4090
4091
4092
# File 'lib/stripe/services/invoice_service.rb', line 4090

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4092
4093
4094
# File 'lib/stripe/services/invoice_service.rb', line 4092

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4094
4095
4096
# File 'lib/stripe/services/invoice_service.rb', line 4094

def type
  @type
end