Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Amendment, Phase, Prebilling
Instance Attribute Summary collapse
-
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
-
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions.
-
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends.
-
#phases ⇒ Object
List representing phases of the subscription schedule.
-
#prebilling ⇒ Object
Provide any time periods to bill in advance.
-
#proration_behavior ⇒ Object
In cases where the ‘schedule_details` params update the currently active phase, specifies if and how to prorate at the time of the request.
Instance Method Summary collapse
-
#initialize(amendments: nil, billing_behavior: nil, end_behavior: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ ScheduleDetails
constructor
A new instance of ScheduleDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(amendments: nil, billing_behavior: nil, end_behavior: nil, phases: nil, prebilling: nil, proration_behavior: nil) ⇒ ScheduleDetails
Returns a new instance of ScheduleDetails.
3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 |
# File 'lib/stripe/services/invoice_service.rb', line 3397 def initialize( amendments: nil, billing_behavior: nil, end_behavior: nil, phases: nil, prebilling: nil, proration_behavior: nil ) @amendments = amendments @billing_behavior = billing_behavior @end_behavior = end_behavior @phases = phases @prebilling = prebilling @proration_behavior = proration_behavior end |
Instance Attribute Details
#amendments ⇒ Object
Changes to apply to the phases of the subscription schedule, in the order provided.
3385 3386 3387 |
# File 'lib/stripe/services/invoice_service.rb', line 3385 def amendments @amendments end |
#billing_behavior ⇒ Object
Configures when the subscription schedule generates prorations for phase transitions. Possible values are ‘prorate_on_next_phase` or `prorate_up_front` with the default being `prorate_on_next_phase`. `prorate_on_next_phase` will apply phase changes and generate prorations at transition time. `prorate_up_front` will bill for all phases within the current billing cycle up front.
3387 3388 3389 |
# File 'lib/stripe/services/invoice_service.rb', line 3387 def billing_behavior @billing_behavior end |
#end_behavior ⇒ Object
Behavior of the subscription schedule and underlying subscription when it ends. Possible values are ‘release` or `cancel` with the default being `release`. `release` will end the subscription schedule and keep the underlying subscription running. `cancel` will end the subscription schedule and cancel the underlying subscription.
3389 3390 3391 |
# File 'lib/stripe/services/invoice_service.rb', line 3389 def end_behavior @end_behavior end |
#phases ⇒ Object
List representing phases of the subscription schedule. Each phase can be customized to have different durations, plans, and coupons. If there are multiple phases, the ‘end_date` of one phase will always equal the `start_date` of the next phase.
3391 3392 3393 |
# File 'lib/stripe/services/invoice_service.rb', line 3391 def phases @phases end |
#prebilling ⇒ Object
Provide any time periods to bill in advance.
3393 3394 3395 |
# File 'lib/stripe/services/invoice_service.rb', line 3393 def prebilling @prebilling end |
#proration_behavior ⇒ Object
In cases where the ‘schedule_details` params update the currently active phase, specifies if and how to prorate at the time of the request.
3395 3396 3397 |
# File 'lib/stripe/services/invoice_service.rb', line 3395 def proration_behavior @proration_behavior end |