Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: AmendmentEnd, AmendmentStart, DiscountAction, ItemAction, MetadataAction, SetPauseCollection, TrialSettings
Instance Attribute Summary collapse
-
#amendment_end ⇒ Object
Details to identify the end of the time range modified by the proposed change.
-
#amendment_start ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
-
#billing_cycle_anchor ⇒ Object
For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.
-
#discount_actions ⇒ Object
Changes to the coupons being redeemed or discounts being applied during the amendment time span.
-
#item_actions ⇒ Object
Changes to the subscription items during the amendment time span.
-
#metadata_actions ⇒ Object
Instructions for how to modify phase metadata.
-
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the amendment time span.
-
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
-
#set_schedule_end ⇒ Object
Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
-
#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment
constructor
A new instance of Amendment.
Methods inherited from RequestParams
Constructor Details
#initialize(amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil) ⇒ Amendment
Returns a new instance of Amendment.
5345 5346 5347 5348 5349 5350 5351 5352 5353 5354 5355 5356 5357 5358 5359 5360 5361 5362 5363 5364 5365 5366 5367 |
# File 'lib/stripe/services/invoice_service.rb', line 5345 def initialize( amendment_end: nil, amendment_start: nil, billing_cycle_anchor: nil, discount_actions: nil, item_actions: nil, metadata_actions: nil, proration_behavior: nil, set_pause_collection: nil, set_schedule_end: nil, trial_settings: nil ) @amendment_end = amendment_end @amendment_start = amendment_start @billing_cycle_anchor = billing_cycle_anchor @discount_actions = discount_actions @item_actions = item_actions @metadata_actions = @proration_behavior = proration_behavior @set_pause_collection = set_pause_collection @set_schedule_end = set_schedule_end @trial_settings = trial_settings end |
Instance Attribute Details
#amendment_end ⇒ Object
Details to identify the end of the time range modified by the proposed change. If not supplied, the amendment is considered a point-in-time operation that only affects the exact timestamp at ‘amendment_start`, and a restricted set of attributes is supported on the amendment.
5316 5317 5318 |
# File 'lib/stripe/services/invoice_service.rb', line 5316 def amendment_end @amendment_end end |
#amendment_start ⇒ Object
Details to identify the earliest timestamp where the proposed change should take effect.
5319 5320 5321 |
# File 'lib/stripe/services/invoice_service.rb', line 5319 def amendment_start @amendment_start end |
#billing_cycle_anchor ⇒ Object
For point-in-time amendments (having no ‘amendment_end`), this attribute lets you set or remove whether the subscription’s billing cycle anchor is reset at the ‘amendment_start` timestamp.For time-span based amendments (having both `amendment_start` and `amendment_end`), the only value valid is `automatic`, which removes any previously configured billing cycle anchor resets scheduled to occur during the window of time spanned by the amendment.
5322 5323 5324 |
# File 'lib/stripe/services/invoice_service.rb', line 5322 def billing_cycle_anchor @billing_cycle_anchor end |
#discount_actions ⇒ Object
Changes to the coupons being redeemed or discounts being applied during the amendment time span.
5325 5326 5327 |
# File 'lib/stripe/services/invoice_service.rb', line 5325 def discount_actions @discount_actions end |
#item_actions ⇒ Object
Changes to the subscription items during the amendment time span.
5328 5329 5330 |
# File 'lib/stripe/services/invoice_service.rb', line 5328 def item_actions @item_actions end |
#metadata_actions ⇒ Object
Instructions for how to modify phase metadata
5331 5332 5333 |
# File 'lib/stripe/services/invoice_service.rb', line 5331 def @metadata_actions end |
#proration_behavior ⇒ Object
Changes to how Stripe handles prorations during the amendment time span. Affects if and how prorations are created when a future phase starts. In cases where the amendment changes the currently active phase, it is used to determine whether or how to prorate now, at the time of the request. Also supported as a point-in-time operation when ‘amendment_end` is `null`.
5334 5335 5336 |
# File 'lib/stripe/services/invoice_service.rb', line 5334 def proration_behavior @proration_behavior end |
#set_pause_collection ⇒ Object
Defines how to pause collection for the underlying subscription throughout the duration of the amendment.
5337 5338 5339 |
# File 'lib/stripe/services/invoice_service.rb', line 5337 def set_pause_collection @set_pause_collection end |
#set_schedule_end ⇒ Object
Ends the subscription schedule early as dictated by either the accompanying amendment’s start or end.
5340 5341 5342 |
# File 'lib/stripe/services/invoice_service.rb', line 5340 def set_schedule_end @set_schedule_end end |
#trial_settings ⇒ Object
Settings related to subscription trials.
5343 5344 5345 |
# File 'lib/stripe/services/invoice_service.rb', line 5343 def trial_settings @trial_settings end |