Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



2452
2453
2454
2455
2456
2457
# File 'lib/stripe/services/invoice_service.rb', line 2452

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



2444
2445
2446
# File 'lib/stripe/services/invoice_service.rb', line 2444

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



2446
2447
2448
# File 'lib/stripe/services/invoice_service.rb', line 2446

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



2448
2449
2450
# File 'lib/stripe/services/invoice_service.rb', line 2448

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



2450
2451
2452
# File 'lib/stripe/services/invoice_service.rb', line 2450

def type
  @type
end