Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: DiscountEnd, Duration
Instance Attribute Summary collapse
-
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
-
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
-
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end.
-
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
Instance Method Summary collapse
-
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
constructor
A new instance of AmendmentEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd
Returns a new instance of AmendmentEnd.
2468 2469 2470 2471 2472 2473 |
# File 'lib/stripe/services/invoice_service.rb', line 2468 def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) @discount_end = discount_end @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#discount_end ⇒ Object
Use the ‘end` time of a given discount.
2460 2461 2462 |
# File 'lib/stripe/services/invoice_service.rb', line 2460 def discount_end @discount_end end |
#duration ⇒ Object
Time span for the amendment starting from the ‘amendment_start`.
2462 2463 2464 |
# File 'lib/stripe/services/invoice_service.rb', line 2462 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.
2464 2465 2466 |
# File 'lib/stripe/services/invoice_service.rb', line 2464 def @timestamp end |
#type ⇒ Object
Select one of three ways to pass the ‘amendment_end`.
2466 2467 2468 |
# File 'lib/stripe/services/invoice_service.rb', line 2466 def type @type end |