Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



2487
2488
2489
2490
2491
2492
# File 'lib/stripe/services/invoice_service.rb', line 2487

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



2479
2480
2481
# File 'lib/stripe/services/invoice_service.rb', line 2479

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



2481
2482
2483
# File 'lib/stripe/services/invoice_service.rb', line 2481

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



2483
2484
2485
# File 'lib/stripe/services/invoice_service.rb', line 2483

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



2485
2486
2487
# File 'lib/stripe/services/invoice_service.rb', line 2485

def type
  @type
end