Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



4933
4934
4935
4936
4937
4938
# File 'lib/stripe/services/invoice_service.rb', line 4933

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



4922
4923
4924
# File 'lib/stripe/services/invoice_service.rb', line 4922

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



4925
4926
4927
# File 'lib/stripe/services/invoice_service.rb', line 4925

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



4928
4929
4930
# File 'lib/stripe/services/invoice_service.rb', line 4928

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



4931
4932
4933
# File 'lib/stripe/services/invoice_service.rb', line 4931

def type
  @type
end