Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
2585 2586 2587 2588 2589 2590 |
# File 'lib/stripe/services/invoice_service.rb', line 2585 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
2577 2578 2579 |
# File 'lib/stripe/services/invoice_service.rb', line 2577 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
2579 2580 2581 |
# File 'lib/stripe/services/invoice_service.rb', line 2579 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
2581 2582 2583 |
# File 'lib/stripe/services/invoice_service.rb', line 2581 def set @set end |
#type ⇒ Object
Determines the type of discount action.
2583 2584 2585 |
# File 'lib/stripe/services/invoice_service.rb', line 2583 def type @type end |