Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#add ⇒ Object
Details of the discount to add.
-
#remove ⇒ Object
Details of the discount to remove.
-
#set ⇒ Object
Details of the discount to replace the existing discounts with.
-
#type ⇒ Object
Determines the type of discount action.
Instance Method Summary collapse
-
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
constructor
A new instance of DiscountAction.
Methods inherited from RequestParams
Constructor Details
#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ DiscountAction
Returns a new instance of DiscountAction.
5026 5027 5028 5029 5030 5031 |
# File 'lib/stripe/services/invoice_service.rb', line 5026 def initialize(add: nil, remove: nil, set: nil, type: nil) @add = add @remove = remove @set = set @type = type end |
Instance Attribute Details
#add ⇒ Object
Details of the discount to add.
5015 5016 5017 |
# File 'lib/stripe/services/invoice_service.rb', line 5015 def add @add end |
#remove ⇒ Object
Details of the discount to remove.
5018 5019 5020 |
# File 'lib/stripe/services/invoice_service.rb', line 5018 def remove @remove end |
#set ⇒ Object
Details of the discount to replace the existing discounts with.
5021 5022 5023 |
# File 'lib/stripe/services/invoice_service.rb', line 5021 def set @set end |
#type ⇒ Object
Determines the type of discount action.
5024 5025 5026 |
# File 'lib/stripe/services/invoice_service.rb', line 5024 def type @type end |