Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Add
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to redeem.
-
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#index ⇒ Object
The index, starting at 0, at which to position the new discount.
-
#promotion_code ⇒ Object
The promotion code to redeem.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add
Returns a new instance of Add.
4966 4967 4968 4969 4970 4971 4972 4973 4974 4975 4976 4977 4978 |
# File 'lib/stripe/services/invoice_service.rb', line 4966 def initialize( coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil ) @coupon = coupon @discount = discount @discount_end = discount_end @index = index @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to redeem.
4952 4953 4954 |
# File 'lib/stripe/services/invoice_service.rb', line 4952 def coupon @coupon end |
#discount ⇒ Object
An ID of an existing discount for a coupon that was already redeemed.
4955 4956 4957 |
# File 'lib/stripe/services/invoice_service.rb', line 4955 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
4958 4959 4960 |
# File 'lib/stripe/services/invoice_service.rb', line 4958 def discount_end @discount_end end |
#index ⇒ Object
The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.
4961 4962 4963 |
# File 'lib/stripe/services/invoice_service.rb', line 4961 def index @index end |
#promotion_code ⇒ Object
The promotion code to redeem.
4964 4965 4966 |
# File 'lib/stripe/services/invoice_service.rb', line 4964 def promotion_code @promotion_code end |