Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



2539
2540
2541
2542
2543
# File 'lib/stripe/services/invoice_service.rb', line 2539

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2533
2534
2535
# File 'lib/stripe/services/invoice_service.rb', line 2533

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



2535
2536
2537
# File 'lib/stripe/services/invoice_service.rb', line 2535

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



2537
2538
2539
# File 'lib/stripe/services/invoice_service.rb', line 2537

def promotion_code
  @promotion_code
end