Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



2555
2556
2557
2558
2559
# File 'lib/stripe/services/invoice_service.rb', line 2555

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



2549
2550
2551
# File 'lib/stripe/services/invoice_service.rb', line 2549

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



2551
2552
2553
# File 'lib/stripe/services/invoice_service.rb', line 2551

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



2553
2554
2555
# File 'lib/stripe/services/invoice_service.rb', line 2553

def promotion_code
  @promotion_code
end