Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



4991
4992
4993
4994
4995
# File 'lib/stripe/services/invoice_service.rb', line 4991

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



4983
4984
4985
# File 'lib/stripe/services/invoice_service.rb', line 4983

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



4986
4987
4988
# File 'lib/stripe/services/invoice_service.rb', line 4986

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



4989
4990
4991
# File 'lib/stripe/services/invoice_service.rb', line 4989

def promotion_code
  @promotion_code
end