Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2765
2766
2767
2768
2769
2770
# File 'lib/stripe/services/invoice_service.rb', line 2765

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2757
2758
2759
# File 'lib/stripe/services/invoice_service.rb', line 2757

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2759
2760
2761
# File 'lib/stripe/services/invoice_service.rb', line 2759

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2761
2762
2763
# File 'lib/stripe/services/invoice_service.rb', line 2761

def set
  @set
end

#typeObject

Determines the type of item action.



2763
2764
2765
# File 'lib/stripe/services/invoice_service.rb', line 2763

def type
  @type
end