Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



2781
2782
2783
2784
2785
2786
# File 'lib/stripe/services/invoice_service.rb', line 2781

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



2773
2774
2775
# File 'lib/stripe/services/invoice_service.rb', line 2773

def add
  @add
end

#removeObject

Details of the subscription item to remove.



2775
2776
2777
# File 'lib/stripe/services/invoice_service.rb', line 2775

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



2777
2778
2779
# File 'lib/stripe/services/invoice_service.rb', line 2777

def set
  @set
end

#typeObject

Determines the type of item action.



2779
2780
2781
# File 'lib/stripe/services/invoice_service.rb', line 2779

def type
  @type
end