Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



5249
5250
5251
5252
5253
5254
# File 'lib/stripe/services/invoice_service.rb', line 5249

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



5238
5239
5240
# File 'lib/stripe/services/invoice_service.rb', line 5238

def add
  @add
end

#removeObject

Details of the subscription item to remove.



5241
5242
5243
# File 'lib/stripe/services/invoice_service.rb', line 5241

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



5244
5245
5246
# File 'lib/stripe/services/invoice_service.rb', line 5244

def set
  @set
end

#typeObject

Determines the type of item action.



5247
5248
5249
# File 'lib/stripe/services/invoice_service.rb', line 5247

def type
  @type
end