Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



4584
4585
4586
4587
4588
4589
# File 'lib/stripe/services/invoice_service.rb', line 4584

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



4576
4577
4578
# File 'lib/stripe/services/invoice_service.rb', line 4576

def add
  @add
end

#removeObject

Details of the subscription item to remove.



4578
4579
4580
# File 'lib/stripe/services/invoice_service.rb', line 4578

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



4580
4581
4582
# File 'lib/stripe/services/invoice_service.rb', line 4580

def set
  @set
end

#typeObject

Determines the type of item action.



4582
4583
4584
# File 'lib/stripe/services/invoice_service.rb', line 4582

def type
  @type
end