Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
2646
2647
2648
2649
# File 'lib/stripe/services/invoice_service.rb', line 2635

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



2623
2624
2625
# File 'lib/stripe/services/invoice_service.rb', line 2623

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2625
2626
2627
# File 'lib/stripe/services/invoice_service.rb', line 2625

def 
  @metadata
end

#priceObject

The ID of the price object.



2627
2628
2629
# File 'lib/stripe/services/invoice_service.rb', line 2627

def price
  @price
end

#quantityObject

Quantity for this item.



2629
2630
2631
# File 'lib/stripe/services/invoice_service.rb', line 2629

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



2631
2632
2633
# File 'lib/stripe/services/invoice_service.rb', line 2631

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



2633
2634
2635
# File 'lib/stripe/services/invoice_service.rb', line 2633

def trial
  @trial
end