Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



2646
2647
2648
2649
2650
2651
2652
2653
2654
2655
2656
2657
2658
2659
2660
# File 'lib/stripe/services/invoice_service.rb', line 2646

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



2634
2635
2636
# File 'lib/stripe/services/invoice_service.rb', line 2634

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2636
2637
2638
# File 'lib/stripe/services/invoice_service.rb', line 2636

def 
  @metadata
end

#priceObject

The ID of the price object.



2638
2639
2640
# File 'lib/stripe/services/invoice_service.rb', line 2638

def price
  @price
end

#quantityObject

Quantity for this item.



2640
2641
2642
# File 'lib/stripe/services/invoice_service.rb', line 2640

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



2642
2643
2644
# File 'lib/stripe/services/invoice_service.rb', line 2642

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



2644
2645
2646
# File 'lib/stripe/services/invoice_service.rb', line 2644

def trial
  @trial
end