Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



4465
4466
4467
4468
4469
4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
# File 'lib/stripe/services/invoice_service.rb', line 4465

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



4453
4454
4455
# File 'lib/stripe/services/invoice_service.rb', line 4453

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



4455
4456
4457
# File 'lib/stripe/services/invoice_service.rb', line 4455

def 
  @metadata
end

#priceObject

The ID of the price object.



4457
4458
4459
# File 'lib/stripe/services/invoice_service.rb', line 4457

def price
  @price
end

#quantityObject

Quantity for this item.



4459
4460
4461
# File 'lib/stripe/services/invoice_service.rb', line 4459

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



4461
4462
4463
# File 'lib/stripe/services/invoice_service.rb', line 4461

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



4463
4464
4465
# File 'lib/stripe/services/invoice_service.rb', line 4463

def trial
  @trial
end