Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add

Returns a new instance of Add.



5115
5116
5117
5118
5119
5120
5121
5122
5123
5124
5125
5126
5127
5128
5129
# File 'lib/stripe/services/invoice_service.rb', line 5115

def initialize(
  discounts: nil,
  metadata: nil,
  price: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @price = price
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The discounts applied to the item. Subscription item discounts are applied before subscription discounts.



5098
5099
5100
# File 'lib/stripe/services/invoice_service.rb', line 5098

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



5101
5102
5103
# File 'lib/stripe/services/invoice_service.rb', line 5101

def 
  @metadata
end

#priceObject

The ID of the price object.



5104
5105
5106
# File 'lib/stripe/services/invoice_service.rb', line 5104

def price
  @price
end

#quantityObject

Quantity for this item.



5107
5108
5109
# File 'lib/stripe/services/invoice_service.rb', line 5107

def quantity
  @quantity
end

#tax_ratesObject

The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.



5110
5111
5112
# File 'lib/stripe/services/invoice_service.rb', line 5110

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



5113
5114
5115
# File 'lib/stripe/services/invoice_service.rb', line 5113

def trial
  @trial
end