Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2614
2615
2616
2617
2618
2619
# File 'lib/stripe/services/invoice_service.rb', line 2614

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2606
2607
2608
# File 'lib/stripe/services/invoice_service.rb', line 2606

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2608
2609
2610
# File 'lib/stripe/services/invoice_service.rb', line 2608

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2610
2611
2612
# File 'lib/stripe/services/invoice_service.rb', line 2610

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2612
2613
2614
# File 'lib/stripe/services/invoice_service.rb', line 2612

def promotion_code
  @promotion_code
end