Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



5077
5078
5079
5080
5081
5082
# File 'lib/stripe/services/invoice_service.rb', line 5077

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



5066
5067
5068
# File 'lib/stripe/services/invoice_service.rb', line 5066

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



5069
5070
5071
# File 'lib/stripe/services/invoice_service.rb', line 5069

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



5072
5073
5074
# File 'lib/stripe/services/invoice_service.rb', line 5072

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



5075
5076
5077
# File 'lib/stripe/services/invoice_service.rb', line 5075

def promotion_code
  @promotion_code
end