Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4433
4434
4435
4436
4437
4438
# File 'lib/stripe/services/invoice_service.rb', line 4433

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4425
4426
4427
# File 'lib/stripe/services/invoice_service.rb', line 4425

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4427
4428
4429
# File 'lib/stripe/services/invoice_service.rb', line 4427

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4429
4430
4431
# File 'lib/stripe/services/invoice_service.rb', line 4429

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4431
4432
4433
# File 'lib/stripe/services/invoice_service.rb', line 4431

def promotion_code
  @promotion_code
end