Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2588
2589
2590
2591
2592
# File 'lib/stripe/services/invoice_service.rb', line 2588

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2582
2583
2584
# File 'lib/stripe/services/invoice_service.rb', line 2582

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2584
2585
2586
# File 'lib/stripe/services/invoice_service.rb', line 2584

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2586
2587
2588
# File 'lib/stripe/services/invoice_service.rb', line 2586

def type
  @type
end