Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4418
4419
4420
4421
4422
# File 'lib/stripe/services/invoice_service.rb', line 4418

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4412
4413
4414
# File 'lib/stripe/services/invoice_service.rb', line 4412

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4414
4415
4416
# File 'lib/stripe/services/invoice_service.rb', line 4414

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4416
4417
4418
# File 'lib/stripe/services/invoice_service.rb', line 4416

def type
  @type
end