Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2682
2683
2684
2685
2686
# File 'lib/stripe/services/invoice_service.rb', line 2682

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2676
2677
2678
# File 'lib/stripe/services/invoice_service.rb', line 2676

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2678
2679
2680
# File 'lib/stripe/services/invoice_service.rb', line 2678

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2680
2681
2682
# File 'lib/stripe/services/invoice_service.rb', line 2680

def type
  @type
end