Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4512
4513
4514
4515
4516
# File 'lib/stripe/services/invoice_service.rb', line 4512

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4506
4507
4508
# File 'lib/stripe/services/invoice_service.rb', line 4506

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4508
4509
4510
# File 'lib/stripe/services/invoice_service.rb', line 4508

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4510
4511
4512
# File 'lib/stripe/services/invoice_service.rb', line 4510

def type
  @type
end