Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



5165
5166
5167
5168
5169
# File 'lib/stripe/services/invoice_service.rb', line 5165

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



5157
5158
5159
# File 'lib/stripe/services/invoice_service.rb', line 5157

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



5160
5161
5162
# File 'lib/stripe/services/invoice_service.rb', line 5160

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



5163
5164
5165
# File 'lib/stripe/services/invoice_service.rb', line 5163

def type
  @type
end