Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::ItemAction::Set::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
4512 4513 4514 4515 4516 |
# File 'lib/stripe/services/invoice_service.rb', line 4512 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
4506 4507 4508 |
# File 'lib/stripe/services/invoice_service.rb', line 4506 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
4508 4509 4510 |
# File 'lib/stripe/services/invoice_service.rb', line 4508 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
4510 4511 4512 |
# File 'lib/stripe/services/invoice_service.rb', line 4510 def type @type end |