Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::TrialSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Amendment::TrialSettings
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: EndBehavior
Instance Attribute Summary collapse
-
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
Instance Method Summary collapse
-
#initialize(end_behavior: nil) ⇒ TrialSettings
constructor
A new instance of TrialSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(end_behavior: nil) ⇒ TrialSettings
Returns a new instance of TrialSettings.
5311 5312 5313 |
# File 'lib/stripe/services/invoice_service.rb', line 5311 def initialize(end_behavior: nil) @end_behavior = end_behavior end |
Instance Attribute Details
#end_behavior ⇒ Object
Defines how the subscription should behave when a trial ends.
5309 5310 5311 |
# File 'lib/stripe/services/invoice_service.rb', line 5309 def end_behavior @end_behavior end |