Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
-
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed.
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule.
-
#default_tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
-
#description ⇒ Object
Subscription description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase.
-
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
-
#iterations ⇒ Object
Integer representing the multiplier applied to the price interval.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
-
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused.
-
#proration_behavior ⇒ Object
Controls whether the subscription schedule should create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase if there is a difference in billing configuration.
-
#start_date ⇒ Object
The date at which this phase of the subscription schedule starts or ‘now`.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
-
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
-
#trial_continuation ⇒ Object
Specify trial behavior when crossing phase boundaries.
-
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil) ⇒ Phase
Returns a new instance of Phase.
3308 3309 3310 3311 3312 3313 3314 3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 3349 3350 3351 3352 3353 3354 3355 3356 3357 3358 3359 3360 |
# File 'lib/stripe/services/invoice_service.rb', line 3308 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @billing_thresholds = billing_thresholds @collection_method = collection_method @currency = currency @default_payment_method = default_payment_method @default_tax_rates = default_tax_rates @description = description @discounts = discounts @end_date = end_date @invoice_settings = invoice_settings @items = items @iterations = iterations @metadata = @on_behalf_of = on_behalf_of @pause_collection = pause_collection @proration_behavior = proration_behavior @start_date = start_date @transfer_data = transfer_data @trial = trial @trial_continuation = trial_continuation @trial_end = trial_end @trial_settings = trial_settings end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.
3258 3259 3260 |
# File 'lib/stripe/services/invoice_service.rb', line 3258 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
3260 3261 3262 |
# File 'lib/stripe/services/invoice_service.rb', line 3260 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
3262 3263 3264 |
# File 'lib/stripe/services/invoice_service.rb', line 3262 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).
3264 3265 3266 |
# File 'lib/stripe/services/invoice_service.rb', line 3264 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
3266 3267 3268 |
# File 'lib/stripe/services/invoice_service.rb', line 3266 def billing_thresholds @billing_thresholds end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.
3268 3269 3270 |
# File 'lib/stripe/services/invoice_service.rb', line 3268 def collection_method @collection_method end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3270 3271 3272 |
# File 'lib/stripe/services/invoice_service.rb', line 3270 def currency @currency end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.
3272 3273 3274 |
# File 'lib/stripe/services/invoice_service.rb', line 3272 def default_payment_method @default_payment_method end |
#default_tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will set the Subscription’s [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates), which means they will be the Invoice’s [‘default_tax_rates`](stripe.com/docs/api/invoices/create#create_invoice-default_tax_rates) for any Invoices issued by the Subscription during this Phase.
3274 3275 3276 |
# File 'lib/stripe/services/invoice_service.rb', line 3274 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
3276 3277 3278 |
# File 'lib/stripe/services/invoice_service.rb', line 3276 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription’s customer. Pass an empty string to avoid inheriting any discounts.
3278 3279 3280 |
# File 'lib/stripe/services/invoice_service.rb', line 3278 def discounts @discounts end |
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends. If set, ‘iterations` must not be set.
3280 3281 3282 |
# File 'lib/stripe/services/invoice_service.rb', line 3280 def end_date @end_date end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
3282 3283 3284 |
# File 'lib/stripe/services/invoice_service.rb', line 3282 def invoice_settings @invoice_settings end |
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
3284 3285 3286 |
# File 'lib/stripe/services/invoice_service.rb', line 3284 def items @items end |
#iterations ⇒ Object
Integer representing the multiplier applied to the price interval. For example, ‘iterations=2` applied to a price with `interval=month` and `interval_count=3` results in a phase of duration `2 * 3 months = 6 months`. If set, `end_date` must not be set.
3286 3287 3288 |
# File 'lib/stripe/services/invoice_service.rb', line 3286 def iterations @iterations end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys in the subscription’s ‘metadata`. Individual keys in the subscription’s ‘metadata` can be unset by posting an empty value to them in the phase’s ‘metadata`. To unset all keys in the subscription’s ‘metadata`, update the subscription directly or unset every key individually from the phase’s ‘metadata`.
3288 3289 3290 |
# File 'lib/stripe/services/invoice_service.rb', line 3288 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
3290 3291 3292 |
# File 'lib/stripe/services/invoice_service.rb', line 3290 def on_behalf_of @on_behalf_of end |
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).
3292 3293 3294 |
# File 'lib/stripe/services/invoice_service.rb', line 3292 def pause_collection @pause_collection end |
#proration_behavior ⇒ Object
Controls whether the subscription schedule should create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase if there is a difference in billing configuration. It’s different from the request-level [proration_behavior](stripe.com/docs/api/subscription_schedules/update#update_subscription_schedule-proration_behavior) parameter which controls what happens if the update request affects the billing configuration (item price, quantity, etc.) of the current phase.
3294 3295 3296 |
# File 'lib/stripe/services/invoice_service.rb', line 3294 def proration_behavior @proration_behavior end |
#start_date ⇒ Object
The date at which this phase of the subscription schedule starts or ‘now`. Must be set on the first phase.
3296 3297 3298 |
# File 'lib/stripe/services/invoice_service.rb', line 3296 def start_date @start_date end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
3298 3299 3300 |
# File 'lib/stripe/services/invoice_service.rb', line 3298 def transfer_data @transfer_data end |
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
3300 3301 3302 |
# File 'lib/stripe/services/invoice_service.rb', line 3300 def trial @trial end |
#trial_continuation ⇒ Object
Specify trial behavior when crossing phase boundaries
3302 3303 3304 |
# File 'lib/stripe/services/invoice_service.rb', line 3302 def trial_continuation @trial_continuation end |
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date. Must be before the phase end date, can not be combined with ‘trial`
3304 3305 3306 |
# File 'lib/stripe/services/invoice_service.rb', line 3304 def trial_end @trial_end end |
#trial_settings ⇒ Object
Settings related to subscription trials.
3306 3307 3308 |
# File 'lib/stripe/services/invoice_service.rb', line 3306 def trial_settings @trial_settings end |