Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem

Returns a new instance of AddInvoiceItem.



2215
2216
2217
2218
2219
2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
# File 'lib/stripe/services/invoice_service.rb', line 2215

def initialize(
  discounts: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @discounts = discounts
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the item.



2201
2202
2203
# File 'lib/stripe/services/invoice_service.rb', line 2201

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2203
2204
2205
# File 'lib/stripe/services/invoice_service.rb', line 2203

def 
  @metadata
end

#periodObject

The period associated with this invoice item. Defaults to the period of the underlying subscription that surrounds the start of the phase.



2205
2206
2207
# File 'lib/stripe/services/invoice_service.rb', line 2205

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



2207
2208
2209
# File 'lib/stripe/services/invoice_service.rb', line 2207

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



2209
2210
2211
# File 'lib/stripe/services/invoice_service.rb', line 2209

def price_data
  @price_data
end

#quantityObject

Quantity for this item. Defaults to 1.



2211
2212
2213
# File 'lib/stripe/services/invoice_service.rb', line 2211

def quantity
  @quantity
end

#tax_ratesObject

The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.



2213
2214
2215
# File 'lib/stripe/services/invoice_service.rb', line 2213

def tax_rates
  @tax_rates
end