Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates which apply to the item.
Instance Method Summary collapse
-
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
constructor
A new instance of AddInvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ AddInvoiceItem
Returns a new instance of AddInvoiceItem.
5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 5478 |
# File 'lib/stripe/services/invoice_service.rb', line 5466 def initialize( discounts: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the item.
5452 5453 5454 |
# File 'lib/stripe/services/invoice_service.rb', line 5452 def discounts @discounts end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
5455 5456 5457 |
# File 'lib/stripe/services/invoice_service.rb', line 5455 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
5458 5459 5460 |
# File 'lib/stripe/services/invoice_service.rb', line 5458 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item. Defaults to 1.
5461 5462 5463 |
# File 'lib/stripe/services/invoice_service.rb', line 5461 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates which apply to the item. When set, the ‘default_tax_rates` do not apply to this item.
5464 5465 5466 |
# File 'lib/stripe/services/invoice_service.rb', line 5464 def tax_rates @tax_rates end |