Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2908
2909
2910
2911
2912
2913
# File 'lib/stripe/services/invoice_service.rb', line 2908

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2900
2901
2902
# File 'lib/stripe/services/invoice_service.rb', line 2900

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2902
2903
2904
# File 'lib/stripe/services/invoice_service.rb', line 2902

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2904
2905
2906
# File 'lib/stripe/services/invoice_service.rb', line 2904

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2906
2907
2908
# File 'lib/stripe/services/invoice_service.rb', line 2906

def promotion_code
  @promotion_code
end