Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2926
2927
2928
2929
2930
2931
# File 'lib/stripe/services/invoice_service.rb', line 2926

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2918
2919
2920
# File 'lib/stripe/services/invoice_service.rb', line 2918

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2920
2921
2922
# File 'lib/stripe/services/invoice_service.rb', line 2920

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2922
2923
2924
# File 'lib/stripe/services/invoice_service.rb', line 2922

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2924
2925
2926
# File 'lib/stripe/services/invoice_service.rb', line 2924

def promotion_code
  @promotion_code
end