Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2118
2119
2120
2121
2122
# File 'lib/stripe/services/invoice_service.rb', line 2118

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2112
2113
2114
# File 'lib/stripe/services/invoice_service.rb', line 2112

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2114
2115
2116
# File 'lib/stripe/services/invoice_service.rb', line 2114

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2116
2117
2118
# File 'lib/stripe/services/invoice_service.rb', line 2116

def promotion_code
  @promotion_code
end