Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4729
4730
4731
4732
4733
4734
# File 'lib/stripe/services/invoice_service.rb', line 4729

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4721
4722
4723
# File 'lib/stripe/services/invoice_service.rb', line 4721

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4723
4724
4725
# File 'lib/stripe/services/invoice_service.rb', line 4723

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4725
4726
4727
# File 'lib/stripe/services/invoice_service.rb', line 4725

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4727
4728
4729
# File 'lib/stripe/services/invoice_service.rb', line 4727

def promotion_code
  @promotion_code
end