Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



5413
5414
5415
5416
5417
5418
# File 'lib/stripe/services/invoice_service.rb', line 5413

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



5402
5403
5404
# File 'lib/stripe/services/invoice_service.rb', line 5402

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



5405
5406
5407
# File 'lib/stripe/services/invoice_service.rb', line 5405

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



5408
5409
5410
# File 'lib/stripe/services/invoice_service.rb', line 5408

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



5411
5412
5413
# File 'lib/stripe/services/invoice_service.rb', line 5411

def promotion_code
  @promotion_code
end