Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2893
2894
2895
2896
2897
# File 'lib/stripe/services/invoice_service.rb', line 2893

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2887
2888
2889
# File 'lib/stripe/services/invoice_service.rb', line 2887

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2889
2890
2891
# File 'lib/stripe/services/invoice_service.rb', line 2889

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2891
2892
2893
# File 'lib/stripe/services/invoice_service.rb', line 2891

def type
  @type
end