Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



2911
2912
2913
2914
2915
# File 'lib/stripe/services/invoice_service.rb', line 2911

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



2905
2906
2907
# File 'lib/stripe/services/invoice_service.rb', line 2905

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



2907
2908
2909
# File 'lib/stripe/services/invoice_service.rb', line 2907

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



2909
2910
2911
# File 'lib/stripe/services/invoice_service.rb', line 2909

def type
  @type
end