Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::End

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(timestamp: nil, type: nil) ⇒ End

Returns a new instance of End.



2146
2147
2148
2149
# File 'lib/stripe/services/invoice_service.rb', line 2146

def initialize(timestamp: nil, type: nil)
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#timestampObject

A precise Unix timestamp for the end of the invoice item period. Must be greater than or equal to ‘period.start`.



2142
2143
2144
# File 'lib/stripe/services/invoice_service.rb', line 2142

def timestamp
  @timestamp
end

#typeObject

Select how to calculate the end of the invoice item period.



2144
2145
2146
# File 'lib/stripe/services/invoice_service.rb', line 2144

def type
  @type
end