Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AddInvoiceItem::Period::Start
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period.
-
#type ⇒ Object
Select how to calculate the start of the invoice item period.
Instance Method Summary collapse
-
#initialize(timestamp: nil, type: nil) ⇒ Start
constructor
A new instance of Start.
Methods inherited from RequestParams
Constructor Details
#initialize(timestamp: nil, type: nil) ⇒ Start
Returns a new instance of Start.
2158 2159 2160 2161 |
# File 'lib/stripe/services/invoice_service.rb', line 2158 def initialize(timestamp: nil, type: nil) @timestamp = @type = type end |
Instance Attribute Details
#timestamp ⇒ Object
A precise Unix timestamp for the start of the invoice item period. Must be less than or equal to ‘period.end`.
2154 2155 2156 |
# File 'lib/stripe/services/invoice_service.rb', line 2154 def @timestamp end |
#type ⇒ Object
Select how to calculate the start of the invoice item period.
2156 2157 2158 |
# File 'lib/stripe/services/invoice_service.rb', line 2156 def type @type end |