Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::AutomaticTax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Liability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax

Returns a new instance of AutomaticTax.



2208
2209
2210
2211
# File 'lib/stripe/services/invoice_service.rb', line 2208

def initialize(enabled: nil, liability: nil)
  @enabled = enabled
  @liability = liability
end

Instance Attribute Details

#enabledObject

Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.



2204
2205
2206
# File 'lib/stripe/services/invoice_service.rb', line 2204

def enabled
  @enabled
end

#liabilityObject

The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.



2206
2207
2208
# File 'lib/stripe/services/invoice_service.rb', line 2206

def liability
  @liability
end