Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3038
3039
3040
3041
3042
3043
# File 'lib/stripe/services/invoice_service.rb', line 3038

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3030
3031
3032
# File 'lib/stripe/services/invoice_service.rb', line 3030

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3032
3033
3034
# File 'lib/stripe/services/invoice_service.rb', line 3032

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3034
3035
3036
# File 'lib/stripe/services/invoice_service.rb', line 3034

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3036
3037
3038
# File 'lib/stripe/services/invoice_service.rb', line 3036

def promotion_code
  @promotion_code
end