Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3029
3030
3031
3032
3033
3034
# File 'lib/stripe/services/invoice_service.rb', line 3029

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3021
3022
3023
# File 'lib/stripe/services/invoice_service.rb', line 3021

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3023
3024
3025
# File 'lib/stripe/services/invoice_service.rb', line 3023

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3025
3026
3027
# File 'lib/stripe/services/invoice_service.rb', line 3025

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3027
3028
3029
# File 'lib/stripe/services/invoice_service.rb', line 3027

def promotion_code
  @promotion_code
end