Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2225 2226 2227 2228 2229 |
# File 'lib/stripe/services/invoice_service.rb', line 2225 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2219 2220 2221 |
# File 'lib/stripe/services/invoice_service.rb', line 2219 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2221 2222 2223 |
# File 'lib/stripe/services/invoice_service.rb', line 2221 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2223 2224 2225 |
# File 'lib/stripe/services/invoice_service.rb', line 2223 def promotion_code @promotion_code end |