Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3044
3045
3046
3047
3048
3049
# File 'lib/stripe/services/invoice_service.rb', line 3044

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3036
3037
3038
# File 'lib/stripe/services/invoice_service.rb', line 3036

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3038
3039
3040
# File 'lib/stripe/services/invoice_service.rb', line 3038

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3040
3041
3042
# File 'lib/stripe/services/invoice_service.rb', line 3040

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3042
3043
3044
# File 'lib/stripe/services/invoice_service.rb', line 3042

def promotion_code
  @promotion_code
end