Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



5560
5561
5562
5563
5564
5565
# File 'lib/stripe/services/invoice_service.rb', line 5560

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



5549
5550
5551
# File 'lib/stripe/services/invoice_service.rb', line 5549

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



5552
5553
5554
# File 'lib/stripe/services/invoice_service.rb', line 5552

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



5555
5556
5557
# File 'lib/stripe/services/invoice_service.rb', line 5555

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



5558
5559
5560
# File 'lib/stripe/services/invoice_service.rb', line 5558

def promotion_code
  @promotion_code
end