Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4859
4860
4861
4862
4863
4864
# File 'lib/stripe/services/invoice_service.rb', line 4859

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4851
4852
4853
# File 'lib/stripe/services/invoice_service.rb', line 4851

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4853
4854
4855
# File 'lib/stripe/services/invoice_service.rb', line 4853

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4855
4856
4857
# File 'lib/stripe/services/invoice_service.rb', line 4855

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4857
4858
4859
# File 'lib/stripe/services/invoice_service.rb', line 4857

def promotion_code
  @promotion_code
end