Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3023
3024
3025
3026
3027
# File 'lib/stripe/services/invoice_service.rb', line 3023

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3017
3018
3019
# File 'lib/stripe/services/invoice_service.rb', line 3017

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3019
3020
3021
# File 'lib/stripe/services/invoice_service.rb', line 3019

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3021
3022
3023
# File 'lib/stripe/services/invoice_service.rb', line 3021

def type
  @type
end