Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3014
3015
3016
3017
3018
# File 'lib/stripe/services/invoice_service.rb', line 3014

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3008
3009
3010
# File 'lib/stripe/services/invoice_service.rb', line 3008

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3010
3011
3012
# File 'lib/stripe/services/invoice_service.rb', line 3010

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3012
3013
3014
# File 'lib/stripe/services/invoice_service.rb', line 3012

def type
  @type
end