Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3013
3014
3015
3016
3017
# File 'lib/stripe/services/invoice_service.rb', line 3013

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3007
3008
3009
# File 'lib/stripe/services/invoice_service.rb', line 3007

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3009
3010
3011
# File 'lib/stripe/services/invoice_service.rb', line 3009

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3011
3012
3013
# File 'lib/stripe/services/invoice_service.rb', line 3011

def type
  @type
end