Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4844
4845
4846
4847
4848
# File 'lib/stripe/services/invoice_service.rb', line 4844

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4838
4839
4840
# File 'lib/stripe/services/invoice_service.rb', line 4838

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4840
4841
4842
# File 'lib/stripe/services/invoice_service.rb', line 4840

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4842
4843
4844
# File 'lib/stripe/services/invoice_service.rb', line 4842

def type
  @type
end