Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::InvoiceSettings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Issuer

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil) ⇒ InvoiceSettings

Returns a new instance of InvoiceSettings.



5590
5591
5592
5593
5594
# File 'lib/stripe/services/invoice_service.rb', line 5590

def initialize(account_tax_ids: nil, days_until_due: nil, issuer: nil)
  @account_tax_ids = 
  @days_until_due = days_until_due
  @issuer = issuer
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with this phase of the subscription schedule. Will be set on invoices generated by this phase of the subscription schedule.



5582
5583
5584
# File 'lib/stripe/services/invoice_service.rb', line 5582

def 
  @account_tax_ids
end

#days_until_dueObject

Number of days within which a customer must pay invoices generated by this subscription schedule. This value will be ‘null` for subscription schedules where `billing=charge_automatically`.



5585
5586
5587
# File 'lib/stripe/services/invoice_service.rb', line 5585

def days_until_due
  @days_until_due
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



5588
5589
5590
# File 'lib/stripe/services/invoice_service.rb', line 5588

def issuer
  @issuer
end