Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, PriceData, Trial

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item

Returns a new instance of Item.



3176
3177
3178
3179
3180
3181
3182
3183
3184
3185
3186
3187
3188
3189
3190
3191
3192
3193
3194
# File 'lib/stripe/services/invoice_service.rb', line 3176

def initialize(
  discounts: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil,
  trial: nil
)
  @discounts = discounts
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
  @trial = trial
end

Instance Attribute Details

#discountsObject

The coupons to redeem into discounts for the subscription item.



3160
3161
3162
# File 'lib/stripe/services/invoice_service.rb', line 3160

def discounts
  @discounts
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.



3162
3163
3164
# File 'lib/stripe/services/invoice_service.rb', line 3162

def 
  @metadata
end

#planObject

The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.



3164
3165
3166
# File 'lib/stripe/services/invoice_service.rb', line 3164

def plan
  @plan
end

#priceObject

The ID of the price object.



3166
3167
3168
# File 'lib/stripe/services/invoice_service.rb', line 3166

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



3168
3169
3170
# File 'lib/stripe/services/invoice_service.rb', line 3168

def price_data
  @price_data
end

#quantityObject

Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.



3170
3171
3172
# File 'lib/stripe/services/invoice_service.rb', line 3170

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3172
3173
3174
# File 'lib/stripe/services/invoice_service.rb', line 3172

def tax_rates
  @tax_rates
end

#trialObject

Options that configure the trial on the subscription item.



3174
3175
3176
# File 'lib/stripe/services/invoice_service.rb', line 3174

def trial
  @trial
end