Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
2313 2314 2315 2316 2317 2318 2319 2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 |
# File 'lib/stripe/services/invoice_service.rb', line 2313 def initialize( discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
2299 2300 2301 |
# File 'lib/stripe/services/invoice_service.rb', line 2299 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.
2301 2302 2303 |
# File 'lib/stripe/services/invoice_service.rb', line 2301 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.
2303 2304 2305 |
# File 'lib/stripe/services/invoice_service.rb', line 2303 def plan @plan end |
#price ⇒ Object
The ID of the price object.
2305 2306 2307 |
# File 'lib/stripe/services/invoice_service.rb', line 2305 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
2307 2308 2309 |
# File 'lib/stripe/services/invoice_service.rb', line 2307 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.
2309 2310 2311 |
# File 'lib/stripe/services/invoice_service.rb', line 2309 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
2311 2312 2313 |
# File 'lib/stripe/services/invoice_service.rb', line 2311 def tax_rates @tax_rates end |