Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
3117 3118 3119 3120 3121 3122 |
# File 'lib/stripe/services/invoice_service.rb', line 3117 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
3109 3110 3111 |
# File 'lib/stripe/services/invoice_service.rb', line 3109 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
3111 3112 3113 |
# File 'lib/stripe/services/invoice_service.rb', line 3111 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
3113 3114 3115 |
# File 'lib/stripe/services/invoice_service.rb', line 3113 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
3115 3116 3117 |
# File 'lib/stripe/services/invoice_service.rb', line 3115 def promotion_code @promotion_code end |