Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2285
2286
2287
2288
2289
# File 'lib/stripe/services/invoice_service.rb', line 2285

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2279
2280
2281
# File 'lib/stripe/services/invoice_service.rb', line 2279

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2281
2282
2283
# File 'lib/stripe/services/invoice_service.rb', line 2281

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2283
2284
2285
# File 'lib/stripe/services/invoice_service.rb', line 2283

def promotion_code
  @promotion_code
end