Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3114
3115
3116
3117
3118
3119
# File 'lib/stripe/services/invoice_service.rb', line 3114

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3106
3107
3108
# File 'lib/stripe/services/invoice_service.rb', line 3106

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3108
3109
3110
# File 'lib/stripe/services/invoice_service.rb', line 3108

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3110
3111
3112
# File 'lib/stripe/services/invoice_service.rb', line 3110

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3112
3113
3114
# File 'lib/stripe/services/invoice_service.rb', line 3112

def promotion_code
  @promotion_code
end