Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4938
4939
4940
4941
4942
4943
# File 'lib/stripe/services/invoice_service.rb', line 4938

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4930
4931
4932
# File 'lib/stripe/services/invoice_service.rb', line 4930

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4932
4933
4934
# File 'lib/stripe/services/invoice_service.rb', line 4932

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4934
4935
4936
# File 'lib/stripe/services/invoice_service.rb', line 4934

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4936
4937
4938
# File 'lib/stripe/services/invoice_service.rb', line 4936

def promotion_code
  @promotion_code
end