Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



5630
5631
5632
5633
5634
# File 'lib/stripe/services/invoice_service.rb', line 5630

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



5622
5623
5624
# File 'lib/stripe/services/invoice_service.rb', line 5622

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



5625
5626
5627
# File 'lib/stripe/services/invoice_service.rb', line 5625

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



5628
5629
5630
# File 'lib/stripe/services/invoice_service.rb', line 5628

def type
  @type
end