Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::Item::Discount::DiscountEnd::Duration
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
4911 4912 4913 4914 |
# File 'lib/stripe/services/invoice_service.rb', line 4911 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
4907 4908 4909 |
# File 'lib/stripe/services/invoice_service.rb', line 4907 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
4909 4910 4911 |
# File 'lib/stripe/services/invoice_service.rb', line 4909 def interval_count @interval_count end |