Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



3307
3308
3309
3310
# File 'lib/stripe/services/invoice_service.rb', line 3307

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



3303
3304
3305
# File 'lib/stripe/services/invoice_service.rb', line 3303

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



3305
3306
3307
# File 'lib/stripe/services/invoice_service.rb', line 3305

def destination
  @destination
end