Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2389
2390
2391
2392
# File 'lib/stripe/services/invoice_service.rb', line 2389

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



2385
2386
2387
# File 'lib/stripe/services/invoice_service.rb', line 2385

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2387
2388
2389
# File 'lib/stripe/services/invoice_service.rb', line 2387

def destination
  @destination
end