Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2368
2369
2370
2371
# File 'lib/stripe/services/invoice_service.rb', line 2368

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



2364
2365
2366
# File 'lib/stripe/services/invoice_service.rb', line 2364

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



2366
2367
2368
# File 'lib/stripe/services/invoice_service.rb', line 2366

def destination
  @destination
end