Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



5056
5057
5058
5059
# File 'lib/stripe/services/invoice_service.rb', line 5056

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



5052
5053
5054
# File 'lib/stripe/services/invoice_service.rb', line 5052

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



5054
5055
5056
# File 'lib/stripe/services/invoice_service.rb', line 5054

def destination
  @destination
end