Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



5782
5783
5784
5785
# File 'lib/stripe/services/invoice_service.rb', line 5782

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



5777
5778
5779
# File 'lib/stripe/services/invoice_service.rb', line 5777

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



5780
5781
5782
# File 'lib/stripe/services/invoice_service.rb', line 5780

def destination
  @destination
end