Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Prebilling
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: BillUntil
Instance Attribute Summary collapse
-
#bill_until ⇒ Object
The end of the prebilled time period.
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(bill_until: nil, iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(bill_until: nil, iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
5231 5232 5233 5234 |
# File 'lib/stripe/services/invoice_service.rb', line 5231 def initialize(bill_until: nil, iterations: nil) @bill_until = bill_until @iterations = iterations end |
Instance Attribute Details
#bill_until ⇒ Object
The end of the prebilled time period.
5227 5228 5229 |
# File 'lib/stripe/services/invoice_service.rb', line 5227 def bill_until @bill_until end |
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
5229 5230 5231 |
# File 'lib/stripe/services/invoice_service.rb', line 5229 def iterations @iterations end |