Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



3394
3395
3396
3397
3398
3399
# File 'lib/stripe/services/invoice_service.rb', line 3394

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



3386
3387
3388
# File 'lib/stripe/services/invoice_service.rb', line 3386

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



3388
3389
3390
# File 'lib/stripe/services/invoice_service.rb', line 3388

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



3390
3391
3392
# File 'lib/stripe/services/invoice_service.rb', line 3390

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



3392
3393
3394
# File 'lib/stripe/services/invoice_service.rb', line 3392

def type
  @type
end