Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ BillUntil

Returns a new instance of BillUntil.



5219
5220
5221
5222
5223
5224
# File 'lib/stripe/services/invoice_service.rb', line 5219

def initialize(amendment_end: nil, duration: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

End the prebilled period when a specified amendment ends.



5211
5212
5213
# File 'lib/stripe/services/invoice_service.rb', line 5211

def amendment_end
  @amendment_end
end

#durationObject

Time span for prebilling, starting from ‘bill_from`.



5213
5214
5215
# File 'lib/stripe/services/invoice_service.rb', line 5213

def duration
  @duration
end

#timestampObject

End the prebilled period at a precise integer timestamp, starting from the Unix epoch.



5215
5216
5217
# File 'lib/stripe/services/invoice_service.rb', line 5215

def timestamp
  @timestamp
end

#typeObject

Select one of several ways to pass the ‘bill_until` value.



5217
5218
5219
# File 'lib/stripe/services/invoice_service.rb', line 5217

def type
  @type
end