Class: Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::ScheduleDetails::Prebilling::BillUntil::Duration
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
5957 5958 5959 5960 |
# File 'lib/stripe/services/invoice_service.rb', line 5957 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
5952 5953 5954 |
# File 'lib/stripe/services/invoice_service.rb', line 5952 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
5955 5956 5957 |
# File 'lib/stripe/services/invoice_service.rb', line 5955 def interval_count @interval_count end |