Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



3648
3649
3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
3664
3665
3666
3667
3668
3669
3670
3671
3672
# File 'lib/stripe/services/invoice_service.rb', line 3648

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



3626
3627
3628
# File 'lib/stripe/services/invoice_service.rb', line 3626

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



3628
3629
3630
# File 'lib/stripe/services/invoice_service.rb', line 3628

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



3630
3631
3632
# File 'lib/stripe/services/invoice_service.rb', line 3630

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3632
3633
3634
# File 'lib/stripe/services/invoice_service.rb', line 3632

def discounts
  @discounts
end

#idObject

Subscription item to update.



3634
3635
3636
# File 'lib/stripe/services/invoice_service.rb', line 3634

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3636
3637
3638
# File 'lib/stripe/services/invoice_service.rb', line 3636

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



3638
3639
3640
# File 'lib/stripe/services/invoice_service.rb', line 3638

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



3640
3641
3642
# File 'lib/stripe/services/invoice_service.rb', line 3640

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3642
3643
3644
# File 'lib/stripe/services/invoice_service.rb', line 3642

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3644
3645
3646
# File 'lib/stripe/services/invoice_service.rb', line 3644

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3646
3647
3648
# File 'lib/stripe/services/invoice_service.rb', line 3646

def tax_rates
  @tax_rates
end