Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
3589
3590
3591
3592
3593
3594
3595
3596
# File 'lib/stripe/services/invoice_service.rb', line 3572

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.



3550
3551
3552
# File 'lib/stripe/services/invoice_service.rb', line 3550

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



3552
3553
3554
# File 'lib/stripe/services/invoice_service.rb', line 3552

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



3554
3555
3556
# File 'lib/stripe/services/invoice_service.rb', line 3554

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3556
3557
3558
# File 'lib/stripe/services/invoice_service.rb', line 3556

def discounts
  @discounts
end

#idObject

Subscription item to update.



3558
3559
3560
# File 'lib/stripe/services/invoice_service.rb', line 3558

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3560
3561
3562
# File 'lib/stripe/services/invoice_service.rb', line 3560

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



3562
3563
3564
# File 'lib/stripe/services/invoice_service.rb', line 3562

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



3564
3565
3566
# File 'lib/stripe/services/invoice_service.rb', line 3564

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3566
3567
3568
# File 'lib/stripe/services/invoice_service.rb', line 3566

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3568
3569
3570
# File 'lib/stripe/services/invoice_service.rb', line 3568

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3570
3571
3572
# File 'lib/stripe/services/invoice_service.rb', line 3570

def tax_rates
  @tax_rates
end