Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



3525
3526
3527
3528
3529
3530
3531
3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
3545
3546
3547
# File 'lib/stripe/services/invoice_service.rb', line 3525

def initialize(
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



3505
3506
3507
# File 'lib/stripe/services/invoice_service.rb', line 3505

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



3507
3508
3509
# File 'lib/stripe/services/invoice_service.rb', line 3507

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



3509
3510
3511
# File 'lib/stripe/services/invoice_service.rb', line 3509

def discounts
  @discounts
end

#idObject

Subscription item to update.



3511
3512
3513
# File 'lib/stripe/services/invoice_service.rb', line 3511

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



3513
3514
3515
# File 'lib/stripe/services/invoice_service.rb', line 3513

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



3515
3516
3517
# File 'lib/stripe/services/invoice_service.rb', line 3515

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



3517
3518
3519
# File 'lib/stripe/services/invoice_service.rb', line 3517

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



3519
3520
3521
# File 'lib/stripe/services/invoice_service.rb', line 3519

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



3521
3522
3523
# File 'lib/stripe/services/invoice_service.rb', line 3521

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



3523
3524
3525
# File 'lib/stripe/services/invoice_service.rb', line 3523

def tax_rates
  @tax_rates
end