Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#clear_usage ⇒ Object
Delete all usage for a given subscription item.
-
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#id ⇒ Object
Subscription item to update.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#plan ⇒ Object
Plan ID for this item, as a string.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
Instance Method Summary collapse
-
#initialize(clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item
Returns a new instance of Item.
2525 2526 2527 2528 2529 2530 2531 2532 2533 2534 2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 2547 |
# File 'lib/stripe/services/invoice_service.rb', line 2525 def initialize( clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil ) @clear_usage = clear_usage @deleted = deleted @discounts = discounts @id = id @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#clear_usage ⇒ Object
Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.
2505 2506 2507 |
# File 'lib/stripe/services/invoice_service.rb', line 2505 def clear_usage @clear_usage end |
#deleted ⇒ Object
A flag that, if set to ‘true`, will delete the specified item.
2507 2508 2509 |
# File 'lib/stripe/services/invoice_service.rb', line 2507 def deleted @deleted end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
2509 2510 2511 |
# File 'lib/stripe/services/invoice_service.rb', line 2509 def discounts @discounts end |
#id ⇒ Object
Subscription item to update.
2511 2512 2513 |
# File 'lib/stripe/services/invoice_service.rb', line 2511 def id @id end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2513 2514 2515 |
# File 'lib/stripe/services/invoice_service.rb', line 2513 def @metadata end |
#plan ⇒ Object
Plan ID for this item, as a string.
2515 2516 2517 |
# File 'lib/stripe/services/invoice_service.rb', line 2515 def plan @plan end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.
2517 2518 2519 |
# File 'lib/stripe/services/invoice_service.rb', line 2517 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
2519 2520 2521 |
# File 'lib/stripe/services/invoice_service.rb', line 2519 def price_data @price_data end |
#quantity ⇒ Object
Quantity for this item.
2521 2522 2523 |
# File 'lib/stripe/services/invoice_service.rb', line 2521 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
2523 2524 2525 |
# File 'lib/stripe/services/invoice_service.rb', line 2523 def tax_rates @tax_rates end |