Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



6167
6168
6169
6170
6171
6172
6173
6174
6175
6176
6177
6178
6179
6180
6181
6182
6183
6184
6185
6186
6187
6188
6189
6190
6191
# File 'lib/stripe/services/invoice_service.rb', line 6167

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



6135
6136
6137
# File 'lib/stripe/services/invoice_service.rb', line 6135

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



6138
6139
6140
# File 'lib/stripe/services/invoice_service.rb', line 6138

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



6141
6142
6143
# File 'lib/stripe/services/invoice_service.rb', line 6141

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



6144
6145
6146
# File 'lib/stripe/services/invoice_service.rb', line 6144

def discounts
  @discounts
end

#idObject

Subscription item to update.



6147
6148
6149
# File 'lib/stripe/services/invoice_service.rb', line 6147

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6150
6151
6152
# File 'lib/stripe/services/invoice_service.rb', line 6150

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



6153
6154
6155
# File 'lib/stripe/services/invoice_service.rb', line 6153

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



6156
6157
6158
# File 'lib/stripe/services/invoice_service.rb', line 6156

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



6159
6160
6161
# File 'lib/stripe/services/invoice_service.rb', line 6159

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



6162
6163
6164
# File 'lib/stripe/services/invoice_service.rb', line 6162

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



6165
6166
6167
# File 'lib/stripe/services/invoice_service.rb', line 6165

def tax_rates
  @tax_rates
end