Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2536
2537
2538
2539
2540
# File 'lib/stripe/services/invoice_service.rb', line 2536

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2530
2531
2532
# File 'lib/stripe/services/invoice_service.rb', line 2530

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2532
2533
2534
# File 'lib/stripe/services/invoice_service.rb', line 2532

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2534
2535
2536
# File 'lib/stripe/services/invoice_service.rb', line 2534

def promotion_code
  @promotion_code
end