Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2520 2521 2522 2523 2524 |
# File 'lib/stripe/services/invoice_service.rb', line 2520 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2514 2515 2516 |
# File 'lib/stripe/services/invoice_service.rb', line 2514 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2516 2517 2518 |
# File 'lib/stripe/services/invoice_service.rb', line 2516 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2518 2519 2520 |
# File 'lib/stripe/services/invoice_service.rb', line 2518 def promotion_code @promotion_code end |