Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



2499
2500
2501
2502
2503
# File 'lib/stripe/services/invoice_service.rb', line 2499

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



2493
2494
2495
# File 'lib/stripe/services/invoice_service.rb', line 2493

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



2495
2496
2497
# File 'lib/stripe/services/invoice_service.rb', line 2495

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



2497
2498
2499
# File 'lib/stripe/services/invoice_service.rb', line 2497

def promotion_code
  @promotion_code
end