Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
2456 2457 2458 2459 2460 |
# File 'lib/stripe/services/invoice_service.rb', line 2456 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2450 2451 2452 |
# File 'lib/stripe/services/invoice_service.rb', line 2450 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2452 2453 2454 |
# File 'lib/stripe/services/invoice_service.rb', line 2452 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
2454 2455 2456 |
# File 'lib/stripe/services/invoice_service.rb', line 2454 def promotion_code @promotion_code end |