Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



6079
6080
6081
6082
6083
6084
# File 'lib/stripe/services/invoice_service.rb', line 6079

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



6068
6069
6070
# File 'lib/stripe/services/invoice_service.rb', line 6068

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



6071
6072
6073
# File 'lib/stripe/services/invoice_service.rb', line 6071

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



6074
6075
6076
# File 'lib/stripe/services/invoice_service.rb', line 6074

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



6077
6078
6079
# File 'lib/stripe/services/invoice_service.rb', line 6077

def promotion_code
  @promotion_code
end