Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



5312
5313
5314
5315
5316
5317
# File 'lib/stripe/services/invoice_service.rb', line 5312

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



5304
5305
5306
# File 'lib/stripe/services/invoice_service.rb', line 5304

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



5306
5307
5308
# File 'lib/stripe/services/invoice_service.rb', line 5306

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



5308
5309
5310
# File 'lib/stripe/services/invoice_service.rb', line 5308

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



5310
5311
5312
# File 'lib/stripe/services/invoice_service.rb', line 5310

def promotion_code
  @promotion_code
end