Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3561
3562
3563
3564
3565
# File 'lib/stripe/services/invoice_service.rb', line 3561

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3555
3556
3557
# File 'lib/stripe/services/invoice_service.rb', line 3555

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3557
3558
3559
# File 'lib/stripe/services/invoice_service.rb', line 3557

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3559
3560
3561
# File 'lib/stripe/services/invoice_service.rb', line 3559

def type
  @type
end