Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Item::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3485
3486
3487
3488
3489
# File 'lib/stripe/services/invoice_service.rb', line 3485

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3479
3480
3481
# File 'lib/stripe/services/invoice_service.rb', line 3479

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3481
3482
3483
# File 'lib/stripe/services/invoice_service.rb', line 3481

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3483
3484
3485
# File 'lib/stripe/services/invoice_service.rb', line 3483

def type
  @type
end