Class: Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Prebilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::CreatePreviewParams::SubscriptionDetails::Prebilling
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
Instance Method Summary collapse
-
#initialize(iterations: nil) ⇒ Prebilling
constructor
A new instance of Prebilling.
Methods inherited from RequestParams
Constructor Details
#initialize(iterations: nil) ⇒ Prebilling
Returns a new instance of Prebilling.
6198 6199 6200 |
# File 'lib/stripe/services/invoice_service.rb', line 6198 def initialize(iterations: nil) @iterations = iterations end |
Instance Attribute Details
#iterations ⇒ Object
This is used to determine the number of billing cycles to prebill.
6196 6197 6198 |
# File 'lib/stripe/services/invoice_service.rb', line 6196 def iterations @iterations end |