Class: Stripe::InvoiceService::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::ListParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#collection_method ⇒ Object
The collection method of the invoice to retrieve.
-
#created ⇒ Object
Only return invoices that were created during the given date interval.
-
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
-
#customer_account ⇒ Object
Only return invoices for the account specified by this account ID.
-
#due_date ⇒ Object
Attribute for param field due_date.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`.
-
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
Instance Method Summary collapse
-
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams
Returns a new instance of ListParams.
704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 |
# File 'lib/stripe/services/invoice_service.rb', line 704 def initialize( collection_method: nil, created: nil, customer: nil, customer_account: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil ) @collection_method = collection_method @created = created @customer = customer @customer_account = customer_account @due_date = due_date @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @subscription = subscription end |
Instance Attribute Details
#collection_method ⇒ Object
The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.
682 683 684 |
# File 'lib/stripe/services/invoice_service.rb', line 682 def collection_method @collection_method end |
#created ⇒ Object
Only return invoices that were created during the given date interval.
684 685 686 |
# File 'lib/stripe/services/invoice_service.rb', line 684 def created @created end |
#customer ⇒ Object
Only return invoices for the customer specified by this customer ID.
686 687 688 |
# File 'lib/stripe/services/invoice_service.rb', line 686 def customer @customer end |
#customer_account ⇒ Object
Only return invoices for the account specified by this account ID.
688 689 690 |
# File 'lib/stripe/services/invoice_service.rb', line 688 def customer_account @customer_account end |
#due_date ⇒ Object
Attribute for param field due_date
690 691 692 |
# File 'lib/stripe/services/invoice_service.rb', line 690 def due_date @due_date end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
692 693 694 |
# File 'lib/stripe/services/invoice_service.rb', line 692 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
694 695 696 |
# File 'lib/stripe/services/invoice_service.rb', line 694 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
696 697 698 |
# File 'lib/stripe/services/invoice_service.rb', line 696 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
698 699 700 |
# File 'lib/stripe/services/invoice_service.rb', line 698 def starting_after @starting_after end |
#status ⇒ Object
The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)
700 701 702 |
# File 'lib/stripe/services/invoice_service.rb', line 700 def status @status end |
#subscription ⇒ Object
Only return invoices for the subscription specified by this subscription ID.
702 703 704 |
# File 'lib/stripe/services/invoice_service.rb', line 702 def subscription @subscription end |