Class: Stripe::InvoiceService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Created, DueDate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collection_method: nil, created: nil, customer: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
# File 'lib/stripe/services/invoice_service.rb', line 638

def initialize(
  collection_method: nil,
  created: nil,
  customer: nil,
  due_date: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @collection_method = collection_method
  @created = created
  @customer = customer
  @due_date = due_date
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#collection_methodObject

The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.



618
619
620
# File 'lib/stripe/services/invoice_service.rb', line 618

def collection_method
  @collection_method
end

#createdObject

Only return invoices that were created during the given date interval.



620
621
622
# File 'lib/stripe/services/invoice_service.rb', line 620

def created
  @created
end

#customerObject

Only return invoices for the customer specified by this customer ID.



622
623
624
# File 'lib/stripe/services/invoice_service.rb', line 622

def customer
  @customer
end

#due_dateObject

Attribute for param field due_date



624
625
626
# File 'lib/stripe/services/invoice_service.rb', line 624

def due_date
  @due_date
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



626
627
628
# File 'lib/stripe/services/invoice_service.rb', line 626

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



628
629
630
# File 'lib/stripe/services/invoice_service.rb', line 628

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



630
631
632
# File 'lib/stripe/services/invoice_service.rb', line 630

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



632
633
634
# File 'lib/stripe/services/invoice_service.rb', line 632

def starting_after
  @starting_after
end

#statusObject

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



634
635
636
# File 'lib/stripe/services/invoice_service.rb', line 634

def status
  @status
end

#subscriptionObject

Only return invoices for the subscription specified by this subscription ID.



636
637
638
# File 'lib/stripe/services/invoice_service.rb', line 636

def subscription
  @subscription
end