Class: Stripe::InvoiceService::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Created, DueDate

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(collection_method: nil, created: nil, customer: nil, due_date: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, subscription: nil) ⇒ ListParams

Returns a new instance of ListParams.



804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
# File 'lib/stripe/services/invoice_service.rb', line 804

def initialize(
  collection_method: nil,
  created: nil,
  customer: nil,
  due_date: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  subscription: nil
)
  @collection_method = collection_method
  @created = created
  @customer = customer
  @due_date = due_date
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @subscription = subscription
end

Instance Attribute Details

#collection_methodObject

The collection method of the invoice to retrieve. Either ‘charge_automatically` or `send_invoice`.



775
776
777
# File 'lib/stripe/services/invoice_service.rb', line 775

def collection_method
  @collection_method
end

#createdObject

Only return invoices that were created during the given date interval.



778
779
780
# File 'lib/stripe/services/invoice_service.rb', line 778

def created
  @created
end

#customerObject

Only return invoices for the customer specified by this customer ID.



781
782
783
# File 'lib/stripe/services/invoice_service.rb', line 781

def customer
  @customer
end

#due_dateObject

Attribute for param field due_date



784
785
786
# File 'lib/stripe/services/invoice_service.rb', line 784

def due_date
  @due_date
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



787
788
789
# File 'lib/stripe/services/invoice_service.rb', line 787

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



790
791
792
# File 'lib/stripe/services/invoice_service.rb', line 790

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



793
794
795
# File 'lib/stripe/services/invoice_service.rb', line 793

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



796
797
798
# File 'lib/stripe/services/invoice_service.rb', line 796

def starting_after
  @starting_after
end

#statusObject

The status of the invoice, one of ‘draft`, `open`, `paid`, `uncollectible`, or `void`. [Learn more](stripe.com/docs/billing/invoices/workflow#workflow-overview)



799
800
801
# File 'lib/stripe/services/invoice_service.rb', line 799

def status
  @status
end

#subscriptionObject

Only return invoices for the subscription specified by this subscription ID.



802
803
804
# File 'lib/stripe/services/invoice_service.rb', line 802

def subscription
  @subscription
end