Class: Stripe::InvoiceService::MarkUncollectibleParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::MarkUncollectibleParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ MarkUncollectibleParams
constructor
A new instance of MarkUncollectibleParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ MarkUncollectibleParams
Returns a new instance of MarkUncollectibleParams.
1748 1749 1750 |
# File 'lib/stripe/services/invoice_service.rb', line 1748 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1746 1747 1748 |
# File 'lib/stripe/services/invoice_service.rb', line 1746 def @expand end |