Class: Stripe::InvoiceService::PayParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::PayParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#forgive ⇒ Object
In cases where the source used to pay the invoice has insufficient funds, passing ‘forgive=true` controls whether a charge should be attempted for the full amount available on the source, up to the amount to fully pay the invoice.
-
#mandate ⇒ Object
ID of the mandate to be used for this invoice.
-
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted.
-
#paid_out_of_band ⇒ Object
Boolean representing whether an invoice is paid outside of Stripe.
-
#payment_method ⇒ Object
A PaymentMethod to be charged.
-
#source ⇒ Object
A payment source to be charged.
Instance Method Summary collapse
-
#initialize(expand: nil, forgive: nil, mandate: nil, off_session: nil, paid_out_of_band: nil, payment_method: nil, source: nil) ⇒ PayParams
constructor
A new instance of PayParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, forgive: nil, mandate: nil, off_session: nil, paid_out_of_band: nil, payment_method: nil, source: nil) ⇒ PayParams
Returns a new instance of PayParams.
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 |
# File 'lib/stripe/services/invoice_service.rb', line 1744 def initialize( expand: nil, forgive: nil, mandate: nil, off_session: nil, paid_out_of_band: nil, payment_method: nil, source: nil ) @expand = @forgive = forgive @mandate = mandate @off_session = off_session @paid_out_of_band = paid_out_of_band @payment_method = payment_method @source = source end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1728 1729 1730 |
# File 'lib/stripe/services/invoice_service.rb', line 1728 def @expand end |
#forgive ⇒ Object
In cases where the source used to pay the invoice has insufficient funds, passing ‘forgive=true` controls whether a charge should be attempted for the full amount available on the source, up to the amount to fully pay the invoice. This effectively forgives the difference between the amount available on the source and the amount due.
Passing ‘forgive=false` will fail the charge if the source hasn’t been pre-funded with the right amount. An example for this case is with ACH Credit Transfers and wires: if the amount wired is less than the amount due by a small amount, you might want to forgive the difference. Defaults to ‘false`.
1732 1733 1734 |
# File 'lib/stripe/services/invoice_service.rb', line 1732 def forgive @forgive end |
#mandate ⇒ Object
ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the payment_method param or the invoice’s default_payment_method or default_source, if set.
1734 1735 1736 |
# File 'lib/stripe/services/invoice_service.rb', line 1734 def mandate @mandate end |
#off_session ⇒ Object
Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘true` (off-session).
1736 1737 1738 |
# File 'lib/stripe/services/invoice_service.rb', line 1736 def off_session @off_session end |
#paid_out_of_band ⇒ Object
Boolean representing whether an invoice is paid outside of Stripe. This will result in no charge being made. Defaults to ‘false`.
1738 1739 1740 |
# File 'lib/stripe/services/invoice_service.rb', line 1738 def paid_out_of_band @paid_out_of_band end |
#payment_method ⇒ Object
A PaymentMethod to be charged. The PaymentMethod must be the ID of a PaymentMethod belonging to the customer associated with the invoice being paid.
1740 1741 1742 |
# File 'lib/stripe/services/invoice_service.rb', line 1740 def payment_method @payment_method end |
#source ⇒ Object
A payment source to be charged. The source must be the ID of a source belonging to the customer associated with the invoice being paid.
1742 1743 1744 |
# File 'lib/stripe/services/invoice_service.rb', line 1742 def source @source end |