Class: Stripe::InvoiceService::PayParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, forgive: nil, mandate: nil, off_session: nil, paid_out_of_band: nil, payment_method: nil, source: nil) ⇒ PayParams

Returns a new instance of PayParams.



1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
# File 'lib/stripe/services/invoice_service.rb', line 1755

def initialize(
  expand: nil,
  forgive: nil,
  mandate: nil,
  off_session: nil,
  paid_out_of_band: nil,
  payment_method: nil,
  source: nil
)
  @expand = expand
  @forgive = forgive
  @mandate = mandate
  @off_session = off_session
  @paid_out_of_band = paid_out_of_band
  @payment_method = payment_method
  @source = source
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1739
1740
1741
# File 'lib/stripe/services/invoice_service.rb', line 1739

def expand
  @expand
end

#forgiveObject

In cases where the source used to pay the invoice has insufficient funds, passing ‘forgive=true` controls whether a charge should be attempted for the full amount available on the source, up to the amount to fully pay the invoice. This effectively forgives the difference between the amount available on the source and the amount due.

Passing ‘forgive=false` will fail the charge if the source hasn’t been pre-funded with the right amount. An example for this case is with ACH Credit Transfers and wires: if the amount wired is less than the amount due by a small amount, you might want to forgive the difference. Defaults to ‘false`.



1743
1744
1745
# File 'lib/stripe/services/invoice_service.rb', line 1743

def forgive
  @forgive
end

#mandateObject

ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the payment_method param or the invoice’s default_payment_method or default_source, if set.



1745
1746
1747
# File 'lib/stripe/services/invoice_service.rb', line 1745

def mandate
  @mandate
end

#off_sessionObject

Indicates if a customer is on or off-session while an invoice payment is attempted. Defaults to ‘true` (off-session).



1747
1748
1749
# File 'lib/stripe/services/invoice_service.rb', line 1747

def off_session
  @off_session
end

Boolean representing whether an invoice is paid outside of Stripe. This will result in no charge being made. Defaults to ‘false`.



1749
1750
1751
# File 'lib/stripe/services/invoice_service.rb', line 1749

def paid_out_of_band
  @paid_out_of_band
end

#payment_methodObject

A PaymentMethod to be charged. The PaymentMethod must be the ID of a PaymentMethod belonging to the customer associated with the invoice being paid.



1751
1752
1753
# File 'lib/stripe/services/invoice_service.rb', line 1751

def payment_method
  @payment_method
end

#sourceObject

A payment source to be charged. The source must be the ID of a source belonging to the customer associated with the invoice being paid.



1753
1754
1755
# File 'lib/stripe/services/invoice_service.rb', line 1753

def source
  @source
end