Class: Stripe::InvoiceService::SearchParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::SearchParams
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#page ⇒ Object
A cursor for pagination across multiple pages of results.
-
#query ⇒ Object
The search query string.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
constructor
A new instance of SearchParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, page: nil, query: nil) ⇒ SearchParams
Returns a new instance of SearchParams.
1585 1586 1587 1588 1589 1590 |
# File 'lib/stripe/services/invoice_service.rb', line 1585 def initialize(expand: nil, limit: nil, page: nil, query: nil) @expand = @limit = limit @page = page @query = query end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1574 1575 1576 |
# File 'lib/stripe/services/invoice_service.rb', line 1574 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1577 1578 1579 |
# File 'lib/stripe/services/invoice_service.rb', line 1577 def limit @limit end |
#page ⇒ Object
A cursor for pagination across multiple pages of results. Don’t include this parameter on the first call. Use the next_page value returned in a previous response to request subsequent results.
1580 1581 1582 |
# File 'lib/stripe/services/invoice_service.rb', line 1580 def page @page end |
#query ⇒ Object
The search query string. See [search query language](stripe.com/docs/search#search-query-language) and the list of supported [query fields for invoices](stripe.com/docs/search#query-fields-for-invoices).
1583 1584 1585 |
# File 'lib/stripe/services/invoice_service.rb', line 1583 def query @query end |