Class: Stripe::InvoiceService::UpcomingParams::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1794
1795
1796
1797
1798
1799
# File 'lib/stripe/services/invoice_service.rb', line 1794

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1783
1784
1785
# File 'lib/stripe/services/invoice_service.rb', line 1783

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1786
1787
1788
# File 'lib/stripe/services/invoice_service.rb', line 1786

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1789
1790
1791
# File 'lib/stripe/services/invoice_service.rb', line 1789

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1792
1793
1794
# File 'lib/stripe/services/invoice_service.rb', line 1792

def promotion_code
  @promotion_code
end