Class: Stripe::InvoiceService::UpcomingParams::InvoiceItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::InvoiceItem
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Discount, Period, PriceData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of previewed invoice item.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Explicitly controls whether discounts apply to this invoice item.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the invoice item in the preview.
-
#invoiceitem ⇒ Object
The ID of the invoice item to update in preview.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
-
#tax_rates ⇒ Object
The tax rates that apply to the item.
-
#unit_amount ⇒ Object
The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem
constructor
A new instance of InvoiceItem.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem
Returns a new instance of InvoiceItem.
1943 1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 1956 1957 1958 1959 1960 1961 1962 1963 1964 1965 1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 |
# File 'lib/stripe/services/invoice_service.rb', line 1943 def initialize( amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil ) @amount = amount @currency = currency @description = description @discountable = discountable @discounts = discounts @invoiceitem = invoiceitem @metadata = @period = period @price = price @price_data = price_data @quantity = quantity @tax_behavior = tax_behavior @tax_code = tax_code @tax_rates = tax_rates @unit_amount = unit_amount @unit_amount_decimal = unit_amount_decimal end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of previewed invoice item.
1896 1897 1898 |
# File 'lib/stripe/services/invoice_service.rb', line 1896 def amount @amount end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Only applicable to new invoice items.
1899 1900 1901 |
# File 'lib/stripe/services/invoice_service.rb', line 1899 def currency @currency end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
1902 1903 1904 |
# File 'lib/stripe/services/invoice_service.rb', line 1902 def description @description end |
#discountable ⇒ Object
Explicitly controls whether discounts apply to this invoice item. Defaults to true, except for negative invoice items.
1905 1906 1907 |
# File 'lib/stripe/services/invoice_service.rb', line 1905 def discountable @discountable end |
#discounts ⇒ Object
The coupons to redeem into discounts for the invoice item in the preview.
1908 1909 1910 |
# File 'lib/stripe/services/invoice_service.rb', line 1908 def discounts @discounts end |
#invoiceitem ⇒ Object
The ID of the invoice item to update in preview. If not specified, a new invoice item will be added to the preview of the upcoming invoice.
1911 1912 1913 |
# File 'lib/stripe/services/invoice_service.rb', line 1911 def invoiceitem @invoiceitem end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1914 1915 1916 |
# File 'lib/stripe/services/invoice_service.rb', line 1914 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
1917 1918 1919 |
# File 'lib/stripe/services/invoice_service.rb', line 1917 def period @period end |
#price ⇒ Object
The ID of the price object. One of ‘price` or `price_data` is required.
1920 1921 1922 |
# File 'lib/stripe/services/invoice_service.rb', line 1920 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.
1923 1924 1925 |
# File 'lib/stripe/services/invoice_service.rb', line 1923 def price_data @price_data end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the invoice item.
1926 1927 1928 |
# File 'lib/stripe/services/invoice_service.rb', line 1926 def quantity @quantity end |
#tax_behavior ⇒ Object
Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.
1929 1930 1931 |
# File 'lib/stripe/services/invoice_service.rb', line 1929 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
1932 1933 1934 |
# File 'lib/stripe/services/invoice_service.rb', line 1932 def tax_code @tax_code end |
#tax_rates ⇒ Object
The tax rates that apply to the item. When set, any ‘default_tax_rates` do not apply to this item.
1935 1936 1937 |
# File 'lib/stripe/services/invoice_service.rb', line 1935 def tax_rates @tax_rates end |
#unit_amount ⇒ Object
The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This unit_amount will be multiplied by the quantity to get the full amount. If you want to apply a credit to the customer’s account, pass a negative unit_amount.
1938 1939 1940 |
# File 'lib/stripe/services/invoice_service.rb', line 1938 def unit_amount @unit_amount end |
#unit_amount_decimal ⇒ Object
Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.
1941 1942 1943 |
# File 'lib/stripe/services/invoice_service.rb', line 1941 def unit_amount_decimal @unit_amount_decimal end |