Class: Stripe::InvoiceService::UpcomingParams::InvoiceItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1604
1605
1606
1607
1608
# File 'lib/stripe/services/invoice_service.rb', line 1604

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1598
1599
1600
# File 'lib/stripe/services/invoice_service.rb', line 1598

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1600
1601
1602
# File 'lib/stripe/services/invoice_service.rb', line 1600

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1602
1603
1604
# File 'lib/stripe/services/invoice_service.rb', line 1602

def type
  @type
end