Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::AmendmentEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd, Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil) ⇒ AmendmentEnd

Returns a new instance of AmendmentEnd.



2029
2030
2031
2032
2033
2034
# File 'lib/stripe/services/invoice_service.rb', line 2029

def initialize(discount_end: nil, duration: nil, timestamp: nil, type: nil)
  @discount_end = discount_end
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#discount_endObject

Use the ‘end` time of a given discount.



2018
2019
2020
# File 'lib/stripe/services/invoice_service.rb', line 2018

def discount_end
  @discount_end
end

#durationObject

Time span for the amendment starting from the ‘amendment_start`.



2021
2022
2023
# File 'lib/stripe/services/invoice_service.rb', line 2021

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the amendment to end. Must be after the ‘amendment_start`.



2024
2025
2026
# File 'lib/stripe/services/invoice_service.rb', line 2024

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_end`.



2027
2028
2029
# File 'lib/stripe/services/invoice_service.rb', line 2027

def type
  @type
end