Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



1814
1815
1816
1817
1818
1819
# File 'lib/stripe/services/invoice_service.rb', line 1814

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



1806
1807
1808
# File 'lib/stripe/services/invoice_service.rb', line 1806

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



1808
1809
1810
# File 'lib/stripe/services/invoice_service.rb', line 1808

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



1810
1811
1812
# File 'lib/stripe/services/invoice_service.rb', line 1810

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



1812
1813
1814
# File 'lib/stripe/services/invoice_service.rb', line 1812

def type
  @type
end