Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::AmendmentStart

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmendmentEnd, DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil) ⇒ AmendmentStart

Returns a new instance of AmendmentStart.



2067
2068
2069
2070
2071
2072
# File 'lib/stripe/services/invoice_service.rb', line 2067

def initialize(amendment_end: nil, discount_end: nil, timestamp: nil, type: nil)
  @amendment_end = amendment_end
  @discount_end = discount_end
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#amendment_endObject

Details of another amendment in the same array, immediately after which this amendment should begin.



2056
2057
2058
# File 'lib/stripe/services/invoice_service.rb', line 2056

def amendment_end
  @amendment_end
end

#discount_endObject

Use the ‘end` time of a given discount.



2059
2060
2061
# File 'lib/stripe/services/invoice_service.rb', line 2059

def discount_end
  @discount_end
end

#timestampObject

A precise Unix timestamp for the amendment to start.



2062
2063
2064
# File 'lib/stripe/services/invoice_service.rb', line 2062

def timestamp
  @timestamp
end

#typeObject

Select one of three ways to pass the ‘amendment_start`.



2065
2066
2067
# File 'lib/stripe/services/invoice_service.rb', line 2065

def type
  @type
end