Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



2100
2101
2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
# File 'lib/stripe/services/invoice_service.rb', line 2100

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



2086
2087
2088
# File 'lib/stripe/services/invoice_service.rb', line 2086

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



2089
2090
2091
# File 'lib/stripe/services/invoice_service.rb', line 2089

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



2092
2093
2094
# File 'lib/stripe/services/invoice_service.rb', line 2092

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



2095
2096
2097
# File 'lib/stripe/services/invoice_service.rb', line 2095

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



2098
2099
2100
# File 'lib/stripe/services/invoice_service.rb', line 2098

def promotion_code
  @promotion_code
end