Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::DiscountAction::Remove

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove

Returns a new instance of Remove.



1866
1867
1868
1869
1870
# File 'lib/stripe/services/invoice_service.rb', line 1866

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to remove from the ‘discounts` array.



1860
1861
1862
# File 'lib/stripe/services/invoice_service.rb', line 1860

def coupon
  @coupon
end

#discountObject

The ID of a discount to remove from the ‘discounts` array.



1862
1863
1864
# File 'lib/stripe/services/invoice_service.rb', line 1862

def discount
  @discount
end

#promotion_codeObject

The ID of a promotion code to remove from the ‘discounts` array.



1864
1865
1866
# File 'lib/stripe/services/invoice_service.rb', line 1864

def promotion_code
  @promotion_code
end