Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Amendment::ItemAction::Add::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1926
1927
1928
1929
1930
# File 'lib/stripe/services/invoice_service.rb', line 1926

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1920
1921
1922
# File 'lib/stripe/services/invoice_service.rb', line 1920

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1922
1923
1924
# File 'lib/stripe/services/invoice_service.rb', line 1922

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1924
1925
1926
# File 'lib/stripe/services/invoice_service.rb', line 1924

def type
  @type
end