Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: AddInvoiceItem, AutomaticTax, BillingThresholds, Discount, InvoiceSettings, Item, PauseCollection, TransferData, TrialSettings
Instance Attribute Summary collapse
-
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase.
-
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places.
-
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
-
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed.
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`.
-
#coupon ⇒ Object
The ID of the coupon to apply to this phase of the subscription schedule.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule.
-
#default_tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
-
#description ⇒ Object
Subscription description, meant to be displayable to the customer.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase.
-
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends.
-
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
-
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
-
#iterations ⇒ Object
Integer representing the multiplier applied to the price interval.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase.
-
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
-
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused.
-
#proration_behavior ⇒ Object
Whether the subscription schedule will create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase.
-
#start_date ⇒ Object
The date at which this phase of the subscription schedule starts or ‘now`.
-
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
-
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
-
#trial_continuation ⇒ Object
Specify trial behavior when crossing phase boundaries.
-
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date.
-
#trial_settings ⇒ Object
Settings related to subscription trials.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, coupon: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil) ⇒ Phase
Returns a new instance of Phase.
2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 2658 2659 2660 2661 2662 2663 2664 2665 2666 2667 2668 2669 2670 2671 2672 2673 2674 2675 2676 2677 2678 2679 2680 2681 2682 2683 2684 2685 2686 2687 2688 2689 2690 2691 2692 2693 |
# File 'lib/stripe/services/invoice_service.rb', line 2639 def initialize( add_invoice_items: nil, application_fee_percent: nil, automatic_tax: nil, billing_cycle_anchor: nil, billing_thresholds: nil, collection_method: nil, coupon: nil, currency: nil, default_payment_method: nil, default_tax_rates: nil, description: nil, discounts: nil, end_date: nil, invoice_settings: nil, items: nil, iterations: nil, metadata: nil, on_behalf_of: nil, pause_collection: nil, proration_behavior: nil, start_date: nil, transfer_data: nil, trial: nil, trial_continuation: nil, trial_end: nil, trial_settings: nil ) @add_invoice_items = add_invoice_items @application_fee_percent = application_fee_percent @automatic_tax = automatic_tax @billing_cycle_anchor = billing_cycle_anchor @billing_thresholds = billing_thresholds @collection_method = collection_method @coupon = coupon @currency = currency @default_payment_method = default_payment_method @default_tax_rates = default_tax_rates @description = description @discounts = discounts @end_date = end_date @invoice_settings = invoice_settings @items = items @iterations = iterations @metadata = @on_behalf_of = on_behalf_of @pause_collection = pause_collection @proration_behavior = proration_behavior @start_date = start_date @transfer_data = transfer_data @trial = trial @trial_continuation = trial_continuation @trial_end = trial_end @trial_settings = trial_settings end |
Instance Attribute Details
#add_invoice_items ⇒ Object
A list of prices and quantities that will generate invoice items appended to the next invoice for this phase. You may pass up to 20 items.
2587 2588 2589 |
# File 'lib/stripe/services/invoice_service.rb', line 2587 def add_invoice_items @add_invoice_items end |
#application_fee_percent ⇒ Object
A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the application owner’s Stripe account. The request must be made by a platform account on a connected account in order to set an application fee percentage. For more information, see the application fees [documentation](stripe.com/docs/connect/subscriptions#collecting-fees-on-subscriptions).
2589 2590 2591 |
# File 'lib/stripe/services/invoice_service.rb', line 2589 def application_fee_percent @application_fee_percent end |
#automatic_tax ⇒ Object
Automatic tax settings for this phase.
2591 2592 2593 |
# File 'lib/stripe/services/invoice_service.rb', line 2591 def automatic_tax @automatic_tax end |
#billing_cycle_anchor ⇒ Object
Can be set to ‘phase_start` to set the anchor to the start of the phase or `automatic` to automatically change it if needed. Cannot be set to `phase_start` if this phase specifies a trial. For more information, see the billing cycle [documentation](stripe.com/docs/billing/subscriptions/billing-cycle).
2593 2594 2595 |
# File 'lib/stripe/services/invoice_service.rb', line 2593 def billing_cycle_anchor @billing_cycle_anchor end |
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. Pass an empty string to remove previously-defined thresholds.
2595 2596 2597 |
# File 'lib/stripe/services/invoice_service.rb', line 2595 def billing_thresholds @billing_thresholds end |
#collection_method ⇒ Object
Either ‘charge_automatically`, or `send_invoice`. When charging automatically, Stripe will attempt to pay the underlying subscription at the end of each billing cycle using the default source attached to the customer. When sending an invoice, Stripe will email your customer an invoice with payment instructions and mark the subscription as `active`. Defaults to `charge_automatically` on creation.
2597 2598 2599 |
# File 'lib/stripe/services/invoice_service.rb', line 2597 def collection_method @collection_method end |
#coupon ⇒ Object
The ID of the coupon to apply to this phase of the subscription schedule. This field has been deprecated and will be removed in a future API version. Use ‘discounts` instead.
2599 2600 2601 |
# File 'lib/stripe/services/invoice_service.rb', line 2599 def coupon @coupon end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2601 2602 2603 |
# File 'lib/stripe/services/invoice_service.rb', line 2601 def currency @currency end |
#default_payment_method ⇒ Object
ID of the default payment method for the subscription schedule. It must belong to the customer associated with the subscription schedule. If not set, invoices will use the default payment method in the customer’s invoice settings.
2603 2604 2605 |
# File 'lib/stripe/services/invoice_service.rb', line 2603 def default_payment_method @default_payment_method end |
#default_tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will set the Subscription’s [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates), which means they will be the Invoice’s [‘default_tax_rates`](stripe.com/docs/api/invoices/create#create_invoice-default_tax_rates) for any Invoices issued by the Subscription during this Phase.
2605 2606 2607 |
# File 'lib/stripe/services/invoice_service.rb', line 2605 def default_tax_rates @default_tax_rates end |
#description ⇒ Object
Subscription description, meant to be displayable to the customer. Use this field to optionally store an explanation of the subscription for rendering in Stripe surfaces and certain local payment methods UIs.
2607 2608 2609 |
# File 'lib/stripe/services/invoice_service.rb', line 2607 def description @description end |
#discounts ⇒ Object
The coupons to redeem into discounts for the schedule phase. If not specified, inherits the discount from the subscription’s customer. Pass an empty string to avoid inheriting any discounts.
2609 2610 2611 |
# File 'lib/stripe/services/invoice_service.rb', line 2609 def discounts @discounts end |
#end_date ⇒ Object
The date at which this phase of the subscription schedule ends. If set, ‘iterations` must not be set.
2611 2612 2613 |
# File 'lib/stripe/services/invoice_service.rb', line 2611 def end_date @end_date end |
#invoice_settings ⇒ Object
All invoices will be billed using the specified settings.
2613 2614 2615 |
# File 'lib/stripe/services/invoice_service.rb', line 2613 def invoice_settings @invoice_settings end |
#items ⇒ Object
List of configuration items, each with an attached price, to apply during this phase of the subscription schedule.
2615 2616 2617 |
# File 'lib/stripe/services/invoice_service.rb', line 2615 def items @items end |
#iterations ⇒ Object
Integer representing the multiplier applied to the price interval. For example, ‘iterations=2` applied to a price with `interval=month` and `interval_count=3` results in a phase of duration `2 * 3 months = 6 months`. If set, `end_date` must not be set.
2617 2618 2619 |
# File 'lib/stripe/services/invoice_service.rb', line 2617 def iterations @iterations end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a phase. Metadata on a schedule’s phase will update the underlying subscription’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys in the subscription’s ‘metadata`. Individual keys in the subscription’s ‘metadata` can be unset by posting an empty value to them in the phase’s ‘metadata`. To unset all keys in the subscription’s ‘metadata`, update the subscription directly or unset every key individually from the phase’s ‘metadata`.
2619 2620 2621 |
# File 'lib/stripe/services/invoice_service.rb', line 2619 def @metadata end |
#on_behalf_of ⇒ Object
The account on behalf of which to charge, for each of the associated subscription’s invoices.
2621 2622 2623 |
# File 'lib/stripe/services/invoice_service.rb', line 2621 def on_behalf_of @on_behalf_of end |
#pause_collection ⇒ Object
If specified, payment collection for this subscription will be paused. Note that the subscription status will be unchanged and will not be updated to ‘paused`. Learn more about [pausing collection](stripe.com/docs/billing/subscriptions/pause-payment).
2623 2624 2625 |
# File 'lib/stripe/services/invoice_service.rb', line 2623 def pause_collection @pause_collection end |
#proration_behavior ⇒ Object
Whether the subscription schedule will create [prorations](stripe.com/docs/billing/subscriptions/prorations) when transitioning to this phase. The default value is ‘create_prorations`. This setting controls prorations when a phase is started asynchronously and it is persisted as a field on the phase. It’s different from the request-level [proration_behavior](stripe.com/docs/api/subscription_schedules/update#update_subscription_schedule-proration_behavior) parameter which controls what happens if the update request affects the billing configuration of the current phase.
2625 2626 2627 |
# File 'lib/stripe/services/invoice_service.rb', line 2625 def proration_behavior @proration_behavior end |
#start_date ⇒ Object
The date at which this phase of the subscription schedule starts or ‘now`. Must be set on the first phase.
2627 2628 2629 |
# File 'lib/stripe/services/invoice_service.rb', line 2627 def start_date @start_date end |
#transfer_data ⇒ Object
The data with which to automatically create a Transfer for each of the associated subscription’s invoices.
2629 2630 2631 |
# File 'lib/stripe/services/invoice_service.rb', line 2629 def transfer_data @transfer_data end |
#trial ⇒ Object
If set to true the entire phase is counted as a trial and the customer will not be charged for any fees.
2631 2632 2633 |
# File 'lib/stripe/services/invoice_service.rb', line 2631 def trial @trial end |
#trial_continuation ⇒ Object
Specify trial behavior when crossing phase boundaries
2633 2634 2635 |
# File 'lib/stripe/services/invoice_service.rb', line 2633 def trial_continuation @trial_continuation end |
#trial_end ⇒ Object
Sets the phase to trialing from the start date to this date. Must be before the phase end date, can not be combined with ‘trial`
2635 2636 2637 |
# File 'lib/stripe/services/invoice_service.rb', line 2635 def trial_end @trial_end end |
#trial_settings ⇒ Object
Settings related to subscription trials.
2637 2638 2639 |
# File 'lib/stripe/services/invoice_service.rb', line 2637 def trial_settings @trial_settings end |