Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::AutomaticTax
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Liability
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
-
#liability ⇒ Object
The account that’s liable for tax.
Instance Method Summary collapse
-
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil, liability: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
2314 2315 2316 2317 |
# File 'lib/stripe/services/invoice_service.rb', line 2314 def initialize(enabled: nil, liability: nil) @enabled = enabled @liability = liability end |
Instance Attribute Details
#enabled ⇒ Object
Enabled automatic tax calculation which will automatically compute tax rates on all invoices generated by the subscription.
2310 2311 2312 |
# File 'lib/stripe/services/invoice_service.rb', line 2310 def enabled @enabled end |
#liability ⇒ Object
The account that’s liable for tax. If set, the business address and tax registrations required to perform the tax calculation are loaded from this account. The tax transaction is returned in the report of the connected account.
2312 2313 2314 |
# File 'lib/stripe/services/invoice_service.rb', line 2312 def liability @liability end |