Class: Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::Item
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpcomingParams::ScheduleDetails::Phase::Item
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: BillingThresholds, Discount, PriceData, Trial
Instance Attribute Summary collapse
-
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period.
-
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item.
-
#plan ⇒ Object
The plan ID to subscribe to.
-
#price ⇒ Object
The ID of the price object.
-
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
-
#quantity ⇒ Object
Quantity for the given price.
-
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
constructor
A new instance of Item.
Methods inherited from RequestParams
Constructor Details
#initialize(billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Item
Returns a new instance of Item.
2877 2878 2879 2880 2881 2882 2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 2896 2897 |
# File 'lib/stripe/services/invoice_service.rb', line 2877 def initialize( billing_thresholds: nil, discounts: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil, trial: nil ) @billing_thresholds = billing_thresholds @discounts = discounts @metadata = @plan = plan @price = price @price_data = price_data @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#billing_thresholds ⇒ Object
Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.
2851 2852 2853 |
# File 'lib/stripe/services/invoice_service.rb', line 2851 def billing_thresholds @billing_thresholds end |
#discounts ⇒ Object
The coupons to redeem into discounts for the subscription item.
2854 2855 2856 |
# File 'lib/stripe/services/invoice_service.rb', line 2854 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to a configuration item. Metadata on a configuration item will update the underlying subscription item’s ‘metadata` when the phase is entered, adding new keys and replacing existing keys. Individual keys in the subscription item’s ‘metadata` can be unset by posting an empty value to them in the configuration item’s ‘metadata`. To unset all keys in the subscription item’s ‘metadata`, update the subscription item directly or unset every key individually from the configuration item’s ‘metadata`.
2857 2858 2859 |
# File 'lib/stripe/services/invoice_service.rb', line 2857 def @metadata end |
#plan ⇒ Object
The plan ID to subscribe to. You may specify the same ID in ‘plan` and `price`.
2860 2861 2862 |
# File 'lib/stripe/services/invoice_service.rb', line 2860 def plan @plan end |
#price ⇒ Object
The ID of the price object.
2863 2864 2865 |
# File 'lib/stripe/services/invoice_service.rb', line 2863 def price @price end |
#price_data ⇒ Object
Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.
2866 2867 2868 |
# File 'lib/stripe/services/invoice_service.rb', line 2866 def price_data @price_data end |
#quantity ⇒ Object
Quantity for the given price. Can be set only if the price’s ‘usage_type` is `licensed` and not `metered`.
2869 2870 2871 |
# File 'lib/stripe/services/invoice_service.rb', line 2869 def quantity @quantity end |
#tax_rates ⇒ Object
A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.
2872 2873 2874 |
# File 'lib/stripe/services/invoice_service.rb', line 2872 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
2875 2876 2877 |
# File 'lib/stripe/services/invoice_service.rb', line 2875 def trial @trial end |