Class: Stripe::InvoiceService::UpcomingParams::SubscriptionDetails::Item

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: BillingThresholds, Discount, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing_thresholds: nil, clear_usage: nil, deleted: nil, discounts: nil, id: nil, metadata: nil, plan: nil, price: nil, price_data: nil, quantity: nil, tax_rates: nil) ⇒ Item

Returns a new instance of Item.



2892
2893
2894
2895
2896
2897
2898
2899
2900
2901
2902
2903
2904
2905
2906
2907
2908
2909
2910
2911
2912
2913
2914
2915
2916
# File 'lib/stripe/services/invoice_service.rb', line 2892

def initialize(
  billing_thresholds: nil,
  clear_usage: nil,
  deleted: nil,
  discounts: nil,
  id: nil,
  metadata: nil,
  plan: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @billing_thresholds = billing_thresholds
  @clear_usage = clear_usage
  @deleted = deleted
  @discounts = discounts
  @id = id
  @metadata = 
  @plan = plan
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#billing_thresholdsObject

Define thresholds at which an invoice will be sent, and the subscription advanced to a new billing period. When updating, pass an empty string to remove previously-defined thresholds.



2870
2871
2872
# File 'lib/stripe/services/invoice_service.rb', line 2870

def billing_thresholds
  @billing_thresholds
end

#clear_usageObject

Delete all usage for a given subscription item. You must pass this when deleting a usage records subscription item. ‘clear_usage` has no effect if the plan has a billing meter attached.



2872
2873
2874
# File 'lib/stripe/services/invoice_service.rb', line 2872

def clear_usage
  @clear_usage
end

#deletedObject

A flag that, if set to ‘true`, will delete the specified item.



2874
2875
2876
# File 'lib/stripe/services/invoice_service.rb', line 2874

def deleted
  @deleted
end

#discountsObject

The coupons to redeem into discounts for the subscription item.



2876
2877
2878
# File 'lib/stripe/services/invoice_service.rb', line 2876

def discounts
  @discounts
end

#idObject

Subscription item to update.



2878
2879
2880
# File 'lib/stripe/services/invoice_service.rb', line 2878

def id
  @id
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2880
2881
2882
# File 'lib/stripe/services/invoice_service.rb', line 2880

def 
  @metadata
end

#planObject

Plan ID for this item, as a string.



2882
2883
2884
# File 'lib/stripe/services/invoice_service.rb', line 2882

def plan
  @plan
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required. When changing a subscription item’s price, ‘quantity` is set to 1 unless a `quantity` parameter is provided.



2884
2885
2886
# File 'lib/stripe/services/invoice_service.rb', line 2884

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



2886
2887
2888
# File 'lib/stripe/services/invoice_service.rb', line 2886

def price_data
  @price_data
end

#quantityObject

Quantity for this item.



2888
2889
2890
# File 'lib/stripe/services/invoice_service.rb', line 2888

def quantity
  @quantity
end

#tax_ratesObject

A list of [Tax Rate](stripe.com/docs/api/tax_rates) ids. These Tax Rates will override the [‘default_tax_rates`](stripe.com/docs/api/subscriptions/create#create_subscription-default_tax_rates) on the Subscription. When updating, pass an empty string to remove previously-defined tax rates.



2890
2891
2892
# File 'lib/stripe/services/invoice_service.rb', line 2890

def tax_rates
  @tax_rates
end