Class: Stripe::InvoiceService::UpcomingParams::SubscriptionItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



3452
3453
3454
3455
3456
3457
# File 'lib/stripe/services/invoice_service.rb', line 3452

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



3441
3442
3443
# File 'lib/stripe/services/invoice_service.rb', line 3441

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



3444
3445
3446
# File 'lib/stripe/services/invoice_service.rb', line 3444

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



3447
3448
3449
# File 'lib/stripe/services/invoice_service.rb', line 3447

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



3450
3451
3452
# File 'lib/stripe/services/invoice_service.rb', line 3450

def promotion_code
  @promotion_code
end