Class: Stripe::InvoiceService::UpcomingParams::SubscriptionItem::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3434
3435
3436
3437
3438
# File 'lib/stripe/services/invoice_service.rb', line 3434

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3426
3427
3428
# File 'lib/stripe/services/invoice_service.rb', line 3426

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3429
3430
3431
# File 'lib/stripe/services/invoice_service.rb', line 3429

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3432
3433
3434
# File 'lib/stripe/services/invoice_service.rb', line 3432

def type
  @type
end