Class: Stripe::InvoiceService::UpdateLinesParams::Line

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData, Pricing, TaxAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line

Returns a new instance of Line.



2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
# File 'lib/stripe/services/invoice_service.rb', line 2019

def initialize(
  amount: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  id: nil,
  margins: nil,
  metadata: nil,
  period: nil,
  price_data: nil,
  pricing: nil,
  quantity: nil,
  tax_amounts: nil,
  tax_rates: nil
)
  @amount = amount
  @description = description
  @discountable = discountable
  @discounts = discounts
  @id = id
  @margins = margins
  @metadata = 
  @period = period
  @price_data = price_data
  @pricing = pricing
  @quantity = quantity
  @tax_amounts = tax_amounts
  @tax_rates = tax_rates
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.



1993
1994
1995
# File 'lib/stripe/services/invoice_service.rb', line 1993

def amount
  @amount
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



1995
1996
1997
# File 'lib/stripe/services/invoice_service.rb', line 1995

def description
  @description
end

#discountableObject

Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.



1997
1998
1999
# File 'lib/stripe/services/invoice_service.rb', line 1997

def discountable
  @discountable
end

#discountsObject

The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.



1999
2000
2001
# File 'lib/stripe/services/invoice_service.rb', line 1999

def discounts
  @discounts
end

#idObject

ID of an existing line item on the invoice.



2001
2002
2003
# File 'lib/stripe/services/invoice_service.rb', line 2001

def id
  @id
end

#marginsObject

The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.



2003
2004
2005
# File 'lib/stripe/services/invoice_service.rb', line 2003

def margins
  @margins
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.



2005
2006
2007
# File 'lib/stripe/services/invoice_service.rb', line 2005

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



2007
2008
2009
# File 'lib/stripe/services/invoice_service.rb', line 2007

def period
  @period
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline.



2009
2010
2011
# File 'lib/stripe/services/invoice_service.rb', line 2009

def price_data
  @price_data
end

#pricingObject

The pricing information for the invoice item.



2011
2012
2013
# File 'lib/stripe/services/invoice_service.rb', line 2011

def pricing
  @pricing
end

#quantityObject

Non-negative integer. The quantity of units for the line item.



2013
2014
2015
# File 'lib/stripe/services/invoice_service.rb', line 2013

def quantity
  @quantity
end

#tax_amountsObject

A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](stripe.com/docs/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](stripe.com/docs/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](stripe.com/docs/tax/invoicing). Pass an empty string to remove previously defined tax amounts.



2015
2016
2017
# File 'lib/stripe/services/invoice_service.rb', line 2015

def tax_amounts
  @tax_amounts
end

#tax_ratesObject

The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.



2017
2018
2019
# File 'lib/stripe/services/invoice_service.rb', line 2017

def tax_rates
  @tax_rates
end