Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1846
1847
1848
1849
1850
1851
# File 'lib/stripe/services/invoice_service.rb', line 1846

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1838
1839
1840
# File 'lib/stripe/services/invoice_service.rb', line 1838

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1840
1841
1842
# File 'lib/stripe/services/invoice_service.rb', line 1840

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1842
1843
1844
# File 'lib/stripe/services/invoice_service.rb', line 1842

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1844
1845
1846
# File 'lib/stripe/services/invoice_service.rb', line 1844

def promotion_code
  @promotion_code
end