Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateLinesParams::Line::Discount
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: DiscountEnd
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1862 1863 1864 1865 1866 1867 |
# File 'lib/stripe/services/invoice_service.rb', line 1862 def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) @coupon = coupon @discount = discount @discount_end = discount_end @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1854 1855 1856 |
# File 'lib/stripe/services/invoice_service.rb', line 1854 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1856 1857 1858 |
# File 'lib/stripe/services/invoice_service.rb', line 1856 def discount @discount end |
#discount_end ⇒ Object
Details to determine how long the discount should be applied for.
1858 1859 1860 |
# File 'lib/stripe/services/invoice_service.rb', line 1858 def discount_end @discount_end end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1860 1861 1862 |
# File 'lib/stripe/services/invoice_service.rb', line 1860 def promotion_code @promotion_code end |