Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1862
1863
1864
1865
1866
1867
# File 'lib/stripe/services/invoice_service.rb', line 1862

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1854
1855
1856
# File 'lib/stripe/services/invoice_service.rb', line 1854

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1856
1857
1858
# File 'lib/stripe/services/invoice_service.rb', line 1856

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



1858
1859
1860
# File 'lib/stripe/services/invoice_service.rb', line 1858

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1860
1861
1862
# File 'lib/stripe/services/invoice_service.rb', line 1860

def promotion_code
  @promotion_code
end