Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



4221
4222
4223
4224
4225
4226
# File 'lib/stripe/services/invoice_service.rb', line 4221

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



4210
4211
4212
# File 'lib/stripe/services/invoice_service.rb', line 4210

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



4213
4214
4215
# File 'lib/stripe/services/invoice_service.rb', line 4213

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



4216
4217
4218
# File 'lib/stripe/services/invoice_service.rb', line 4216

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



4219
4220
4221
# File 'lib/stripe/services/invoice_service.rb', line 4219

def promotion_code
  @promotion_code
end