Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



1831
1832
1833
1834
1835
# File 'lib/stripe/services/invoice_service.rb', line 1831

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



1825
1826
1827
# File 'lib/stripe/services/invoice_service.rb', line 1825

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



1827
1828
1829
# File 'lib/stripe/services/invoice_service.rb', line 1827

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



1829
1830
1831
# File 'lib/stripe/services/invoice_service.rb', line 1829

def type
  @type
end