Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



3671
3672
3673
3674
3675
# File 'lib/stripe/services/invoice_service.rb', line 3671

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



3665
3666
3667
# File 'lib/stripe/services/invoice_service.rb', line 3665

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



3667
3668
3669
# File 'lib/stripe/services/invoice_service.rb', line 3667

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



3669
3670
3671
# File 'lib/stripe/services/invoice_service.rb', line 3669

def type
  @type
end