Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



4203
4204
4205
4206
4207
# File 'lib/stripe/services/invoice_service.rb', line 4203

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



4195
4196
4197
# File 'lib/stripe/services/invoice_service.rb', line 4195

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



4198
4199
4200
# File 'lib/stripe/services/invoice_service.rb', line 4198

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



4201
4202
4203
# File 'lib/stripe/services/invoice_service.rb', line 4201

def type
  @type
end