Class: Stripe::InvoiceService::UpdateLinesParams::Line::Discount::DiscountEnd::Duration

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(interval: nil, interval_count: nil) ⇒ Duration

Returns a new instance of Duration.



3659
3660
3661
3662
# File 'lib/stripe/services/invoice_service.rb', line 3659

def initialize(interval: nil, interval_count: nil)
  @interval = interval
  @interval_count = interval_count
end

Instance Attribute Details

#intervalObject

Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.



3655
3656
3657
# File 'lib/stripe/services/invoice_service.rb', line 3655

def interval
  @interval
end

#interval_countObject

The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.



3657
3658
3659
# File 'lib/stripe/services/invoice_service.rb', line 3657

def interval_count
  @interval_count
end