Class: Stripe::InvoiceService::UpdateLinesParams::Line::PriceData::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData

Returns a new instance of ProductData.



1631
1632
1633
1634
1635
1636
1637
# File 'lib/stripe/services/invoice_service.rb', line 1631

def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil)
  @description = description
  @images = images
  @metadata = 
  @name = name
  @tax_code = tax_code
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1621
1622
1623
# File 'lib/stripe/services/invoice_service.rb', line 1621

def description
  @description
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1623
1624
1625
# File 'lib/stripe/services/invoice_service.rb', line 1623

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1625
1626
1627
# File 'lib/stripe/services/invoice_service.rb', line 1625

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1627
1628
1629
# File 'lib/stripe/services/invoice_service.rb', line 1627

def name
  @name
end

#tax_codeObject



1629
1630
1631
# File 'lib/stripe/services/invoice_service.rb', line 1629

def tax_code
  @tax_code
end