Class: Stripe::InvoiceService::UpdateLinesParams::Line::PriceData::ProductData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateLinesParams::Line::PriceData::ProductData
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
The product’s description, meant to be displayable to the customer.
-
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
-
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
Instance Method Summary collapse
-
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
constructor
A new instance of ProductData.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) ⇒ ProductData
Returns a new instance of ProductData.
1626 1627 1628 1629 1630 1631 1632 |
# File 'lib/stripe/services/invoice_service.rb', line 1626 def initialize(description: nil, images: nil, metadata: nil, name: nil, tax_code: nil) @description = description @images = images @metadata = @name = name @tax_code = tax_code end |
Instance Attribute Details
#description ⇒ Object
The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.
1616 1617 1618 |
# File 'lib/stripe/services/invoice_service.rb', line 1616 def description @description end |
#images ⇒ Object
A list of up to 8 URLs of images for this product, meant to be displayable to the customer.
1618 1619 1620 |
# File 'lib/stripe/services/invoice_service.rb', line 1618 def images @images end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1620 1621 1622 |
# File 'lib/stripe/services/invoice_service.rb', line 1620 def @metadata end |
#name ⇒ Object
The product’s name, meant to be displayable to the customer.
1622 1623 1624 |
# File 'lib/stripe/services/invoice_service.rb', line 1622 def name @name end |
#tax_code ⇒ Object
A [tax code](stripe.com/docs/tax/tax-categories) ID.
1624 1625 1626 |
# File 'lib/stripe/services/invoice_service.rb', line 1624 def tax_code @tax_code end |