Class: Stripe::InvoiceService::UpdateLinesParams::Line::TaxAmount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: TaxRateData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount

Returns a new instance of TaxAmount.



1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
# File 'lib/stripe/services/invoice_service.rb', line 1732

def initialize(
  amount: nil,
  tax_rate_data: nil,
  taxability_reason: nil,
  taxable_amount: nil
)
  @amount = amount
  @tax_rate_data = tax_rate_data
  @taxability_reason = taxability_reason
  @taxable_amount = taxable_amount
end

Instance Attribute Details

#amountObject

The amount, in cents (or local equivalent), of the tax.



1722
1723
1724
# File 'lib/stripe/services/invoice_service.rb', line 1722

def amount
  @amount
end

#tax_rate_dataObject

Data to find or create a TaxRate object.

Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.



1726
1727
1728
# File 'lib/stripe/services/invoice_service.rb', line 1726

def tax_rate_data
  @tax_rate_data
end

#taxability_reasonObject

The reasoning behind this tax, for example, if the product is tax exempt.



1728
1729
1730
# File 'lib/stripe/services/invoice_service.rb', line 1728

def taxability_reason
  @taxability_reason
end

#taxable_amountObject

The amount on which tax is calculated, in cents (or local equivalent).



1730
1731
1732
# File 'lib/stripe/services/invoice_service.rb', line 1730

def taxable_amount
  @taxable_amount
end