Class: Stripe::InvoiceService::UpdateLinesParams::Line::TaxAmount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateLinesParams::Line::TaxAmount
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: TaxRateData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
-
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
-
#taxability_reason ⇒ Object
The reasoning behind this tax, for example, if the product is tax exempt.
-
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
Instance Method Summary collapse
-
#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount
constructor
A new instance of TaxAmount.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil) ⇒ TaxAmount
Returns a new instance of TaxAmount.
1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 |
# File 'lib/stripe/services/invoice_service.rb', line 1996 def initialize( amount: nil, tax_rate_data: nil, taxability_reason: nil, taxable_amount: nil ) @amount = amount @tax_rate_data = tax_rate_data @taxability_reason = taxability_reason @taxable_amount = taxable_amount end |
Instance Attribute Details
#amount ⇒ Object
The amount, in cents (or local equivalent), of the tax.
1986 1987 1988 |
# File 'lib/stripe/services/invoice_service.rb', line 1986 def amount @amount end |
#tax_rate_data ⇒ Object
Data to find or create a TaxRate object.
Stripe automatically creates or reuses a TaxRate object for each tax amount. If the ‘tax_rate_data` exactly matches a previous value, Stripe will reuse the TaxRate object. TaxRate objects created automatically by Stripe are immediately archived, do not appear in the line item’s `tax_rates`, and cannot be directly added to invoices, payments, or line items.
1990 1991 1992 |
# File 'lib/stripe/services/invoice_service.rb', line 1990 def tax_rate_data @tax_rate_data end |
#taxability_reason ⇒ Object
The reasoning behind this tax, for example, if the product is tax exempt.
1992 1993 1994 |
# File 'lib/stripe/services/invoice_service.rb', line 1992 def taxability_reason @taxability_reason end |
#taxable_amount ⇒ Object
The amount on which tax is calculated, in cents (or local equivalent).
1994 1995 1996 |
# File 'lib/stripe/services/invoice_service.rb', line 1994 def taxable_amount @taxable_amount end |