Class: Stripe::InvoiceService::UpdateLinesParams::Line::TaxAmount::TaxRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, jurisdiction_level: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData

Returns a new instance of TaxRateData.



1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
# File 'lib/stripe/services/invoice_service.rb', line 1963

def initialize(
  country: nil,
  description: nil,
  display_name: nil,
  inclusive: nil,
  jurisdiction: nil,
  jurisdiction_level: nil,
  percentage: nil,
  state: nil,
  tax_type: nil
)
  @country = country
  @description = description
  @display_name = display_name
  @inclusive = inclusive
  @jurisdiction = jurisdiction
  @jurisdiction_level = jurisdiction_level
  @percentage = percentage
  @state = state
  @tax_type = tax_type
end

Instance Attribute Details

#countryObject

Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).



1945
1946
1947
# File 'lib/stripe/services/invoice_service.rb', line 1945

def country
  @country
end

#descriptionObject

An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.



1947
1948
1949
# File 'lib/stripe/services/invoice_service.rb', line 1947

def description
  @description
end

#display_nameObject

The display name of the tax rate, which will be shown to users.



1949
1950
1951
# File 'lib/stripe/services/invoice_service.rb', line 1949

def display_name
  @display_name
end

#inclusiveObject

This specifies if the tax rate is inclusive or exclusive.



1951
1952
1953
# File 'lib/stripe/services/invoice_service.rb', line 1951

def inclusive
  @inclusive
end

#jurisdictionObject

The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.



1953
1954
1955
# File 'lib/stripe/services/invoice_service.rb', line 1953

def jurisdiction
  @jurisdiction
end

#jurisdiction_levelObject

The level of the jurisdiction that imposes this tax rate.



1955
1956
1957
# File 'lib/stripe/services/invoice_service.rb', line 1955

def jurisdiction_level
  @jurisdiction_level
end

#percentageObject

The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.



1957
1958
1959
# File 'lib/stripe/services/invoice_service.rb', line 1957

def percentage
  @percentage
end

#stateObject

[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.



1959
1960
1961
# File 'lib/stripe/services/invoice_service.rb', line 1959

def state
  @state
end

#tax_typeObject

The high-level tax type, such as ‘vat` or `sales_tax`.



1961
1962
1963
# File 'lib/stripe/services/invoice_service.rb', line 1961

def tax_type
  @tax_type
end