Class: Stripe::InvoiceService::UpdateLinesParams::Line::TaxAmount::TaxRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateLinesParams::Line::TaxAmount::TaxRateData
- Defined in:
- lib/stripe/services/invoice_service.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
-
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only.
-
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
-
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
-
#jurisdiction ⇒ Object
The jurisdiction for the tax rate.
-
#percentage ⇒ Object
The statutory tax rate percent.
-
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix.
-
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
Instance Method Summary collapse
-
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
constructor
A new instance of TaxRateData.
Methods inherited from RequestParams
Constructor Details
#initialize(country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil) ⇒ TaxRateData
Returns a new instance of TaxRateData.
3776 3777 3778 3779 3780 3781 3782 3783 3784 3785 3786 3787 3788 3789 3790 3791 3792 3793 3794 |
# File 'lib/stripe/services/invoice_service.rb', line 3776 def initialize( country: nil, description: nil, display_name: nil, inclusive: nil, jurisdiction: nil, percentage: nil, state: nil, tax_type: nil ) @country = country @description = description @display_name = display_name @inclusive = inclusive @jurisdiction = jurisdiction @percentage = percentage @state = state @tax_type = tax_type end |
Instance Attribute Details
#country ⇒ Object
Two-letter country code ([ISO 3166-1 alpha-2](en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
3760 3761 3762 |
# File 'lib/stripe/services/invoice_service.rb', line 3760 def country @country end |
#description ⇒ Object
An arbitrary string attached to the tax rate for your internal use only. It will not be visible to your customers.
3762 3763 3764 |
# File 'lib/stripe/services/invoice_service.rb', line 3762 def description @description end |
#display_name ⇒ Object
The display name of the tax rate, which will be shown to users.
3764 3765 3766 |
# File 'lib/stripe/services/invoice_service.rb', line 3764 def display_name @display_name end |
#inclusive ⇒ Object
This specifies if the tax rate is inclusive or exclusive.
3766 3767 3768 |
# File 'lib/stripe/services/invoice_service.rb', line 3766 def inclusive @inclusive end |
#jurisdiction ⇒ Object
The jurisdiction for the tax rate. You can use this label field for tax reporting purposes. It also appears on your customer’s invoice.
3768 3769 3770 |
# File 'lib/stripe/services/invoice_service.rb', line 3768 def jurisdiction @jurisdiction end |
#percentage ⇒ Object
The statutory tax rate percent. This field accepts decimal values between 0 and 100 inclusive with at most 4 decimal places. To accommodate fixed-amount taxes, set the percentage to zero. Stripe will not display zero percentages on the invoice unless the ‘amount` of the tax is also zero.
3770 3771 3772 |
# File 'lib/stripe/services/invoice_service.rb', line 3770 def percentage @percentage end |
#state ⇒ Object
[ISO 3166-2 subdivision code](en.wikipedia.org/wiki/ISO_3166-2:US), without country prefix. For example, “NY” for New York, United States.
3772 3773 3774 |
# File 'lib/stripe/services/invoice_service.rb', line 3772 def state @state end |
#tax_type ⇒ Object
The high-level tax type, such as ‘vat` or `sales_tax`.
3774 3775 3776 |
# File 'lib/stripe/services/invoice_service.rb', line 3774 def tax_type @tax_type end |