Class: Stripe::InvoiceService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AmountsDue, AutomaticTax, CustomField, Discount, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, custom_fields: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, transfer_data: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
# File 'lib/stripe/services/invoice_service.rb', line 584

def initialize(
  account_tax_ids: nil,
  amounts_due: nil,
  application_fee_amount: nil,
  auto_advance: nil,
  automatic_tax: nil,
  automatically_finalizes_at: nil,
  collection_method: nil,
  custom_fields: nil,
  days_until_due: nil,
  default_margins: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  due_date: nil,
  effective_at: nil,
  expand: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  number: nil,
  on_behalf_of: nil,
  payment_settings: nil,
  rendering: nil,
  shipping_cost: nil,
  shipping_details: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @account_tax_ids = 
  @amounts_due = amounts_due
  @application_fee_amount = application_fee_amount
  @auto_advance = auto_advance
  @automatic_tax = automatic_tax
  @automatically_finalizes_at = automatically_finalizes_at
  @collection_method = collection_method
  @custom_fields = custom_fields
  @days_until_due = days_until_due
  @default_margins = default_margins
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @due_date = due_date
  @effective_at = effective_at
  @expand = expand
  @footer = footer
  @issuer = issuer
  @metadata = 
  @number = number
  @on_behalf_of = on_behalf_of
  @payment_settings = payment_settings
  @rendering = rendering
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



526
527
528
# File 'lib/stripe/services/invoice_service.rb', line 526

def 
  @account_tax_ids
end

#amounts_dueObject

List of expected payments and corresponding due dates. Valid only for invoices where ‘collection_method=send_invoice`.



528
529
530
# File 'lib/stripe/services/invoice_service.rb', line 528

def amounts_due
  @amounts_due
end

#application_fee_amountObject

A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](stripe.com/docs/billing/invoices/connect#collecting-fees).



530
531
532
# File 'lib/stripe/services/invoice_service.rb', line 530

def application_fee_amount
  @application_fee_amount
end

#auto_advanceObject

Controls whether Stripe performs [automatic collection](stripe.com/docs/invoicing/integration/automatic-advancement-collection) of the invoice.



532
533
534
# File 'lib/stripe/services/invoice_service.rb', line 532

def auto_advance
  @auto_advance
end

#automatic_taxObject

Settings for automatic tax lookup for this invoice.



534
535
536
# File 'lib/stripe/services/invoice_service.rb', line 534

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject

The time when this invoice should be scheduled to finalize. The invoice will be finalized at this time if it is still in draft state. To turn off automatic finalization, set ‘auto_advance` to false.



536
537
538
# File 'lib/stripe/services/invoice_service.rb', line 536

def automatically_finalizes_at
  @automatically_finalizes_at
end

#collection_methodObject

Either ‘charge_automatically` or `send_invoice`. This field can be updated only on `draft` invoices.



538
539
540
# File 'lib/stripe/services/invoice_service.rb', line 538

def collection_method
  @collection_method
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice. If a value for ‘custom_fields` is specified, the list specified will replace the existing custom field list on this invoice. Pass an empty string to remove previously-defined fields.



540
541
542
# File 'lib/stripe/services/invoice_service.rb', line 540

def custom_fields
  @custom_fields
end

#days_until_dueObject

The number of days from which the invoice is created until it is due. Only valid for invoices where ‘collection_method=send_invoice`. This field can only be updated on `draft` invoices.



542
543
544
# File 'lib/stripe/services/invoice_service.rb', line 542

def days_until_due
  @days_until_due
end

#default_marginsObject

The ids of the margins to apply to the invoice. Can be overridden by line item ‘margins`.



544
545
546
# File 'lib/stripe/services/invoice_service.rb', line 544

def default_margins
  @default_margins
end

#default_payment_methodObject

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



546
547
548
# File 'lib/stripe/services/invoice_service.rb', line 546

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



548
549
550
# File 'lib/stripe/services/invoice_service.rb', line 548

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set. Pass an empty string to remove previously-defined tax rates.



550
551
552
# File 'lib/stripe/services/invoice_service.rb', line 550

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



552
553
554
# File 'lib/stripe/services/invoice_service.rb', line 552

def description
  @description
end

#discountsObject

The discounts that will apply to the invoice. Pass an empty string to remove previously-defined discounts.



554
555
556
# File 'lib/stripe/services/invoice_service.rb', line 554

def discounts
  @discounts
end

#due_dateObject

The date on which payment for this invoice is due. Only valid for invoices where ‘collection_method=send_invoice`. This field can only be updated on `draft` invoices.



556
557
558
# File 'lib/stripe/services/invoice_service.rb', line 556

def due_date
  @due_date
end

#effective_atObject

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



558
559
560
# File 'lib/stripe/services/invoice_service.rb', line 558

def effective_at
  @effective_at
end

#expandObject

Specifies which fields in the response should be expanded.



560
561
562
# File 'lib/stripe/services/invoice_service.rb', line 560

def expand
  @expand
end

Footer to be displayed on the invoice.



562
563
564
# File 'lib/stripe/services/invoice_service.rb', line 562

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



564
565
566
# File 'lib/stripe/services/invoice_service.rb', line 564

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



566
567
568
# File 'lib/stripe/services/invoice_service.rb', line 566

def 
  @metadata
end

#numberObject

Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.



568
569
570
# File 'lib/stripe/services/invoice_service.rb', line 568

def number
  @number
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](stripe.com/docs/billing/invoices/connect) documentation for details.



570
571
572
# File 'lib/stripe/services/invoice_service.rb', line 570

def on_behalf_of
  @on_behalf_of
end

#payment_settingsObject

Configuration settings for the PaymentIntent that is generated when the invoice is finalized.



572
573
574
# File 'lib/stripe/services/invoice_service.rb', line 572

def payment_settings
  @payment_settings
end

#renderingObject

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



574
575
576
# File 'lib/stripe/services/invoice_service.rb', line 574

def rendering
  @rendering
end

#shipping_costObject

Settings for the cost of shipping for this invoice.



576
577
578
# File 'lib/stripe/services/invoice_service.rb', line 576

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



578
579
580
# File 'lib/stripe/services/invoice_service.rb', line 578

def shipping_details
  @shipping_details
end

#statement_descriptorObject

Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.



580
581
582
# File 'lib/stripe/services/invoice_service.rb', line 580

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge. This will be unset if you POST an empty value.



582
583
584
# File 'lib/stripe/services/invoice_service.rb', line 582

def transfer_data
  @transfer_data
end