Class: Stripe::InvoiceService::UpdateParams::Discount::DiscountEnd

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Duration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd

Returns a new instance of DiscountEnd.



110
111
112
113
114
# File 'lib/stripe/services/invoice_service.rb', line 110

def initialize(duration: nil, timestamp: nil, type: nil)
  @duration = duration
  @timestamp = timestamp
  @type = type
end

Instance Attribute Details

#durationObject

Time span for the redeemed discount.



102
103
104
# File 'lib/stripe/services/invoice_service.rb', line 102

def duration
  @duration
end

#timestampObject

A precise Unix timestamp for the discount to end. Must be in the future.



105
106
107
# File 'lib/stripe/services/invoice_service.rb', line 105

def timestamp
  @timestamp
end

#typeObject

The type of calculation made to determine when the discount ends.



108
109
110
# File 'lib/stripe/services/invoice_service.rb', line 108

def type
  @type
end