Class: Stripe::InvoiceService::UpdateParams::PaymentSettings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateParams::PaymentSettings
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions
Instance Attribute Summary collapse
-
#default_mandate ⇒ Object
ID of the mandate to be used for this invoice.
-
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to the invoice’s PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil) ⇒ PaymentSettings
constructor
A new instance of PaymentSettings.
Methods inherited from RequestParams
Constructor Details
#initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil) ⇒ PaymentSettings
Returns a new instance of PaymentSettings.
326 327 328 329 330 |
# File 'lib/stripe/services/invoice_service.rb', line 326 def initialize(default_mandate: nil, payment_method_options: nil, payment_method_types: nil) @default_mandate = default_mandate @payment_method_options = @payment_method_types = payment_method_types end |
Instance Attribute Details
#default_mandate ⇒ Object
ID of the mandate to be used for this invoice. It must correspond to the payment method used to pay the invoice, including the invoice’s default_payment_method or default_source, if set.
320 321 322 |
# File 'lib/stripe/services/invoice_service.rb', line 320 def default_mandate @default_mandate end |
#payment_method_options ⇒ Object
Payment-method-specific configuration to provide to the invoice’s PaymentIntent.
322 323 324 |
# File 'lib/stripe/services/invoice_service.rb', line 322 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (e.g. card) to provide to the invoice’s PaymentIntent. If not set, Stripe attempts to automatically determine the types to use by looking at the invoice’s default payment method, the subscription’s default payment method, the customer’s default payment method, and your [invoice template settings](dashboard.stripe.com/settings/billing/invoice). Should not be specified with payment_method_configuration
324 325 326 |
# File 'lib/stripe/services/invoice_service.rb', line 324 def payment_method_types @payment_method_types end |