Class: Stripe::InvoiceService::UpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/stripe/services/invoice_service.rb', line 301

def initialize(
  acss_debit: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  sepa_debit: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @sepa_debit = sepa_debit
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



285
286
287
# File 'lib/stripe/services/invoice_service.rb', line 285

def acss_debit
  @acss_debit
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



287
288
289
# File 'lib/stripe/services/invoice_service.rb', line 287

def bancontact
  @bancontact
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



289
290
291
# File 'lib/stripe/services/invoice_service.rb', line 289

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



291
292
293
# File 'lib/stripe/services/invoice_service.rb', line 291

def customer_balance
  @customer_balance
end

#id_bank_transferObject

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



293
294
295
# File 'lib/stripe/services/invoice_service.rb', line 293

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



295
296
297
# File 'lib/stripe/services/invoice_service.rb', line 295

def konbini
  @konbini
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



297
298
299
# File 'lib/stripe/services/invoice_service.rb', line 297

def sepa_debit
  @sepa_debit
end

#us_bank_accountObject

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



299
300
301
# File 'lib/stripe/services/invoice_service.rb', line 299

def 
  @us_bank_account
end