Class: Stripe::InvoiceService::UpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Card, CustomerBalance, IdBankTransfer, Konbini, SepaDebit, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, sepa_debit: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/stripe/services/invoice_service.rb', line 332

def initialize(
  acss_debit: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  sepa_debit: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @sepa_debit = sepa_debit
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



309
310
311
# File 'lib/stripe/services/invoice_service.rb', line 309

def acss_debit
  @acss_debit
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



312
313
314
# File 'lib/stripe/services/invoice_service.rb', line 312

def bancontact
  @bancontact
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



315
316
317
# File 'lib/stripe/services/invoice_service.rb', line 315

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



318
319
320
# File 'lib/stripe/services/invoice_service.rb', line 318

def customer_balance
  @customer_balance
end

#id_bank_transferObject

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



321
322
323
# File 'lib/stripe/services/invoice_service.rb', line 321

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



324
325
326
# File 'lib/stripe/services/invoice_service.rb', line 324

def konbini
  @konbini
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



327
328
329
# File 'lib/stripe/services/invoice_service.rb', line 327

def sepa_debit
  @sepa_debit
end

#us_bank_accountObject

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



330
331
332
# File 'lib/stripe/services/invoice_service.rb', line 330

def 
  @us_bank_account
end