Class: Stripe::InvoiceService::UpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



177
178
179
180
181
# File 'lib/stripe/services/invoice_service.rb', line 177

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



170
171
172
# File 'lib/stripe/services/invoice_service.rb', line 170

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



173
174
175
# File 'lib/stripe/services/invoice_service.rb', line 173

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



175
176
177
# File 'lib/stripe/services/invoice_service.rb', line 175

def type
  @type
end