Class: Stripe::InvoiceService::UpdateParams::PaymentSettings::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceService::UpdateParams::PaymentSettings::PaymentMethodOptions::UsBankAccount::FinancialConnections
- Defined in:
- lib/stripe/services/invoice_service.rb
Defined Under Namespace
Classes: Filters
Instance Attribute Summary collapse
-
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
-
#permissions ⇒ Object
The list of permissions to request.
-
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
Instance Method Summary collapse
-
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
constructor
A new instance of FinancialConnections.
Methods inherited from RequestParams
Constructor Details
#initialize(filters: nil, permissions: nil, prefetch: nil) ⇒ FinancialConnections
Returns a new instance of FinancialConnections.
268 269 270 271 272 |
# File 'lib/stripe/services/invoice_service.rb', line 268 def initialize(filters: nil, permissions: nil, prefetch: nil) @filters = filters @permissions = @prefetch = prefetch end |
Instance Attribute Details
#filters ⇒ Object
Provide filters for the linked accounts that the customer can select for the payment method.
262 263 264 |
# File 'lib/stripe/services/invoice_service.rb', line 262 def filters @filters end |
#permissions ⇒ Object
The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.
264 265 266 |
# File 'lib/stripe/services/invoice_service.rb', line 264 def @permissions end |
#prefetch ⇒ Object
List of data features that you would like to retrieve upon account creation.
266 267 268 |
# File 'lib/stripe/services/invoice_service.rb', line 266 def prefetch @prefetch end |