Class: Stripe::InvoiceService::UpdateParams::Rendering

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_service.rb

Defined Under Namespace

Classes: Pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering

Returns a new instance of Rendering.



354
355
356
357
358
359
# File 'lib/stripe/services/invoice_service.rb', line 354

def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil)
  @amount_tax_display = amount_tax_display
  @pdf = pdf
  @template = template
  @template_version = template_version
end

Instance Attribute Details

#amount_tax_displayObject

How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.



346
347
348
# File 'lib/stripe/services/invoice_service.rb', line 346

def amount_tax_display
  @amount_tax_display
end

#pdfObject

Invoice pdf rendering options



348
349
350
# File 'lib/stripe/services/invoice_service.rb', line 348

def pdf
  @pdf
end

#templateObject

ID of the invoice rendering template to use for this invoice.



350
351
352
# File 'lib/stripe/services/invoice_service.rb', line 350

def template
  @template
end

#template_versionObject

The specific version of invoice rendering template to use for this invoice.



352
353
354
# File 'lib/stripe/services/invoice_service.rb', line 352

def template_version
  @template_version
end