Class: Stripe::InvoiceUpcomingLinesService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::InvoiceUpcomingLinesService
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Defined Under Namespace
Classes: ListParams
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
When retrieving an upcoming invoice, you’ll get a lines property containing the total count of line items and the first handful of those items.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
When retrieving an upcoming invoice, you’ll get a lines property containing the total count of line items and the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.
2149 2150 2151 2152 2153 2154 2155 2156 2157 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 2149 def list(params = {}, opts = {}) request( method: :get, path: "/v1/invoices/upcoming/lines", params: params, opts: opts, base_address: :api ) end |