Class: Stripe::InvoiceUpcomingLinesService::ListParams::InvoiceItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Discount, Period, PriceData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, description: nil, discountable: nil, discounts: nil, invoiceitem: nil, metadata: nil, period: nil, price: nil, price_data: nil, quantity: nil, tax_behavior: nil, tax_code: nil, tax_rates: nil, unit_amount: nil, unit_amount_decimal: nil) ⇒ InvoiceItem

Returns a new instance of InvoiceItem.



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 305

def initialize(
  amount: nil,
  currency: nil,
  description: nil,
  discountable: nil,
  discounts: nil,
  invoiceitem: nil,
  metadata: nil,
  period: nil,
  price: nil,
  price_data: nil,
  quantity: nil,
  tax_behavior: nil,
  tax_code: nil,
  tax_rates: nil,
  unit_amount: nil,
  unit_amount_decimal: nil
)
  @amount = amount
  @currency = currency
  @description = description
  @discountable = discountable
  @discounts = discounts
  @invoiceitem = invoiceitem
  @metadata = 
  @period = period
  @price = price
  @price_data = price_data
  @quantity = quantity
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @tax_rates = tax_rates
  @unit_amount = unit_amount
  @unit_amount_decimal = unit_amount_decimal
end

Instance Attribute Details

#amountObject

The integer amount in cents (or local equivalent) of previewed invoice item.



273
274
275
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 273

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies). Only applicable to new invoice items.



275
276
277
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 275

def currency
  @currency
end

#descriptionObject

An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.



277
278
279
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 277

def description
  @description
end

#discountableObject

Explicitly controls whether discounts apply to this invoice item. Defaults to true, except for negative invoice items.



279
280
281
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 279

def discountable
  @discountable
end

#discountsObject

The coupons to redeem into discounts for the invoice item in the preview.



281
282
283
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 281

def discounts
  @discounts
end

#invoiceitemObject

The ID of the invoice item to update in preview. If not specified, a new invoice item will be added to the preview of the upcoming invoice.



283
284
285
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 283

def invoiceitem
  @invoiceitem
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



285
286
287
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 285

def 
  @metadata
end

#periodObject

The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](stripe.com/docs/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](stripe.com/docs/revenue-recognition/methodology/subscriptions-and-invoicing) for details.



287
288
289
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 287

def period
  @period
end

#priceObject

The ID of the price object. One of ‘price` or `price_data` is required.



289
290
291
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 289

def price
  @price
end

#price_dataObject

Data used to generate a new [Price](stripe.com/docs/api/prices) object inline. One of ‘price` or `price_data` is required.



291
292
293
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 291

def price_data
  @price_data
end

#quantityObject

Non-negative integer. The quantity of units for the invoice item.



293
294
295
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 293

def quantity
  @quantity
end

#tax_behaviorObject

Only required if a [default tax behavior](stripe.com/docs/tax/products-prices-tax-categories-tax-behavior#setting-a-default-tax-behavior-(recommended)) was not provided in the Stripe Tax settings. Specifies whether the price is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`. Once specified as either `inclusive` or `exclusive`, it cannot be changed.



295
296
297
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 295

def tax_behavior
  @tax_behavior
end

#tax_codeObject



297
298
299
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 297

def tax_code
  @tax_code
end

#tax_ratesObject

The tax rates that apply to the item. When set, any ‘default_tax_rates` do not apply to this item.



299
300
301
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 299

def tax_rates
  @tax_rates
end

#unit_amountObject

The integer unit amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. This unit_amount will be multiplied by the quantity to get the full amount. If you want to apply a credit to the customer’s account, pass a negative unit_amount.



301
302
303
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 301

def unit_amount
  @unit_amount
end

#unit_amount_decimalObject

Same as ‘unit_amount`, but accepts a decimal value in cents (or local equivalent) with at most 12 decimal places. Only one of `unit_amount` and `unit_amount_decimal` can be set.



303
304
305
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 303

def unit_amount_decimal
  @unit_amount_decimal
end