Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



513
514
515
516
517
518
519
520
521
522
523
524
525
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 513

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



499
500
501
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 499

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



502
503
504
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 502

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



505
506
507
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 505

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



508
509
510
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 508

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



511
512
513
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 511

def promotion_code
  @promotion_code
end