Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::DiscountAction::Add

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, index: nil, promotion_code: nil) ⇒ Add

Returns a new instance of Add.



450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 450

def initialize(
  coupon: nil,
  discount: nil,
  discount_end: nil,
  index: nil,
  promotion_code: nil
)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @index = index
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

The coupon code to redeem.



440
441
442
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 440

def coupon
  @coupon
end

#discountObject

An ID of an existing discount for a coupon that was already redeemed.



442
443
444
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 442

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



444
445
446
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 444

def discount_end
  @discount_end
end

#indexObject

The index, starting at 0, at which to position the new discount. When not supplied, Stripe defaults to appending the discount to the end of the ‘discounts` array.



446
447
448
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 446

def index
  @index
end

#promotion_codeObject

The promotion code to redeem.



448
449
450
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 448

def promotion_code
  @promotion_code
end