Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::DiscountAction::Remove
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::DiscountAction::Remove
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
-
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
-
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove
constructor
A new instance of Remove.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Remove
Returns a new instance of Remove.
473 474 475 476 477 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 473 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
The coupon code to remove from the ‘discounts` array.
467 468 469 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 467 def coupon @coupon end |
#discount ⇒ Object
The ID of a discount to remove from the ‘discounts` array.
469 470 471 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 469 def discount @discount end |
#promotion_code ⇒ Object
The ID of a promotion code to remove from the ‘discounts` array.
471 472 473 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 471 def promotion_code @promotion_code end |