Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::ItemAction

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: Add, Remove, Set

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(add: nil, remove: nil, set: nil, type: nil) ⇒ ItemAction

Returns a new instance of ItemAction.



796
797
798
799
800
801
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 796

def initialize(add: nil, remove: nil, set: nil, type: nil)
  @add = add
  @remove = remove
  @set = set
  @type = type
end

Instance Attribute Details

#addObject

Details of the subscription item to add. If an item with the same ‘price` exists, it will be replaced by this new item. Otherwise, it adds the new item.



785
786
787
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 785

def add
  @add
end

#removeObject

Details of the subscription item to remove.



788
789
790
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 788

def remove
  @remove
end

#setObject

Details of the subscription item to replace the existing items with. If an item with the ‘set` already exists, the `items` array is not cleared. Instead, all of the other `set` properties that are passed in this request will replace the existing values for the configuration item.



791
792
793
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 791

def set
  @set
end

#typeObject

Determines the type of item action.



794
795
796
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 794

def type
  @type
end