Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::ItemAction::Add
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Amendment::ItemAction::Add
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#discounts ⇒ Object
The discounts applied to the item.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#price ⇒ Object
The ID of the price object.
-
#quantity ⇒ Object
Quantity for this item.
-
#tax_rates ⇒ Object
The tax rates that apply to this subscription item.
-
#trial ⇒ Object
Options that configure the trial on the subscription item.
Instance Method Summary collapse
-
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
constructor
A new instance of Add.
Methods inherited from RequestParams
Constructor Details
#initialize(discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil) ⇒ Add
Returns a new instance of Add.
580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 580 def initialize( discounts: nil, metadata: nil, price: nil, quantity: nil, tax_rates: nil, trial: nil ) @discounts = discounts @metadata = @price = price @quantity = quantity @tax_rates = tax_rates @trial = trial end |
Instance Attribute Details
#discounts ⇒ Object
The discounts applied to the item. Subscription item discounts are applied before subscription discounts.
568 569 570 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 568 def discounts @discounts end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
570 571 572 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 570 def @metadata end |
#price ⇒ Object
The ID of the price object.
572 573 574 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 572 def price @price end |
#quantity ⇒ Object
Quantity for this item.
574 575 576 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 574 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates that apply to this subscription item. When set, the ‘default_tax_rates` on the subscription do not apply to this `subscription_item`.
576 577 578 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 576 def tax_rates @tax_rates end |
#trial ⇒ Object
Options that configure the trial on the subscription item.
578 579 580 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 578 def trial @trial end |