Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Phase::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Defined Under Namespace

Classes: DiscountEnd

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



974
975
976
977
978
979
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 974

def initialize(coupon: nil, discount: nil, discount_end: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @discount_end = discount_end
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



966
967
968
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 966

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



968
969
970
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 968

def discount
  @discount
end

#discount_endObject

Details to determine how long the discount should be applied for.



970
971
972
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 970

def discount_end
  @discount_end
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



972
973
974
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 972

def promotion_code
  @promotion_code
end