Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Phase::Discount::DiscountEnd
- Defined in:
- lib/stripe/services/invoice_upcoming_lines_service.rb
Defined Under Namespace
Classes: Duration
Instance Attribute Summary collapse
-
#duration ⇒ Object
Time span for the redeemed discount.
-
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end.
-
#type ⇒ Object
The type of calculation made to determine when the discount ends.
Instance Method Summary collapse
-
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
constructor
A new instance of DiscountEnd.
Methods inherited from RequestParams
Constructor Details
#initialize(duration: nil, timestamp: nil, type: nil) ⇒ DiscountEnd
Returns a new instance of DiscountEnd.
959 960 961 962 963 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 959 def initialize(duration: nil, timestamp: nil, type: nil) @duration = duration @timestamp = @type = type end |
Instance Attribute Details
#duration ⇒ Object
Time span for the redeemed discount.
953 954 955 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 953 def duration @duration end |
#timestamp ⇒ Object
A precise Unix timestamp for the discount to end. Must be in the future.
955 956 957 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 955 def @timestamp end |
#type ⇒ Object
The type of calculation made to determine when the discount ends.
957 958 959 |
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 957 def type @type end |