Class: Stripe::InvoiceUpcomingLinesService::ListParams::ScheduleDetails::Phase::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/invoice_upcoming_lines_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_percent: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1329
1330
1331
1332
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1329

def initialize(amount_percent: nil, destination: nil)
  @amount_percent = amount_percent
  @destination = destination
end

Instance Attribute Details

#amount_percentObject

A non-negative decimal between 0 and 100, with at most two decimal places. This represents the percentage of the subscription invoice total that will be transferred to the destination account. By default, the entire amount is transferred to the destination.



1324
1325
1326
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1324

def amount_percent
  @amount_percent
end

#destinationObject

ID of an existing, connected Stripe account.



1327
1328
1329
# File 'lib/stripe/services/invoice_upcoming_lines_service.rb', line 1327

def destination
  @destination
end