Class: Stripe::InvoiceUpdateLinesParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateLinesParams
- Defined in:
- lib/stripe/params/invoice_update_lines_params.rb
Defined Under Namespace
Classes: Line
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#invoice_metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#lines ⇒ Object
The line items to update.
Instance Method Summary collapse
-
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ InvoiceUpdateLinesParams
constructor
A new instance of InvoiceUpdateLinesParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, invoice_metadata: nil, lines: nil) ⇒ InvoiceUpdateLinesParams
Returns a new instance of InvoiceUpdateLinesParams.
272 273 274 275 276 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 272 def initialize(expand: nil, invoice_metadata: nil, lines: nil) @expand = @invoice_metadata = @lines = lines end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
266 267 268 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 266 def @expand end |
#invoice_metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](docs.stripe.com/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.
268 269 270 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 268 def @invoice_metadata end |
#lines ⇒ Object
The line items to update.
270 271 272 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 270 def lines @lines end |