Class: Stripe::InvoiceUpdateLinesParams::Line
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateLinesParams::Line
- Defined in:
- lib/stripe/params/invoice_update_lines_params.rb
Defined Under Namespace
Classes: Discount, Period, PriceData, Pricing, TaxAmount
Instance Attribute Summary collapse
-
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice.
-
#description ⇒ Object
An arbitrary string which you can attach to the invoice item.
-
#discountable ⇒ Object
Controls whether discounts apply to this line item.
-
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item.
-
#id ⇒ Object
ID of an existing line item on the invoice.
-
#margins ⇒ Object
The IDs of the margins to apply to the line item.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#period ⇒ Object
The period associated with this invoice item.
-
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
-
#pricing ⇒ Object
The pricing information for the invoice item.
-
#quantity ⇒ Object
Non-negative integer.
-
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item.
-
#tax_rates ⇒ Object
The tax rates which apply to the line item.
Instance Method Summary collapse
-
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line
constructor
A new instance of Line.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil) ⇒ Line
Returns a new instance of Line.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 235 def initialize( amount: nil, description: nil, discountable: nil, discounts: nil, id: nil, margins: nil, metadata: nil, period: nil, price_data: nil, pricing: nil, quantity: nil, tax_amounts: nil, tax_rates: nil ) @amount = amount @description = description @discountable = discountable @discounts = discounts @id = id @margins = margins @metadata = @period = period @price_data = price_data @pricing = pricing @quantity = quantity @tax_amounts = tax_amounts @tax_rates = tax_rates end |
Instance Attribute Details
#amount ⇒ Object
The integer amount in cents (or local equivalent) of the charge to be applied to the upcoming invoice. If you want to apply a credit to the customer’s account, pass a negative amount.
209 210 211 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 209 def amount @amount end |
#description ⇒ Object
An arbitrary string which you can attach to the invoice item. The description is displayed in the invoice for easy tracking.
211 212 213 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 211 def description @description end |
#discountable ⇒ Object
Controls whether discounts apply to this line item. Defaults to false for prorations or negative line items, and true for all other line items. Cannot be set to true for prorations.
213 214 215 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 213 def discountable @discountable end |
#discounts ⇒ Object
The coupons, promotion codes & existing discounts which apply to the line item. Item discounts are applied before invoice discounts. Pass an empty string to remove previously-defined discounts.
215 216 217 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 215 def discounts @discounts end |
#id ⇒ Object
ID of an existing line item on the invoice.
217 218 219 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 217 def id @id end |
#margins ⇒ Object
The IDs of the margins to apply to the line item. When set, the ‘default_margins` on the invoice do not apply to this line item.
219 220 221 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 219 def margins @margins end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`. For [type=subscription](docs.stripe.com/api/invoices/line_item#invoice_line_item_object-type) line items, the incoming metadata specified on the request is directly used to set this value, in contrast to [type=invoiceitem](api/invoices/line_item#invoice_line_item_object-type) line items, where any existing metadata on the invoice line is merged with the incoming data.
221 222 223 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 221 def @metadata end |
#period ⇒ Object
The period associated with this invoice item. When set to different values, the period will be rendered on the invoice. If you have [Stripe Revenue Recognition](docs.stripe.com/revenue-recognition) enabled, the period will be used to recognize and defer revenue. See the [Revenue Recognition documentation](docs.stripe.com/revenue-recognition/methodology/subscriptions-and-invoicing) for details.
223 224 225 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 223 def period @period end |
#price_data ⇒ Object
Data used to generate a new [Price](docs.stripe.com/api/prices) object inline.
225 226 227 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 225 def price_data @price_data end |
#pricing ⇒ Object
The pricing information for the invoice item.
227 228 229 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 227 def pricing @pricing end |
#quantity ⇒ Object
Non-negative integer. The quantity of units for the line item.
229 230 231 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 229 def quantity @quantity end |
#tax_amounts ⇒ Object
A list of up to 10 tax amounts for this line item. This can be useful if you calculate taxes on your own or use a third-party to calculate them. You cannot set tax amounts if any line item has [tax_rates](docs.stripe.com/api/invoices/line_item#invoice_line_item_object-tax_rates) or if the invoice has [default_tax_rates](docs.stripe.com/api/invoices/object#invoice_object-default_tax_rates) or uses [automatic tax](docs.stripe.com/tax/invoicing). Pass an empty string to remove previously defined tax amounts.
231 232 233 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 231 def tax_amounts @tax_amounts end |
#tax_rates ⇒ Object
The tax rates which apply to the line item. When set, the ‘default_tax_rates` on the invoice do not apply to this line item. Pass an empty string to remove previously-defined tax rates.
233 234 235 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 233 def tax_rates @tax_rates end |