Class: Stripe::InvoiceUpdateLinesParams::Line::Discount::DiscountEnd::Duration
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateLinesParams::Line::Discount::DiscountEnd::Duration
- Defined in:
- lib/stripe/params/invoice_update_lines_params.rb
Instance Attribute Summary collapse
-
#interval ⇒ Object
Specifies a type of interval unit.
-
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil) ⇒ Duration
constructor
A new instance of Duration.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(interval: nil, interval_count: nil) ⇒ Duration
Returns a new instance of Duration.
15 16 17 18 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 15 def initialize(interval: nil, interval_count: nil) @interval = interval @interval_count = interval_count end |
Instance Attribute Details
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
11 12 13 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 11 def interval @interval end |
#interval_count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
13 14 15 |
# File 'lib/stripe/params/invoice_update_lines_params.rb', line 13 def interval_count @interval_count end |