Class: Stripe::InvoiceUpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Defined Under Namespace

Classes: AmountsDue, AutomaticTax, CustomField, Discount, Issuer, PaymentSettings, Rendering, ShippingCost, ShippingDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(account_tax_ids: nil, amounts_due: nil, application_fee_amount: nil, auto_advance: nil, automatic_tax: nil, automatically_finalizes_at: nil, collection_method: nil, custom_fields: nil, days_until_due: nil, default_margins: nil, default_payment_method: nil, default_source: nil, default_tax_rates: nil, description: nil, discounts: nil, due_date: nil, effective_at: nil, expand: nil, footer: nil, issuer: nil, metadata: nil, number: nil, on_behalf_of: nil, payment_settings: nil, rendering: nil, shipping_cost: nil, shipping_details: nil, statement_descriptor: nil, transfer_data: nil) ⇒ InvoiceUpdateParams

Returns a new instance of InvoiceUpdateParams.



682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
# File 'lib/stripe/params/invoice_update_params.rb', line 682

def initialize(
  account_tax_ids: nil,
  amounts_due: nil,
  application_fee_amount: nil,
  auto_advance: nil,
  automatic_tax: nil,
  automatically_finalizes_at: nil,
  collection_method: nil,
  custom_fields: nil,
  days_until_due: nil,
  default_margins: nil,
  default_payment_method: nil,
  default_source: nil,
  default_tax_rates: nil,
  description: nil,
  discounts: nil,
  due_date: nil,
  effective_at: nil,
  expand: nil,
  footer: nil,
  issuer: nil,
  metadata: nil,
  number: nil,
  on_behalf_of: nil,
  payment_settings: nil,
  rendering: nil,
  shipping_cost: nil,
  shipping_details: nil,
  statement_descriptor: nil,
  transfer_data: nil
)
  @account_tax_ids = 
  @amounts_due = amounts_due
  @application_fee_amount = application_fee_amount
  @auto_advance = auto_advance
  @automatic_tax = automatic_tax
  @automatically_finalizes_at = automatically_finalizes_at
  @collection_method = collection_method
  @custom_fields = custom_fields
  @days_until_due = days_until_due
  @default_margins = default_margins
  @default_payment_method = default_payment_method
  @default_source = default_source
  @default_tax_rates = default_tax_rates
  @description = description
  @discounts = discounts
  @due_date = due_date
  @effective_at = effective_at
  @expand = expand
  @footer = footer
  @issuer = issuer
  @metadata = 
  @number = number
  @on_behalf_of = on_behalf_of
  @payment_settings = payment_settings
  @rendering = rendering
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @statement_descriptor = statement_descriptor
  @transfer_data = transfer_data
end

Instance Attribute Details

#account_tax_idsObject

The account tax IDs associated with the invoice. Only editable when the invoice is a draft.



624
625
626
# File 'lib/stripe/params/invoice_update_params.rb', line 624

def 
  @account_tax_ids
end

#amounts_dueObject

List of expected payments and corresponding due dates. Valid only for invoices where ‘collection_method=send_invoice`.



626
627
628
# File 'lib/stripe/params/invoice_update_params.rb', line 626

def amounts_due
  @amounts_due
end

#application_fee_amountObject

A fee in cents (or local equivalent) that will be applied to the invoice and transferred to the application owner’s Stripe account. The request must be made with an OAuth key or the Stripe-Account header in order to take an application fee. For more information, see the application fees [documentation](docs.stripe.com/billing/invoices/connect#collecting-fees).



628
629
630
# File 'lib/stripe/params/invoice_update_params.rb', line 628

def application_fee_amount
  @application_fee_amount
end

#auto_advanceObject

Controls whether Stripe performs [automatic collection](docs.stripe.com/invoicing/integration/automatic-advancement-collection) of the invoice.



630
631
632
# File 'lib/stripe/params/invoice_update_params.rb', line 630

def auto_advance
  @auto_advance
end

#automatic_taxObject

Settings for automatic tax lookup for this invoice.



632
633
634
# File 'lib/stripe/params/invoice_update_params.rb', line 632

def automatic_tax
  @automatic_tax
end

#automatically_finalizes_atObject

The time when this invoice should be scheduled to finalize (up to 5 years in the future). The invoice is finalized at this time if it’s still in draft state. To turn off automatic finalization, set ‘auto_advance` to false.



634
635
636
# File 'lib/stripe/params/invoice_update_params.rb', line 634

def automatically_finalizes_at
  @automatically_finalizes_at
end

#collection_methodObject

Either ‘charge_automatically` or `send_invoice`. This field can be updated only on `draft` invoices.



636
637
638
# File 'lib/stripe/params/invoice_update_params.rb', line 636

def collection_method
  @collection_method
end

#custom_fieldsObject

A list of up to 4 custom fields to be displayed on the invoice. If a value for ‘custom_fields` is specified, the list specified will replace the existing custom field list on this invoice. Pass an empty string to remove previously-defined fields.



638
639
640
# File 'lib/stripe/params/invoice_update_params.rb', line 638

def custom_fields
  @custom_fields
end

#days_until_dueObject

The number of days from which the invoice is created until it is due. Only valid for invoices where ‘collection_method=send_invoice`. This field can only be updated on `draft` invoices.



640
641
642
# File 'lib/stripe/params/invoice_update_params.rb', line 640

def days_until_due
  @days_until_due
end

#default_marginsObject

The ids of the margins to apply to the invoice. Can be overridden by line item ‘margins`.



642
643
644
# File 'lib/stripe/params/invoice_update_params.rb', line 642

def default_margins
  @default_margins
end

#default_payment_methodObject

ID of the default payment method for the invoice. It must belong to the customer associated with the invoice. If not set, defaults to the subscription’s default payment method, if any, or to the default payment method in the customer’s invoice settings.



644
645
646
# File 'lib/stripe/params/invoice_update_params.rb', line 644

def default_payment_method
  @default_payment_method
end

#default_sourceObject

ID of the default payment source for the invoice. It must belong to the customer associated with the invoice and be in a chargeable state. If not set, defaults to the subscription’s default source, if any, or to the customer’s default source.



646
647
648
# File 'lib/stripe/params/invoice_update_params.rb', line 646

def default_source
  @default_source
end

#default_tax_ratesObject

The tax rates that will apply to any line item that does not have ‘tax_rates` set. Pass an empty string to remove previously-defined tax rates.



648
649
650
# File 'lib/stripe/params/invoice_update_params.rb', line 648

def default_tax_rates
  @default_tax_rates
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users. Referenced as ‘memo’ in the Dashboard.



650
651
652
# File 'lib/stripe/params/invoice_update_params.rb', line 650

def description
  @description
end

#discountsObject

The discounts that will apply to the invoice. Pass an empty string to remove previously-defined discounts.



652
653
654
# File 'lib/stripe/params/invoice_update_params.rb', line 652

def discounts
  @discounts
end

#due_dateObject

The date on which payment for this invoice is due. Only valid for invoices where ‘collection_method=send_invoice`. This field can only be updated on `draft` invoices.



654
655
656
# File 'lib/stripe/params/invoice_update_params.rb', line 654

def due_date
  @due_date
end

#effective_atObject

The date when this invoice is in effect. Same as ‘finalized_at` unless overwritten. When defined, this value replaces the system-generated ’Date of issue’ printed on the invoice PDF and receipt.



656
657
658
# File 'lib/stripe/params/invoice_update_params.rb', line 656

def effective_at
  @effective_at
end

#expandObject

Specifies which fields in the response should be expanded.



658
659
660
# File 'lib/stripe/params/invoice_update_params.rb', line 658

def expand
  @expand
end

Footer to be displayed on the invoice.



660
661
662
# File 'lib/stripe/params/invoice_update_params.rb', line 660

def footer
  @footer
end

#issuerObject

The connected account that issues the invoice. The invoice is presented with the branding and support information of the specified account.



662
663
664
# File 'lib/stripe/params/invoice_update_params.rb', line 662

def issuer
  @issuer
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



664
665
666
# File 'lib/stripe/params/invoice_update_params.rb', line 664

def 
  @metadata
end

#numberObject

Set the number for this invoice. If no number is present then a number will be assigned automatically when the invoice is finalized. In many markets, regulations require invoices to be unique, sequential and / or gapless. You are responsible for ensuring this is true across all your different invoicing systems in the event that you edit the invoice number using our API. If you use only Stripe for your invoices and do not change invoice numbers, Stripe handles this aspect of compliance for you automatically.



666
667
668
# File 'lib/stripe/params/invoice_update_params.rb', line 666

def number
  @number
end

#on_behalf_ofObject

The account (if any) for which the funds of the invoice payment are intended. If set, the invoice will be presented with the branding and support information of the specified account. See the [Invoices with Connect](docs.stripe.com/billing/invoices/connect) documentation for details.



668
669
670
# File 'lib/stripe/params/invoice_update_params.rb', line 668

def on_behalf_of
  @on_behalf_of
end

#payment_settingsObject

Configuration settings for the PaymentIntent that is generated when the invoice is finalized.



670
671
672
# File 'lib/stripe/params/invoice_update_params.rb', line 670

def payment_settings
  @payment_settings
end

#renderingObject

The rendering-related settings that control how the invoice is displayed on customer-facing surfaces such as PDF and Hosted Invoice Page.



672
673
674
# File 'lib/stripe/params/invoice_update_params.rb', line 672

def rendering
  @rendering
end

#shipping_costObject

Settings for the cost of shipping for this invoice.



674
675
676
# File 'lib/stripe/params/invoice_update_params.rb', line 674

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the invoice. The Invoice PDF will use the ‘shipping_details` value if it is set, otherwise the PDF will render the shipping address from the customer.



676
677
678
# File 'lib/stripe/params/invoice_update_params.rb', line 676

def shipping_details
  @shipping_details
end

#statement_descriptorObject

Extra information about a charge for the customer’s credit card statement. It must contain at least one letter. If not specified and this invoice is part of a subscription, the default ‘statement_descriptor` will be set to the first subscription item’s product’s ‘statement_descriptor`.



678
679
680
# File 'lib/stripe/params/invoice_update_params.rb', line 678

def statement_descriptor
  @statement_descriptor
end

#transfer_dataObject

If specified, the funds from the invoice will be transferred to the destination and the ID of the resulting transfer will be found on the invoice’s charge. This will be unset if you POST an empty value.



680
681
682
# File 'lib/stripe/params/invoice_update_params.rb', line 680

def transfer_data
  @transfer_data
end