Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Bizum, Card, CheckScan, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, bizum: nil, card: nil, check_scan: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/stripe/params/invoice_update_params.rb', line 384

def initialize(
  acss_debit: nil,
  bancontact: nil,
  bizum: nil,
  card: nil,
  check_scan: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @bizum = bizum
  @card = card
  @check_scan = check_scan
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



358
359
360
# File 'lib/stripe/params/invoice_update_params.rb', line 358

def acss_debit
  @acss_debit
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



360
361
362
# File 'lib/stripe/params/invoice_update_params.rb', line 360

def bancontact
  @bancontact
end

#bizumObject

If paying by ‘bizum`, this sub-hash contains details about the Bizum payment method options to pass to the invoice’s PaymentIntent.



362
363
364
# File 'lib/stripe/params/invoice_update_params.rb', line 362

def bizum
  @bizum
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



364
365
366
# File 'lib/stripe/params/invoice_update_params.rb', line 364

def card
  @card
end

#check_scanObject

If paying by ‘check_scan`, this sub-hash contains details about the Check Scan payment method options to pass to the invoice’s PaymentIntent.



366
367
368
# File 'lib/stripe/params/invoice_update_params.rb', line 366

def check_scan
  @check_scan
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



368
369
370
# File 'lib/stripe/params/invoice_update_params.rb', line 368

def customer_balance
  @customer_balance
end

#id_bank_transferObject

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



370
371
372
# File 'lib/stripe/params/invoice_update_params.rb', line 370

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



372
373
374
# File 'lib/stripe/params/invoice_update_params.rb', line 372

def konbini
  @konbini
end

#paytoObject

If paying by ‘payto`, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



374
375
376
# File 'lib/stripe/params/invoice_update_params.rb', line 374

def payto
  @payto
end

#pixObject

If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



376
377
378
# File 'lib/stripe/params/invoice_update_params.rb', line 376

def pix
  @pix
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



378
379
380
# File 'lib/stripe/params/invoice_update_params.rb', line 378

def sepa_debit
  @sepa_debit
end

#upiObject

If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



380
381
382
# File 'lib/stripe/params/invoice_update_params.rb', line 380

def upi
  @upi
end

#us_bank_accountObject

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



382
383
384
# File 'lib/stripe/params/invoice_update_params.rb', line 382

def 
  @us_bank_account
end