Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Defined Under Namespace

Classes: AcssDebit, Bancontact, Blik, Card, CustomerBalance, IdBankTransfer, Konbini, Payto, Pix, SepaDebit, Upi, UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(acss_debit: nil, bancontact: nil, blik: nil, card: nil, customer_balance: nil, id_bank_transfer: nil, konbini: nil, payto: nil, pix: nil, sepa_debit: nil, upi: nil, us_bank_account: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/stripe/params/invoice_update_params.rb', line 343

def initialize(
  acss_debit: nil,
  bancontact: nil,
  blik: nil,
  card: nil,
  customer_balance: nil,
  id_bank_transfer: nil,
  konbini: nil,
  payto: nil,
  pix: nil,
  sepa_debit: nil,
  upi: nil,
  us_bank_account: nil
)
  @acss_debit = acss_debit
  @bancontact = bancontact
  @blik = blik
  @card = card
  @customer_balance = customer_balance
  @id_bank_transfer = id_bank_transfer
  @konbini = konbini
  @payto = payto
  @pix = pix
  @sepa_debit = sepa_debit
  @upi = upi
  @us_bank_account = 
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the Canadian pre-authorized debit payment method options to pass to the invoice’s PaymentIntent.



319
320
321
# File 'lib/stripe/params/invoice_update_params.rb', line 319

def acss_debit
  @acss_debit
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the invoice’s PaymentIntent.



321
322
323
# File 'lib/stripe/params/invoice_update_params.rb', line 321

def bancontact
  @bancontact
end

#blikObject

If paying by ‘blik`, this sub-hash contains details about the Blik payment method options to pass to the invoice’s PaymentIntent.



323
324
325
# File 'lib/stripe/params/invoice_update_params.rb', line 323

def blik
  @blik
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the invoice’s PaymentIntent.



325
326
327
# File 'lib/stripe/params/invoice_update_params.rb', line 325

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Bank transfer payment method options to pass to the invoice’s PaymentIntent.



327
328
329
# File 'lib/stripe/params/invoice_update_params.rb', line 327

def customer_balance
  @customer_balance
end

#id_bank_transferObject

If paying by ‘id_bank_transfer`, this sub-hash contains details about the Indonesia bank transfer payment method options to pass to the invoice’s PaymentIntent.



329
330
331
# File 'lib/stripe/params/invoice_update_params.rb', line 329

def id_bank_transfer
  @id_bank_transfer
end

#konbiniObject

If paying by ‘konbini`, this sub-hash contains details about the Konbini payment method options to pass to the invoice’s PaymentIntent.



331
332
333
# File 'lib/stripe/params/invoice_update_params.rb', line 331

def konbini
  @konbini
end

#paytoObject

If paying by ‘payto`, this sub-hash contains details about the PayTo payment method options to pass to the invoice’s PaymentIntent.



333
334
335
# File 'lib/stripe/params/invoice_update_params.rb', line 333

def payto
  @payto
end

#pixObject

If paying by ‘pix`, this sub-hash contains details about the Pix payment method options to pass to the invoice’s PaymentIntent.



335
336
337
# File 'lib/stripe/params/invoice_update_params.rb', line 335

def pix
  @pix
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Direct Debit payment method options to pass to the invoice’s PaymentIntent.



337
338
339
# File 'lib/stripe/params/invoice_update_params.rb', line 337

def sepa_debit
  @sepa_debit
end

#upiObject

If paying by ‘upi`, this sub-hash contains details about the UPI payment method options to pass to the invoice’s PaymentIntent.



339
340
341
# File 'lib/stripe/params/invoice_update_params.rb', line 339

def upi
  @upi
end

#us_bank_accountObject

If paying by ‘us_bank_account`, this sub-hash contains details about the ACH direct debit payment method options to pass to the invoice’s PaymentIntent.



341
342
343
# File 'lib/stripe/params/invoice_update_params.rb', line 341

def 
  @us_bank_account
end