Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Card::Installments
- Defined in:
- lib/stripe/params/invoice_update_params.rb
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Setting to true enables installments for this invoice.
-
#plan ⇒ Object
The selected installment plan to use for this invoice.
Instance Method Summary collapse
-
#initialize(enabled: nil, plan: nil) ⇒ Installments
constructor
A new instance of Installments.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(enabled: nil, plan: nil) ⇒ Installments
Returns a new instance of Installments.
170 171 172 173 |
# File 'lib/stripe/params/invoice_update_params.rb', line 170 def initialize(enabled: nil, plan: nil) @enabled = enabled @plan = plan end |
Instance Attribute Details
#enabled ⇒ Object
Setting to true enables installments for this invoice. Setting to false will prevent any selected plan from applying to a payment.
166 167 168 |
# File 'lib/stripe/params/invoice_update_params.rb', line 166 def enabled @enabled end |
#plan ⇒ Object
The selected installment plan to use for this invoice.
168 169 170 |
# File 'lib/stripe/params/invoice_update_params.rb', line 168 def plan @plan end |