Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



267
268
269
270
271
272
# File 'lib/stripe/params/invoice_update_params.rb', line 267

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



259
260
261
# File 'lib/stripe/params/invoice_update_params.rb', line 259

def amount
  @amount
end

#amount_typeObject

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



261
262
263
# File 'lib/stripe/params/invoice_update_params.rb', line 261

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



263
264
265
# File 'lib/stripe/params/invoice_update_params.rb', line 263

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



265
266
267
# File 'lib/stripe/params/invoice_update_params.rb', line 265

def end_date
  @end_date
end