Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



218
219
220
221
222
223
# File 'lib/stripe/params/invoice_update_params.rb', line 218

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



210
211
212
# File 'lib/stripe/params/invoice_update_params.rb', line 210

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



212
213
214
# File 'lib/stripe/params/invoice_update_params.rb', line 212

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



214
215
216
# File 'lib/stripe/params/invoice_update_params.rb', line 214

def description
  @description
end

#end_dateObject

End date of the mandate or subscription.



216
217
218
# File 'lib/stripe/params/invoice_update_params.rb', line 216

def end_date
  @end_date
end