Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions
- Defined in:
- lib/stripe/params/invoice_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of ‘fixed` or `maximum`.
-
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
262 263 264 265 266 267 |
# File 'lib/stripe/params/invoice_update_params.rb', line 262 def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) @amount = amount @amount_type = amount_type @description = description @end_date = end_date end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
254 255 256 |
# File 'lib/stripe/params/invoice_update_params.rb', line 254 def amount @amount end |
#amount_type ⇒ Object
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
256 257 258 |
# File 'lib/stripe/params/invoice_update_params.rb', line 256 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
258 259 260 |
# File 'lib/stripe/params/invoice_update_params.rb', line 258 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
260 261 262 |
# File 'lib/stripe/params/invoice_update_params.rb', line 260 def end_date @end_date end |