Class: Stripe::InvoiceUpdateParams::PaymentSettings::PaymentMethodOptions::Upi::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



242
243
244
245
246
247
# File 'lib/stripe/params/invoice_update_params.rb', line 242

def initialize(amount: nil, amount_type: nil, description: nil, end_date: nil)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



234
235
236
# File 'lib/stripe/params/invoice_update_params.rb', line 234

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



236
237
238
# File 'lib/stripe/params/invoice_update_params.rb', line 236

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



238
239
240
# File 'lib/stripe/params/invoice_update_params.rb', line 238

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



240
241
242
# File 'lib/stripe/params/invoice_update_params.rb', line 240

def end_date
  @end_date
end