Class: Stripe::InvoiceUpdateParams::Rendering
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateParams::Rendering
- Defined in:
- lib/stripe/params/invoice_update_params.rb
Defined Under Namespace
Classes: Pdf
Instance Attribute Summary collapse
-
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs.
-
#pdf ⇒ Object
Invoice pdf rendering options.
-
#template ⇒ Object
ID of the invoice rendering template to use for this invoice.
-
#template_version ⇒ Object
The specific version of invoice rendering template to use for this invoice.
Instance Method Summary collapse
-
#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering
constructor
A new instance of Rendering.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) ⇒ Rendering
Returns a new instance of Rendering.
405 406 407 408 409 410 |
# File 'lib/stripe/params/invoice_update_params.rb', line 405 def initialize(amount_tax_display: nil, pdf: nil, template: nil, template_version: nil) @amount_tax_display = amount_tax_display @pdf = pdf @template = template @template_version = template_version end |
Instance Attribute Details
#amount_tax_display ⇒ Object
How line-item prices and amounts will be displayed with respect to tax on invoice PDFs. One of ‘exclude_tax` or `include_inclusive_tax`. `include_inclusive_tax` will include inclusive tax (and exclude exclusive tax) in invoice PDF amounts. `exclude_tax` will exclude all tax (inclusive and exclusive alike) from invoice PDF amounts.
397 398 399 |
# File 'lib/stripe/params/invoice_update_params.rb', line 397 def amount_tax_display @amount_tax_display end |
#pdf ⇒ Object
Invoice pdf rendering options
399 400 401 |
# File 'lib/stripe/params/invoice_update_params.rb', line 399 def pdf @pdf end |
#template ⇒ Object
ID of the invoice rendering template to use for this invoice.
401 402 403 |
# File 'lib/stripe/params/invoice_update_params.rb', line 401 def template @template end |
#template_version ⇒ Object
The specific version of invoice rendering template to use for this invoice.
403 404 405 |
# File 'lib/stripe/params/invoice_update_params.rb', line 403 def template_version @template_version end |