Class: Stripe::InvoiceUpdateParams::ShippingCost::ShippingRateData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/invoice_update_params.rb

Defined Under Namespace

Classes: DeliveryEstimate, FixedAmount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData

Returns a new instance of ShippingRateData.



490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
# File 'lib/stripe/params/invoice_update_params.rb', line 490

def initialize(
  delivery_estimate: nil,
  display_name: nil,
  fixed_amount: nil,
  metadata: nil,
  tax_behavior: nil,
  tax_code: nil,
  type: nil
)
  @delivery_estimate = delivery_estimate
  @display_name = display_name
  @fixed_amount = fixed_amount
  @metadata = 
  @tax_behavior = tax_behavior
  @tax_code = tax_code
  @type = type
end

Instance Attribute Details

#delivery_estimateObject

The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.



476
477
478
# File 'lib/stripe/params/invoice_update_params.rb', line 476

def delivery_estimate
  @delivery_estimate
end

#display_nameObject

The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.



478
479
480
# File 'lib/stripe/params/invoice_update_params.rb', line 478

def display_name
  @display_name
end

#fixed_amountObject

Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.



480
481
482
# File 'lib/stripe/params/invoice_update_params.rb', line 480

def fixed_amount
  @fixed_amount
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



482
483
484
# File 'lib/stripe/params/invoice_update_params.rb', line 482

def 
  @metadata
end

#tax_behaviorObject

Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.



484
485
486
# File 'lib/stripe/params/invoice_update_params.rb', line 484

def tax_behavior
  @tax_behavior
end

#tax_codeObject

A [tax code](docs.stripe.com/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.



486
487
488
# File 'lib/stripe/params/invoice_update_params.rb', line 486

def tax_code
  @tax_code
end

#typeObject

The type of calculation to use on the shipping rate.



488
489
490
# File 'lib/stripe/params/invoice_update_params.rb', line 488

def type
  @type
end