Class: Stripe::InvoiceUpdateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::InvoiceUpdateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions
- Defined in:
- lib/stripe/params/invoice_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
Instance Method Summary collapse
-
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
451 452 453 454 |
# File 'lib/stripe/params/invoice_update_params.rb', line 451 def initialize(amount: nil, tax_behavior: nil) @amount = amount @tax_behavior = tax_behavior end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
447 448 449 |
# File 'lib/stripe/params/invoice_update_params.rb', line 447 def amount @amount end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
449 450 451 |
# File 'lib/stripe/params/invoice_update_params.rb', line 449 def tax_behavior @tax_behavior end |