Class: Stripe::Issuing::Authorization
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Authorization
- Extended by:
- Gem::Deprecate, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Overview
When an [issued card](docs.stripe.com/issuing) is used to make a purchase, an Issuing ‘Authorization` object is created. [Authorizations](docs.stripe.com/issuing/purchases/authorizations) must be approved for the purchase to be completed successfully.
Related guide: [Issued card authorizations](docs.stripe.com/issuing/purchases/authorizations)
Defined Under Namespace
Classes: AmountDetails, CryptoTransaction, Fleet, FraudChallenge, Fuel, MerchantData, NetworkData, PendingRequest, RequestHistory, TestHelpers, TokenDetails, Treasury, VerificationData
Constant Summary collapse
- OBJECT_NAME =
"issuing.authorization"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The total amount that was authorized or rejected.
-
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#approved ⇒ Object
readonly
Whether the authorization has been approved.
-
#authorization_method ⇒ Object
readonly
How the card details were provided.
-
#balance_transactions ⇒ Object
readonly
List of balance transactions associated with this authorization.
-
#card ⇒ Object
readonly
You can [create physical or virtual cards](docs.stripe.com/issuing) that are issued to cardholders.
-
#cardholder ⇒ Object
readonly
The cardholder to whom this authorization belongs.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#crypto_transactions ⇒ Object
readonly
Array of onchain crypto transactions linked to this resource.
-
#currency ⇒ Object
readonly
The currency of the cardholder.
-
#fleet ⇒ Object
readonly
Fleet-specific information for authorizations using Fleet cards.
-
#fraud_challenges ⇒ Object
readonly
Fraud challenges sent to the cardholder, if this authorization was declined for fraud risk reasons.
-
#fuel ⇒ Object
readonly
Information about fuel that was purchased with this transaction.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#merchant_amount ⇒ Object
readonly
The total amount that was authorized or rejected.
-
#merchant_currency ⇒ Object
readonly
The local currency that was presented to the cardholder for the authorization.
-
#merchant_data ⇒ Object
readonly
Attribute for field merchant_data.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#network_data ⇒ Object
readonly
Details about the authorization, such as identifiers, set by the card network.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#pending_request ⇒ Object
readonly
The pending authorization request.
-
#request_history ⇒ Object
readonly
History of every time a ‘pending_request` authorization was approved/declined, either by you directly or by Stripe (e.g. based on your spending_controls).
-
#status ⇒ Object
readonly
The current status of the authorization in its lifecycle.
-
#token ⇒ Object
readonly
[Token](docs.stripe.com/api/issuing/tokens/object) object used for this authorization.
-
#token_details ⇒ Object
readonly
Attribute for field token_details.
-
#transactions ⇒ Object
readonly
List of [transactions](docs.stripe.com/api/issuing/transactions) associated with this authorization.
-
#treasury ⇒ Object
readonly
[Treasury](docs.stripe.com/api/treasury) details related to this authorization if it was created on a [FinancialAccount](docs.stripe.com/api/treasury/financial_accounts).
-
#verification_data ⇒ Object
readonly
Attribute for field verification_data.
-
#verified_by_fraud_challenge ⇒ Object
readonly
Whether the authorization bypassed fraud risk checks because the cardholder has previously completed a fraud challenge on a similar high-risk authorization from the same merchant.
-
#wallet ⇒ Object
readonly
The digital wallet used for this transaction.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.approve(authorization, params = {}, opts = {}) ⇒ Object
- Deprecated
-
Approves a pending Issuing Authorization object.
-
.decline(authorization, params = {}, opts = {}) ⇒ Object
- Deprecated
-
Declines a pending Issuing Authorization object.
- .field_encodings ⇒ Object
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Authorization objects.
- .object_name ⇒ Object
-
.update(authorization, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Authorization object by setting the values of the parameters passed.
Instance Method Summary collapse
-
#approve(params = {}, opts = {}) ⇒ Object
- Deprecated
-
Approves a pending Issuing Authorization object.
-
#decline(params = {}, opts = {}) ⇒ Object
- Deprecated
-
Declines a pending Issuing Authorization object.
- #test_helpers ⇒ Object
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The total amount that was authorized or rejected. This amount is in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `amount` should be the same as `merchant_amount`, unless `currency` and `merchant_currency` are different.
673 674 675 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 673 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
675 676 677 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 675 def amount_details @amount_details end |
#approved ⇒ Object (readonly)
Whether the authorization has been approved.
677 678 679 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 677 def approved @approved end |
#authorization_method ⇒ Object (readonly)
How the card details were provided.
679 680 681 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 679 def @authorization_method end |
#balance_transactions ⇒ Object (readonly)
List of balance transactions associated with this authorization.
681 682 683 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 681 def balance_transactions @balance_transactions end |
#card ⇒ Object (readonly)
You can [create physical or virtual cards](docs.stripe.com/issuing) that are issued to cardholders.
683 684 685 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 683 def card @card end |
#cardholder ⇒ Object (readonly)
The cardholder to whom this authorization belongs.
685 686 687 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 685 def cardholder @cardholder end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
687 688 689 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 687 def created @created end |
#crypto_transactions ⇒ Object (readonly)
Array of onchain crypto transactions linked to this resource.
689 690 691 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 689 def crypto_transactions @crypto_transactions end |
#currency ⇒ Object (readonly)
The currency of the cardholder. This currency can be different from the currency presented at authorization and the ‘merchant_currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
691 692 693 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 691 def currency @currency end |
#fleet ⇒ Object (readonly)
Fleet-specific information for authorizations using Fleet cards.
693 694 695 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 693 def fleet @fleet end |
#fraud_challenges ⇒ Object (readonly)
Fraud challenges sent to the cardholder, if this authorization was declined for fraud risk reasons.
695 696 697 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 695 def fraud_challenges @fraud_challenges end |
#fuel ⇒ Object (readonly)
Information about fuel that was purchased with this transaction. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed.
697 698 699 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 697 def fuel @fuel end |
#id ⇒ Object (readonly)
Unique identifier for the object.
699 700 701 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 699 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
701 702 703 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 701 def livemode @livemode end |
#merchant_amount ⇒ Object (readonly)
The total amount that was authorized or rejected. This amount is in the ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `merchant_amount` should be the same as `amount`, unless `merchant_currency` and `currency` are different.
703 704 705 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 703 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The local currency that was presented to the cardholder for the authorization. This currency can be different from the cardholder currency and the ‘currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
705 706 707 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 705 def merchant_currency @merchant_currency end |
#merchant_data ⇒ Object (readonly)
Attribute for field merchant_data
707 708 709 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 707 def merchant_data @merchant_data end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
709 710 711 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 709 def @metadata end |
#network_data ⇒ Object (readonly)
Details about the authorization, such as identifiers, set by the card network.
711 712 713 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 711 def network_data @network_data end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
713 714 715 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 713 def object @object end |
#pending_request ⇒ Object (readonly)
The pending authorization request. This field will only be non-null during an ‘issuing_authorization.request` webhook.
715 716 717 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 715 def pending_request @pending_request end |
#request_history ⇒ Object (readonly)
History of every time a ‘pending_request` authorization was approved/declined, either by you directly or by Stripe (e.g. based on your spending_controls). If the merchant changes the authorization by performing an incremental authorization, you can look at this field to see the previous requests for the authorization. This field can be helpful in determining why a given authorization was approved/declined.
717 718 719 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 717 def request_history @request_history end |
#status ⇒ Object (readonly)
The current status of the authorization in its lifecycle.
719 720 721 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 719 def status @status end |
#token ⇒ Object (readonly)
[Token](docs.stripe.com/api/issuing/tokens/object) object used for this authorization. If a network token was not used for this authorization, this field will be null.
721 722 723 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 721 def token @token end |
#token_details ⇒ Object (readonly)
Attribute for field token_details
723 724 725 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 723 def token_details @token_details end |
#transactions ⇒ Object (readonly)
List of [transactions](docs.stripe.com/api/issuing/transactions) associated with this authorization.
725 726 727 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 725 def transactions @transactions end |
#treasury ⇒ Object (readonly)
[Treasury](docs.stripe.com/api/treasury) details related to this authorization if it was created on a [FinancialAccount](docs.stripe.com/api/treasury/financial_accounts).
727 728 729 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 727 def treasury @treasury end |
#verification_data ⇒ Object (readonly)
Attribute for field verification_data
729 730 731 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 729 def verification_data @verification_data end |
#verified_by_fraud_challenge ⇒ Object (readonly)
Whether the authorization bypassed fraud risk checks because the cardholder has previously completed a fraud challenge on a similar high-risk authorization from the same merchant.
731 732 733 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 731 def verified_by_fraud_challenge @verified_by_fraud_challenge end |
#wallet ⇒ Object (readonly)
The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.
733 734 735 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 733 def wallet @wallet end |
Class Method Details
.approve(authorization, params = {}, opts = {}) ⇒ Object
- Deprecated
-
Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.
This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).
749 750 751 752 753 754 755 756 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 749 def self.approve(, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape() }), params: params, opts: opts ) end |
.decline(authorization, params = {}, opts = {}) ⇒ Object
- Deprecated
-
Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.
This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).
777 778 779 780 781 782 783 784 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 777 def self.decline(, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape() }), params: params, opts: opts ) end |
.field_encodings ⇒ Object
973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 973 def self.field_encodings @field_encodings = { fleet: { kind: :object, fields: { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, }, }, fuel: { kind: :object, fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }, }, } end |
.field_remappings ⇒ Object
969 970 971 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 969 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 952 def self.inner_class_types @inner_class_types = { amount_details: AmountDetails, crypto_transactions: CryptoTransaction, fleet: Fleet, fraud_challenges: FraudChallenge, fuel: Fuel, merchant_data: MerchantData, network_data: NetworkData, pending_request: PendingRequest, request_history: RequestHistory, token_details: TokenDetails, treasury: Treasury, verification_data: VerificationData, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Authorization objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
792 793 794 795 796 797 798 799 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 792 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/authorizations", params: params, opts: opts ) end |
.object_name ⇒ Object
17 18 19 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 17 def self.object_name "issuing.authorization" end |
.update(authorization, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Authorization object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
802 803 804 805 806 807 808 809 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 802 def self.update(, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/authorizations/%<authorization>s", { authorization: CGI.escape() }), params: params, opts: opts ) end |
Instance Method Details
#approve(params = {}, opts = {}) ⇒ Object
- Deprecated
-
Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.
This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).
737 738 739 740 741 742 743 744 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 737 def approve(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#decline(params = {}, opts = {}) ⇒ Object
- Deprecated
-
Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.
This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).
765 766 767 768 769 770 771 772 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 765 def decline(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#test_helpers ⇒ Object
811 812 813 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 811 def test_helpers TestHelpers.new(self) end |