Class: Stripe::Issuing::Authorization

Inherits:
APIResource show all
Extended by:
Gem::Deprecate, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/authorization.rb

Overview

When an [issued card](docs.stripe.com/issuing) is used to make a purchase, an Issuing ‘Authorization` object is created. [Authorizations](docs.stripe.com/issuing/purchases/authorizations) must be approved for the purchase to be completed successfully.

Related guide: [Issued card authorizations](docs.stripe.com/issuing/purchases/authorizations)

Defined Under Namespace

Classes: AmountDetails, Fleet, FraudChallenge, Fuel, MerchantData, NetworkData, PendingRequest, RequestHistory, TestHelpers, TokenDetails, Treasury, VerificationData

Constant Summary collapse

OBJECT_NAME =
"issuing.authorization"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The total amount that was authorized or rejected. This amount is in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `amount` should be the same as `merchant_amount`, unless `currency` and `merchant_currency` are different.



554
555
556
# File 'lib/stripe/resources/issuing/authorization.rb', line 554

def amount
  @amount
end

#amount_detailsObject (readonly)

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).



556
557
558
# File 'lib/stripe/resources/issuing/authorization.rb', line 556

def amount_details
  @amount_details
end

#approvedObject (readonly)

Whether the authorization has been approved.



558
559
560
# File 'lib/stripe/resources/issuing/authorization.rb', line 558

def approved
  @approved
end

#authorization_methodObject (readonly)

How the card details were provided.



560
561
562
# File 'lib/stripe/resources/issuing/authorization.rb', line 560

def authorization_method
  @authorization_method
end

#balance_transactionsObject (readonly)

List of balance transactions associated with this authorization.



562
563
564
# File 'lib/stripe/resources/issuing/authorization.rb', line 562

def balance_transactions
  @balance_transactions
end

#cardObject (readonly)

You can [create physical or virtual cards](docs.stripe.com/issuing) that are issued to cardholders.



564
565
566
# File 'lib/stripe/resources/issuing/authorization.rb', line 564

def card
  @card
end

#cardholderObject (readonly)

The cardholder to whom this authorization belongs.



566
567
568
# File 'lib/stripe/resources/issuing/authorization.rb', line 566

def cardholder
  @cardholder
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



568
569
570
# File 'lib/stripe/resources/issuing/authorization.rb', line 568

def created
  @created
end

#currencyObject (readonly)

The currency of the cardholder. This currency can be different from the currency presented at authorization and the ‘merchant_currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



570
571
572
# File 'lib/stripe/resources/issuing/authorization.rb', line 570

def currency
  @currency
end

#fleetObject (readonly)

Fleet-specific information for authorizations using Fleet cards.



572
573
574
# File 'lib/stripe/resources/issuing/authorization.rb', line 572

def fleet
  @fleet
end

#fraud_challengesObject (readonly)

Fraud challenges sent to the cardholder, if this authorization was declined for fraud risk reasons.



574
575
576
# File 'lib/stripe/resources/issuing/authorization.rb', line 574

def fraud_challenges
  @fraud_challenges
end

#fuelObject (readonly)

Information about fuel that was purchased with this transaction. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed.



576
577
578
# File 'lib/stripe/resources/issuing/authorization.rb', line 576

def fuel
  @fuel
end

#idObject (readonly)

Unique identifier for the object.



578
579
580
# File 'lib/stripe/resources/issuing/authorization.rb', line 578

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



580
581
582
# File 'lib/stripe/resources/issuing/authorization.rb', line 580

def livemode
  @livemode
end

#merchant_amountObject (readonly)

The total amount that was authorized or rejected. This amount is in the ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `merchant_amount` should be the same as `amount`, unless `merchant_currency` and `currency` are different.



582
583
584
# File 'lib/stripe/resources/issuing/authorization.rb', line 582

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject (readonly)

The local currency that was presented to the cardholder for the authorization. This currency can be different from the cardholder currency and the ‘currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



584
585
586
# File 'lib/stripe/resources/issuing/authorization.rb', line 584

def merchant_currency
  @merchant_currency
end

#merchant_dataObject (readonly)

Attribute for field merchant_data



586
587
588
# File 'lib/stripe/resources/issuing/authorization.rb', line 586

def merchant_data
  @merchant_data
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



588
589
590
# File 'lib/stripe/resources/issuing/authorization.rb', line 588

def 
  @metadata
end

#network_dataObject (readonly)

Details about the authorization, such as identifiers, set by the card network.



590
591
592
# File 'lib/stripe/resources/issuing/authorization.rb', line 590

def network_data
  @network_data
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



592
593
594
# File 'lib/stripe/resources/issuing/authorization.rb', line 592

def object
  @object
end

#pending_requestObject (readonly)

The pending authorization request. This field will only be non-null during an ‘issuing_authorization.request` webhook.



594
595
596
# File 'lib/stripe/resources/issuing/authorization.rb', line 594

def pending_request
  @pending_request
end

#request_historyObject (readonly)

History of every time a ‘pending_request` authorization was approved/declined, either by you directly or by Stripe (e.g. based on your spending_controls). If the merchant changes the authorization by performing an incremental authorization, you can look at this field to see the previous requests for the authorization. This field can be helpful in determining why a given authorization was approved/declined.



596
597
598
# File 'lib/stripe/resources/issuing/authorization.rb', line 596

def request_history
  @request_history
end

#statusObject (readonly)

The current status of the authorization in its lifecycle.



598
599
600
# File 'lib/stripe/resources/issuing/authorization.rb', line 598

def status
  @status
end

#tokenObject (readonly)

[Token](docs.stripe.com/api/issuing/tokens/object) object used for this authorization. If a network token was not used for this authorization, this field will be null.



600
601
602
# File 'lib/stripe/resources/issuing/authorization.rb', line 600

def token
  @token
end

#token_detailsObject (readonly)

Attribute for field token_details



602
603
604
# File 'lib/stripe/resources/issuing/authorization.rb', line 602

def token_details
  @token_details
end

#transactionsObject (readonly)

List of [transactions](docs.stripe.com/api/issuing/transactions) associated with this authorization.



604
605
606
# File 'lib/stripe/resources/issuing/authorization.rb', line 604

def transactions
  @transactions
end

#treasuryObject (readonly)

[Treasury](docs.stripe.com/api/treasury) details related to this authorization if it was created on a [FinancialAccount](docs.stripe.com/api/treasury/financial_accounts).



606
607
608
# File 'lib/stripe/resources/issuing/authorization.rb', line 606

def treasury
  @treasury
end

#verification_dataObject (readonly)

Attribute for field verification_data



608
609
610
# File 'lib/stripe/resources/issuing/authorization.rb', line 608

def verification_data
  @verification_data
end

#verified_by_fraud_challengeObject (readonly)

Whether the authorization bypassed fraud risk checks because the cardholder has previously completed a fraud challenge on a similar high-risk authorization from the same merchant.



610
611
612
# File 'lib/stripe/resources/issuing/authorization.rb', line 610

def verified_by_fraud_challenge
  @verified_by_fraud_challenge
end

#walletObject (readonly)

The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.



612
613
614
# File 'lib/stripe/resources/issuing/authorization.rb', line 612

def wallet
  @wallet
end

Class Method Details

.approve(authorization, params = {}, opts = {}) ⇒ Object

Deprecated

Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



628
629
630
631
632
633
634
635
# File 'lib/stripe/resources/issuing/authorization.rb', line 628

def self.approve(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

.decline(authorization, params = {}, opts = {}) ⇒ Object

Deprecated

Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



656
657
658
659
660
661
662
663
# File 'lib/stripe/resources/issuing/authorization.rb', line 656

def self.decline(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

.field_encodingsObject



851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
# File 'lib/stripe/resources/issuing/authorization.rb', line 851

def self.field_encodings
  @field_encodings = {
    fleet: {
      kind: :object,
      fields: {
        reported_breakdown: {
          kind: :object,
          fields: {
            fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
            non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
            tax: {
              kind: :object,
              fields: {
                local_amount_decimal: :decimal_string,
                national_amount_decimal: :decimal_string,
              },
            },
          },
        },
      },
    },
    fuel: {
      kind: :object,
      fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string },
    },
  }
end

.field_remappingsObject



847
848
849
# File 'lib/stripe/resources/issuing/authorization.rb', line 847

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
# File 'lib/stripe/resources/issuing/authorization.rb', line 831

def self.inner_class_types
  @inner_class_types = {
    amount_details: AmountDetails,
    fleet: Fleet,
    fraud_challenges: FraudChallenge,
    fuel: Fuel,
    merchant_data: MerchantData,
    network_data: NetworkData,
    pending_request: PendingRequest,
    request_history: RequestHistory,
    token_details: TokenDetails,
    treasury: Treasury,
    verification_data: VerificationData,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Authorization objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



671
672
673
674
675
676
677
678
# File 'lib/stripe/resources/issuing/authorization.rb', line 671

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/authorizations",
    params: params,
    opts: opts
  )
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/issuing/authorization.rb', line 17

def self.object_name
  "issuing.authorization"
end

.update(authorization, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Authorization object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



681
682
683
684
685
686
687
688
# File 'lib/stripe/resources/issuing/authorization.rb', line 681

def self.update(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#approve(params = {}, opts = {}) ⇒ Object

Deprecated

Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



616
617
618
619
620
621
622
623
# File 'lib/stripe/resources/issuing/authorization.rb', line 616

def approve(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#decline(params = {}, opts = {}) ⇒ Object

Deprecated

Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



644
645
646
647
648
649
650
651
# File 'lib/stripe/resources/issuing/authorization.rb', line 644

def decline(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#test_helpersObject



690
691
692
# File 'lib/stripe/resources/issuing/authorization.rb', line 690

def test_helpers
  TestHelpers.new(self)
end