Class: Stripe::Issuing::Authorization

Inherits:
APIResource show all
Extended by:
Gem::Deprecate, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/authorization.rb

Overview

When an [issued card](docs.stripe.com/issuing) is used to make a purchase, an Issuing ‘Authorization` object is created. [Authorizations](docs.stripe.com/issuing/purchases/authorizations) must be approved for the purchase to be completed successfully.

Related guide: [Issued card authorizations](docs.stripe.com/issuing/purchases/authorizations)

Defined Under Namespace

Classes: AmountDetails, Fleet, FraudChallenge, Fuel, MerchantData, NetworkData, PendingRequest, RequestHistory, TestHelpers, TokenDetails, Treasury, VerificationData

Constant Summary collapse

OBJECT_NAME =
"issuing.authorization"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The total amount that was authorized or rejected. This amount is in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `amount` should be the same as `merchant_amount`, unless `currency` and `merchant_currency` are different.



502
503
504
# File 'lib/stripe/resources/issuing/authorization.rb', line 502

def amount
  @amount
end

#amount_detailsObject (readonly)

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).



504
505
506
# File 'lib/stripe/resources/issuing/authorization.rb', line 504

def amount_details
  @amount_details
end

#approvedObject (readonly)

Whether the authorization has been approved.



506
507
508
# File 'lib/stripe/resources/issuing/authorization.rb', line 506

def approved
  @approved
end

#authorization_methodObject (readonly)

How the card details were provided.



508
509
510
# File 'lib/stripe/resources/issuing/authorization.rb', line 508

def authorization_method
  @authorization_method
end

#balance_transactionsObject (readonly)

List of balance transactions associated with this authorization.



510
511
512
# File 'lib/stripe/resources/issuing/authorization.rb', line 510

def balance_transactions
  @balance_transactions
end

#cardObject (readonly)

You can [create physical or virtual cards](docs.stripe.com/issuing) that are issued to cardholders.



512
513
514
# File 'lib/stripe/resources/issuing/authorization.rb', line 512

def card
  @card
end

#cardholderObject (readonly)

The cardholder to whom this authorization belongs.



514
515
516
# File 'lib/stripe/resources/issuing/authorization.rb', line 514

def cardholder
  @cardholder
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



516
517
518
# File 'lib/stripe/resources/issuing/authorization.rb', line 516

def created
  @created
end

#currencyObject (readonly)

The currency of the cardholder. This currency can be different from the currency presented at authorization and the ‘merchant_currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



518
519
520
# File 'lib/stripe/resources/issuing/authorization.rb', line 518

def currency
  @currency
end

#fleetObject (readonly)

Fleet-specific information for authorizations using Fleet cards.



520
521
522
# File 'lib/stripe/resources/issuing/authorization.rb', line 520

def fleet
  @fleet
end

#fraud_challengesObject (readonly)

Fraud challenges sent to the cardholder, if this authorization was declined for fraud risk reasons.



522
523
524
# File 'lib/stripe/resources/issuing/authorization.rb', line 522

def fraud_challenges
  @fraud_challenges
end

#fuelObject (readonly)

Information about fuel that was purchased with this transaction. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed.



524
525
526
# File 'lib/stripe/resources/issuing/authorization.rb', line 524

def fuel
  @fuel
end

#idObject (readonly)

Unique identifier for the object.



526
527
528
# File 'lib/stripe/resources/issuing/authorization.rb', line 526

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



528
529
530
# File 'lib/stripe/resources/issuing/authorization.rb', line 528

def livemode
  @livemode
end

#merchant_amountObject (readonly)

The total amount that was authorized or rejected. This amount is in the ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `merchant_amount` should be the same as `amount`, unless `merchant_currency` and `currency` are different.



530
531
532
# File 'lib/stripe/resources/issuing/authorization.rb', line 530

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject (readonly)

The local currency that was presented to the cardholder for the authorization. This currency can be different from the cardholder currency and the ‘currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



532
533
534
# File 'lib/stripe/resources/issuing/authorization.rb', line 532

def merchant_currency
  @merchant_currency
end

#merchant_dataObject (readonly)

Attribute for field merchant_data



534
535
536
# File 'lib/stripe/resources/issuing/authorization.rb', line 534

def merchant_data
  @merchant_data
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



536
537
538
# File 'lib/stripe/resources/issuing/authorization.rb', line 536

def 
  @metadata
end

#network_dataObject (readonly)

Details about the authorization, such as identifiers, set by the card network.



538
539
540
# File 'lib/stripe/resources/issuing/authorization.rb', line 538

def network_data
  @network_data
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



540
541
542
# File 'lib/stripe/resources/issuing/authorization.rb', line 540

def object
  @object
end

#pending_requestObject (readonly)

The pending authorization request. This field will only be non-null during an ‘issuing_authorization.request` webhook.



542
543
544
# File 'lib/stripe/resources/issuing/authorization.rb', line 542

def pending_request
  @pending_request
end

#request_historyObject (readonly)

History of every time a ‘pending_request` authorization was approved/declined, either by you directly or by Stripe (e.g. based on your spending_controls). If the merchant changes the authorization by performing an incremental authorization, you can look at this field to see the previous requests for the authorization. This field can be helpful in determining why a given authorization was approved/declined.



544
545
546
# File 'lib/stripe/resources/issuing/authorization.rb', line 544

def request_history
  @request_history
end

#statusObject (readonly)

The current status of the authorization in its lifecycle.



546
547
548
# File 'lib/stripe/resources/issuing/authorization.rb', line 546

def status
  @status
end

#tokenObject (readonly)

[Token](docs.stripe.com/api/issuing/tokens/object) object used for this authorization. If a network token was not used for this authorization, this field will be null.



548
549
550
# File 'lib/stripe/resources/issuing/authorization.rb', line 548

def token
  @token
end

#token_detailsObject (readonly)

Attribute for field token_details



560
561
562
# File 'lib/stripe/resources/issuing/authorization.rb', line 560

def token_details
  @token_details
end

#transactionsObject (readonly)

List of [transactions](docs.stripe.com/api/issuing/transactions) associated with this authorization.



550
551
552
# File 'lib/stripe/resources/issuing/authorization.rb', line 550

def transactions
  @transactions
end

#treasuryObject (readonly)

[Treasury](docs.stripe.com/api/treasury) details related to this authorization if it was created on a [FinancialAccount](docs.stripe.com/api/treasury/financial_accounts).



552
553
554
# File 'lib/stripe/resources/issuing/authorization.rb', line 552

def treasury
  @treasury
end

#verification_dataObject (readonly)

Attribute for field verification_data



554
555
556
# File 'lib/stripe/resources/issuing/authorization.rb', line 554

def verification_data
  @verification_data
end

#verified_by_fraud_challengeObject (readonly)

Whether the authorization bypassed fraud risk checks because the cardholder has previously completed a fraud challenge on a similar high-risk authorization from the same merchant.



556
557
558
# File 'lib/stripe/resources/issuing/authorization.rb', line 556

def verified_by_fraud_challenge
  @verified_by_fraud_challenge
end

#walletObject (readonly)

The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.



558
559
560
# File 'lib/stripe/resources/issuing/authorization.rb', line 558

def wallet
  @wallet
end

Class Method Details

.approve(authorization, params = {}, opts = {}) ⇒ Object

Deprecated

Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



576
577
578
579
580
581
582
583
# File 'lib/stripe/resources/issuing/authorization.rb', line 576

def self.approve(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

.decline(authorization, params = {}, opts = {}) ⇒ Object

Deprecated

Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



604
605
606
607
608
609
610
611
# File 'lib/stripe/resources/issuing/authorization.rb', line 604

def self.decline(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



795
796
797
# File 'lib/stripe/resources/issuing/authorization.rb', line 795

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
# File 'lib/stripe/resources/issuing/authorization.rb', line 779

def self.inner_class_types
  @inner_class_types = {
    amount_details: AmountDetails,
    fleet: Fleet,
    fraud_challenges: FraudChallenge,
    fuel: Fuel,
    merchant_data: MerchantData,
    network_data: NetworkData,
    pending_request: PendingRequest,
    request_history: RequestHistory,
    treasury: Treasury,
    verification_data: VerificationData,
    token_details: TokenDetails,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Authorization objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



619
620
621
622
623
624
625
626
# File 'lib/stripe/resources/issuing/authorization.rb', line 619

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/authorizations",
    params: params,
    opts: opts
  )
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/issuing/authorization.rb', line 17

def self.object_name
  "issuing.authorization"
end

.update(authorization, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Authorization object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



629
630
631
632
633
634
635
636
# File 'lib/stripe/resources/issuing/authorization.rb', line 629

def self.update(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#approve(params = {}, opts = {}) ⇒ Object

Deprecated

Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



564
565
566
567
568
569
570
571
# File 'lib/stripe/resources/issuing/authorization.rb', line 564

def approve(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#decline(params = {}, opts = {}) ⇒ Object

Deprecated

Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](docs.stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



592
593
594
595
596
597
598
599
# File 'lib/stripe/resources/issuing/authorization.rb', line 592

def decline(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#test_helpersObject



638
639
640
# File 'lib/stripe/resources/issuing/authorization.rb', line 638

def test_helpers
  TestHelpers.new(self)
end