Class: Stripe::Issuing::Authorization

Inherits:
APIResource show all
Extended by:
Gem::Deprecate, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/authorization.rb

Overview

When an [issued card](stripe.com/docs/issuing) is used to make a purchase, an Issuing ‘Authorization` object is created. [Authorizations](stripe.com/docs/issuing/purchases/authorizations) must be approved for the purchase to be completed successfully.

Related guide: [Issued card authorizations](stripe.com/docs/issuing/purchases/authorizations)

Defined Under Namespace

Classes: AmountDetails, ApproveParams, CaptureParams, CreateParams, DeclineParams, ExpireParams, FinalizeAmountParams, Fleet, FraudChallenge, Fuel, IncrementParams, ListParams, MerchantData, NetworkData, PendingRequest, RequestHistory, RespondParams, RetrieveParams, ReverseParams, TestHelpers, Treasury, UpdateParams, VerificationData

Constant Summary collapse

OBJECT_NAME =
"issuing.authorization"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The total amount that was authorized or rejected. This amount is in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `amount` should be the same as `merchant_amount`, unless `currency` and `merchant_currency` are different.



1247
1248
1249
# File 'lib/stripe/resources/issuing/authorization.rb', line 1247

def amount
  @amount
end

#amount_detailsObject (readonly)

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



1250
1251
1252
# File 'lib/stripe/resources/issuing/authorization.rb', line 1250

def amount_details
  @amount_details
end

#approvedObject (readonly)

Whether the authorization has been approved.



1253
1254
1255
# File 'lib/stripe/resources/issuing/authorization.rb', line 1253

def approved
  @approved
end

#authorization_methodObject (readonly)

How the card details were provided.



1256
1257
1258
# File 'lib/stripe/resources/issuing/authorization.rb', line 1256

def authorization_method
  @authorization_method
end

#balance_transactionsObject (readonly)

List of balance transactions associated with this authorization.



1259
1260
1261
# File 'lib/stripe/resources/issuing/authorization.rb', line 1259

def balance_transactions
  @balance_transactions
end

#cardObject (readonly)

You can [create physical or virtual cards](stripe.com/docs/issuing) that are issued to cardholders.



1262
1263
1264
# File 'lib/stripe/resources/issuing/authorization.rb', line 1262

def card
  @card
end

#cardholderObject (readonly)

The cardholder to whom this authorization belongs.



1265
1266
1267
# File 'lib/stripe/resources/issuing/authorization.rb', line 1265

def cardholder
  @cardholder
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1268
1269
1270
# File 'lib/stripe/resources/issuing/authorization.rb', line 1268

def created
  @created
end

#currencyObject (readonly)

The currency of the cardholder. This currency can be different from the currency presented at authorization and the ‘merchant_currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1271
1272
1273
# File 'lib/stripe/resources/issuing/authorization.rb', line 1271

def currency
  @currency
end

#fleetObject (readonly)

Fleet-specific information for authorizations using Fleet cards.



1274
1275
1276
# File 'lib/stripe/resources/issuing/authorization.rb', line 1274

def fleet
  @fleet
end

#fraud_challengesObject (readonly)

Fraud challenges sent to the cardholder, if this authorization was declined for fraud risk reasons.



1277
1278
1279
# File 'lib/stripe/resources/issuing/authorization.rb', line 1277

def fraud_challenges
  @fraud_challenges
end

#fuelObject (readonly)

Information about fuel that was purchased with this transaction. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed.



1280
1281
1282
# File 'lib/stripe/resources/issuing/authorization.rb', line 1280

def fuel
  @fuel
end

#idObject (readonly)

Unique identifier for the object.



1283
1284
1285
# File 'lib/stripe/resources/issuing/authorization.rb', line 1283

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1286
1287
1288
# File 'lib/stripe/resources/issuing/authorization.rb', line 1286

def livemode
  @livemode
end

#merchant_amountObject (readonly)

The total amount that was authorized or rejected. This amount is in the ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `merchant_amount` should be the same as `amount`, unless `merchant_currency` and `currency` are different.



1289
1290
1291
# File 'lib/stripe/resources/issuing/authorization.rb', line 1289

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject (readonly)

The local currency that was presented to the cardholder for the authorization. This currency can be different from the cardholder currency and the ‘currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1292
1293
1294
# File 'lib/stripe/resources/issuing/authorization.rb', line 1292

def merchant_currency
  @merchant_currency
end

#merchant_dataObject (readonly)

Attribute for field merchant_data



1295
1296
1297
# File 'lib/stripe/resources/issuing/authorization.rb', line 1295

def merchant_data
  @merchant_data
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1298
1299
1300
# File 'lib/stripe/resources/issuing/authorization.rb', line 1298

def 
  @metadata
end

#network_dataObject (readonly)

Details about the authorization, such as identifiers, set by the card network.



1301
1302
1303
# File 'lib/stripe/resources/issuing/authorization.rb', line 1301

def network_data
  @network_data
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1304
1305
1306
# File 'lib/stripe/resources/issuing/authorization.rb', line 1304

def object
  @object
end

#pending_requestObject (readonly)

The pending authorization request. This field will only be non-null during an ‘issuing_authorization.request` webhook.



1307
1308
1309
# File 'lib/stripe/resources/issuing/authorization.rb', line 1307

def pending_request
  @pending_request
end

#request_historyObject (readonly)

History of every time a ‘pending_request` authorization was approved/declined, either by you directly or by Stripe (e.g. based on your spending_controls). If the merchant changes the authorization by performing an incremental authorization, you can look at this field to see the previous requests for the authorization. This field can be helpful in determining why a given authorization was approved/declined.



1310
1311
1312
# File 'lib/stripe/resources/issuing/authorization.rb', line 1310

def request_history
  @request_history
end

#statusObject (readonly)

The current status of the authorization in its lifecycle.



1313
1314
1315
# File 'lib/stripe/resources/issuing/authorization.rb', line 1313

def status
  @status
end

#tokenObject (readonly)

[Token](stripe.com/docs/api/issuing/tokens/object) object used for this authorization. If a network token was not used for this authorization, this field will be null.



1316
1317
1318
# File 'lib/stripe/resources/issuing/authorization.rb', line 1316

def token
  @token
end

#transactionsObject (readonly)

List of [transactions](stripe.com/docs/api/issuing/transactions) associated with this authorization.



1319
1320
1321
# File 'lib/stripe/resources/issuing/authorization.rb', line 1319

def transactions
  @transactions
end

#treasuryObject (readonly)

[Treasury](stripe.com/docs/api/treasury) details related to this authorization if it was created on a [FinancialAccount](stripe.com/docs/api/treasury/financial_accounts).



1322
1323
1324
# File 'lib/stripe/resources/issuing/authorization.rb', line 1322

def treasury
  @treasury
end

#verification_dataObject (readonly)

Attribute for field verification_data



1325
1326
1327
# File 'lib/stripe/resources/issuing/authorization.rb', line 1325

def verification_data
  @verification_data
end

#verified_by_fraud_challengeObject (readonly)

Whether the authorization bypassed fraud risk checks because the cardholder has previously completed a fraud challenge on a similar high-risk authorization from the same merchant.



1328
1329
1330
# File 'lib/stripe/resources/issuing/authorization.rb', line 1328

def verified_by_fraud_challenge
  @verified_by_fraud_challenge
end

#walletObject (readonly)

The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.



1331
1332
1333
# File 'lib/stripe/resources/issuing/authorization.rb', line 1331

def wallet
  @wallet
end

Class Method Details

.approve(authorization, params = {}, opts = {}) ⇒ Object

Deprecated

Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



1347
1348
1349
1350
1351
1352
1353
1354
# File 'lib/stripe/resources/issuing/authorization.rb', line 1347

def self.approve(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

.decline(authorization, params = {}, opts = {}) ⇒ Object

Deprecated

Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



1375
1376
1377
1378
1379
1380
1381
1382
# File 'lib/stripe/resources/issuing/authorization.rb', line 1375

def self.decline(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Authorization objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



1390
1391
1392
1393
1394
1395
1396
1397
# File 'lib/stripe/resources/issuing/authorization.rb', line 1390

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/authorizations",
    params: params,
    opts: opts
  )
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/issuing/authorization.rb', line 17

def self.object_name
  "issuing.authorization"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Authorization object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



1400
1401
1402
1403
1404
1405
1406
1407
# File 'lib/stripe/resources/issuing/authorization.rb', line 1400

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#approve(params = {}, opts = {}) ⇒ Object

Deprecated

Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



1335
1336
1337
1338
1339
1340
1341
1342
# File 'lib/stripe/resources/issuing/authorization.rb', line 1335

def approve(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#decline(params = {}, opts = {}) ⇒ Object

Deprecated

Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



1363
1364
1365
1366
1367
1368
1369
1370
# File 'lib/stripe/resources/issuing/authorization.rb', line 1363

def decline(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#test_helpersObject



1409
1410
1411
# File 'lib/stripe/resources/issuing/authorization.rb', line 1409

def test_helpers
  TestHelpers.new(self)
end