Class: Stripe::Issuing::Authorization

Inherits:
APIResource show all
Extended by:
Gem::Deprecate, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/authorization.rb

Overview

When an [issued card](stripe.com/docs/issuing) is used to make a purchase, an Issuing ‘Authorization` object is created. [Authorizations](stripe.com/docs/issuing/purchases/authorizations) must be approved for the purchase to be completed successfully.

Related guide: [Issued card authorizations](stripe.com/docs/issuing/purchases/authorizations)

Defined Under Namespace

Classes: AmountDetails, Fleet, FraudChallenge, Fuel, MerchantData, NetworkData, PendingRequest, RequestHistory, TestHelpers, Treasury, VerificationData

Constant Summary collapse

OBJECT_NAME =
"issuing.authorization"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The total amount that was authorized or rejected. This amount is in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `amount` should be the same as `merchant_amount`, unless `currency` and `merchant_currency` are different.



92
93
94
# File 'lib/stripe/resources/issuing/authorization.rb', line 92

def amount
  @amount
end

#amount_detailsObject (readonly)

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



94
95
96
# File 'lib/stripe/resources/issuing/authorization.rb', line 94

def amount_details
  @amount_details
end

#approvedObject (readonly)

Whether the authorization has been approved.



96
97
98
# File 'lib/stripe/resources/issuing/authorization.rb', line 96

def approved
  @approved
end

#authorization_methodObject (readonly)

How the card details were provided.



98
99
100
# File 'lib/stripe/resources/issuing/authorization.rb', line 98

def authorization_method
  @authorization_method
end

#balance_transactionsObject (readonly)

List of balance transactions associated with this authorization.



100
101
102
# File 'lib/stripe/resources/issuing/authorization.rb', line 100

def balance_transactions
  @balance_transactions
end

#cardObject (readonly)

You can [create physical or virtual cards](stripe.com/docs/issuing) that are issued to cardholders.



102
103
104
# File 'lib/stripe/resources/issuing/authorization.rb', line 102

def card
  @card
end

#cardholderObject (readonly)

The cardholder to whom this authorization belongs.



104
105
106
# File 'lib/stripe/resources/issuing/authorization.rb', line 104

def cardholder
  @cardholder
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



106
107
108
# File 'lib/stripe/resources/issuing/authorization.rb', line 106

def created
  @created
end

#currencyObject (readonly)

The currency of the cardholder. This currency can be different from the currency presented at authorization and the ‘merchant_currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



108
109
110
# File 'lib/stripe/resources/issuing/authorization.rb', line 108

def currency
  @currency
end

#fleetObject (readonly)

Fleet-specific information for authorizations using Fleet cards.



110
111
112
# File 'lib/stripe/resources/issuing/authorization.rb', line 110

def fleet
  @fleet
end

#fraud_challengesObject (readonly)

Fraud challenges sent to the cardholder, if this authorization was declined for fraud risk reasons.



112
113
114
# File 'lib/stripe/resources/issuing/authorization.rb', line 112

def fraud_challenges
  @fraud_challenges
end

#fuelObject (readonly)

Information about fuel that was purchased with this transaction. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed.



114
115
116
# File 'lib/stripe/resources/issuing/authorization.rb', line 114

def fuel
  @fuel
end

#idObject (readonly)

Unique identifier for the object.



116
117
118
# File 'lib/stripe/resources/issuing/authorization.rb', line 116

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



118
119
120
# File 'lib/stripe/resources/issuing/authorization.rb', line 118

def livemode
  @livemode
end

#merchant_amountObject (readonly)

The total amount that was authorized or rejected. This amount is in the ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). `merchant_amount` should be the same as `amount`, unless `merchant_currency` and `currency` are different.



120
121
122
# File 'lib/stripe/resources/issuing/authorization.rb', line 120

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject (readonly)

The local currency that was presented to the cardholder for the authorization. This currency can be different from the cardholder currency and the ‘currency` field on this authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



122
123
124
# File 'lib/stripe/resources/issuing/authorization.rb', line 122

def merchant_currency
  @merchant_currency
end

#merchant_dataObject (readonly)

Attribute for field merchant_data



124
125
126
# File 'lib/stripe/resources/issuing/authorization.rb', line 124

def merchant_data
  @merchant_data
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



126
127
128
# File 'lib/stripe/resources/issuing/authorization.rb', line 126

def 
  @metadata
end

#network_dataObject (readonly)

Details about the authorization, such as identifiers, set by the card network.



128
129
130
# File 'lib/stripe/resources/issuing/authorization.rb', line 128

def network_data
  @network_data
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



130
131
132
# File 'lib/stripe/resources/issuing/authorization.rb', line 130

def object
  @object
end

#pending_requestObject (readonly)

The pending authorization request. This field will only be non-null during an ‘issuing_authorization.request` webhook.



132
133
134
# File 'lib/stripe/resources/issuing/authorization.rb', line 132

def pending_request
  @pending_request
end

#request_historyObject (readonly)

History of every time a ‘pending_request` authorization was approved/declined, either by you directly or by Stripe (e.g. based on your spending_controls). If the merchant changes the authorization by performing an incremental authorization, you can look at this field to see the previous requests for the authorization. This field can be helpful in determining why a given authorization was approved/declined.



134
135
136
# File 'lib/stripe/resources/issuing/authorization.rb', line 134

def request_history
  @request_history
end

#statusObject (readonly)

The current status of the authorization in its lifecycle.



136
137
138
# File 'lib/stripe/resources/issuing/authorization.rb', line 136

def status
  @status
end

#tokenObject (readonly)

[Token](stripe.com/docs/api/issuing/tokens/object) object used for this authorization. If a network token was not used for this authorization, this field will be null.



138
139
140
# File 'lib/stripe/resources/issuing/authorization.rb', line 138

def token
  @token
end

#transactionsObject (readonly)

List of [transactions](stripe.com/docs/api/issuing/transactions) associated with this authorization.



140
141
142
# File 'lib/stripe/resources/issuing/authorization.rb', line 140

def transactions
  @transactions
end

#treasuryObject (readonly)

[Treasury](stripe.com/docs/api/treasury) details related to this authorization if it was created on a [FinancialAccount](stripe.com/docs/api/treasury/financial_accounts).



142
143
144
# File 'lib/stripe/resources/issuing/authorization.rb', line 142

def treasury
  @treasury
end

#verification_dataObject (readonly)

Attribute for field verification_data



144
145
146
# File 'lib/stripe/resources/issuing/authorization.rb', line 144

def verification_data
  @verification_data
end

#verified_by_fraud_challengeObject (readonly)

Whether the authorization bypassed fraud risk checks because the cardholder has previously completed a fraud challenge on a similar high-risk authorization from the same merchant.



146
147
148
# File 'lib/stripe/resources/issuing/authorization.rb', line 146

def verified_by_fraud_challenge
  @verified_by_fraud_challenge
end

#walletObject (readonly)

The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.



148
149
150
# File 'lib/stripe/resources/issuing/authorization.rb', line 148

def wallet
  @wallet
end

Class Method Details

.approve(authorization, params = {}, opts = {}) ⇒ Object

Deprecated

Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



164
165
166
167
168
169
170
171
# File 'lib/stripe/resources/issuing/authorization.rb', line 164

def self.approve(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

.decline(authorization, params = {}, opts = {}) ⇒ Object

Deprecated

Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



191
192
193
194
195
196
197
198
# File 'lib/stripe/resources/issuing/authorization.rb', line 191

def self.decline(authorization, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(authorization) }),
    params: params,
    opts: opts
  )
end

.list(filters = {}, opts = {}) ⇒ Object

Returns a list of Issuing Authorization objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



205
206
207
208
209
210
211
212
# File 'lib/stripe/resources/issuing/authorization.rb', line 205

def self.list(filters = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/authorizations",
    params: filters,
    opts: opts
  )
end

.object_nameObject



17
18
19
# File 'lib/stripe/resources/issuing/authorization.rb', line 17

def self.object_name
  "issuing.authorization"
end

.update(id, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Authorization object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



215
216
217
218
219
220
221
222
# File 'lib/stripe/resources/issuing/authorization.rb', line 215

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#approve(params = {}, opts = {}) ⇒ Object

Deprecated

Approves a pending Issuing Authorization object. This request should be made within the timeout window of the [real-time authorization](stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to approve an authorization](stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



152
153
154
155
156
157
158
159
# File 'lib/stripe/resources/issuing/authorization.rb', line 152

def approve(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/approve", { authorization: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#decline(params = {}, opts = {}) ⇒ Object

Deprecated

Declines a pending Issuing Authorization object. This request should be made within the timeout window of the [real time authorization](stripe.com/docs/issuing/controls/real-time-authorizations) flow.

This method is deprecated. Instead, [respond directly to the webhook request to decline an authorization](stripe.com/docs/issuing/controls/real-time-authorizations#authorization-handling).



179
180
181
182
183
184
185
186
# File 'lib/stripe/resources/issuing/authorization.rb', line 179

def decline(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/authorizations/%<authorization>s/decline", { authorization: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#test_helpersObject



224
225
226
# File 'lib/stripe/resources/issuing/authorization.rb', line 224

def test_helpers
  TestHelpers.new(self)
end