Class: Stripe::Issuing::Authorization::CaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CaptureParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: PurchaseDetails
Instance Attribute Summary collapse
-
#capture_amount ⇒ Object
The amount to capture from the authorization.
-
#close_authorization ⇒ Object
Whether to close the authorization after capture.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
Instance Method Summary collapse
-
#initialize(capture_amount: nil, close_authorization: nil, expand: nil, purchase_details: nil) ⇒ CaptureParams
constructor
A new instance of CaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_amount: nil, close_authorization: nil, expand: nil, purchase_details: nil) ⇒ CaptureParams
Returns a new instance of CaptureParams.
878 879 880 881 882 883 884 885 886 887 888 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 878 def initialize( capture_amount: nil, close_authorization: nil, expand: nil, purchase_details: nil ) @capture_amount = capture_amount @close_authorization = @expand = @purchase_details = purchase_details end |
Instance Attribute Details
#capture_amount ⇒ Object
The amount to capture from the authorization. If not provided, the full amount of the authorization will be captured. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
870 871 872 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 870 def capture_amount @capture_amount end |
#close_authorization ⇒ Object
Whether to close the authorization after capture. Defaults to true. Set to false to enable multi-capture flows.
872 873 874 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 872 def @close_authorization end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
874 875 876 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 874 def @expand end |
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
876 877 878 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 876 def purchase_details @purchase_details end |