Class: Stripe::Issuing::Authorization::CaptureParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: PurchaseDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_amount: nil, close_authorization: nil, expand: nil, purchase_details: nil) ⇒ CaptureParams

Returns a new instance of CaptureParams.



1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
# File 'lib/stripe/resources/issuing/authorization.rb', line 1028

def initialize(
  capture_amount: nil,
  close_authorization: nil,
  expand: nil,
  purchase_details: nil
)
  @capture_amount = capture_amount
  @close_authorization = close_authorization
  @expand = expand
  @purchase_details = purchase_details
end

Instance Attribute Details

#capture_amountObject

The amount to capture from the authorization. If not provided, the full amount of the authorization will be captured. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



1017
1018
1019
# File 'lib/stripe/resources/issuing/authorization.rb', line 1017

def capture_amount
  @capture_amount
end

#close_authorizationObject

Whether to close the authorization after capture. Defaults to true. Set to false to enable multi-capture flows.



1020
1021
1022
# File 'lib/stripe/resources/issuing/authorization.rb', line 1020

def close_authorization
  @close_authorization
end

#expandObject

Specifies which fields in the response should be expanded.



1023
1024
1025
# File 'lib/stripe/resources/issuing/authorization.rb', line 1023

def expand
  @expand
end

#purchase_detailsObject

Additional purchase information that is optionally provided by the merchant.



1026
1027
1028
# File 'lib/stripe/resources/issuing/authorization.rb', line 1026

def purchase_details
  @purchase_details
end