Class: Stripe::Issuing::Authorization::CaptureParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CaptureParams::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1000 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
983 984 985 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 983 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
986 987 988 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 986 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
989 990 991 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 989 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
992 993 994 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 992 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
995 996 997 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 995 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
998 999 1000 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 998 def reference @reference end |