Class: Stripe::Issuing::Authorization::CaptureParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CaptureParams::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 853 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
841 842 843 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 841 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
843 844 845 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 843 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
845 846 847 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 845 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
847 848 849 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 847 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
849 850 851 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 849 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
851 852 853 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 851 def reference @reference end |