Class: Stripe::Issuing::Authorization::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CreateParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AmountDetails, Fleet, Fuel, MerchantData, NetworkData, VerificationData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The total amount to attempt to authorize.
-
#amount_details ⇒ Object
Detailed breakdown of amount components.
-
#authorization_method ⇒ Object
How the card details were provided.
-
#card ⇒ Object
Card associated with this authorization.
-
#currency ⇒ Object
The currency of the authorization.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#is_amount_controllable ⇒ Object
If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
-
#merchant_amount ⇒ Object
The total amount to attempt to authorize.
-
#merchant_currency ⇒ Object
The currency of the authorization.
-
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
-
#network_data ⇒ Object
Details about the authorization, such as identifiers, set by the card network.
-
#verification_data ⇒ Object
Verifications that Stripe performed on information that the cardholder provided to the merchant.
-
#wallet ⇒ Object
The digital wallet used for this transaction.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 746 def initialize( amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil ) @amount = amount @amount_details = amount_details @authorization_method = @card = card @currency = currency @expand = @fleet = fleet @fuel = fuel @is_amount_controllable = is_amount_controllable @merchant_amount = merchant_amount @merchant_currency = merchant_currency @merchant_data = merchant_data @network_data = network_data @verification_data = verification_data @wallet = wallet end |
Instance Attribute Details
#amount ⇒ Object
The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card’s currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
716 717 718 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 716 def amount @amount end |
#amount_details ⇒ Object
Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
718 719 720 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 718 def amount_details @amount_details end |
#authorization_method ⇒ Object
How the card details were provided. Defaults to online.
720 721 722 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 720 def @authorization_method end |
#card ⇒ Object
Card associated with this authorization.
722 723 724 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 722 def card @card end |
#currency ⇒ Object
The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
724 725 726 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 724 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
726 727 728 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 726 def @expand end |
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
728 729 730 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 728 def fleet @fleet end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
730 731 732 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 730 def fuel @fuel end |
#is_amount_controllable ⇒ Object
If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
732 733 734 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 732 def is_amount_controllable @is_amount_controllable end |
#merchant_amount ⇒ Object
The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
734 735 736 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 734 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object
The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
736 737 738 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 736 def merchant_currency @merchant_currency end |
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
738 739 740 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 738 def merchant_data @merchant_data end |
#network_data ⇒ Object
Details about the authorization, such as identifiers, set by the card network.
740 741 742 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 740 def network_data @network_data end |
#verification_data ⇒ Object
Verifications that Stripe performed on information that the cardholder provided to the merchant.
742 743 744 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 742 def verification_data @verification_data end |
#wallet ⇒ Object
The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.
744 745 746 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 744 def wallet @wallet end |