Class: Stripe::Issuing::Authorization::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AmountDetails, Fleet, Fuel, MerchantData, NetworkData, VerificationData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/stripe/resources/issuing/authorization.rb', line 588

def initialize(
  amount: nil,
  amount_details: nil,
  authorization_method: nil,
  card: nil,
  currency: nil,
  expand: nil,
  fleet: nil,
  fuel: nil,
  is_amount_controllable: nil,
  merchant_amount: nil,
  merchant_currency: nil,
  merchant_data: nil,
  network_data: nil,
  verification_data: nil,
  wallet: nil
)
  @amount = amount
  @amount_details = amount_details
  @authorization_method = authorization_method
  @card = card
  @currency = currency
  @expand = expand
  @fleet = fleet
  @fuel = fuel
  @is_amount_controllable = is_amount_controllable
  @merchant_amount = merchant_amount
  @merchant_currency = merchant_currency
  @merchant_data = merchant_data
  @network_data = network_data
  @verification_data = verification_data
  @wallet = wallet
end

Instance Attribute Details

#amountObject

The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card’s currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



558
559
560
# File 'lib/stripe/resources/issuing/authorization.rb', line 558

def amount
  @amount
end

#amount_detailsObject

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



560
561
562
# File 'lib/stripe/resources/issuing/authorization.rb', line 560

def amount_details
  @amount_details
end

#authorization_methodObject

How the card details were provided. Defaults to online.



562
563
564
# File 'lib/stripe/resources/issuing/authorization.rb', line 562

def authorization_method
  @authorization_method
end

#cardObject

Card associated with this authorization.



564
565
566
# File 'lib/stripe/resources/issuing/authorization.rb', line 564

def card
  @card
end

#currencyObject

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



566
567
568
# File 'lib/stripe/resources/issuing/authorization.rb', line 566

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



568
569
570
# File 'lib/stripe/resources/issuing/authorization.rb', line 568

def expand
  @expand
end

#fleetObject

Fleet-specific information for authorizations using Fleet cards.



570
571
572
# File 'lib/stripe/resources/issuing/authorization.rb', line 570

def fleet
  @fleet
end

#fuelObject

Information about fuel that was purchased with this transaction.



572
573
574
# File 'lib/stripe/resources/issuing/authorization.rb', line 572

def fuel
  @fuel
end

#is_amount_controllableObject

If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.



574
575
576
# File 'lib/stripe/resources/issuing/authorization.rb', line 574

def is_amount_controllable
  @is_amount_controllable
end

#merchant_amountObject

The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



576
577
578
# File 'lib/stripe/resources/issuing/authorization.rb', line 576

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



578
579
580
# File 'lib/stripe/resources/issuing/authorization.rb', line 578

def merchant_currency
  @merchant_currency
end

#merchant_dataObject

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.



580
581
582
# File 'lib/stripe/resources/issuing/authorization.rb', line 580

def merchant_data
  @merchant_data
end

#network_dataObject

Details about the authorization, such as identifiers, set by the card network.



582
583
584
# File 'lib/stripe/resources/issuing/authorization.rb', line 582

def network_data
  @network_data
end

#verification_dataObject

Verifications that Stripe performed on information that the cardholder provided to the merchant.



584
585
586
# File 'lib/stripe/resources/issuing/authorization.rb', line 584

def verification_data
  @verification_data
end

#walletObject

The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.



586
587
588
# File 'lib/stripe/resources/issuing/authorization.rb', line 586

def wallet
  @wallet
end