Class: Stripe::Issuing::Authorization::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CreateParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AmountDetails, Fleet, Fuel, MerchantData, NetworkData, VerificationData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The total amount to attempt to authorize.
-
#amount_details ⇒ Object
Detailed breakdown of amount components.
-
#authorization_method ⇒ Object
How the card details were provided.
-
#card ⇒ Object
Card associated with this authorization.
-
#currency ⇒ Object
The currency of the authorization.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#is_amount_controllable ⇒ Object
If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
-
#merchant_amount ⇒ Object
The total amount to attempt to authorize.
-
#merchant_currency ⇒ Object
The currency of the authorization.
-
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
-
#network_data ⇒ Object
Details about the authorization, such as identifiers, set by the card network.
-
#verification_data ⇒ Object
Verifications that Stripe performed on information that the cardholder provided to the merchant.
-
#wallet ⇒ Object
The digital wallet used for this transaction.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 597 def initialize( amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil ) @amount = amount @amount_details = amount_details @authorization_method = @card = card @currency = currency @expand = @fleet = fleet @fuel = fuel @is_amount_controllable = is_amount_controllable @merchant_amount = merchant_amount @merchant_currency = merchant_currency @merchant_data = merchant_data @network_data = network_data @verification_data = verification_data @wallet = wallet end |
Instance Attribute Details
#amount ⇒ Object
The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card’s currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
567 568 569 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 567 def amount @amount end |
#amount_details ⇒ Object
Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
569 570 571 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 569 def amount_details @amount_details end |
#authorization_method ⇒ Object
How the card details were provided. Defaults to online.
571 572 573 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 571 def @authorization_method end |
#card ⇒ Object
Card associated with this authorization.
573 574 575 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 573 def card @card end |
#currency ⇒ Object
The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
575 576 577 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 575 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
577 578 579 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 577 def @expand end |
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
579 580 581 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 579 def fleet @fleet end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
581 582 583 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 581 def fuel @fuel end |
#is_amount_controllable ⇒ Object
If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
583 584 585 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 583 def is_amount_controllable @is_amount_controllable end |
#merchant_amount ⇒ Object
The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
585 586 587 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 585 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object
The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
587 588 589 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 587 def merchant_currency @merchant_currency end |
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
589 590 591 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 589 def merchant_data @merchant_data end |
#network_data ⇒ Object
Details about the authorization, such as identifiers, set by the card network.
591 592 593 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 591 def network_data @network_data end |
#verification_data ⇒ Object
Verifications that Stripe performed on information that the cardholder provided to the merchant.
593 594 595 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 593 def verification_data @verification_data end |
#wallet ⇒ Object
The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.
595 596 597 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 595 def wallet @wallet end |