Class: Stripe::Issuing::Authorization::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AmountDetails, Fleet, Fuel, MerchantData, NetworkData, VerificationData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fuel: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, verification_data: nil, wallet: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
# File 'lib/stripe/resources/issuing/authorization.rb', line 712

def initialize(
  amount: nil,
  amount_details: nil,
  authorization_method: nil,
  card: nil,
  currency: nil,
  expand: nil,
  fleet: nil,
  fuel: nil,
  is_amount_controllable: nil,
  merchant_amount: nil,
  merchant_currency: nil,
  merchant_data: nil,
  network_data: nil,
  verification_data: nil,
  wallet: nil
)
  @amount = amount
  @amount_details = amount_details
  @authorization_method = authorization_method
  @card = card
  @currency = currency
  @expand = expand
  @fleet = fleet
  @fuel = fuel
  @is_amount_controllable = is_amount_controllable
  @merchant_amount = merchant_amount
  @merchant_currency = merchant_currency
  @merchant_data = merchant_data
  @network_data = network_data
  @verification_data = verification_data
  @wallet = wallet
end

Instance Attribute Details

#amountObject

The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card’s currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



668
669
670
# File 'lib/stripe/resources/issuing/authorization.rb', line 668

def amount
  @amount
end

#amount_detailsObject

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



671
672
673
# File 'lib/stripe/resources/issuing/authorization.rb', line 671

def amount_details
  @amount_details
end

#authorization_methodObject

How the card details were provided. Defaults to online.



674
675
676
# File 'lib/stripe/resources/issuing/authorization.rb', line 674

def authorization_method
  @authorization_method
end

#cardObject

Card associated with this authorization.



677
678
679
# File 'lib/stripe/resources/issuing/authorization.rb', line 677

def card
  @card
end

#currencyObject

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



680
681
682
# File 'lib/stripe/resources/issuing/authorization.rb', line 680

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



683
684
685
# File 'lib/stripe/resources/issuing/authorization.rb', line 683

def expand
  @expand
end

#fleetObject

Fleet-specific information for authorizations using Fleet cards.



686
687
688
# File 'lib/stripe/resources/issuing/authorization.rb', line 686

def fleet
  @fleet
end

#fuelObject

Information about fuel that was purchased with this transaction.



689
690
691
# File 'lib/stripe/resources/issuing/authorization.rb', line 689

def fuel
  @fuel
end

#is_amount_controllableObject

If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.



692
693
694
# File 'lib/stripe/resources/issuing/authorization.rb', line 692

def is_amount_controllable
  @is_amount_controllable
end

#merchant_amountObject

The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



695
696
697
# File 'lib/stripe/resources/issuing/authorization.rb', line 695

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject

The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



698
699
700
# File 'lib/stripe/resources/issuing/authorization.rb', line 698

def merchant_currency
  @merchant_currency
end

#merchant_dataObject

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.



701
702
703
# File 'lib/stripe/resources/issuing/authorization.rb', line 701

def merchant_data
  @merchant_data
end

#network_dataObject

Details about the authorization, such as identifiers, set by the card network.



704
705
706
# File 'lib/stripe/resources/issuing/authorization.rb', line 704

def network_data
  @network_data
end

#verification_dataObject

Verifications that Stripe performed on information that the cardholder provided to the merchant.



707
708
709
# File 'lib/stripe/resources/issuing/authorization.rb', line 707

def verification_data
  @verification_data
end

#walletObject

The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`. Will populate as `null` when no digital wallet was utilized.



710
711
712
# File 'lib/stripe/resources/issuing/authorization.rb', line 710

def wallet
  @wallet
end