Class: Stripe::Issuing::Authorization::CreateParams::Fleet

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet

Returns a new instance of Fleet.



507
508
509
510
511
512
513
514
515
516
517
# File 'lib/stripe/resources/issuing/authorization.rb', line 507

def initialize(
  cardholder_prompt_data: nil,
  purchase_type: nil,
  reported_breakdown: nil,
  service_type: nil
)
  @cardholder_prompt_data = cardholder_prompt_data
  @purchase_type = purchase_type
  @reported_breakdown = reported_breakdown
  @service_type = service_type
end

Instance Attribute Details

#cardholder_prompt_dataObject

Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.



496
497
498
# File 'lib/stripe/resources/issuing/authorization.rb', line 496

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject

The type of purchase. One of ‘fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.



499
500
501
# File 'lib/stripe/resources/issuing/authorization.rb', line 499

def purchase_type
  @purchase_type
end

#reported_breakdownObject

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



502
503
504
# File 'lib/stripe/resources/issuing/authorization.rb', line 502

def reported_breakdown
  @reported_breakdown
end

#service_typeObject

The type of fuel service. One of ‘non_fuel_transaction`, `full_service`, or `self_service`.



505
506
507
# File 'lib/stripe/resources/issuing/authorization.rb', line 505

def service_type
  @service_type
end