Class: Stripe::Issuing::Authorization::CreateParams::MerchantData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData

Returns a new instance of MerchantData.



579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
# File 'lib/stripe/resources/issuing/authorization.rb', line 579

def initialize(
  category: nil,
  city: nil,
  country: nil,
  name: nil,
  network_id: nil,
  postal_code: nil,
  state: nil,
  terminal_id: nil,
  url: nil
)
  @category = category
  @city = city
  @country = country
  @name = name
  @network_id = network_id
  @postal_code = postal_code
  @state = state
  @terminal_id = terminal_id
  @url = url
end

Instance Attribute Details

#categoryObject

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



553
554
555
# File 'lib/stripe/resources/issuing/authorization.rb', line 553

def category
  @category
end

#cityObject

City where the seller is located



556
557
558
# File 'lib/stripe/resources/issuing/authorization.rb', line 556

def city
  @city
end

#countryObject

Country where the seller is located



559
560
561
# File 'lib/stripe/resources/issuing/authorization.rb', line 559

def country
  @country
end

#nameObject

Name of the seller



562
563
564
# File 'lib/stripe/resources/issuing/authorization.rb', line 562

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



565
566
567
# File 'lib/stripe/resources/issuing/authorization.rb', line 565

def network_id
  @network_id
end

#postal_codeObject

Postal code where the seller is located



568
569
570
# File 'lib/stripe/resources/issuing/authorization.rb', line 568

def postal_code
  @postal_code
end

#stateObject

State where the seller is located



571
572
573
# File 'lib/stripe/resources/issuing/authorization.rb', line 571

def state
  @state
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



574
575
576
# File 'lib/stripe/resources/issuing/authorization.rb', line 574

def terminal_id
  @terminal_id
end

#urlObject

URL provided by the merchant on a 3DS request



577
578
579
# File 'lib/stripe/resources/issuing/authorization.rb', line 577

def url
  @url
end