Class: Stripe::Issuing::Authorization::CreateParams::VerificationData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::CreateParams::VerificationData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AuthenticationExemption, ThreeDSecure
Instance Attribute Summary collapse
-
#address_line1_check ⇒ Object
Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.
-
#address_postal_code_check ⇒ Object
Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.
-
#authentication_exemption ⇒ Object
The exemption applied to this authorization.
-
#cvc_check ⇒ Object
Whether the cardholder provided a CVC and if it matched Stripe’s record.
-
#expiry_check ⇒ Object
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
-
#three_d_secure ⇒ Object
3D Secure details.
Instance Method Summary collapse
-
#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData
constructor
A new instance of VerificationData.
Methods inherited from RequestParams
Constructor Details
#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData
Returns a new instance of VerificationData.
699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 699 def initialize( address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil ) @address_line1_check = address_line1_check @address_postal_code_check = address_postal_code_check @authentication_exemption = authentication_exemption @cvc_check = cvc_check @expiry_check = expiry_check @three_d_secure = three_d_secure end |
Instance Attribute Details
#address_line1_check ⇒ Object
Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.
687 688 689 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 687 def address_line1_check @address_line1_check end |
#address_postal_code_check ⇒ Object
Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.
689 690 691 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 689 def address_postal_code_check @address_postal_code_check end |
#authentication_exemption ⇒ Object
The exemption applied to this authorization.
691 692 693 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 691 def authentication_exemption @authentication_exemption end |
#cvc_check ⇒ Object
Whether the cardholder provided a CVC and if it matched Stripe’s record.
693 694 695 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 693 def cvc_check @cvc_check end |
#expiry_check ⇒ Object
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
695 696 697 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 695 def expiry_check @expiry_check end |
#three_d_secure ⇒ Object
3D Secure details.
697 698 699 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 697 def three_d_secure @three_d_secure end |