Class: Stripe::Issuing::Authorization::CreateParams::VerificationData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData

Returns a new instance of VerificationData.



541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
# File 'lib/stripe/resources/issuing/authorization.rb', line 541

def initialize(
  address_line1_check: nil,
  address_postal_code_check: nil,
  authentication_exemption: nil,
  cvc_check: nil,
  expiry_check: nil,
  three_d_secure: nil
)
  @address_line1_check = address_line1_check
  @address_postal_code_check = address_postal_code_check
  @authentication_exemption = authentication_exemption
  @cvc_check = cvc_check
  @expiry_check = expiry_check
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#address_line1_checkObject

Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.



529
530
531
# File 'lib/stripe/resources/issuing/authorization.rb', line 529

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject

Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.



531
532
533
# File 'lib/stripe/resources/issuing/authorization.rb', line 531

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject

The exemption applied to this authorization.



533
534
535
# File 'lib/stripe/resources/issuing/authorization.rb', line 533

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject

Whether the cardholder provided a CVC and if it matched Stripe’s record.



535
536
537
# File 'lib/stripe/resources/issuing/authorization.rb', line 535

def cvc_check
  @cvc_check
end

#expiry_checkObject

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



537
538
539
# File 'lib/stripe/resources/issuing/authorization.rb', line 537

def expiry_check
  @expiry_check
end

#three_d_secureObject

3D Secure details.



539
540
541
# File 'lib/stripe/resources/issuing/authorization.rb', line 539

def three_d_secure
  @three_d_secure
end