Class: Stripe::Issuing::Authorization::CreateParams::VerificationData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData

Returns a new instance of VerificationData.



550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
# File 'lib/stripe/resources/issuing/authorization.rb', line 550

def initialize(
  address_line1_check: nil,
  address_postal_code_check: nil,
  authentication_exemption: nil,
  cvc_check: nil,
  expiry_check: nil,
  three_d_secure: nil
)
  @address_line1_check = address_line1_check
  @address_postal_code_check = address_postal_code_check
  @authentication_exemption = authentication_exemption
  @cvc_check = cvc_check
  @expiry_check = expiry_check
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#address_line1_checkObject

Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.



538
539
540
# File 'lib/stripe/resources/issuing/authorization.rb', line 538

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject

Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.



540
541
542
# File 'lib/stripe/resources/issuing/authorization.rb', line 540

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject

The exemption applied to this authorization.



542
543
544
# File 'lib/stripe/resources/issuing/authorization.rb', line 542

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject

Whether the cardholder provided a CVC and if it matched Stripe’s record.



544
545
546
# File 'lib/stripe/resources/issuing/authorization.rb', line 544

def cvc_check
  @cvc_check
end

#expiry_checkObject

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



546
547
548
# File 'lib/stripe/resources/issuing/authorization.rb', line 546

def expiry_check
  @expiry_check
end

#three_d_secureObject

3D Secure details.



548
549
550
# File 'lib/stripe/resources/issuing/authorization.rb', line 548

def three_d_secure
  @three_d_secure
end