Class: Stripe::Issuing::Authorization::CreateParams::VerificationData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData

Returns a new instance of VerificationData.



651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'lib/stripe/resources/issuing/authorization.rb', line 651

def initialize(
  address_line1_check: nil,
  address_postal_code_check: nil,
  authentication_exemption: nil,
  cvc_check: nil,
  expiry_check: nil,
  three_d_secure: nil
)
  @address_line1_check = address_line1_check
  @address_postal_code_check = address_postal_code_check
  @authentication_exemption = authentication_exemption
  @cvc_check = cvc_check
  @expiry_check = expiry_check
  @three_d_secure = three_d_secure
end

Instance Attribute Details

#address_line1_checkObject

Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.



634
635
636
# File 'lib/stripe/resources/issuing/authorization.rb', line 634

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject

Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.



637
638
639
# File 'lib/stripe/resources/issuing/authorization.rb', line 637

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject

The exemption applied to this authorization.



640
641
642
# File 'lib/stripe/resources/issuing/authorization.rb', line 640

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject

Whether the cardholder provided a CVC and if it matched Stripe’s record.



643
644
645
# File 'lib/stripe/resources/issuing/authorization.rb', line 643

def cvc_check
  @cvc_check
end

#expiry_checkObject

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



646
647
648
# File 'lib/stripe/resources/issuing/authorization.rb', line 646

def expiry_check
  @expiry_check
end

#three_d_secureObject

3D Secure details.



649
650
651
# File 'lib/stripe/resources/issuing/authorization.rb', line 649

def three_d_secure
  @three_d_secure
end