Class: Stripe::Issuing::Authorization::FinalizeAmountParams::Fleet
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::FinalizeAmountParams::Fleet
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: CardholderPromptData, ReportedBreakdown
Instance Attribute Summary collapse
-
#cardholder_prompt_data ⇒ Object
Answers to prompts presented to the cardholder at the point of sale.
-
#purchase_type ⇒ Object
The type of purchase.
-
#reported_breakdown ⇒ Object
More information about the total amount.
-
#service_type ⇒ Object
The type of fuel service.
Instance Method Summary collapse
-
#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet
constructor
A new instance of Fleet.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet
Returns a new instance of Fleet.
1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1130 def initialize( cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil ) @cardholder_prompt_data = cardholder_prompt_data @purchase_type = purchase_type @reported_breakdown = reported_breakdown @service_type = service_type end |
Instance Attribute Details
#cardholder_prompt_data ⇒ Object
Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.
1122 1123 1124 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1122 def cardholder_prompt_data @cardholder_prompt_data end |
#purchase_type ⇒ Object
The type of purchase. One of ‘fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.
1124 1125 1126 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1124 def purchase_type @purchase_type end |
#reported_breakdown ⇒ Object
More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
1126 1127 1128 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1126 def reported_breakdown @reported_breakdown end |
#service_type ⇒ Object
The type of fuel service. One of ‘non_fuel_transaction`, `full_service`, or `self_service`.
1128 1129 1130 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1128 def service_type @service_type end |