Class: Stripe::Issuing::Authorization::FinalizeAmountParams::Fuel

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel

Returns a new instance of Fuel.



1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
# File 'lib/stripe/resources/issuing/authorization.rb', line 1170

def initialize(
  industry_product_code: nil,
  quantity_decimal: nil,
  type: nil,
  unit: nil,
  unit_cost_decimal: nil
)
  @industry_product_code = industry_product_code
  @quantity_decimal = quantity_decimal
  @type = type
  @unit = unit
  @unit_cost_decimal = unit_cost_decimal
end

Instance Attribute Details

#industry_product_codeObject

[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.



1156
1157
1158
# File 'lib/stripe/resources/issuing/authorization.rb', line 1156

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject

The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



1159
1160
1161
# File 'lib/stripe/resources/issuing/authorization.rb', line 1159

def quantity_decimal
  @quantity_decimal
end

#typeObject

The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.



1162
1163
1164
# File 'lib/stripe/resources/issuing/authorization.rb', line 1162

def type
  @type
end

#unitObject

The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.



1165
1166
1167
# File 'lib/stripe/resources/issuing/authorization.rb', line 1165

def unit
  @unit
end

#unit_cost_decimalObject

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



1168
1169
1170
# File 'lib/stripe/resources/issuing/authorization.rb', line 1168

def unit_cost_decimal
  @unit_cost_decimal
end