Class: Stripe::Issuing::Authorization::Fleet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::Fleet
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: CardholderPromptData, ReportedBreakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cardholder_prompt_data ⇒ Object
readonly
Answers to prompts presented to the cardholder at the point of sale.
-
#purchase_type ⇒ Object
readonly
The type of purchase.
-
#reported_breakdown ⇒ Object
readonly
More information about the total amount.
-
#service_type ⇒ Object
readonly
The type of fuel service.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cardholder_prompt_data ⇒ Object (readonly)
Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.
450 451 452 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 450 def cardholder_prompt_data @cardholder_prompt_data end |
#purchase_type ⇒ Object (readonly)
The type of purchase.
452 453 454 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 452 def purchase_type @purchase_type end |
#reported_breakdown ⇒ Object (readonly)
More information about the total amount. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
454 455 456 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 454 def reported_breakdown @reported_breakdown end |
#service_type ⇒ Object (readonly)
The type of fuel service.
456 457 458 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 456 def service_type @service_type end |
Class Method Details
.field_encodings ⇒ Object
469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 469 def self.field_encodings @field_encodings = { reported_breakdown: { kind: :nullable, inner: { kind: :object, fields: { fuel: { kind: :nullable, inner: { kind: :object, fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string } }, }, }, non_fuel: { kind: :nullable, inner: { kind: :object, fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string } }, }, }, tax: { kind: :nullable, inner: { kind: :object, fields: { local_amount_decimal: { kind: :nullable, inner: :decimal_string }, national_amount_decimal: { kind: :nullable, inner: :decimal_string }, }, }, }, }, }, }, } end |
.field_remappings ⇒ Object
465 466 467 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 465 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
458 459 460 461 462 463 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 458 def self.inner_class_types @inner_class_types = { cardholder_prompt_data: CardholderPromptData, reported_breakdown: ReportedBreakdown, } end |