Class: Stripe::Issuing::Authorization::Fleet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::Fleet
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: CardholderPromptData, ReportedBreakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cardholder_prompt_data ⇒ Object
readonly
Answers to prompts presented to the cardholder at the point of sale.
-
#purchase_type ⇒ Object
readonly
The type of purchase.
-
#reported_breakdown ⇒ Object
readonly
More information about the total amount.
-
#service_type ⇒ Object
readonly
The type of fuel service.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cardholder_prompt_data ⇒ Object (readonly)
Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.
435 436 437 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 435 def cardholder_prompt_data @cardholder_prompt_data end |
#purchase_type ⇒ Object (readonly)
The type of purchase.
437 438 439 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 437 def purchase_type @purchase_type end |
#reported_breakdown ⇒ Object (readonly)
More information about the total amount. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
439 440 441 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 439 def reported_breakdown @reported_breakdown end |
#service_type ⇒ Object (readonly)
The type of fuel service.
441 442 443 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 441 def service_type @service_type end |
Class Method Details
.field_encodings ⇒ Object
454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 454 def self.field_encodings @field_encodings = { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, } end |
.field_remappings ⇒ Object
450 451 452 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 450 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
443 444 445 446 447 448 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 443 def self.inner_class_types @inner_class_types = { cardholder_prompt_data: CardholderPromptData, reported_breakdown: ReportedBreakdown, } end |