Class: Stripe::Issuing::Authorization::Fleet

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardholder_prompt_dataObject (readonly)

Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.



278
279
280
# File 'lib/stripe/resources/issuing/authorization.rb', line 278

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject (readonly)

The type of purchase.



280
281
282
# File 'lib/stripe/resources/issuing/authorization.rb', line 280

def purchase_type
  @purchase_type
end

#reported_breakdownObject (readonly)

More information about the total amount. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



282
283
284
# File 'lib/stripe/resources/issuing/authorization.rb', line 282

def reported_breakdown
  @reported_breakdown
end

#service_typeObject (readonly)

The type of fuel service.



284
285
286
# File 'lib/stripe/resources/issuing/authorization.rb', line 284

def service_type
  @service_type
end

Class Method Details

.field_encodingsObject



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/stripe/resources/issuing/authorization.rb', line 297

def self.field_encodings
  @field_encodings = {
    reported_breakdown: {
      kind: :object,
      fields: {
        fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
        non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
        tax: {
          kind: :object,
          fields: {
            local_amount_decimal: :decimal_string,
            national_amount_decimal: :decimal_string,
          },
        },
      },
    },
  }
end

.field_remappingsObject



293
294
295
# File 'lib/stripe/resources/issuing/authorization.rb', line 293

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



286
287
288
289
290
291
# File 'lib/stripe/resources/issuing/authorization.rb', line 286

def self.inner_class_types
  @inner_class_types = {
    cardholder_prompt_data: CardholderPromptData,
    reported_breakdown: ReportedBreakdown,
  }
end