Class: Stripe::Issuing::Authorization::Fleet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::Fleet
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: CardholderPromptData, ReportedBreakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cardholder_prompt_data ⇒ Object
readonly
Answers to prompts presented to the cardholder at the point of sale.
-
#purchase_type ⇒ Object
readonly
The type of purchase.
-
#reported_breakdown ⇒ Object
readonly
More information about the total amount.
-
#service_type ⇒ Object
readonly
The type of fuel service.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cardholder_prompt_data ⇒ Object (readonly)
Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.
69 70 71 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 69 def cardholder_prompt_data @cardholder_prompt_data end |
#purchase_type ⇒ Object (readonly)
The type of purchase.
71 72 73 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 71 def purchase_type @purchase_type end |
#reported_breakdown ⇒ Object (readonly)
More information about the total amount. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
73 74 75 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 73 def reported_breakdown @reported_breakdown end |
#service_type ⇒ Object (readonly)
The type of fuel service.
75 76 77 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 75 def service_type @service_type end |