Class: Stripe::Issuing::Authorization::Fleet

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardholder_prompt_dataObject (readonly)

Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.



78
79
80
# File 'lib/stripe/resources/issuing/authorization.rb', line 78

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject (readonly)

The type of purchase.



81
82
83
# File 'lib/stripe/resources/issuing/authorization.rb', line 81

def purchase_type
  @purchase_type
end

#reported_breakdownObject (readonly)

More information about the total amount. Typically this information is received from the merchant after the authorization has been approved and the fuel dispensed. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



84
85
86
# File 'lib/stripe/resources/issuing/authorization.rb', line 84

def reported_breakdown
  @reported_breakdown
end

#service_typeObject (readonly)

The type of fuel service.



87
88
89
# File 'lib/stripe/resources/issuing/authorization.rb', line 87

def service_type
  @service_type
end