Class: Stripe::Issuing::Authorization::Fuel
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::Fuel
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#industry_product_code ⇒ Object
readonly
Conexxus Payment System Product Code identifying the primary fuel product purchased.
-
#quantity_decimal ⇒ Object
readonly
The quantity of
units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places. -
#type ⇒ Object
readonly
The type of fuel that was purchased.
-
#unit ⇒ Object
readonly
The units for
quantity_decimal. -
#unit_cost_decimal ⇒ Object
readonly
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#industry_product_code ⇒ Object (readonly)
Conexxus Payment System Product Code identifying the primary fuel product purchased.
526 527 528 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 526 def industry_product_code @industry_product_code end |
#quantity_decimal ⇒ Object (readonly)
The quantity of units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
528 529 530 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 528 def quantity_decimal @quantity_decimal end |
#type ⇒ Object (readonly)
The type of fuel that was purchased.
530 531 532 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 530 def type @type end |
#unit ⇒ Object (readonly)
The units for quantity_decimal.
532 533 534 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 532 def unit @unit end |
#unit_cost_decimal ⇒ Object (readonly)
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
534 535 536 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 534 def unit_cost_decimal @unit_cost_decimal end |
Class Method Details
.field_encodings ⇒ Object
544 545 546 547 548 549 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 544 def self.field_encodings @field_encodings = { quantity_decimal: { kind: :nullable, inner: :decimal_string }, unit_cost_decimal: { kind: :nullable, inner: :decimal_string }, } end |
.field_remappings ⇒ Object
540 541 542 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 540 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
536 537 538 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 536 def self.inner_class_types @inner_class_types = {} end |