Class: Stripe::Issuing::Authorization::Fuel
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::Fuel
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#industry_product_code ⇒ Object
readonly
Conexxus Payment System Product Code identifying the primary fuel product purchased.
-
#quantity_decimal ⇒ Object
readonly
The quantity of
units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places. -
#type ⇒ Object
readonly
The type of fuel that was purchased.
-
#unit ⇒ Object
readonly
The units for
quantity_decimal. -
#unit_cost_decimal ⇒ Object
readonly
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#industry_product_code ⇒ Object (readonly)
Conexxus Payment System Product Code identifying the primary fuel product purchased.
493 494 495 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 493 def industry_product_code @industry_product_code end |
#quantity_decimal ⇒ Object (readonly)
The quantity of units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
495 496 497 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 495 def quantity_decimal @quantity_decimal end |
#type ⇒ Object (readonly)
The type of fuel that was purchased.
497 498 499 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 497 def type @type end |
#unit ⇒ Object (readonly)
The units for quantity_decimal.
499 500 501 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 499 def unit @unit end |
#unit_cost_decimal ⇒ Object (readonly)
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
501 502 503 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 501 def unit_cost_decimal @unit_cost_decimal end |
Class Method Details
.field_encodings ⇒ Object
511 512 513 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 511 def self.field_encodings @field_encodings = { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string } end |
.field_remappings ⇒ Object
507 508 509 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 507 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
503 504 505 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 503 def self.inner_class_types @inner_class_types = {} end |