Class: Stripe::Issuing::Authorization::Fuel

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#industry_product_codeObject (readonly)

[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.



204
205
206
# File 'lib/stripe/resources/issuing/authorization.rb', line 204

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject (readonly)

The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



206
207
208
# File 'lib/stripe/resources/issuing/authorization.rb', line 206

def quantity_decimal
  @quantity_decimal
end

#typeObject (readonly)

The type of fuel that was purchased.



208
209
210
# File 'lib/stripe/resources/issuing/authorization.rb', line 208

def type
  @type
end

#unitObject (readonly)

The units for ‘quantity_decimal`.



210
211
212
# File 'lib/stripe/resources/issuing/authorization.rb', line 210

def unit
  @unit
end

#unit_cost_decimalObject (readonly)

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



212
213
214
# File 'lib/stripe/resources/issuing/authorization.rb', line 212

def unit_cost_decimal
  @unit_cost_decimal
end

Class Method Details

.field_encodingsObject



222
223
224
# File 'lib/stripe/resources/issuing/authorization.rb', line 222

def self.field_encodings
  @field_encodings = { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }
end

.field_remappingsObject



218
219
220
# File 'lib/stripe/resources/issuing/authorization.rb', line 218

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



214
215
216
# File 'lib/stripe/resources/issuing/authorization.rb', line 214

def self.inner_class_types
  @inner_class_types = {}
end