Class: Stripe::Issuing::Authorization::Fuel
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::Fuel
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#industry_product_code ⇒ Object
readonly
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
-
#quantity_decimal ⇒ Object
readonly
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
-
#type ⇒ Object
readonly
The type of fuel that was purchased.
-
#unit ⇒ Object
readonly
The units for ‘quantity_decimal`.
-
#unit_cost_decimal ⇒ Object
readonly
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#industry_product_code ⇒ Object (readonly)
[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.
103 104 105 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 103 def industry_product_code @industry_product_code end |
#quantity_decimal ⇒ Object (readonly)
The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.
106 107 108 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 106 def quantity_decimal @quantity_decimal end |
#type ⇒ Object (readonly)
The type of fuel that was purchased.
109 110 111 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 109 def type @type end |
#unit ⇒ Object (readonly)
The units for ‘quantity_decimal`.
112 113 114 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 112 def unit @unit end |
#unit_cost_decimal ⇒ Object (readonly)
The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.
115 116 117 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 115 def unit_cost_decimal @unit_cost_decimal end |