Class: Stripe::Issuing::Authorization::IncrementParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::IncrementParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#increment_amount ⇒ Object
The amount to increment the authorization by.
-
#is_amount_controllable ⇒ Object
If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
Instance Method Summary collapse
-
#initialize(expand: nil, increment_amount: nil, is_amount_controllable: nil) ⇒ IncrementParams
constructor
A new instance of IncrementParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, increment_amount: nil, is_amount_controllable: nil) ⇒ IncrementParams
Returns a new instance of IncrementParams.
1227 1228 1229 1230 1231 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1227 def initialize(expand: nil, increment_amount: nil, is_amount_controllable: nil) @expand = @increment_amount = increment_amount @is_amount_controllable = is_amount_controllable end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1219 1220 1221 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1219 def @expand end |
#increment_amount ⇒ Object
The amount to increment the authorization by. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
1222 1223 1224 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1222 def increment_amount @increment_amount end |
#is_amount_controllable ⇒ Object
If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
1225 1226 1227 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1225 def is_amount_controllable @is_amount_controllable end |