Class: Stripe::Issuing::Authorization::MerchantData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

A categorization of the seller's type of business. See our merchant categories guide for a list of possible values.



581
582
583
# File 'lib/stripe/resources/issuing/authorization.rb', line 581

def category
  @category
end

#category_codeObject (readonly)

The merchant category code for the seller’s business



583
584
585
# File 'lib/stripe/resources/issuing/authorization.rb', line 583

def category_code
  @category_code
end

#cityObject (readonly)

City where the seller is located



585
586
587
# File 'lib/stripe/resources/issuing/authorization.rb', line 585

def city
  @city
end

#countryObject (readonly)

Country where the seller is located



587
588
589
# File 'lib/stripe/resources/issuing/authorization.rb', line 587

def country
  @country
end

#nameObject (readonly)

Name of the seller



589
590
591
# File 'lib/stripe/resources/issuing/authorization.rb', line 589

def name
  @name
end

#network_idObject (readonly)

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



591
592
593
# File 'lib/stripe/resources/issuing/authorization.rb', line 591

def network_id
  @network_id
end

#payment_facilitator_idObject (readonly)

The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network. Null when the transaction was not processed through a PayFac.



593
594
595
# File 'lib/stripe/resources/issuing/authorization.rb', line 593

def payment_facilitator_id
  @payment_facilitator_id
end

#postal_codeObject (readonly)

Postal code where the seller is located



595
596
597
# File 'lib/stripe/resources/issuing/authorization.rb', line 595

def postal_code
  @postal_code
end

#stateObject (readonly)

State where the seller is located



597
598
599
# File 'lib/stripe/resources/issuing/authorization.rb', line 597

def state
  @state
end

#sub_merchant_idObject (readonly)

The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator. Null when the transaction was not processed through a PayFac or when no sub-merchant ID was provided.



599
600
601
# File 'lib/stripe/resources/issuing/authorization.rb', line 599

def sub_merchant_id
  @sub_merchant_id
end

#tax_idObject (readonly)

The seller's tax identification number. Currently populated for French merchants only.



601
602
603
# File 'lib/stripe/resources/issuing/authorization.rb', line 601

def tax_id
  @tax_id
end

#terminal_idObject (readonly)

An ID assigned by the seller to the location of the sale.



603
604
605
# File 'lib/stripe/resources/issuing/authorization.rb', line 603

def terminal_id
  @terminal_id
end

#urlObject (readonly)

URL provided by the merchant on a 3DS request



605
606
607
# File 'lib/stripe/resources/issuing/authorization.rb', line 605

def url
  @url
end

Class Method Details

.field_remappingsObject



611
612
613
# File 'lib/stripe/resources/issuing/authorization.rb', line 611

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



607
608
609
# File 'lib/stripe/resources/issuing/authorization.rb', line 607

def self.inner_class_types
  @inner_class_types = {}
end