Class: Stripe::Issuing::Authorization::MerchantData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::MerchantData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
A categorization of the seller's type of business.
-
#category_code ⇒ Object
readonly
The merchant category code for the seller’s business.
-
#city ⇒ Object
readonly
City where the seller is located.
-
#country ⇒ Object
readonly
Country where the seller is located.
-
#name ⇒ Object
readonly
Name of the seller.
-
#network_id ⇒ Object
readonly
Identifier assigned to the seller by the card network.
-
#payment_facilitator_id ⇒ Object
readonly
The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network.
-
#postal_code ⇒ Object
readonly
Postal code where the seller is located.
-
#state ⇒ Object
readonly
State where the seller is located.
-
#sub_merchant_id ⇒ Object
readonly
The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator.
-
#tax_id ⇒ Object
readonly
The seller's tax identification number.
-
#terminal_id ⇒ Object
readonly
An ID assigned by the seller to the location of the sale.
-
#url ⇒ Object
readonly
URL provided by the merchant on a 3DS request.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
A categorization of the seller's type of business. See our merchant categories guide for a list of possible values.
545 546 547 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 545 def category @category end |
#category_code ⇒ Object (readonly)
The merchant category code for the seller’s business
547 548 549 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 547 def category_code @category_code end |
#city ⇒ Object (readonly)
City where the seller is located
549 550 551 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 549 def city @city end |
#country ⇒ Object (readonly)
Country where the seller is located
551 552 553 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 551 def country @country end |
#name ⇒ Object (readonly)
Name of the seller
553 554 555 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 553 def name @name end |
#network_id ⇒ Object (readonly)
Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
555 556 557 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 555 def network_id @network_id end |
#payment_facilitator_id ⇒ Object (readonly)
The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network. Null when the transaction was not processed through a PayFac.
557 558 559 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 557 def payment_facilitator_id @payment_facilitator_id end |
#postal_code ⇒ Object (readonly)
Postal code where the seller is located
559 560 561 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 559 def postal_code @postal_code end |
#state ⇒ Object (readonly)
State where the seller is located
561 562 563 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 561 def state @state end |
#sub_merchant_id ⇒ Object (readonly)
The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator. Null when the transaction was not processed through a PayFac or when no sub-merchant ID was provided.
563 564 565 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 563 def sub_merchant_id @sub_merchant_id end |
#tax_id ⇒ Object (readonly)
The seller's tax identification number. Currently populated for French merchants only.
565 566 567 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 565 def tax_id @tax_id end |
#terminal_id ⇒ Object (readonly)
An ID assigned by the seller to the location of the sale.
567 568 569 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 567 def terminal_id @terminal_id end |
#url ⇒ Object (readonly)
URL provided by the merchant on a 3DS request
569 570 571 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 569 def url @url end |
Class Method Details
.field_remappings ⇒ Object
575 576 577 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 575 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
571 572 573 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 571 def self.inner_class_types @inner_class_types = {} end |