Class: Stripe::Issuing::Authorization::MerchantData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

A categorization of the seller’s type of business. See our [merchant categories guide](docs.stripe.com/issuing/merchant-categories) for a list of possible values.



344
345
346
# File 'lib/stripe/resources/issuing/authorization.rb', line 344

def category
  @category
end

#category_codeObject (readonly)

The merchant category code for the seller’s business



346
347
348
# File 'lib/stripe/resources/issuing/authorization.rb', line 346

def category_code
  @category_code
end

#cityObject (readonly)

City where the seller is located



348
349
350
# File 'lib/stripe/resources/issuing/authorization.rb', line 348

def city
  @city
end

#countryObject (readonly)

Country where the seller is located



350
351
352
# File 'lib/stripe/resources/issuing/authorization.rb', line 350

def country
  @country
end

#nameObject (readonly)

Name of the seller



352
353
354
# File 'lib/stripe/resources/issuing/authorization.rb', line 352

def name
  @name
end

#network_idObject (readonly)

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



354
355
356
# File 'lib/stripe/resources/issuing/authorization.rb', line 354

def network_id
  @network_id
end

#payment_facilitator_idObject (readonly)

The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network. Null when the transaction was not processed through a PayFac.



356
357
358
# File 'lib/stripe/resources/issuing/authorization.rb', line 356

def payment_facilitator_id
  @payment_facilitator_id
end

#postal_codeObject (readonly)

Postal code where the seller is located



358
359
360
# File 'lib/stripe/resources/issuing/authorization.rb', line 358

def postal_code
  @postal_code
end

#stateObject (readonly)

State where the seller is located



360
361
362
# File 'lib/stripe/resources/issuing/authorization.rb', line 360

def state
  @state
end

#sub_merchant_idObject (readonly)

The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator. Null when the transaction was not processed through a PayFac or when no sub-merchant ID was provided.



362
363
364
# File 'lib/stripe/resources/issuing/authorization.rb', line 362

def sub_merchant_id
  @sub_merchant_id
end

#tax_idObject (readonly)

The seller’s tax identification number. Currently populated for French merchants only.



364
365
366
# File 'lib/stripe/resources/issuing/authorization.rb', line 364

def tax_id
  @tax_id
end

#terminal_idObject (readonly)

An ID assigned by the seller to the location of the sale.



366
367
368
# File 'lib/stripe/resources/issuing/authorization.rb', line 366

def terminal_id
  @terminal_id
end

#urlObject (readonly)

URL provided by the merchant on a 3DS request



368
369
370
# File 'lib/stripe/resources/issuing/authorization.rb', line 368

def url
  @url
end

Class Method Details

.field_remappingsObject



374
375
376
# File 'lib/stripe/resources/issuing/authorization.rb', line 374

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



370
371
372
# File 'lib/stripe/resources/issuing/authorization.rb', line 370

def self.inner_class_types
  @inner_class_types = {}
end