Class: Stripe::Issuing::Authorization::MerchantData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::MerchantData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
A categorization of the seller’s type of business.
-
#category_code ⇒ Object
readonly
The merchant category code for the seller’s business.
-
#city ⇒ Object
readonly
City where the seller is located.
-
#country ⇒ Object
readonly
Country where the seller is located.
-
#name ⇒ Object
readonly
Name of the seller.
-
#network_id ⇒ Object
readonly
Identifier assigned to the seller by the card network.
-
#payment_facilitator_id ⇒ Object
readonly
The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network.
-
#postal_code ⇒ Object
readonly
Postal code where the seller is located.
-
#state ⇒ Object
readonly
State where the seller is located.
-
#sub_merchant_id ⇒ Object
readonly
The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator.
-
#tax_id ⇒ Object
readonly
The seller’s tax identification number.
-
#terminal_id ⇒ Object
readonly
An ID assigned by the seller to the location of the sale.
-
#url ⇒ Object
readonly
URL provided by the merchant on a 3DS request.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
A categorization of the seller’s type of business. See our [merchant categories guide](docs.stripe.com/issuing/merchant-categories) for a list of possible values.
361 362 363 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 361 def category @category end |
#category_code ⇒ Object (readonly)
The merchant category code for the seller’s business
363 364 365 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 363 def category_code @category_code end |
#city ⇒ Object (readonly)
City where the seller is located
365 366 367 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 365 def city @city end |
#country ⇒ Object (readonly)
Country where the seller is located
367 368 369 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 367 def country @country end |
#name ⇒ Object (readonly)
Name of the seller
369 370 371 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 369 def name @name end |
#network_id ⇒ Object (readonly)
Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
371 372 373 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 371 def network_id @network_id end |
#payment_facilitator_id ⇒ Object (readonly)
The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network. Null when the transaction was not processed through a PayFac.
373 374 375 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 373 def payment_facilitator_id @payment_facilitator_id end |
#postal_code ⇒ Object (readonly)
Postal code where the seller is located
375 376 377 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 375 def postal_code @postal_code end |
#state ⇒ Object (readonly)
State where the seller is located
377 378 379 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 377 def state @state end |
#sub_merchant_id ⇒ Object (readonly)
The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator. Null when the transaction was not processed through a PayFac or when no sub-merchant ID was provided.
379 380 381 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 379 def sub_merchant_id @sub_merchant_id end |
#tax_id ⇒ Object (readonly)
The seller’s tax identification number. Currently populated for French merchants only.
381 382 383 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 381 def tax_id @tax_id end |
#terminal_id ⇒ Object (readonly)
An ID assigned by the seller to the location of the sale.
383 384 385 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 383 def terminal_id @terminal_id end |
#url ⇒ Object (readonly)
URL provided by the merchant on a 3DS request
385 386 387 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 385 def url @url end |
Class Method Details
.field_remappings ⇒ Object
391 392 393 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 391 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
387 388 389 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 387 def self.inner_class_types @inner_class_types = {} end |