Class: Stripe::Issuing::Authorization::MerchantData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::MerchantData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
A categorization of the seller’s type of business.
-
#category_code ⇒ Object
readonly
The merchant category code for the seller’s business.
-
#city ⇒ Object
readonly
City where the seller is located.
-
#country ⇒ Object
readonly
Country where the seller is located.
-
#name ⇒ Object
readonly
Name of the seller.
-
#network_id ⇒ Object
readonly
Identifier assigned to the seller by the card network.
-
#postal_code ⇒ Object
readonly
Postal code where the seller is located.
-
#state ⇒ Object
readonly
State where the seller is located.
-
#tax_id ⇒ Object
readonly
The seller’s tax identification number.
-
#terminal_id ⇒ Object
readonly
An ID assigned by the seller to the location of the sale.
-
#url ⇒ Object
readonly
URL provided by the merchant on a 3DS request.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
A categorization of the seller’s type of business. See our [merchant categories guide](docs.stripe.com/issuing/merchant-categories) for a list of possible values.
229 230 231 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 229 def category @category end |
#category_code ⇒ Object (readonly)
The merchant category code for the seller’s business
231 232 233 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 231 def category_code @category_code end |
#city ⇒ Object (readonly)
City where the seller is located
233 234 235 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 233 def city @city end |
#country ⇒ Object (readonly)
Country where the seller is located
235 236 237 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 235 def country @country end |
#name ⇒ Object (readonly)
Name of the seller
237 238 239 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 237 def name @name end |
#network_id ⇒ Object (readonly)
Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
239 240 241 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 239 def network_id @network_id end |
#postal_code ⇒ Object (readonly)
Postal code where the seller is located
241 242 243 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 241 def postal_code @postal_code end |
#state ⇒ Object (readonly)
State where the seller is located
243 244 245 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 243 def state @state end |
#tax_id ⇒ Object (readonly)
The seller’s tax identification number. Currently populated for French merchants only.
245 246 247 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 245 def tax_id @tax_id end |
#terminal_id ⇒ Object (readonly)
An ID assigned by the seller to the location of the sale.
247 248 249 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 247 def terminal_id @terminal_id end |
#url ⇒ Object (readonly)
URL provided by the merchant on a 3DS request
249 250 251 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 249 def url @url end |
Class Method Details
.field_remappings ⇒ Object
255 256 257 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 255 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
251 252 253 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 251 def self.inner_class_types @inner_class_types = {} end |