Class: Stripe::Issuing::Authorization::MerchantData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



102
103
104
# File 'lib/stripe/resources/issuing/authorization.rb', line 102

def category
  @category
end

#category_codeObject (readonly)

The merchant category code for the seller’s business



104
105
106
# File 'lib/stripe/resources/issuing/authorization.rb', line 104

def category_code
  @category_code
end

#cityObject (readonly)

City where the seller is located



106
107
108
# File 'lib/stripe/resources/issuing/authorization.rb', line 106

def city
  @city
end

#countryObject (readonly)

Country where the seller is located



108
109
110
# File 'lib/stripe/resources/issuing/authorization.rb', line 108

def country
  @country
end

#nameObject (readonly)

Name of the seller



110
111
112
# File 'lib/stripe/resources/issuing/authorization.rb', line 110

def name
  @name
end

#network_idObject (readonly)

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



112
113
114
# File 'lib/stripe/resources/issuing/authorization.rb', line 112

def network_id
  @network_id
end

#postal_codeObject (readonly)

Postal code where the seller is located



114
115
116
# File 'lib/stripe/resources/issuing/authorization.rb', line 114

def postal_code
  @postal_code
end

#stateObject (readonly)

State where the seller is located



116
117
118
# File 'lib/stripe/resources/issuing/authorization.rb', line 116

def state
  @state
end

#tax_idObject (readonly)

The seller’s tax identification number. Currently populated for French merchants only.



118
119
120
# File 'lib/stripe/resources/issuing/authorization.rb', line 118

def tax_id
  @tax_id
end

#terminal_idObject (readonly)

An ID assigned by the seller to the location of the sale.



120
121
122
# File 'lib/stripe/resources/issuing/authorization.rb', line 120

def terminal_id
  @terminal_id
end

#urlObject (readonly)

URL provided by the merchant on a 3DS request



122
123
124
# File 'lib/stripe/resources/issuing/authorization.rb', line 122

def url
  @url
end