Class: Stripe::Issuing::Authorization::MerchantData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



120
121
122
# File 'lib/stripe/resources/issuing/authorization.rb', line 120

def category
  @category
end

#category_codeObject (readonly)

The merchant category code for the seller’s business



123
124
125
# File 'lib/stripe/resources/issuing/authorization.rb', line 123

def category_code
  @category_code
end

#cityObject (readonly)

City where the seller is located



126
127
128
# File 'lib/stripe/resources/issuing/authorization.rb', line 126

def city
  @city
end

#countryObject (readonly)

Country where the seller is located



129
130
131
# File 'lib/stripe/resources/issuing/authorization.rb', line 129

def country
  @country
end

#nameObject (readonly)

Name of the seller



132
133
134
# File 'lib/stripe/resources/issuing/authorization.rb', line 132

def name
  @name
end

#network_idObject (readonly)

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



135
136
137
# File 'lib/stripe/resources/issuing/authorization.rb', line 135

def network_id
  @network_id
end

#postal_codeObject (readonly)

Postal code where the seller is located



138
139
140
# File 'lib/stripe/resources/issuing/authorization.rb', line 138

def postal_code
  @postal_code
end

#stateObject (readonly)

State where the seller is located



141
142
143
# File 'lib/stripe/resources/issuing/authorization.rb', line 141

def state
  @state
end

#tax_idObject (readonly)

The seller’s tax identification number. Currently populated for French merchants only.



144
145
146
# File 'lib/stripe/resources/issuing/authorization.rb', line 144

def tax_id
  @tax_id
end

#terminal_idObject (readonly)

An ID assigned by the seller to the location of the sale.



147
148
149
# File 'lib/stripe/resources/issuing/authorization.rb', line 147

def terminal_id
  @terminal_id
end

#urlObject (readonly)

URL provided by the merchant on a 3DS request



150
151
152
# File 'lib/stripe/resources/issuing/authorization.rb', line 150

def url
  @url
end