Class: Stripe::Issuing::Authorization::NetworkData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::NetworkData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acquiring_institution_country ⇒ Object
readonly
Country code of the acquirer assigned by the card network.
-
#acquiring_institution_id ⇒ Object
readonly
Identifier assigned to the acquirer by the card network.
-
#retrieval_reference_number ⇒ Object
readonly
Identifier assigned by the acquirer to track all messages related to this transaction.
-
#system_trace_audit_number ⇒ Object
readonly
The System Trace Audit Number (STAN) is a 6-digit identifier assigned by the acquirer.
-
#transaction_id ⇒ Object
readonly
Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acquiring_institution_country ⇒ Object (readonly)
Country code of the acquirer assigned by the card network.
582 583 584 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 582 def acquiring_institution_country @acquiring_institution_country end |
#acquiring_institution_id ⇒ Object (readonly)
Identifier assigned to the acquirer by the card network. Sometimes this value is not provided by the network; in this case, the value will be null.
584 585 586 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 584 def acquiring_institution_id @acquiring_institution_id end |
#retrieval_reference_number ⇒ Object (readonly)
Identifier assigned by the acquirer to track all messages related to this transaction.
586 587 588 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 586 def retrieval_reference_number @retrieval_reference_number end |
#system_trace_audit_number ⇒ Object (readonly)
The System Trace Audit Number (STAN) is a 6-digit identifier assigned by the acquirer. Prefer network_data.transaction_id if present, unless you have special requirements.
588 589 590 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 588 def system_trace_audit_number @system_trace_audit_number end |
#transaction_id ⇒ Object (readonly)
Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions.
590 591 592 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 590 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
596 597 598 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 596 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
592 593 594 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 592 def self.inner_class_types @inner_class_types = {} end |