Class: Stripe::Issuing::Authorization::PendingRequest
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::PendingRequest
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AmountDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The additional amount Stripe will hold if the authorization is approved, in the card’s [currency](stripe.com/docs/api#issuing_authorization_object-pending-request-currency) and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#is_amount_controllable ⇒ Object
readonly
If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
-
#merchant_amount ⇒ Object
readonly
The amount the merchant is requesting to be authorized in the ‘merchant_currency`.
-
#merchant_currency ⇒ Object
readonly
The local currency the merchant is requesting to authorize.
-
#network_risk_score ⇒ Object
readonly
The card network’s estimate of the likelihood that an authorization is fraudulent.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The additional amount Stripe will hold if the authorization is approved, in the card’s [currency](stripe.com/docs/api#issuing_authorization_object-pending-request-currency) and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
142 143 144 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 142 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
144 145 146 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 144 def amount_details @amount_details end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
146 147 148 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 146 def currency @currency end |
#is_amount_controllable ⇒ Object (readonly)
If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.
148 149 150 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 148 def is_amount_controllable @is_amount_controllable end |
#merchant_amount ⇒ Object (readonly)
The amount the merchant is requesting to be authorized in the ‘merchant_currency`. The amount is in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
150 151 152 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 150 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The local currency the merchant is requesting to authorize.
152 153 154 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 152 def merchant_currency @merchant_currency end |
#network_risk_score ⇒ Object (readonly)
The card network’s estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.
154 155 156 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 154 def network_risk_score @network_risk_score end |