Class: Stripe::Issuing::Authorization::PendingRequest

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AmountDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The additional amount Stripe will hold if the authorization is approved, in the card’s [currency](stripe.com/docs/api#issuing_authorization_object-pending-request-currency) and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



173
174
175
# File 'lib/stripe/resources/issuing/authorization.rb', line 173

def amount
  @amount
end

#amount_detailsObject (readonly)

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



176
177
178
# File 'lib/stripe/resources/issuing/authorization.rb', line 176

def amount_details
  @amount_details
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



179
180
181
# File 'lib/stripe/resources/issuing/authorization.rb', line 179

def currency
  @currency
end

#is_amount_controllableObject (readonly)

If set ‘true`, you may provide [amount](stripe.com/docs/api/issuing/authorizations/approve#approve_issuing_authorization-amount) to control how much to hold for the authorization.



182
183
184
# File 'lib/stripe/resources/issuing/authorization.rb', line 182

def is_amount_controllable
  @is_amount_controllable
end

#merchant_amountObject (readonly)

The amount the merchant is requesting to be authorized in the ‘merchant_currency`. The amount is in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



185
186
187
# File 'lib/stripe/resources/issuing/authorization.rb', line 185

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject (readonly)

The local currency the merchant is requesting to authorize.



188
189
190
# File 'lib/stripe/resources/issuing/authorization.rb', line 188

def merchant_currency
  @merchant_currency
end

#network_risk_scoreObject (readonly)

The card network’s estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.



191
192
193
# File 'lib/stripe/resources/issuing/authorization.rb', line 191

def network_risk_score
  @network_risk_score
end