Class: Stripe::Issuing::Authorization::RequestHistory
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::RequestHistory
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AmountDetails, HoldAmount, HoldAmountDetails, NetworkData
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The
pending_request.amountat the time of the request, presented in your card's currency and in the smallest currency unit. -
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#approved ⇒ Object
readonly
Whether this request was approved.
-
#authorization_code ⇒ Object
readonly
A code created by Stripe which is shared with the merchant to validate the authorization.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter ISO currency code, in lowercase.
-
#hold_amount ⇒ Object
readonly
The total amount that was held for this authorization request.
-
#hold_amount_details ⇒ Object
readonly
Breakdown of the amounts contributing to hold_amount.
-
#merchant_amount ⇒ Object
readonly
The
pending_request.merchant_amountat the time of the request, presented in themerchant_currencyand in the smallest currency unit. -
#merchant_currency ⇒ Object
readonly
The currency that was collected by the merchant and presented to the cardholder for the authorization.
-
#network_data ⇒ Object
readonly
Details about the authorization request, such as identifiers, set by the card network.
-
#network_risk_score ⇒ Object
readonly
The card network's estimate of the likelihood that an authorization is fraudulent.
-
#reason ⇒ Object
readonly
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
-
#reason_message ⇒ Object
readonly
If the
request_history.reasoniswebhook_errorbecause the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field. -
#requested_at ⇒ Object
readonly
Time when the card network received an authorization request from the acquirer in UTC.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The pending_request.amount at the time of the request, presented in your card's currency and in the smallest currency unit. Stripe held this amount from your account to fund the authorization if the request was approved.
1024 1025 1026 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1024 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in currency and in the smallest currency unit.
1026 1027 1028 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1026 def amount_details @amount_details end |
#approved ⇒ Object (readonly)
Whether this request was approved.
1028 1029 1030 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1028 def approved @approved end |
#authorization_code ⇒ Object (readonly)
A code created by Stripe which is shared with the merchant to validate the authorization. This field will be populated if the authorization message was approved. The code typically starts with the letter "S", followed by a six-digit number. For example, "S498162". Please note that the code is not guaranteed to be unique across authorizations.
1030 1031 1032 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1030 def @authorization_code end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
1032 1033 1034 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1032 def created @created end |
#currency ⇒ Object (readonly)
Three-letter ISO currency code, in lowercase. Must be a supported currency.
1034 1035 1036 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1034 def currency @currency end |
#hold_amount ⇒ Object (readonly)
The total amount that was held for this authorization request.
1036 1037 1038 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1036 def hold_amount @hold_amount end |
#hold_amount_details ⇒ Object (readonly)
Breakdown of the amounts contributing to hold_amount.
1038 1039 1040 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1038 def hold_amount_details @hold_amount_details end |
#merchant_amount ⇒ Object (readonly)
The pending_request.merchant_amount at the time of the request, presented in the merchant_currency and in the smallest currency unit.
1040 1041 1042 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1040 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The currency that was collected by the merchant and presented to the cardholder for the authorization. Three-letter ISO currency code, in lowercase. Must be a supported currency.
1042 1043 1044 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1042 def merchant_currency @merchant_currency end |
#network_data ⇒ Object (readonly)
Details about the authorization request, such as identifiers, set by the card network.
1044 1045 1046 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1044 def network_data @network_data end |
#network_risk_score ⇒ Object (readonly)
The card network's estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.
1046 1047 1048 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1046 def network_risk_score @network_risk_score end |
#reason ⇒ Object (readonly)
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
1048 1049 1050 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1048 def reason @reason end |
#reason_message ⇒ Object (readonly)
If the request_history.reason is webhook_error because the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field.
1050 1051 1052 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1050 def @reason_message end |
#requested_at ⇒ Object (readonly)
Time when the card network received an authorization request from the acquirer in UTC. Referred to by networks as transmission time.
1052 1053 1054 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1052 def requested_at @requested_at end |
Class Method Details
.field_remappings ⇒ Object
1063 1064 1065 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1063 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1054 1055 1056 1057 1058 1059 1060 1061 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1054 def self.inner_class_types @inner_class_types = { amount_details: AmountDetails, hold_amount: HoldAmount, hold_amount_details: HoldAmountDetails, network_data: NetworkData, } end |