Class: Stripe::Issuing::Authorization::RequestHistory

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AmountDetails

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

The ‘pending_request.amount` at the time of the request, presented in your card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). Stripe held this amount from your account to fund the authorization if the request was approved.



165
166
167
# File 'lib/stripe/resources/issuing/authorization.rb', line 165

def amount
  @amount
end

#amount_detailsObject (readonly)

Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



167
168
169
# File 'lib/stripe/resources/issuing/authorization.rb', line 167

def amount_details
  @amount_details
end

#approvedObject (readonly)

Whether this request was approved.



169
170
171
# File 'lib/stripe/resources/issuing/authorization.rb', line 169

def approved
  @approved
end

#authorization_codeObject (readonly)

A code created by Stripe which is shared with the merchant to validate the authorization. This field will be populated if the authorization message was approved. The code typically starts with the letter “S”, followed by a six-digit number. For example, “S498162”. Please note that the code is not guaranteed to be unique across authorizations.



171
172
173
# File 'lib/stripe/resources/issuing/authorization.rb', line 171

def authorization_code
  @authorization_code
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



173
174
175
# File 'lib/stripe/resources/issuing/authorization.rb', line 173

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



175
176
177
# File 'lib/stripe/resources/issuing/authorization.rb', line 175

def currency
  @currency
end

#merchant_amountObject (readonly)

The ‘pending_request.merchant_amount` at the time of the request, presented in the `merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



177
178
179
# File 'lib/stripe/resources/issuing/authorization.rb', line 177

def merchant_amount
  @merchant_amount
end

#merchant_currencyObject (readonly)

The currency that was collected by the merchant and presented to the cardholder for the authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



179
180
181
# File 'lib/stripe/resources/issuing/authorization.rb', line 179

def merchant_currency
  @merchant_currency
end

#network_risk_scoreObject (readonly)

The card network’s estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.



181
182
183
# File 'lib/stripe/resources/issuing/authorization.rb', line 181

def network_risk_score
  @network_risk_score
end

#reasonObject (readonly)

When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.



183
184
185
# File 'lib/stripe/resources/issuing/authorization.rb', line 183

def reason
  @reason
end

#reason_messageObject (readonly)

If the ‘request_history.reason` is `webhook_error` because the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field.



185
186
187
# File 'lib/stripe/resources/issuing/authorization.rb', line 185

def reason_message
  @reason_message
end

#requested_atObject (readonly)

Time when the card network received an authorization request from the acquirer in UTC. Referred to by networks as transmission time.



187
188
189
# File 'lib/stripe/resources/issuing/authorization.rb', line 187

def requested_at
  @requested_at
end