Class: Stripe::Issuing::Authorization::RequestHistory
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::RequestHistory
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AmountDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The ‘pending_request.amount` at the time of the request, presented in your card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#approved ⇒ Object
readonly
Whether this request was approved.
-
#authorization_code ⇒ Object
readonly
A code created by Stripe which is shared with the merchant to validate the authorization.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#merchant_amount ⇒ Object
readonly
The ‘pending_request.merchant_amount` at the time of the request, presented in the `merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#merchant_currency ⇒ Object
readonly
The currency that was collected by the merchant and presented to the cardholder for the authorization.
-
#network_risk_score ⇒ Object
readonly
The card network’s estimate of the likelihood that an authorization is fraudulent.
-
#reason ⇒ Object
readonly
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
-
#reason_message ⇒ Object
readonly
If the ‘request_history.reason` is `webhook_error` because the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field.
-
#requested_at ⇒ Object
readonly
Time when the card network received an authorization request from the acquirer in UTC.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The ‘pending_request.amount` at the time of the request, presented in your card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). Stripe held this amount from your account to fund the authorization if the request was approved.
203 204 205 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 203 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
206 207 208 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 206 def amount_details @amount_details end |
#approved ⇒ Object (readonly)
Whether this request was approved.
209 210 211 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 209 def approved @approved end |
#authorization_code ⇒ Object (readonly)
A code created by Stripe which is shared with the merchant to validate the authorization. This field will be populated if the authorization message was approved. The code typically starts with the letter “S”, followed by a six-digit number. For example, “S498162”. Please note that the code is not guaranteed to be unique across authorizations.
212 213 214 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 212 def @authorization_code end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
215 216 217 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 215 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
218 219 220 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 218 def currency @currency end |
#merchant_amount ⇒ Object (readonly)
The ‘pending_request.merchant_amount` at the time of the request, presented in the `merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
221 222 223 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 221 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The currency that was collected by the merchant and presented to the cardholder for the authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
224 225 226 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 224 def merchant_currency @merchant_currency end |
#network_risk_score ⇒ Object (readonly)
The card network’s estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.
227 228 229 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 227 def network_risk_score @network_risk_score end |
#reason ⇒ Object (readonly)
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
230 231 232 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 230 def reason @reason end |
#reason_message ⇒ Object (readonly)
If the ‘request_history.reason` is `webhook_error` because the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field.
233 234 235 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 233 def @reason_message end |
#requested_at ⇒ Object (readonly)
Time when the card network received an authorization request from the acquirer in UTC. Referred to by networks as transmission time.
236 237 238 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 236 def requested_at @requested_at end |