Class: Stripe::Issuing::Authorization::RequestHistory
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::RequestHistory
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AmountDetails
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The
pending_request.amountat the time of the request, presented in your card’s currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). -
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#approved ⇒ Object
readonly
Whether this request was approved.
-
#authorization_code ⇒ Object
readonly
A code created by Stripe which is shared with the merchant to validate the authorization.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#merchant_amount ⇒ Object
readonly
The
pending_request.merchant_amountat the time of the request, presented in themerchant_currencyand in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). -
#merchant_currency ⇒ Object
readonly
The currency that was collected by the merchant and presented to the cardholder for the authorization.
-
#network_risk_score ⇒ Object
readonly
The card network’s estimate of the likelihood that an authorization is fraudulent.
-
#reason ⇒ Object
readonly
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
-
#reason_message ⇒ Object
readonly
If the
request_history.reasoniswebhook_errorbecause the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field. -
#requested_at ⇒ Object
readonly
Time when the card network received an authorization request from the acquirer in UTC.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The pending_request.amount at the time of the request, presented in your card’s currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). Stripe held this amount from your account to fund the authorization if the request was approved.
332 333 334 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 332 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
334 335 336 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 334 def amount_details @amount_details end |
#approved ⇒ Object (readonly)
Whether this request was approved.
336 337 338 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 336 def approved @approved end |
#authorization_code ⇒ Object (readonly)
A code created by Stripe which is shared with the merchant to validate the authorization. This field will be populated if the authorization message was approved. The code typically starts with the letter “S”, followed by a six-digit number. For example, “S498162”. Please note that the code is not guaranteed to be unique across authorizations.
338 339 340 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 338 def end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
340 341 342 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 340 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
342 343 344 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 342 def currency @currency end |
#merchant_amount ⇒ Object (readonly)
The pending_request.merchant_amount at the time of the request, presented in the merchant_currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
344 345 346 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 344 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The currency that was collected by the merchant and presented to the cardholder for the authorization. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
346 347 348 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 346 def merchant_currency @merchant_currency end |
#network_risk_score ⇒ Object (readonly)
The card network’s estimate of the likelihood that an authorization is fraudulent. Takes on values between 1 and 99.
348 349 350 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 348 def network_risk_score @network_risk_score end |
#reason ⇒ Object (readonly)
When an authorization is approved or declined by you or by Stripe, this field provides additional detail on the reason for the outcome.
350 351 352 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 350 def reason @reason end |
#reason_message ⇒ Object (readonly)
If the request_history.reason is webhook_error because the direct webhook response is invalid (for example, parsing errors or missing parameters), we surface a more detailed error message via this field.
352 353 354 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 352 def end |
#requested_at ⇒ Object (readonly)
Time when the card network received an authorization request from the acquirer in UTC. Referred to by networks as transmission time.
354 355 356 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 354 def requested_at @requested_at end |
Class Method Details
.field_remappings ⇒ Object
360 361 362 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 360 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
356 357 358 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 356 def self.inner_class_types @inner_class_types = { amount_details: AmountDetails } end |