Class: Stripe::Issuing::Authorization::RespondParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmed: nil, expand: nil) ⇒ RespondParams

Returns a new instance of RespondParams.



1043
1044
1045
1046
# File 'lib/stripe/resources/issuing/authorization.rb', line 1043

def initialize(confirmed: nil, expand: nil)
  @confirmed = confirmed
  @expand = expand
end

Instance Attribute Details

#confirmedObject

Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).



1039
1040
1041
# File 'lib/stripe/resources/issuing/authorization.rb', line 1039

def confirmed
  @confirmed
end

#expandObject

Specifies which fields in the response should be expanded.



1041
1042
1043
# File 'lib/stripe/resources/issuing/authorization.rb', line 1041

def expand
  @expand
end