Class: Stripe::Issuing::Authorization::RespondParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::RespondParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#confirmed ⇒ Object
Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(confirmed: nil, expand: nil) ⇒ RespondParams
constructor
A new instance of RespondParams.
Methods inherited from RequestParams
Constructor Details
#initialize(confirmed: nil, expand: nil) ⇒ RespondParams
Returns a new instance of RespondParams.
1043 1044 1045 1046 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1043 def initialize(confirmed: nil, expand: nil) @confirmed = confirmed @expand = end |
Instance Attribute Details
#confirmed ⇒ Object
Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).
1039 1040 1041 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1039 def confirmed @confirmed end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1041 1042 1043 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1041 def @expand end |