Class: Stripe::Issuing::Authorization::RespondParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::RespondParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#confirmed ⇒ Object
Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(confirmed: nil, expand: nil) ⇒ RespondParams
constructor
A new instance of RespondParams.
Methods inherited from RequestParams
Constructor Details
#initialize(confirmed: nil, expand: nil) ⇒ RespondParams
Returns a new instance of RespondParams.
1211 1212 1213 1214 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1211 def initialize(confirmed: nil, expand: nil) @confirmed = confirmed @expand = end |
Instance Attribute Details
#confirmed ⇒ Object
Whether to simulate the user confirming that the transaction was legitimate (true) or telling Stripe that it was fraudulent (false).
1206 1207 1208 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1206 def confirmed @confirmed end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1209 1210 1211 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1209 def @expand end |