Class: Stripe::Issuing::Authorization::ReverseParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Authorization::ReverseParams
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#reverse_amount ⇒ Object
The amount to reverse from the authorization.
Instance Method Summary collapse
-
#initialize(expand: nil, reverse_amount: nil) ⇒ ReverseParams
constructor
A new instance of ReverseParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, reverse_amount: nil) ⇒ ReverseParams
Returns a new instance of ReverseParams.
1070 1071 1072 1073 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1070 def initialize(expand: nil, reverse_amount: nil) @expand = @reverse_amount = reverse_amount end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1066 1067 1068 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1066 def @expand end |
#reverse_amount ⇒ Object
The amount to reverse from the authorization. If not provided, the full amount of the authorization will be reversed. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
1068 1069 1070 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1068 def reverse_amount @reverse_amount end |