Class: Stripe::Issuing::Authorization::ReverseParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, reverse_amount: nil) ⇒ ReverseParams

Returns a new instance of ReverseParams.



1241
1242
1243
1244
# File 'lib/stripe/resources/issuing/authorization.rb', line 1241

def initialize(expand: nil, reverse_amount: nil)
  @expand = expand
  @reverse_amount = reverse_amount
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



1236
1237
1238
# File 'lib/stripe/resources/issuing/authorization.rb', line 1236

def expand
  @expand
end

#reverse_amountObject

The amount to reverse from the authorization. If not provided, the full amount of the authorization will be reversed. This amount is in the authorization currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



1239
1240
1241
# File 'lib/stripe/resources/issuing/authorization.rb', line 1239

def reverse_amount
  @reverse_amount
end