Class: Stripe::Issuing::Authorization::TokenDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::TokenDetails
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: NetworkData
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card ⇒ Object
readonly
The card associated with this token.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#device_fingerprint ⇒ Object
readonly
The hashed ID derived from the device ID from the card network associated with the token.
-
#network_data ⇒ Object
readonly
Attribute for field network_data.
-
#provisioning_decision ⇒ Object
readonly
The decision made during token provisioning.
-
#token_type ⇒ Object
readonly
The type of the token, indicating how it is used.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card ⇒ Object (readonly)
The card associated with this token.
1185 1186 1187 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1185 def card @card end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
1187 1188 1189 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1187 def created @created end |
#device_fingerprint ⇒ Object (readonly)
The hashed ID derived from the device ID from the card network associated with the token.
1189 1190 1191 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1189 def device_fingerprint @device_fingerprint end |
#network_data ⇒ Object (readonly)
Attribute for field network_data
1191 1192 1193 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1191 def network_data @network_data end |
#provisioning_decision ⇒ Object (readonly)
The decision made during token provisioning.
1193 1194 1195 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1193 def provisioning_decision @provisioning_decision end |
#token_type ⇒ Object (readonly)
The type of the token, indicating how it is used.
1195 1196 1197 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1195 def token_type @token_type end |
Class Method Details
.field_remappings ⇒ Object
1201 1202 1203 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1201 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1197 1198 1199 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 1197 def self.inner_class_types @inner_class_types = { network_data: NetworkData } end |