Class: Stripe::Issuing::Authorization::TokenDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: NetworkData

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardObject (readonly)

The card associated with this token.



985
986
987
# File 'lib/stripe/resources/issuing/authorization.rb', line 985

def card
  @card
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



987
988
989
# File 'lib/stripe/resources/issuing/authorization.rb', line 987

def created
  @created
end

#device_fingerprintObject (readonly)

The hashed ID derived from the device ID from the card network associated with the token.



989
990
991
# File 'lib/stripe/resources/issuing/authorization.rb', line 989

def device_fingerprint
  @device_fingerprint
end

#network_dataObject (readonly)

Attribute for field network_data



991
992
993
# File 'lib/stripe/resources/issuing/authorization.rb', line 991

def network_data
  @network_data
end

#provisioning_decisionObject (readonly)

The decision made during token provisioning.



993
994
995
# File 'lib/stripe/resources/issuing/authorization.rb', line 993

def provisioning_decision
  @provisioning_decision
end

#token_typeObject (readonly)

The type of the token, indicating how it is used.



995
996
997
# File 'lib/stripe/resources/issuing/authorization.rb', line 995

def token_type
  @token_type
end

Class Method Details

.field_remappingsObject



1001
1002
1003
# File 'lib/stripe/resources/issuing/authorization.rb', line 1001

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



997
998
999
# File 'lib/stripe/resources/issuing/authorization.rb', line 997

def self.inner_class_types
  @inner_class_types = { network_data: NetworkData }
end