Class: Stripe::Issuing::Authorization::TokenDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::TokenDetails
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: NetworkData
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card ⇒ Object
readonly
The card associated with this token.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#device_fingerprint ⇒ Object
readonly
The hashed ID derived from the device ID from the card network associated with the token.
-
#network_data ⇒ Object
readonly
Attribute for field network_data.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card ⇒ Object (readonly)
The card associated with this token.
601 602 603 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 601 def card @card end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
603 604 605 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 603 def created @created end |
#device_fingerprint ⇒ Object (readonly)
The hashed ID derived from the device ID from the card network associated with the token.
605 606 607 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 605 def device_fingerprint @device_fingerprint end |
#network_data ⇒ Object (readonly)
Attribute for field network_data
607 608 609 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 607 def network_data @network_data end |
Class Method Details
.field_remappings ⇒ Object
613 614 615 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 613 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
609 610 611 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 609 def self.inner_class_types @inner_class_types = { network_data: NetworkData } end |