Class: Stripe::Issuing::Authorization::TokenDetails::NetworkData::Device
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::TokenDetails::NetworkData::Device
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ip_address ⇒ Object
readonly
The IP address of the device at provisioning time.
-
#language ⇒ Object
readonly
The ISO 639-1 language code of the device associated with the tokenization request.
-
#phone_number ⇒ Object
readonly
The phone number of the device used for tokenization.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ip_address ⇒ Object (readonly)
The IP address of the device at provisioning time.
389 390 391 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 389 def ip_address @ip_address end |
#language ⇒ Object (readonly)
The ISO 639-1 language code of the device associated with the tokenization request.
391 392 393 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 391 def language @language end |
#phone_number ⇒ Object (readonly)
The phone number of the device used for tokenization.
393 394 395 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 393 def phone_number @phone_number end |
Class Method Details
.field_remappings ⇒ Object
399 400 401 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 399 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
395 396 397 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 395 def self.inner_class_types @inner_class_types = {} end |