Class: Stripe::Issuing::Authorization::TokenDetails::NetworkData::Visa

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#card_reference_idObject (readonly)

A unique reference ID from the network to represent the card account number.



423
424
425
# File 'lib/stripe/resources/issuing/authorization.rb', line 423

def card_reference_id
  @card_reference_id
end

#token_reference_idObject (readonly)

The network-unique identifier for the token.



425
426
427
# File 'lib/stripe/resources/issuing/authorization.rb', line 425

def token_reference_id
  @token_reference_id
end

#token_requestor_idObject (readonly)

The ID of the entity requesting tokenization.



427
428
429
# File 'lib/stripe/resources/issuing/authorization.rb', line 427

def token_requestor_id
  @token_requestor_id
end

#token_risk_scoreObject (readonly)

Degree of risk associated with the token between ‘01` and `99`, with higher number indicating higher risk. A `00` value indicates the token was not scored by Visa.



429
430
431
# File 'lib/stripe/resources/issuing/authorization.rb', line 429

def token_risk_score
  @token_risk_score
end

Class Method Details

.field_remappingsObject



435
436
437
# File 'lib/stripe/resources/issuing/authorization.rb', line 435

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



431
432
433
# File 'lib/stripe/resources/issuing/authorization.rb', line 431

def self.inner_class_types
  @inner_class_types = {}
end