Class: Stripe::Issuing::Authorization::TokenDetails::NetworkData::WalletProvider
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::TokenDetails::NetworkData::WalletProvider
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_trust_score ⇒ Object
readonly
An evaluation on the trustworthiness of the wallet account between 1 and 5.
-
#card_number_source ⇒ Object
readonly
The method used for tokenizing a card.
-
#device_trust_score ⇒ Object
readonly
An evaluation on the trustworthiness of the device.
-
#reason_codes ⇒ Object
readonly
The reasons for suggested tokenization given by the card network.
-
#suggested_decision ⇒ Object
readonly
The recommendation on responding to the tokenization request.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_trust_score ⇒ Object (readonly)
An evaluation on the trustworthiness of the wallet account between 1 and 5. A higher score indicates more trustworthy.
442 443 444 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 442 def account_trust_score @account_trust_score end |
#card_number_source ⇒ Object (readonly)
The method used for tokenizing a card.
444 445 446 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 444 def card_number_source @card_number_source end |
#device_trust_score ⇒ Object (readonly)
An evaluation on the trustworthiness of the device. A higher score indicates more trustworthy.
446 447 448 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 446 def device_trust_score @device_trust_score end |
#reason_codes ⇒ Object (readonly)
The reasons for suggested tokenization given by the card network.
448 449 450 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 448 def reason_codes @reason_codes end |
#suggested_decision ⇒ Object (readonly)
The recommendation on responding to the tokenization request.
450 451 452 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 450 def suggested_decision @suggested_decision end |
Class Method Details
.field_remappings ⇒ Object
456 457 458 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 456 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
452 453 454 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 452 def self.inner_class_types @inner_class_types = {} end |