Class: Stripe::Issuing::Authorization::VerificationData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#address_line1_checkObject (readonly)

Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.



424
425
426
# File 'lib/stripe/resources/issuing/authorization.rb', line 424

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject (readonly)

Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.



426
427
428
# File 'lib/stripe/resources/issuing/authorization.rb', line 426

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject (readonly)

The exemption applied to this authorization.



428
429
430
# File 'lib/stripe/resources/issuing/authorization.rb', line 428

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject (readonly)

Whether the cardholder provided a CVC and if it matched Stripe’s record.



430
431
432
# File 'lib/stripe/resources/issuing/authorization.rb', line 430

def cvc_check
  @cvc_check
end

#expiry_checkObject (readonly)

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



432
433
434
# File 'lib/stripe/resources/issuing/authorization.rb', line 432

def expiry_check
  @expiry_check
end

#postal_codeObject (readonly)

The postal code submitted as part of the authorization used for postal code verification.



434
435
436
# File 'lib/stripe/resources/issuing/authorization.rb', line 434

def postal_code
  @postal_code
end

#three_d_secureObject (readonly)

3D Secure details.



436
437
438
# File 'lib/stripe/resources/issuing/authorization.rb', line 436

def three_d_secure
  @three_d_secure
end

Class Method Details

.field_remappingsObject



445
446
447
# File 'lib/stripe/resources/issuing/authorization.rb', line 445

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



438
439
440
441
442
443
# File 'lib/stripe/resources/issuing/authorization.rb', line 438

def self.inner_class_types
  @inner_class_types = {
    authentication_exemption: AuthenticationExemption,
    three_d_secure: ThreeDSecure,
  }
end