Class: Stripe::Issuing::Authorization::VerificationData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#address_line1_checkObject (readonly)

Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.



647
648
649
# File 'lib/stripe/resources/issuing/authorization.rb', line 647

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject (readonly)

Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.



649
650
651
# File 'lib/stripe/resources/issuing/authorization.rb', line 649

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject (readonly)

The exemption applied to this authorization.



651
652
653
# File 'lib/stripe/resources/issuing/authorization.rb', line 651

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject (readonly)

Whether the cardholder provided a CVC and if it matched Stripe’s record.



653
654
655
# File 'lib/stripe/resources/issuing/authorization.rb', line 653

def cvc_check
  @cvc_check
end

#expiry_checkObject (readonly)

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



655
656
657
# File 'lib/stripe/resources/issuing/authorization.rb', line 655

def expiry_check
  @expiry_check
end

#postal_codeObject (readonly)

The postal code submitted as part of the authorization used for postal code verification.



657
658
659
# File 'lib/stripe/resources/issuing/authorization.rb', line 657

def postal_code
  @postal_code
end

#three_d_secureObject (readonly)

3D Secure details.



659
660
661
# File 'lib/stripe/resources/issuing/authorization.rb', line 659

def three_d_secure
  @three_d_secure
end

Class Method Details

.field_remappingsObject



668
669
670
# File 'lib/stripe/resources/issuing/authorization.rb', line 668

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



661
662
663
664
665
666
# File 'lib/stripe/resources/issuing/authorization.rb', line 661

def self.inner_class_types
  @inner_class_types = {
    authentication_exemption: AuthenticationExemption,
    three_d_secure: ThreeDSecure,
  }
end