Class: Stripe::Issuing::Authorization::VerificationData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::VerificationData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AuthenticationExemption, ThreeDSecure
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address_line1_check ⇒ Object
readonly
Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.
-
#address_postal_code_check ⇒ Object
readonly
Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.
-
#authentication_exemption ⇒ Object
readonly
The exemption applied to this authorization.
-
#cvc_check ⇒ Object
readonly
Whether the cardholder provided a CVC and if it matched Stripe’s record.
-
#expiry_check ⇒ Object
readonly
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
-
#postal_code ⇒ Object
readonly
The postal code submitted as part of the authorization used for postal code verification.
-
#three_d_secure ⇒ Object
readonly
3D Secure details.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address_line1_check ⇒ Object (readonly)
Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.
411 412 413 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 411 def address_line1_check @address_line1_check end |
#address_postal_code_check ⇒ Object (readonly)
Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.
413 414 415 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 413 def address_postal_code_check @address_postal_code_check end |
#authentication_exemption ⇒ Object (readonly)
The exemption applied to this authorization.
415 416 417 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 415 def authentication_exemption @authentication_exemption end |
#cvc_check ⇒ Object (readonly)
Whether the cardholder provided a CVC and if it matched Stripe’s record.
417 418 419 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 417 def cvc_check @cvc_check end |
#expiry_check ⇒ Object (readonly)
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
419 420 421 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 419 def expiry_check @expiry_check end |
#postal_code ⇒ Object (readonly)
The postal code submitted as part of the authorization used for postal code verification.
421 422 423 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 421 def postal_code @postal_code end |
#three_d_secure ⇒ Object (readonly)
3D Secure details.
423 424 425 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 423 def three_d_secure @three_d_secure end |
Class Method Details
.field_remappings ⇒ Object
432 433 434 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 432 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
425 426 427 428 429 430 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 425 def self.inner_class_types @inner_class_types = { authentication_exemption: AuthenticationExemption, three_d_secure: ThreeDSecure, } end |