Class: Stripe::Issuing::Authorization::VerificationData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#address_line1_checkObject (readonly)

Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.



528
529
530
# File 'lib/stripe/resources/issuing/authorization.rb', line 528

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject (readonly)

Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.



530
531
532
# File 'lib/stripe/resources/issuing/authorization.rb', line 530

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject (readonly)

The exemption applied to this authorization.



532
533
534
# File 'lib/stripe/resources/issuing/authorization.rb', line 532

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject (readonly)

Whether the cardholder provided a CVC and if it matched Stripe’s record.



534
535
536
# File 'lib/stripe/resources/issuing/authorization.rb', line 534

def cvc_check
  @cvc_check
end

#expiry_checkObject (readonly)

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



536
537
538
# File 'lib/stripe/resources/issuing/authorization.rb', line 536

def expiry_check
  @expiry_check
end

#postal_codeObject (readonly)

The postal code submitted as part of the authorization used for postal code verification.



538
539
540
# File 'lib/stripe/resources/issuing/authorization.rb', line 538

def postal_code
  @postal_code
end

#three_d_secureObject (readonly)

3D Secure details.



540
541
542
# File 'lib/stripe/resources/issuing/authorization.rb', line 540

def three_d_secure
  @three_d_secure
end

Class Method Details

.field_remappingsObject



549
550
551
# File 'lib/stripe/resources/issuing/authorization.rb', line 549

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



542
543
544
545
546
547
# File 'lib/stripe/resources/issuing/authorization.rb', line 542

def self.inner_class_types
  @inner_class_types = {
    authentication_exemption: AuthenticationExemption,
    three_d_secure: ThreeDSecure,
  }
end