Class: Stripe::Issuing::Authorization::VerificationData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/authorization.rb

Defined Under Namespace

Classes: AuthenticationExemption, ThreeDSecure

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#address_line1_checkObject (readonly)

Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.



212
213
214
# File 'lib/stripe/resources/issuing/authorization.rb', line 212

def address_line1_check
  @address_line1_check
end

#address_postal_code_checkObject (readonly)

Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.



214
215
216
# File 'lib/stripe/resources/issuing/authorization.rb', line 214

def address_postal_code_check
  @address_postal_code_check
end

#authentication_exemptionObject (readonly)

The exemption applied to this authorization.



216
217
218
# File 'lib/stripe/resources/issuing/authorization.rb', line 216

def authentication_exemption
  @authentication_exemption
end

#cvc_checkObject (readonly)

Whether the cardholder provided a CVC and if it matched Stripe’s record.



218
219
220
# File 'lib/stripe/resources/issuing/authorization.rb', line 218

def cvc_check
  @cvc_check
end

#expiry_checkObject (readonly)

Whether the cardholder provided an expiry date and if it matched Stripe’s record.



220
221
222
# File 'lib/stripe/resources/issuing/authorization.rb', line 220

def expiry_check
  @expiry_check
end

#postal_codeObject (readonly)

The postal code submitted as part of the authorization used for postal code verification.



222
223
224
# File 'lib/stripe/resources/issuing/authorization.rb', line 222

def postal_code
  @postal_code
end

#three_d_secureObject (readonly)

3D Secure details.



224
225
226
# File 'lib/stripe/resources/issuing/authorization.rb', line 224

def three_d_secure
  @three_d_secure
end