Class: Stripe::Issuing::Authorization::VerificationData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Authorization::VerificationData
- Defined in:
- lib/stripe/resources/issuing/authorization.rb
Defined Under Namespace
Classes: AuthenticationExemption, ThreeDSecure
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address_line1_check ⇒ Object
readonly
Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.
-
#address_postal_code_check ⇒ Object
readonly
Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.
-
#authentication_exemption ⇒ Object
readonly
The exemption applied to this authorization.
-
#cvc_check ⇒ Object
readonly
Whether the cardholder provided a CVC and if it matched Stripe’s record.
-
#expiry_check ⇒ Object
readonly
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
-
#postal_code ⇒ Object
readonly
The postal code submitted as part of the authorization used for postal code verification.
-
#three_d_secure ⇒ Object
readonly
3D Secure details.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address_line1_check ⇒ Object (readonly)
Whether the cardholder provided an address first line and if it matched the cardholder’s ‘billing.address.line1`.
264 265 266 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 264 def address_line1_check @address_line1_check end |
#address_postal_code_check ⇒ Object (readonly)
Whether the cardholder provided a postal code and if it matched the cardholder’s ‘billing.address.postal_code`.
267 268 269 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 267 def address_postal_code_check @address_postal_code_check end |
#authentication_exemption ⇒ Object (readonly)
The exemption applied to this authorization.
270 271 272 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 270 def authentication_exemption @authentication_exemption end |
#cvc_check ⇒ Object (readonly)
Whether the cardholder provided a CVC and if it matched Stripe’s record.
273 274 275 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 273 def cvc_check @cvc_check end |
#expiry_check ⇒ Object (readonly)
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
276 277 278 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 276 def expiry_check @expiry_check end |
#postal_code ⇒ Object (readonly)
The postal code submitted as part of the authorization used for postal code verification.
279 280 281 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 279 def postal_code @postal_code end |
#three_d_secure ⇒ Object (readonly)
3D Secure details.
282 283 284 |
# File 'lib/stripe/resources/issuing/authorization.rb', line 282 def three_d_secure @three_d_secure end |