Class: Stripe::Issuing::AuthorizationCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::AuthorizationCreateParams
- Defined in:
- lib/stripe/params/issuing/authorization_create_params.rb
Defined Under Namespace
Classes: AmountDetails, Fleet, Fuel, Healthcare, MerchantData, NetworkData, RiskAssessment, VerificationData
Instance Attribute Summary collapse
-
#amount ⇒ Object
The total amount to attempt to authorize.
-
#amount_details ⇒ Object
Detailed breakdown of amount components.
-
#authorization_method ⇒ Object
How the card details were provided.
-
#card ⇒ Object
Card associated with this authorization.
-
#currency ⇒ Object
The currency of the authorization.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
-
#fraud_disputability_likelihood ⇒ Object
Probability that this transaction can be disputed in the event of fraud.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#healthcare ⇒ Object
Healthcare-specific information for IIAS-eligible authorizations.
-
#is_amount_controllable ⇒ Object
If set
true, you may provide amount to control how much to hold for the authorization. -
#merchant_amount ⇒ Object
The total amount to attempt to authorize.
-
#merchant_currency ⇒ Object
The currency of the authorization.
-
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
-
#network_data ⇒ Object
Details about the authorization, such as identifiers, set by the card network.
-
#risk_assessment ⇒ Object
Stripe’s assessment of the fraud risk for this authorization.
-
#verification_data ⇒ Object
Verifications that Stripe performed on information that the cardholder provided to the merchant.
-
#wallet ⇒ Object
The digital wallet used for this transaction.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fraud_disputability_likelihood: nil, fuel: nil, healthcare: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, risk_assessment: nil, verification_data: nil, wallet: nil) ⇒ AuthorizationCreateParams
constructor
A new instance of AuthorizationCreateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fraud_disputability_likelihood: nil, fuel: nil, healthcare: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, risk_assessment: nil, verification_data: nil, wallet: nil) ⇒ AuthorizationCreateParams
Returns a new instance of AuthorizationCreateParams.
434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 434 def initialize( amount: nil, amount_details: nil, authorization_method: nil, card: nil, currency: nil, expand: nil, fleet: nil, fraud_disputability_likelihood: nil, fuel: nil, healthcare: nil, is_amount_controllable: nil, merchant_amount: nil, merchant_currency: nil, merchant_data: nil, network_data: nil, risk_assessment: nil, verification_data: nil, wallet: nil ) @amount = amount @amount_details = amount_details @authorization_method = @card = card @currency = currency @expand = @fleet = fleet @fraud_disputability_likelihood = fraud_disputability_likelihood @fuel = fuel @healthcare = healthcare @is_amount_controllable = is_amount_controllable @merchant_amount = merchant_amount @merchant_currency = merchant_currency @merchant_data = merchant_data @network_data = network_data @risk_assessment = risk_assessment @verification_data = verification_data @wallet = wallet end |
Instance Attribute Details
#amount ⇒ Object
The total amount to attempt to authorize. This amount is in the provided currency, or defaults to the card's currency, and in the smallest currency unit.
398 399 400 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 398 def amount @amount end |
#amount_details ⇒ Object
Detailed breakdown of amount components. These amounts are denominated in currency and in the smallest currency unit.
400 401 402 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 400 def amount_details @amount_details end |
#authorization_method ⇒ Object
How the card details were provided. Defaults to online.
402 403 404 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 402 def @authorization_method end |
#card ⇒ Object
Card associated with this authorization.
404 405 406 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 404 def card @card end |
#currency ⇒ Object
The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.
406 407 408 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 406 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
408 409 410 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 408 def @expand end |
#fleet ⇒ Object
Fleet-specific information for authorizations using Fleet cards.
410 411 412 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 410 def fleet @fleet end |
#fraud_disputability_likelihood ⇒ Object
Probability that this transaction can be disputed in the event of fraud. Assessed by comparing the characteristics of the authorization to card network rules.
412 413 414 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 412 def fraud_disputability_likelihood @fraud_disputability_likelihood end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
414 415 416 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 414 def fuel @fuel end |
#healthcare ⇒ Object
Healthcare-specific information for IIAS-eligible authorizations.
416 417 418 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 416 def healthcare @healthcare end |
#is_amount_controllable ⇒ Object
If set true, you may provide amount to control how much to hold for the authorization.
418 419 420 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 418 def is_amount_controllable @is_amount_controllable end |
#merchant_amount ⇒ Object
The total amount to attempt to authorize. This amount is in the provided merchant currency, and in the smallest currency unit.
420 421 422 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 420 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object
The currency of the authorization. If not provided, defaults to the currency of the card. Three-letter ISO currency code, in lowercase. Must be a supported currency.
422 423 424 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 422 def merchant_currency @merchant_currency end |
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
424 425 426 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 424 def merchant_data @merchant_data end |
#network_data ⇒ Object
Details about the authorization, such as identifiers, set by the card network.
426 427 428 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 426 def network_data @network_data end |
#risk_assessment ⇒ Object
Stripe’s assessment of the fraud risk for this authorization.
428 429 430 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 428 def risk_assessment @risk_assessment end |
#verification_data ⇒ Object
Verifications that Stripe performed on information that the cardholder provided to the merchant.
430 431 432 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 430 def verification_data @verification_data end |
#wallet ⇒ Object
The digital wallet used for this transaction. One of apple_pay, google_pay, or samsung_pay. Will populate as null when no digital wallet was utilized.
432 433 434 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 432 def wallet @wallet end |
Class Method Details
.field_encodings ⇒ Object
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 474 def self.field_encodings @field_encodings = { fleet: { kind: :object, fields: { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, }, }, fuel: { kind: :object, fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }, }, } end |