Class: Stripe::Issuing::AuthorizationCreateParams::MerchantData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::AuthorizationCreateParams::MerchantData
- Defined in:
- lib/stripe/params/issuing/authorization_create_params.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
A categorization of the seller’s type of business.
-
#city ⇒ Object
City where the seller is located.
-
#country ⇒ Object
Country where the seller is located.
-
#name ⇒ Object
Name of the seller.
-
#network_id ⇒ Object
Identifier assigned to the seller by the card network.
-
#payment_facilitator_id ⇒ Object
The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network.
-
#postal_code ⇒ Object
Postal code where the seller is located.
-
#state ⇒ Object
State where the seller is located.
-
#sub_merchant_id ⇒ Object
The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator.
-
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
-
#url ⇒ Object
URL provided by the merchant on a 3DS request.
Instance Method Summary collapse
-
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, payment_facilitator_id: nil, postal_code: nil, state: nil, sub_merchant_id: nil, terminal_id: nil, url: nil) ⇒ MerchantData
constructor
A new instance of MerchantData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, payment_facilitator_id: nil, postal_code: nil, state: nil, sub_merchant_id: nil, terminal_id: nil, url: nil) ⇒ MerchantData
Returns a new instance of MerchantData.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 215 def initialize( category: nil, city: nil, country: nil, name: nil, network_id: nil, payment_facilitator_id: nil, postal_code: nil, state: nil, sub_merchant_id: nil, terminal_id: nil, url: nil ) @category = category @city = city @country = country @name = name @network_id = network_id @payment_facilitator_id = payment_facilitator_id @postal_code = postal_code @state = state @sub_merchant_id = sub_merchant_id @terminal_id = terminal_id @url = url end |
Instance Attribute Details
#category ⇒ Object
A categorization of the seller’s type of business. See our [merchant categories guide](docs.stripe.com/issuing/merchant-categories) for a list of possible values.
193 194 195 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 193 def category @category end |
#city ⇒ Object
City where the seller is located
195 196 197 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 195 def city @city end |
#country ⇒ Object
Country where the seller is located
197 198 199 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 197 def country @country end |
#name ⇒ Object
Name of the seller
199 200 201 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 199 def name @name end |
#network_id ⇒ Object
Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
201 202 203 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 201 def network_id @network_id end |
#payment_facilitator_id ⇒ Object
The identifier of the payment facilitator (PayFac) that processed this authorization, as assigned by the card network.
203 204 205 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 203 def payment_facilitator_id @payment_facilitator_id end |
#postal_code ⇒ Object
Postal code where the seller is located
205 206 207 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 205 def postal_code @postal_code end |
#state ⇒ Object
State where the seller is located
207 208 209 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 207 def state @state end |
#sub_merchant_id ⇒ Object
The identifier of the sub-merchant involved in this authorization, as assigned by the payment facilitator.
209 210 211 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 209 def sub_merchant_id @sub_merchant_id end |
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
211 212 213 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 211 def terminal_id @terminal_id end |
#url ⇒ Object
URL provided by the merchant on a 3DS request
213 214 215 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 213 def url @url end |