Class: Stripe::Issuing::AuthorizationCreateParams::VerificationData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::AuthorizationCreateParams::VerificationData
- Defined in:
- lib/stripe/params/issuing/authorization_create_params.rb
Defined Under Namespace
Classes: AuthenticationExemption, ThreeDSecure
Instance Attribute Summary collapse
-
#address_line1_check ⇒ Object
Whether the cardholder provided an address first line and if it matched the cardholder’s
billing.address.line1. -
#address_postal_code_check ⇒ Object
Whether the cardholder provided a postal code and if it matched the cardholder’s
billing.address.postal_code. -
#authentication_exemption ⇒ Object
The exemption applied to this authorization.
-
#cvc_check ⇒ Object
Whether the cardholder provided a CVC and if it matched Stripe’s record.
-
#expiry_check ⇒ Object
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
-
#three_d_secure ⇒ Object
3D Secure details.
Instance Method Summary collapse
-
#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData
constructor
A new instance of VerificationData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil) ⇒ VerificationData
Returns a new instance of VerificationData.
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 334 def initialize( address_line1_check: nil, address_postal_code_check: nil, authentication_exemption: nil, cvc_check: nil, expiry_check: nil, three_d_secure: nil ) @address_line1_check = address_line1_check @address_postal_code_check = address_postal_code_check @authentication_exemption = authentication_exemption @cvc_check = cvc_check @expiry_check = expiry_check @three_d_secure = three_d_secure end |
Instance Attribute Details
#address_line1_check ⇒ Object
Whether the cardholder provided an address first line and if it matched the cardholder’s billing.address.line1.
322 323 324 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 322 def address_line1_check @address_line1_check end |
#address_postal_code_check ⇒ Object
Whether the cardholder provided a postal code and if it matched the cardholder’s billing.address.postal_code.
324 325 326 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 324 def address_postal_code_check @address_postal_code_check end |
#authentication_exemption ⇒ Object
The exemption applied to this authorization.
326 327 328 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 326 def authentication_exemption @authentication_exemption end |
#cvc_check ⇒ Object
Whether the cardholder provided a CVC and if it matched Stripe’s record.
328 329 330 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 328 def cvc_check @cvc_check end |
#expiry_check ⇒ Object
Whether the cardholder provided an expiry date and if it matched Stripe’s record.
330 331 332 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 330 def expiry_check @expiry_check end |
#three_d_secure ⇒ Object
3D Secure details.
332 333 334 |
# File 'lib/stripe/params/issuing/authorization_create_params.rb', line 332 def three_d_secure @three_d_secure end |