Class: Stripe::Issuing::Card

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/card.rb

Overview

You can [create physical or virtual cards](docs.stripe.com/issuing) that are issued to cardholders.

Defined Under Namespace

Classes: LatestFraudWarning, LifecycleControls, Redaction, Shipping, SpendingControls, TestHelpers, Wallets

Constant Summary collapse

OBJECT_NAME =
"issuing.card"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

The brand of the card.



274
275
276
# File 'lib/stripe/resources/issuing/card.rb', line 274

def brand
  @brand
end

#cancellation_reasonObject (readonly)

The reason why the card was canceled.



276
277
278
# File 'lib/stripe/resources/issuing/card.rb', line 276

def cancellation_reason
  @cancellation_reason
end

#cardholderObject (readonly)

An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](docs.stripe.com/issuing) cards.

Related guide: [How to create a cardholder](docs.stripe.com/issuing/cards/virtual/issue-cards#create-cardholder)



280
281
282
# File 'lib/stripe/resources/issuing/card.rb', line 280

def cardholder
  @cardholder
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



282
283
284
# File 'lib/stripe/resources/issuing/card.rb', line 282

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Supported currencies are ‘usd` in the US, `eur` in the EU, and `gbp` in the UK.



284
285
286
# File 'lib/stripe/resources/issuing/card.rb', line 284

def currency
  @currency
end

#cvcObject (readonly)

The card’s CVC. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with [the ‘expand` parameter](docs.stripe.com/api/expanding_objects). Additionally, it’s only available via the [“Retrieve a card” endpoint](docs.stripe.com/api/issuing/cards/retrieve), not via “List all cards” or any other endpoint.



286
287
288
# File 'lib/stripe/resources/issuing/card.rb', line 286

def cvc
  @cvc
end

#exp_monthObject (readonly)

The expiration month of the card.



288
289
290
# File 'lib/stripe/resources/issuing/card.rb', line 288

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the card.



290
291
292
# File 'lib/stripe/resources/issuing/card.rb', line 290

def exp_year
  @exp_year
end

#financial_accountObject (readonly)

The financial account this card is attached to.



292
293
294
# File 'lib/stripe/resources/issuing/card.rb', line 292

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the object.



294
295
296
# File 'lib/stripe/resources/issuing/card.rb', line 294

def id
  @id
end

#last4Object (readonly)

The last 4 digits of the card number.



296
297
298
# File 'lib/stripe/resources/issuing/card.rb', line 296

def last4
  @last4
end

#latest_fraud_warningObject (readonly)

Stripe’s assessment of whether this card’s details have been compromised. If this property isn’t null, cancel and reissue the card to prevent fraudulent activity risk.



298
299
300
# File 'lib/stripe/resources/issuing/card.rb', line 298

def latest_fraud_warning
  @latest_fraud_warning
end

#lifecycle_controlsObject (readonly)

Rules that control the lifecycle of this card, such as automatic cancellation. Refer to our [documentation](/issuing/controls/lifecycle-controls) for more details.



300
301
302
# File 'lib/stripe/resources/issuing/card.rb', line 300

def lifecycle_controls
  @lifecycle_controls
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



302
303
304
# File 'lib/stripe/resources/issuing/card.rb', line 302

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



304
305
306
# File 'lib/stripe/resources/issuing/card.rb', line 304

def 
  @metadata
end

#numberObject (readonly)

The full unredacted card number. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with [the ‘expand` parameter](docs.stripe.com/api/expanding_objects). Additionally, it’s only available via the [“Retrieve a card” endpoint](docs.stripe.com/api/issuing/cards/retrieve), not via “List all cards” or any other endpoint.



306
307
308
# File 'lib/stripe/resources/issuing/card.rb', line 306

def number
  @number
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



308
309
310
# File 'lib/stripe/resources/issuing/card.rb', line 308

def object
  @object
end

#personalization_designObject (readonly)

The personalization design object belonging to this card.



310
311
312
# File 'lib/stripe/resources/issuing/card.rb', line 310

def personalization_design
  @personalization_design
end

#redactionObject (readonly)

Redaction status of this card. If not null, this card is associated to a redaction job.



312
313
314
# File 'lib/stripe/resources/issuing/card.rb', line 312

def redaction
  @redaction
end

#replaced_byObject (readonly)

The latest card that replaces this card, if any.



314
315
316
# File 'lib/stripe/resources/issuing/card.rb', line 314

def replaced_by
  @replaced_by
end

#replacement_forObject (readonly)

The card this card replaces, if any.



316
317
318
# File 'lib/stripe/resources/issuing/card.rb', line 316

def replacement_for
  @replacement_for
end

#replacement_reasonObject (readonly)

The reason why the previous card needed to be replaced.



318
319
320
# File 'lib/stripe/resources/issuing/card.rb', line 318

def replacement_reason
  @replacement_reason
end

#second_lineObject (readonly)

Text separate from cardholder name, printed on the card.



320
321
322
# File 'lib/stripe/resources/issuing/card.rb', line 320

def second_line
  @second_line
end

#shippingObject (readonly)

Where and how the card will be shipped.



322
323
324
# File 'lib/stripe/resources/issuing/card.rb', line 322

def shipping
  @shipping
end

#spending_controlsObject (readonly)

Attribute for field spending_controls



324
325
326
# File 'lib/stripe/resources/issuing/card.rb', line 324

def spending_controls
  @spending_controls
end

#statusObject (readonly)

Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.



326
327
328
# File 'lib/stripe/resources/issuing/card.rb', line 326

def status
  @status
end

#typeObject (readonly)

The type of the card.



328
329
330
# File 'lib/stripe/resources/issuing/card.rb', line 328

def type
  @type
end

#walletsObject (readonly)

Information relating to digital wallets (like Apple Pay and Google Pay).



330
331
332
# File 'lib/stripe/resources/issuing/card.rb', line 330

def wallets
  @wallets
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates an Issuing Card object.



333
334
335
# File 'lib/stripe/resources/issuing/card.rb', line 333

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/issuing/cards", params: params, opts: opts)
end

.field_remappingsObject



474
475
476
# File 'lib/stripe/resources/issuing/card.rb', line 474

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



463
464
465
466
467
468
469
470
471
472
# File 'lib/stripe/resources/issuing/card.rb', line 463

def self.inner_class_types
  @inner_class_types = {
    latest_fraud_warning: LatestFraudWarning,
    lifecycle_controls: LifecycleControls,
    redaction: Redaction,
    shipping: Shipping,
    spending_controls: SpendingControls,
    wallets: Wallets,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Card objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



338
339
340
# File 'lib/stripe/resources/issuing/card.rb', line 338

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/issuing/cards", params: params, opts: opts)
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/issuing/card.rb', line 13

def self.object_name
  "issuing.card"
end

.update(card, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Card object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



343
344
345
346
347
348
349
350
# File 'lib/stripe/resources/issuing/card.rb', line 343

def self.update(card, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/cards/%<card>s", { card: CGI.escape(card) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#test_helpersObject



352
353
354
# File 'lib/stripe/resources/issuing/card.rb', line 352

def test_helpers
  TestHelpers.new(self)
end