Class: Stripe::Issuing::Card

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/card.rb

Overview

You can [create physical or virtual cards](docs.stripe.com/issuing) that are issued to cardholders.

Defined Under Namespace

Classes: LatestFraudWarning, LifecycleControls, Shipping, SpendingControls, TestHelpers, Wallets

Constant Summary collapse

OBJECT_NAME =
"issuing.card"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

The brand of the card.



265
266
267
# File 'lib/stripe/resources/issuing/card.rb', line 265

def brand
  @brand
end

#cancellation_reasonObject (readonly)

The reason why the card was canceled.



267
268
269
# File 'lib/stripe/resources/issuing/card.rb', line 267

def cancellation_reason
  @cancellation_reason
end

#cardholderObject (readonly)

An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](docs.stripe.com/issuing) cards.

Related guide: [How to create a cardholder](docs.stripe.com/issuing/cards/virtual/issue-cards#create-cardholder)



271
272
273
# File 'lib/stripe/resources/issuing/card.rb', line 271

def cardholder
  @cardholder
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



273
274
275
# File 'lib/stripe/resources/issuing/card.rb', line 273

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Supported currencies are ‘usd` in the US, `eur` in the EU, and `gbp` in the UK.



275
276
277
# File 'lib/stripe/resources/issuing/card.rb', line 275

def currency
  @currency
end

#cvcObject (readonly)

The card’s CVC. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with [the ‘expand` parameter](docs.stripe.com/api/expanding_objects). Additionally, it’s only available via the [“Retrieve a card” endpoint](docs.stripe.com/api/issuing/cards/retrieve), not via “List all cards” or any other endpoint.



277
278
279
# File 'lib/stripe/resources/issuing/card.rb', line 277

def cvc
  @cvc
end

#exp_monthObject (readonly)

The expiration month of the card.



279
280
281
# File 'lib/stripe/resources/issuing/card.rb', line 279

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the card.



281
282
283
# File 'lib/stripe/resources/issuing/card.rb', line 281

def exp_year
  @exp_year
end

#financial_accountObject (readonly)

The financial account this card is attached to.



283
284
285
# File 'lib/stripe/resources/issuing/card.rb', line 283

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the object.



285
286
287
# File 'lib/stripe/resources/issuing/card.rb', line 285

def id
  @id
end

#last4Object (readonly)

The last 4 digits of the card number.



287
288
289
# File 'lib/stripe/resources/issuing/card.rb', line 287

def last4
  @last4
end

#latest_fraud_warningObject (readonly)

Stripe’s assessment of whether this card’s details have been compromised. If this property isn’t null, cancel and reissue the card to prevent fraudulent activity risk.



289
290
291
# File 'lib/stripe/resources/issuing/card.rb', line 289

def latest_fraud_warning
  @latest_fraud_warning
end

#lifecycle_controlsObject (readonly)

Rules that control the lifecycle of this card, such as automatic cancellation. Refer to our [documentation](/issuing/controls/lifecycle-controls) for more details.



291
292
293
# File 'lib/stripe/resources/issuing/card.rb', line 291

def lifecycle_controls
  @lifecycle_controls
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



293
294
295
# File 'lib/stripe/resources/issuing/card.rb', line 293

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



295
296
297
# File 'lib/stripe/resources/issuing/card.rb', line 295

def 
  @metadata
end

#numberObject (readonly)

The full unredacted card number. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with [the ‘expand` parameter](docs.stripe.com/api/expanding_objects). Additionally, it’s only available via the [“Retrieve a card” endpoint](docs.stripe.com/api/issuing/cards/retrieve), not via “List all cards” or any other endpoint.



297
298
299
# File 'lib/stripe/resources/issuing/card.rb', line 297

def number
  @number
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



299
300
301
# File 'lib/stripe/resources/issuing/card.rb', line 299

def object
  @object
end

#personalization_designObject (readonly)

The personalization design object belonging to this card.



301
302
303
# File 'lib/stripe/resources/issuing/card.rb', line 301

def personalization_design
  @personalization_design
end

#replaced_byObject (readonly)

The latest card that replaces this card, if any.



303
304
305
# File 'lib/stripe/resources/issuing/card.rb', line 303

def replaced_by
  @replaced_by
end

#replacement_forObject (readonly)

The card this card replaces, if any.



305
306
307
# File 'lib/stripe/resources/issuing/card.rb', line 305

def replacement_for
  @replacement_for
end

#replacement_reasonObject (readonly)

The reason why the previous card needed to be replaced.



307
308
309
# File 'lib/stripe/resources/issuing/card.rb', line 307

def replacement_reason
  @replacement_reason
end

#second_lineObject (readonly)

Text separate from cardholder name, printed on the card.



309
310
311
# File 'lib/stripe/resources/issuing/card.rb', line 309

def second_line
  @second_line
end

#shippingObject (readonly)

Where and how the card will be shipped.



311
312
313
# File 'lib/stripe/resources/issuing/card.rb', line 311

def shipping
  @shipping
end

#spending_controlsObject (readonly)

Attribute for field spending_controls



313
314
315
# File 'lib/stripe/resources/issuing/card.rb', line 313

def spending_controls
  @spending_controls
end

#statusObject (readonly)

Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.



315
316
317
# File 'lib/stripe/resources/issuing/card.rb', line 315

def status
  @status
end

#typeObject (readonly)

The type of the card.



317
318
319
# File 'lib/stripe/resources/issuing/card.rb', line 317

def type
  @type
end

#walletsObject (readonly)

Information relating to digital wallets (like Apple Pay and Google Pay).



319
320
321
# File 'lib/stripe/resources/issuing/card.rb', line 319

def wallets
  @wallets
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates an Issuing Card object.



322
323
324
# File 'lib/stripe/resources/issuing/card.rb', line 322

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/issuing/cards", params: params, opts: opts)
end

.field_remappingsObject



462
463
464
# File 'lib/stripe/resources/issuing/card.rb', line 462

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



452
453
454
455
456
457
458
459
460
# File 'lib/stripe/resources/issuing/card.rb', line 452

def self.inner_class_types
  @inner_class_types = {
    latest_fraud_warning: LatestFraudWarning,
    lifecycle_controls: LifecycleControls,
    shipping: Shipping,
    spending_controls: SpendingControls,
    wallets: Wallets,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Card objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



327
328
329
# File 'lib/stripe/resources/issuing/card.rb', line 327

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/issuing/cards", params: params, opts: opts)
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/issuing/card.rb', line 13

def self.object_name
  "issuing.card"
end

.update(card, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Card object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



332
333
334
335
336
337
338
339
# File 'lib/stripe/resources/issuing/card.rb', line 332

def self.update(card, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/cards/%<card>s", { card: CGI.escape(card) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#test_helpersObject



341
342
343
# File 'lib/stripe/resources/issuing/card.rb', line 341

def test_helpers
  TestHelpers.new(self)
end