Class: Stripe::Issuing::Card

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/card.rb

Overview

You can [create physical or virtual cards](stripe.com/docs/issuing) that are issued to cardholders.

Defined Under Namespace

Classes: CreateParams, DeliverCardParams, FailCardParams, ListParams, RetrieveParams, ReturnCardParams, ShipCardParams, Shipping, SpendingControls, SubmitCardParams, TestHelpers, UpdateParams, Wallets

Constant Summary collapse

OBJECT_NAME =
"issuing.card"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

The brand of the card.



633
634
635
# File 'lib/stripe/resources/issuing/card.rb', line 633

def brand
  @brand
end

#cancellation_reasonObject (readonly)

The reason why the card was canceled.



635
636
637
# File 'lib/stripe/resources/issuing/card.rb', line 635

def cancellation_reason
  @cancellation_reason
end

#cardholderObject (readonly)

An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](stripe.com/docs/issuing) cards.

Related guide: [How to create a cardholder](stripe.com/docs/issuing/cards/virtual/issue-cards#create-cardholder)



639
640
641
# File 'lib/stripe/resources/issuing/card.rb', line 639

def cardholder
  @cardholder
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



641
642
643
# File 'lib/stripe/resources/issuing/card.rb', line 641

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Supported currencies are ‘usd` in the US, `eur` in the EU, and `gbp` in the UK.



643
644
645
# File 'lib/stripe/resources/issuing/card.rb', line 643

def currency
  @currency
end

#cvcObject (readonly)

The card’s CVC. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with [the ‘expand` parameter](stripe.com/docs/api/expanding_objects). Additionally, it’s only available via the [“Retrieve a card” endpoint](stripe.com/docs/api/issuing/cards/retrieve), not via “List all cards” or any other endpoint.



645
646
647
# File 'lib/stripe/resources/issuing/card.rb', line 645

def cvc
  @cvc
end

#exp_monthObject (readonly)

The expiration month of the card.



647
648
649
# File 'lib/stripe/resources/issuing/card.rb', line 647

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the card.



649
650
651
# File 'lib/stripe/resources/issuing/card.rb', line 649

def exp_year
  @exp_year
end

#financial_accountObject (readonly)

The financial account this card is attached to.



651
652
653
# File 'lib/stripe/resources/issuing/card.rb', line 651

def 
  @financial_account
end

#idObject (readonly)

Unique identifier for the object.



653
654
655
# File 'lib/stripe/resources/issuing/card.rb', line 653

def id
  @id
end

#last4Object (readonly)

The last 4 digits of the card number.



655
656
657
# File 'lib/stripe/resources/issuing/card.rb', line 655

def last4
  @last4
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



657
658
659
# File 'lib/stripe/resources/issuing/card.rb', line 657

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



659
660
661
# File 'lib/stripe/resources/issuing/card.rb', line 659

def 
  @metadata
end

#numberObject (readonly)

The full unredacted card number. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with [the ‘expand` parameter](stripe.com/docs/api/expanding_objects). Additionally, it’s only available via the [“Retrieve a card” endpoint](stripe.com/docs/api/issuing/cards/retrieve), not via “List all cards” or any other endpoint.



661
662
663
# File 'lib/stripe/resources/issuing/card.rb', line 661

def number
  @number
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



663
664
665
# File 'lib/stripe/resources/issuing/card.rb', line 663

def object
  @object
end

#personalization_designObject (readonly)

The personalization design object belonging to this card.



665
666
667
# File 'lib/stripe/resources/issuing/card.rb', line 665

def personalization_design
  @personalization_design
end

#replaced_byObject (readonly)

The latest card that replaces this card, if any.



667
668
669
# File 'lib/stripe/resources/issuing/card.rb', line 667

def replaced_by
  @replaced_by
end

#replacement_forObject (readonly)

The card this card replaces, if any.



669
670
671
# File 'lib/stripe/resources/issuing/card.rb', line 669

def replacement_for
  @replacement_for
end

#replacement_reasonObject (readonly)

The reason why the previous card needed to be replaced.



671
672
673
# File 'lib/stripe/resources/issuing/card.rb', line 671

def replacement_reason
  @replacement_reason
end

#shippingObject (readonly)

Where and how the card will be shipped.



673
674
675
# File 'lib/stripe/resources/issuing/card.rb', line 673

def shipping
  @shipping
end

#spending_controlsObject (readonly)

Attribute for field spending_controls



675
676
677
# File 'lib/stripe/resources/issuing/card.rb', line 675

def spending_controls
  @spending_controls
end

#statusObject (readonly)

Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.



677
678
679
# File 'lib/stripe/resources/issuing/card.rb', line 677

def status
  @status
end

#typeObject (readonly)

The type of the card.



679
680
681
# File 'lib/stripe/resources/issuing/card.rb', line 679

def type
  @type
end

#walletsObject (readonly)

Information relating to digital wallets (like Apple Pay and Google Pay).



681
682
683
# File 'lib/stripe/resources/issuing/card.rb', line 681

def wallets
  @wallets
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates an Issuing Card object.



684
685
686
# File 'lib/stripe/resources/issuing/card.rb', line 684

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/issuing/cards", params: params, opts: opts)
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Card objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



689
690
691
# File 'lib/stripe/resources/issuing/card.rb', line 689

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/issuing/cards", params: params, opts: opts)
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/issuing/card.rb', line 13

def self.object_name
  "issuing.card"
end

.update(card, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Card object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



694
695
696
697
698
699
700
701
# File 'lib/stripe/resources/issuing/card.rb', line 694

def self.update(card, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/cards/%<card>s", { card: CGI.escape(card) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#test_helpersObject



703
704
705
# File 'lib/stripe/resources/issuing/card.rb', line 703

def test_helpers
  TestHelpers.new(self)
end