Class: Stripe::Issuing::Card
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Card
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/card.rb
Overview
You can [create physical or virtual cards](stripe.com/docs/issuing) that are issued to cardholders.
Defined Under Namespace
Classes: Shipping, SpendingControls, TestHelpers, Wallets
Constant Summary collapse
- OBJECT_NAME =
"issuing.card"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#brand ⇒ Object
readonly
The brand of the card.
-
#cancellation_reason ⇒ Object
readonly
The reason why the card was canceled.
-
#cardholder ⇒ Object
readonly
An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](stripe.com/docs/issuing) cards.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#cvc ⇒ Object
readonly
The card’s CVC.
-
#exp_month ⇒ Object
readonly
The expiration month of the card.
-
#exp_year ⇒ Object
readonly
The expiration year of the card.
-
#financial_account ⇒ Object
readonly
The financial account this card is attached to.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last4 ⇒ Object
readonly
The last 4 digits of the card number.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#number ⇒ Object
readonly
The full unredacted card number.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#personalization_design ⇒ Object
readonly
The personalization design object belonging to this card.
-
#replaced_by ⇒ Object
readonly
The latest card that replaces this card, if any.
-
#replacement_for ⇒ Object
readonly
The card this card replaces, if any.
-
#replacement_reason ⇒ Object
readonly
The reason why the previous card needed to be replaced.
-
#shipping ⇒ Object
readonly
Where and how the card will be shipped.
-
#spending_controls ⇒ Object
readonly
Attribute for field spending_controls.
-
#status ⇒ Object
readonly
Whether authorizations can be approved on this card.
-
#type ⇒ Object
readonly
The type of the card.
-
#wallets ⇒ Object
readonly
Information relating to digital wallets (like Apple Pay and Google Pay).
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates an Issuing Card object.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Issuing Card objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Card object by setting the values of the parameters passed.
Instance Method Summary collapse
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#brand ⇒ Object (readonly)
The brand of the card.
53 54 55 |
# File 'lib/stripe/resources/issuing/card.rb', line 53 def brand @brand end |
#cancellation_reason ⇒ Object (readonly)
The reason why the card was canceled.
55 56 57 |
# File 'lib/stripe/resources/issuing/card.rb', line 55 def cancellation_reason @cancellation_reason end |
#cardholder ⇒ Object (readonly)
An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](stripe.com/docs/issuing) cards.
Related guide: [How to create a cardholder](stripe.com/docs/issuing/cards/virtual/issue-cards#create-cardholder)
59 60 61 |
# File 'lib/stripe/resources/issuing/card.rb', line 59 def cardholder @cardholder end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
61 62 63 |
# File 'lib/stripe/resources/issuing/card.rb', line 61 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Supported currencies are ‘usd` in the US, `eur` in the EU, and `gbp` in the UK.
63 64 65 |
# File 'lib/stripe/resources/issuing/card.rb', line 63 def currency @currency end |
#cvc ⇒ Object (readonly)
The card’s CVC. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with [the ‘expand` parameter](stripe.com/docs/api/expanding_objects). Additionally, it’s only available via the [“Retrieve a card” endpoint](stripe.com/docs/api/issuing/cards/retrieve), not via “List all cards” or any other endpoint.
65 66 67 |
# File 'lib/stripe/resources/issuing/card.rb', line 65 def cvc @cvc end |
#exp_month ⇒ Object (readonly)
The expiration month of the card.
67 68 69 |
# File 'lib/stripe/resources/issuing/card.rb', line 67 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
The expiration year of the card.
69 70 71 |
# File 'lib/stripe/resources/issuing/card.rb', line 69 def exp_year @exp_year end |
#financial_account ⇒ Object (readonly)
The financial account this card is attached to.
71 72 73 |
# File 'lib/stripe/resources/issuing/card.rb', line 71 def financial_account @financial_account end |
#id ⇒ Object (readonly)
Unique identifier for the object.
73 74 75 |
# File 'lib/stripe/resources/issuing/card.rb', line 73 def id @id end |
#last4 ⇒ Object (readonly)
The last 4 digits of the card number.
75 76 77 |
# File 'lib/stripe/resources/issuing/card.rb', line 75 def last4 @last4 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
77 78 79 |
# File 'lib/stripe/resources/issuing/card.rb', line 77 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
79 80 81 |
# File 'lib/stripe/resources/issuing/card.rb', line 79 def @metadata end |
#number ⇒ Object (readonly)
The full unredacted card number. For security reasons, this is only available for virtual cards, and will be omitted unless you explicitly request it with [the ‘expand` parameter](stripe.com/docs/api/expanding_objects). Additionally, it’s only available via the [“Retrieve a card” endpoint](stripe.com/docs/api/issuing/cards/retrieve), not via “List all cards” or any other endpoint.
81 82 83 |
# File 'lib/stripe/resources/issuing/card.rb', line 81 def number @number end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
83 84 85 |
# File 'lib/stripe/resources/issuing/card.rb', line 83 def object @object end |
#personalization_design ⇒ Object (readonly)
The personalization design object belonging to this card.
85 86 87 |
# File 'lib/stripe/resources/issuing/card.rb', line 85 def personalization_design @personalization_design end |
#replaced_by ⇒ Object (readonly)
The latest card that replaces this card, if any.
87 88 89 |
# File 'lib/stripe/resources/issuing/card.rb', line 87 def replaced_by @replaced_by end |
#replacement_for ⇒ Object (readonly)
The card this card replaces, if any.
89 90 91 |
# File 'lib/stripe/resources/issuing/card.rb', line 89 def replacement_for @replacement_for end |
#replacement_reason ⇒ Object (readonly)
The reason why the previous card needed to be replaced.
91 92 93 |
# File 'lib/stripe/resources/issuing/card.rb', line 91 def replacement_reason @replacement_reason end |
#shipping ⇒ Object (readonly)
Where and how the card will be shipped.
93 94 95 |
# File 'lib/stripe/resources/issuing/card.rb', line 93 def shipping @shipping end |
#spending_controls ⇒ Object (readonly)
Attribute for field spending_controls
95 96 97 |
# File 'lib/stripe/resources/issuing/card.rb', line 95 def spending_controls @spending_controls end |
#status ⇒ Object (readonly)
Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.
97 98 99 |
# File 'lib/stripe/resources/issuing/card.rb', line 97 def status @status end |
#type ⇒ Object (readonly)
The type of the card.
99 100 101 |
# File 'lib/stripe/resources/issuing/card.rb', line 99 def type @type end |
#wallets ⇒ Object (readonly)
Information relating to digital wallets (like Apple Pay and Google Pay).
101 102 103 |
# File 'lib/stripe/resources/issuing/card.rb', line 101 def wallets @wallets end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates an Issuing Card object.
104 105 106 |
# File 'lib/stripe/resources/issuing/card.rb', line 104 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/issuing/cards", params: params, opts: opts) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Issuing Card objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
109 110 111 |
# File 'lib/stripe/resources/issuing/card.rb', line 109 def self.list(filters = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/issuing/cards", params: filters, opts: opts) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/issuing/card.rb', line 13 def self.object_name "issuing.card" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Card object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
114 115 116 117 118 119 120 121 |
# File 'lib/stripe/resources/issuing/card.rb', line 114 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/cards/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#test_helpers ⇒ Object
123 124 125 |
# File 'lib/stripe/resources/issuing/card.rb', line 123 def test_helpers TestHelpers.new(self) end |