Class: Stripe::Issuing::Card::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/card.rb

Defined Under Namespace

Classes: Pin, Shipping, SpendingControls

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cardholder: nil, currency: nil, exp_month: nil, exp_year: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/stripe/resources/issuing/card.rb', line 375

def initialize(
  cardholder: nil,
  currency: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  financial_account: nil,
  metadata: nil,
  personalization_design: nil,
  pin: nil,
  replacement_for: nil,
  replacement_reason: nil,
  second_line: nil,
  shipping: nil,
  spending_controls: nil,
  status: nil,
  type: nil
)
  @cardholder = cardholder
  @currency = currency
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @financial_account = 
  @metadata = 
  @personalization_design = personalization_design
  @pin = pin
  @replacement_for = replacement_for
  @replacement_reason = replacement_reason
  @second_line = second_line
  @shipping = shipping
  @spending_controls = spending_controls
  @status = status
  @type = type
end

Instance Attribute Details

#cardholderObject

The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.



343
344
345
# File 'lib/stripe/resources/issuing/card.rb', line 343

def cardholder
  @cardholder
end

#currencyObject

The currency for the card.



345
346
347
# File 'lib/stripe/resources/issuing/card.rb', line 345

def currency
  @currency
end

#exp_monthObject

The desired expiration month (1-12) for this card if [specifying a custom expiration date](/issuing/cards/virtual/issue-cards?testing-method=with-code#exp-dates).



347
348
349
# File 'lib/stripe/resources/issuing/card.rb', line 347

def exp_month
  @exp_month
end

#exp_yearObject

The desired 4-digit expiration year for this card if [specifying a custom expiration date](/issuing/cards/virtual/issue-cards?testing-method=with-code#exp-dates).



349
350
351
# File 'lib/stripe/resources/issuing/card.rb', line 349

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



351
352
353
# File 'lib/stripe/resources/issuing/card.rb', line 351

def expand
  @expand
end

#financial_accountObject

The new financial account ID the card will be associated with. This field allows a card to be reassigned to a different financial account.



353
354
355
# File 'lib/stripe/resources/issuing/card.rb', line 353

def 
  @financial_account
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



355
356
357
# File 'lib/stripe/resources/issuing/card.rb', line 355

def 
  @metadata
end

#personalization_designObject

The personalization design object belonging to this card.



357
358
359
# File 'lib/stripe/resources/issuing/card.rb', line 357

def personalization_design
  @personalization_design
end

#pinObject

The desired PIN for this card.



359
360
361
# File 'lib/stripe/resources/issuing/card.rb', line 359

def pin
  @pin
end

#replacement_forObject

The card this is meant to be a replacement for (if any).



361
362
363
# File 'lib/stripe/resources/issuing/card.rb', line 361

def replacement_for
  @replacement_for
end

#replacement_reasonObject

If ‘replacement_for` is specified, this should indicate why that card is being replaced.



363
364
365
# File 'lib/stripe/resources/issuing/card.rb', line 363

def replacement_reason
  @replacement_reason
end

#second_lineObject

The second line to print on the card. Max length: 24 characters.



365
366
367
# File 'lib/stripe/resources/issuing/card.rb', line 365

def second_line
  @second_line
end

#shippingObject

The address where the card will be shipped.



367
368
369
# File 'lib/stripe/resources/issuing/card.rb', line 367

def shipping
  @shipping
end

#spending_controlsObject

Rules that control spending for this card. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.



369
370
371
# File 'lib/stripe/resources/issuing/card.rb', line 369

def spending_controls
  @spending_controls
end

#statusObject

Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.



371
372
373
# File 'lib/stripe/resources/issuing/card.rb', line 371

def status
  @status
end

#typeObject

The type of card to issue. Possible values are ‘physical` or `virtual`.



373
374
375
# File 'lib/stripe/resources/issuing/card.rb', line 373

def type
  @type
end