Class: Stripe::Issuing::Card::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Card::CreateParams
- Defined in:
- lib/stripe/resources/issuing/card.rb
Defined Under Namespace
Classes: Pin, Shipping, SpendingControls
Instance Attribute Summary collapse
-
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
-
#currency ⇒ Object
The currency for the card.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
The new financial account ID the card will be associated with.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#personalization_design ⇒ Object
The personalization design object belonging to this card.
-
#pin ⇒ Object
The desired PIN for this card.
-
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
-
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
-
#second_line ⇒ Object
The second line to print on the card.
-
#shipping ⇒ Object
The address where the card will be shipped.
-
#spending_controls ⇒ Object
Rules that control spending for this card.
-
#status ⇒ Object
Whether authorizations can be approved on this card.
-
#type ⇒ Object
The type of card to issue.
Instance Method Summary collapse
-
#initialize(cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/stripe/resources/issuing/card.rb', line 371 def initialize( cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil ) @cardholder = cardholder @currency = currency @expand = @financial_account = financial_account @metadata = @personalization_design = personalization_design @pin = pin @replacement_for = replacement_for @replacement_reason = replacement_reason @second_line = second_line @shipping = shipping @spending_controls = spending_controls @status = status @type = type end |
Instance Attribute Details
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
343 344 345 |
# File 'lib/stripe/resources/issuing/card.rb', line 343 def cardholder @cardholder end |
#currency ⇒ Object
The currency for the card.
345 346 347 |
# File 'lib/stripe/resources/issuing/card.rb', line 345 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
347 348 349 |
# File 'lib/stripe/resources/issuing/card.rb', line 347 def @expand end |
#financial_account ⇒ Object
The new financial account ID the card will be associated with. This field allows a card to be reassigned to a different financial account.
349 350 351 |
# File 'lib/stripe/resources/issuing/card.rb', line 349 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
351 352 353 |
# File 'lib/stripe/resources/issuing/card.rb', line 351 def @metadata end |
#personalization_design ⇒ Object
The personalization design object belonging to this card.
353 354 355 |
# File 'lib/stripe/resources/issuing/card.rb', line 353 def personalization_design @personalization_design end |
#pin ⇒ Object
The desired PIN for this card.
355 356 357 |
# File 'lib/stripe/resources/issuing/card.rb', line 355 def pin @pin end |
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
357 358 359 |
# File 'lib/stripe/resources/issuing/card.rb', line 357 def replacement_for @replacement_for end |
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
359 360 361 |
# File 'lib/stripe/resources/issuing/card.rb', line 359 def replacement_reason @replacement_reason end |
#second_line ⇒ Object
The second line to print on the card. Max length: 24 characters.
361 362 363 |
# File 'lib/stripe/resources/issuing/card.rb', line 361 def second_line @second_line end |
#shipping ⇒ Object
The address where the card will be shipped.
363 364 365 |
# File 'lib/stripe/resources/issuing/card.rb', line 363 def shipping @shipping end |
#spending_controls ⇒ Object
Rules that control spending for this card. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
365 366 367 |
# File 'lib/stripe/resources/issuing/card.rb', line 365 def spending_controls @spending_controls end |
#status ⇒ Object
Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.
367 368 369 |
# File 'lib/stripe/resources/issuing/card.rb', line 367 def status @status end |
#type ⇒ Object
The type of card to issue. Possible values are ‘physical` or `virtual`.
369 370 371 |
# File 'lib/stripe/resources/issuing/card.rb', line 369 def type @type end |