Class: Stripe::Issuing::Card::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Card::CreateParams
- Defined in:
- lib/stripe/resources/issuing/card.rb
Defined Under Namespace
Classes: Pin, Shipping, SpendingControls
Instance Attribute Summary collapse
-
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
-
#currency ⇒ Object
The currency for the card.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
Attribute for param field financial_account.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#personalization_design ⇒ Object
The personalization design object belonging to this card.
-
#pin ⇒ Object
The desired PIN for this card.
-
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
-
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
-
#second_line ⇒ Object
The second line to print on the card.
-
#shipping ⇒ Object
The address where the card will be shipped.
-
#spending_controls ⇒ Object
Rules that control spending for this card.
-
#status ⇒ Object
Whether authorizations can be approved on this card.
-
#type ⇒ Object
The type of card to issue.
Instance Method Summary collapse
-
#initialize(cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/stripe/resources/issuing/card.rb', line 451 def initialize( cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil ) @cardholder = cardholder @currency = currency @expand = @financial_account = financial_account @metadata = @personalization_design = personalization_design @pin = pin @replacement_for = replacement_for @replacement_reason = replacement_reason @second_line = second_line @shipping = shipping @spending_controls = spending_controls @status = status @type = type end |
Instance Attribute Details
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
410 411 412 |
# File 'lib/stripe/resources/issuing/card.rb', line 410 def cardholder @cardholder end |
#currency ⇒ Object
The currency for the card.
413 414 415 |
# File 'lib/stripe/resources/issuing/card.rb', line 413 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
416 417 418 |
# File 'lib/stripe/resources/issuing/card.rb', line 416 def @expand end |
#financial_account ⇒ Object
Attribute for param field financial_account
419 420 421 |
# File 'lib/stripe/resources/issuing/card.rb', line 419 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
422 423 424 |
# File 'lib/stripe/resources/issuing/card.rb', line 422 def @metadata end |
#personalization_design ⇒ Object
The personalization design object belonging to this card.
425 426 427 |
# File 'lib/stripe/resources/issuing/card.rb', line 425 def personalization_design @personalization_design end |
#pin ⇒ Object
The desired PIN for this card.
428 429 430 |
# File 'lib/stripe/resources/issuing/card.rb', line 428 def pin @pin end |
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
431 432 433 |
# File 'lib/stripe/resources/issuing/card.rb', line 431 def replacement_for @replacement_for end |
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
434 435 436 |
# File 'lib/stripe/resources/issuing/card.rb', line 434 def replacement_reason @replacement_reason end |
#second_line ⇒ Object
The second line to print on the card. Max length: 24 characters.
437 438 439 |
# File 'lib/stripe/resources/issuing/card.rb', line 437 def second_line @second_line end |
#shipping ⇒ Object
The address where the card will be shipped.
440 441 442 |
# File 'lib/stripe/resources/issuing/card.rb', line 440 def shipping @shipping end |
#spending_controls ⇒ Object
Rules that control spending for this card. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
443 444 445 |
# File 'lib/stripe/resources/issuing/card.rb', line 443 def spending_controls @spending_controls end |
#status ⇒ Object
Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.
446 447 448 |
# File 'lib/stripe/resources/issuing/card.rb', line 446 def status @status end |
#type ⇒ Object
The type of card to issue. Possible values are ‘physical` or `virtual`.
449 450 451 |
# File 'lib/stripe/resources/issuing/card.rb', line 449 def type @type end |