Class: Stripe::Issuing::Card::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/card.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cardholder: nil, created: nil, ending_before: nil, exp_month: nil, exp_year: nil, expand: nil, last4: nil, limit: nil, personalization_design: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/stripe/resources/issuing/card.rb', line 176

def initialize(
  cardholder: nil,
  created: nil,
  ending_before: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  last4: nil,
  limit: nil,
  personalization_design: nil,
  starting_after: nil,
  status: nil,
  type: nil
)
  @cardholder = cardholder
  @created = created
  @ending_before = ending_before
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @last4 = last4
  @limit = limit
  @personalization_design = personalization_design
  @starting_after = starting_after
  @status = status
  @type = type
end

Instance Attribute Details

#cardholderObject

Only return cards belonging to the Cardholder with the provided ID.



152
153
154
# File 'lib/stripe/resources/issuing/card.rb', line 152

def cardholder
  @cardholder
end

#createdObject

Only return cards that were issued during the given date interval.



154
155
156
# File 'lib/stripe/resources/issuing/card.rb', line 154

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



156
157
158
# File 'lib/stripe/resources/issuing/card.rb', line 156

def ending_before
  @ending_before
end

#exp_monthObject

Only return cards that have the given expiration month.



158
159
160
# File 'lib/stripe/resources/issuing/card.rb', line 158

def exp_month
  @exp_month
end

#exp_yearObject

Only return cards that have the given expiration year.



160
161
162
# File 'lib/stripe/resources/issuing/card.rb', line 160

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



162
163
164
# File 'lib/stripe/resources/issuing/card.rb', line 162

def expand
  @expand
end

#last4Object

Only return cards that have the given last four digits.



164
165
166
# File 'lib/stripe/resources/issuing/card.rb', line 164

def last4
  @last4
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



166
167
168
# File 'lib/stripe/resources/issuing/card.rb', line 166

def limit
  @limit
end

#personalization_designObject

Attribute for param field personalization_design



168
169
170
# File 'lib/stripe/resources/issuing/card.rb', line 168

def personalization_design
  @personalization_design
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



170
171
172
# File 'lib/stripe/resources/issuing/card.rb', line 170

def starting_after
  @starting_after
end

#statusObject

Only return cards that have the given status. One of ‘active`, `inactive`, or `canceled`.



172
173
174
# File 'lib/stripe/resources/issuing/card.rb', line 172

def status
  @status
end

#typeObject

Only return cards that have the given type. One of ‘virtual` or `physical`.



174
175
176
# File 'lib/stripe/resources/issuing/card.rb', line 174

def type
  @type
end