Class: Stripe::Issuing::Card::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/card.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cardholder: nil, created: nil, ending_before: nil, exp_month: nil, exp_year: nil, expand: nil, last4: nil, limit: nil, personalization_design: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/stripe/resources/issuing/card.rb', line 225

def initialize(
  cardholder: nil,
  created: nil,
  ending_before: nil,
  exp_month: nil,
  exp_year: nil,
  expand: nil,
  last4: nil,
  limit: nil,
  personalization_design: nil,
  starting_after: nil,
  status: nil,
  type: nil
)
  @cardholder = cardholder
  @created = created
  @ending_before = ending_before
  @exp_month = exp_month
  @exp_year = exp_year
  @expand = expand
  @last4 = last4
  @limit = limit
  @personalization_design = personalization_design
  @starting_after = starting_after
  @status = status
  @type = type
end

Instance Attribute Details

#cardholderObject

Only return cards belonging to the Cardholder with the provided ID.



190
191
192
# File 'lib/stripe/resources/issuing/card.rb', line 190

def cardholder
  @cardholder
end

#createdObject

Only return cards that were issued during the given date interval.



193
194
195
# File 'lib/stripe/resources/issuing/card.rb', line 193

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



196
197
198
# File 'lib/stripe/resources/issuing/card.rb', line 196

def ending_before
  @ending_before
end

#exp_monthObject

Only return cards that have the given expiration month.



199
200
201
# File 'lib/stripe/resources/issuing/card.rb', line 199

def exp_month
  @exp_month
end

#exp_yearObject

Only return cards that have the given expiration year.



202
203
204
# File 'lib/stripe/resources/issuing/card.rb', line 202

def exp_year
  @exp_year
end

#expandObject

Specifies which fields in the response should be expanded.



205
206
207
# File 'lib/stripe/resources/issuing/card.rb', line 205

def expand
  @expand
end

#last4Object

Only return cards that have the given last four digits.



208
209
210
# File 'lib/stripe/resources/issuing/card.rb', line 208

def last4
  @last4
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



211
212
213
# File 'lib/stripe/resources/issuing/card.rb', line 211

def limit
  @limit
end

#personalization_designObject

Attribute for param field personalization_design



214
215
216
# File 'lib/stripe/resources/issuing/card.rb', line 214

def personalization_design
  @personalization_design
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



217
218
219
# File 'lib/stripe/resources/issuing/card.rb', line 217

def starting_after
  @starting_after
end

#statusObject

Only return cards that have the given status. One of ‘active`, `inactive`, or `canceled`.



220
221
222
# File 'lib/stripe/resources/issuing/card.rb', line 220

def status
  @status
end

#typeObject

Only return cards that have the given type. One of ‘virtual` or `physical`.



223
224
225
# File 'lib/stripe/resources/issuing/card.rb', line 223

def type
  @type
end