Class: Stripe::Issuing::Card::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/issuing/card.rb

Defined Under Namespace

Classes: Address, AddressValidation, Customs

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



133
134
135
# File 'lib/stripe/resources/issuing/card.rb', line 133

def address
  @address
end

#address_validationObject (readonly)

Address validation details for the shipment.



135
136
137
# File 'lib/stripe/resources/issuing/card.rb', line 135

def address_validation
  @address_validation
end

#carrierObject (readonly)

The delivery company that shipped a card.



137
138
139
# File 'lib/stripe/resources/issuing/card.rb', line 137

def carrier
  @carrier
end

#customsObject (readonly)

Additional information that may be required for clearing customs.



139
140
141
# File 'lib/stripe/resources/issuing/card.rb', line 139

def customs
  @customs
end

#etaObject (readonly)

A unix timestamp representing a best estimate of when the card will be delivered.



141
142
143
# File 'lib/stripe/resources/issuing/card.rb', line 141

def eta
  @eta
end

#nameObject (readonly)

Recipient name.



143
144
145
# File 'lib/stripe/resources/issuing/card.rb', line 143

def name
  @name
end

#phone_numberObject (readonly)

The phone number of the receiver of the shipment. Our courier partners will use this number to contact you in the event of card delivery issues. For individual shipments to the EU/UK, if this field is empty, we will provide them with the phone number provided when the cardholder was initially created.



145
146
147
# File 'lib/stripe/resources/issuing/card.rb', line 145

def phone_number
  @phone_number
end

#require_signatureObject (readonly)

Whether a signature is required for card delivery. This feature is only supported for US users. Standard shipping service does not support signature on delivery. The default value for standard shipping service is false and for express and priority services is true.



147
148
149
# File 'lib/stripe/resources/issuing/card.rb', line 147

def require_signature
  @require_signature
end

#serviceObject (readonly)

Shipment service, such as ‘standard` or `express`.



149
150
151
# File 'lib/stripe/resources/issuing/card.rb', line 149

def service
  @service
end

#statusObject (readonly)

The delivery status of the card.



151
152
153
# File 'lib/stripe/resources/issuing/card.rb', line 151

def status
  @status
end

#tracking_numberObject (readonly)

A tracking number for a card shipment.



153
154
155
# File 'lib/stripe/resources/issuing/card.rb', line 153

def tracking_number
  @tracking_number
end

#tracking_urlObject (readonly)

A link to the shipping carrier’s site where you can view detailed information about a card shipment.



155
156
157
# File 'lib/stripe/resources/issuing/card.rb', line 155

def tracking_url
  @tracking_url
end

#typeObject (readonly)

Packaging options.



157
158
159
# File 'lib/stripe/resources/issuing/card.rb', line 157

def type
  @type
end

Class Method Details

.field_remappingsObject



167
168
169
# File 'lib/stripe/resources/issuing/card.rb', line 167

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



159
160
161
162
163
164
165
# File 'lib/stripe/resources/issuing/card.rb', line 159

def self.inner_class_types
  @inner_class_types = {
    address: Address,
    address_validation: AddressValidation,
    customs: Customs,
  }
end