Class: Stripe::Issuing::Card::Shipping

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/issuing/card.rb

Defined Under Namespace

Classes: Address, AddressValidation, Customs

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#addressObject (readonly)

Attribute for field address



61
62
63
# File 'lib/stripe/resources/issuing/card.rb', line 61

def address
  @address
end

#address_validationObject (readonly)

Address validation details for the shipment.



63
64
65
# File 'lib/stripe/resources/issuing/card.rb', line 63

def address_validation
  @address_validation
end

#carrierObject (readonly)

The delivery company that shipped a card.



65
66
67
# File 'lib/stripe/resources/issuing/card.rb', line 65

def carrier
  @carrier
end

#customsObject (readonly)

Additional information that may be required for clearing customs.



67
68
69
# File 'lib/stripe/resources/issuing/card.rb', line 67

def customs
  @customs
end

#etaObject (readonly)

A unix timestamp representing a best estimate of when the card will be delivered.



69
70
71
# File 'lib/stripe/resources/issuing/card.rb', line 69

def eta
  @eta
end

#nameObject (readonly)

Recipient name.



71
72
73
# File 'lib/stripe/resources/issuing/card.rb', line 71

def name
  @name
end

#phone_numberObject (readonly)

The phone number of the receiver of the shipment. Our courier partners will use this number to contact you in the event of card delivery issues. For individual shipments to the EU/UK, if this field is empty, we will provide them with the phone number provided when the cardholder was initially created.



73
74
75
# File 'lib/stripe/resources/issuing/card.rb', line 73

def phone_number
  @phone_number
end

#require_signatureObject (readonly)

Whether a signature is required for card delivery. This feature is only supported for US users. Standard shipping service does not support signature on delivery. The default value for standard shipping service is false and for express and priority services is true.



75
76
77
# File 'lib/stripe/resources/issuing/card.rb', line 75

def require_signature
  @require_signature
end

#serviceObject (readonly)

Shipment service, such as ‘standard` or `express`.



77
78
79
# File 'lib/stripe/resources/issuing/card.rb', line 77

def service
  @service
end

#statusObject (readonly)

The delivery status of the card.



79
80
81
# File 'lib/stripe/resources/issuing/card.rb', line 79

def status
  @status
end

#tracking_numberObject (readonly)

A tracking number for a card shipment.



81
82
83
# File 'lib/stripe/resources/issuing/card.rb', line 81

def tracking_number
  @tracking_number
end

#tracking_urlObject (readonly)

A link to the shipping carrier’s site where you can view detailed information about a card shipment.



83
84
85
# File 'lib/stripe/resources/issuing/card.rb', line 83

def tracking_url
  @tracking_url
end

#typeObject (readonly)

Packaging options.



85
86
87
# File 'lib/stripe/resources/issuing/card.rb', line 85

def type
  @type
end