Class: Stripe::Issuing::Card::Shipping
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Card::Shipping
- Defined in:
- lib/stripe/resources/issuing/card.rb
Defined Under Namespace
Classes: Address, AddressValidation, Customs
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#address ⇒ Object
readonly
Attribute for field address.
-
#address_validation ⇒ Object
readonly
Address validation details for the shipment.
-
#carrier ⇒ Object
readonly
The delivery company that shipped a card.
-
#customs ⇒ Object
readonly
Additional information that may be required for clearing customs.
-
#eta ⇒ Object
readonly
A unix timestamp representing a best estimate of when the card will be delivered.
-
#name ⇒ Object
readonly
Recipient name.
-
#phone_number ⇒ Object
readonly
The phone number of the receiver of the shipment.
-
#require_signature ⇒ Object
readonly
Whether a signature is required for card delivery.
-
#service ⇒ Object
readonly
Shipment service, such as ‘standard` or `express`.
-
#status ⇒ Object
readonly
The delivery status of the card.
-
#tracking_number ⇒ Object
readonly
A tracking number for a card shipment.
-
#tracking_url ⇒ Object
readonly
A link to the shipping carrier’s site where you can view detailed information about a card shipment.
-
#type ⇒ Object
readonly
Packaging options.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#address ⇒ Object (readonly)
Attribute for field address
73 74 75 |
# File 'lib/stripe/resources/issuing/card.rb', line 73 def address @address end |
#address_validation ⇒ Object (readonly)
Address validation details for the shipment.
76 77 78 |
# File 'lib/stripe/resources/issuing/card.rb', line 76 def address_validation @address_validation end |
#carrier ⇒ Object (readonly)
The delivery company that shipped a card.
79 80 81 |
# File 'lib/stripe/resources/issuing/card.rb', line 79 def carrier @carrier end |
#customs ⇒ Object (readonly)
Additional information that may be required for clearing customs.
82 83 84 |
# File 'lib/stripe/resources/issuing/card.rb', line 82 def customs @customs end |
#eta ⇒ Object (readonly)
A unix timestamp representing a best estimate of when the card will be delivered.
85 86 87 |
# File 'lib/stripe/resources/issuing/card.rb', line 85 def eta @eta end |
#name ⇒ Object (readonly)
Recipient name.
88 89 90 |
# File 'lib/stripe/resources/issuing/card.rb', line 88 def name @name end |
#phone_number ⇒ Object (readonly)
The phone number of the receiver of the shipment. Our courier partners will use this number to contact you in the event of card delivery issues. For individual shipments to the EU/UK, if this field is empty, we will provide them with the phone number provided when the cardholder was initially created.
91 92 93 |
# File 'lib/stripe/resources/issuing/card.rb', line 91 def phone_number @phone_number end |
#require_signature ⇒ Object (readonly)
Whether a signature is required for card delivery. This feature is only supported for US users. Standard shipping service does not support signature on delivery. The default value for standard shipping service is false and for express and priority services is true.
94 95 96 |
# File 'lib/stripe/resources/issuing/card.rb', line 94 def require_signature @require_signature end |
#service ⇒ Object (readonly)
Shipment service, such as ‘standard` or `express`.
97 98 99 |
# File 'lib/stripe/resources/issuing/card.rb', line 97 def service @service end |
#status ⇒ Object (readonly)
The delivery status of the card.
100 101 102 |
# File 'lib/stripe/resources/issuing/card.rb', line 100 def status @status end |
#tracking_number ⇒ Object (readonly)
A tracking number for a card shipment.
103 104 105 |
# File 'lib/stripe/resources/issuing/card.rb', line 103 def tracking_number @tracking_number end |
#tracking_url ⇒ Object (readonly)
A link to the shipping carrier’s site where you can view detailed information about a card shipment.
106 107 108 |
# File 'lib/stripe/resources/issuing/card.rb', line 106 def tracking_url @tracking_url end |
#type ⇒ Object (readonly)
Packaging options.
109 110 111 |
# File 'lib/stripe/resources/issuing/card.rb', line 109 def type @type end |