Class: Stripe::Issuing::Card::SpendingControls

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/card.rb

Defined Under Namespace

Classes: SpendingLimit

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allowed_card_presencesObject (readonly)

Array of card presence statuses from which authorizations will be allowed. Possible options are ‘present`, `not_present`. All other statuses will be blocked. Cannot be set with `blocked_card_presences`. Provide an empty value to unset this control.



190
191
192
# File 'lib/stripe/resources/issuing/card.rb', line 190

def allowed_card_presences
  @allowed_card_presences
end

#allowed_categoriesObject (readonly)

Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to allow. All other categories will be blocked. Cannot be set with ‘blocked_categories`.



192
193
194
# File 'lib/stripe/resources/issuing/card.rb', line 192

def allowed_categories
  @allowed_categories
end

#allowed_merchant_countriesObject (readonly)

Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `blocked_merchant_countries`. Provide an empty value to unset this control.



194
195
196
# File 'lib/stripe/resources/issuing/card.rb', line 194

def allowed_merchant_countries
  @allowed_merchant_countries
end

#blocked_card_presencesObject (readonly)

Array of card presence statuses from which authorizations will be declined. Possible options are ‘present`, `not_present`. Cannot be set with `allowed_card_presences`. Provide an empty value to unset this control.



196
197
198
# File 'lib/stripe/resources/issuing/card.rb', line 196

def blocked_card_presences
  @blocked_card_presences
end

#blocked_categoriesObject (readonly)

Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to decline. All other categories will be allowed. Cannot be set with ‘allowed_categories`.



198
199
200
# File 'lib/stripe/resources/issuing/card.rb', line 198

def blocked_categories
  @blocked_categories
end

#blocked_merchant_countriesObject (readonly)

Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `allowed_merchant_countries`. Provide an empty value to unset this control.



200
201
202
# File 'lib/stripe/resources/issuing/card.rb', line 200

def blocked_merchant_countries
  @blocked_merchant_countries
end

#spending_limitsObject (readonly)

Limit spending with amount-based rules that apply across any cards this card replaced (i.e., its ‘replacement_for` card and that card’s ‘replacement_for` card, up the chain).



202
203
204
# File 'lib/stripe/resources/issuing/card.rb', line 202

def spending_limits
  @spending_limits
end

#spending_limits_currencyObject (readonly)

Currency of the amounts within ‘spending_limits`. Always the same as the currency of the card.



204
205
206
# File 'lib/stripe/resources/issuing/card.rb', line 204

def spending_limits_currency
  @spending_limits_currency
end

Class Method Details

.field_remappingsObject



210
211
212
# File 'lib/stripe/resources/issuing/card.rb', line 210

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



206
207
208
# File 'lib/stripe/resources/issuing/card.rb', line 206

def self.inner_class_types
  @inner_class_types = { spending_limits: SpendingLimit }
end