Class: Stripe::Issuing::Card::TestHelpers
- Inherits:
-
APIResourceTestHelpers
- Object
- APIResourceTestHelpers
- Stripe::Issuing::Card::TestHelpers
- Defined in:
- lib/stripe/resources/issuing/card.rb
Constant Summary collapse
- RESOURCE_CLASS =
Card
Class Method Summary collapse
-
.deliver_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
-
.fail_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
- .resource_class ⇒ Object
-
.return_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
-
.ship_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
-
.submit_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted.
Instance Method Summary collapse
-
#deliver_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
-
#fail_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
-
#return_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
-
#ship_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
-
#submit_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted.
Methods inherited from APIResourceTestHelpers
custom_method, #initialize, resource_url, #resource_url
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Stripe::APIResourceTestHelpers
Class Method Details
.deliver_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
348 349 350 351 352 353 354 355 |
# File 'lib/stripe/resources/issuing/card.rb', line 348 def self.deliver_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/deliver", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.fail_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
368 369 370 371 372 373 374 375 |
# File 'lib/stripe/resources/issuing/card.rb', line 368 def self.fail_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/fail", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.resource_class ⇒ Object
343 344 345 |
# File 'lib/stripe/resources/issuing/card.rb', line 343 def self.resource_class "Card" end |
.return_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
388 389 390 391 392 393 394 395 |
# File 'lib/stripe/resources/issuing/card.rb', line 388 def self.return_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/return", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.ship_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
408 409 410 411 412 413 414 415 |
# File 'lib/stripe/resources/issuing/card.rb', line 408 def self.ship_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/ship", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.submit_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted. This method requires Stripe Version ‘2024-09-30.acacia’ or later.
428 429 430 431 432 433 434 435 |
# File 'lib/stripe/resources/issuing/card.rb', line 428 def self.submit_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/submit", { card: CGI.escape(card) }), params: params, opts: opts ) end |
Instance Method Details
#deliver_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
358 359 360 361 362 363 364 365 |
# File 'lib/stripe/resources/issuing/card.rb', line 358 def deliver_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/deliver", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#fail_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
378 379 380 381 382 383 384 385 |
# File 'lib/stripe/resources/issuing/card.rb', line 378 def fail_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/fail", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#return_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
398 399 400 401 402 403 404 405 |
# File 'lib/stripe/resources/issuing/card.rb', line 398 def return_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/return", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#ship_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
418 419 420 421 422 423 424 425 |
# File 'lib/stripe/resources/issuing/card.rb', line 418 def ship_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/ship", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#submit_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted. This method requires Stripe Version ‘2024-09-30.acacia’ or later.
438 439 440 441 442 443 444 445 |
# File 'lib/stripe/resources/issuing/card.rb', line 438 def submit_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/submit", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |