Class: Stripe::Issuing::Card::TestHelpers
- Inherits:
-
APIResourceTestHelpers
- Object
- APIResourceTestHelpers
- Stripe::Issuing::Card::TestHelpers
- Defined in:
- lib/stripe/resources/issuing/card.rb
Constant Summary collapse
- RESOURCE_CLASS =
Card
Class Method Summary collapse
-
.deliver_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
-
.fail_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
- .resource_class ⇒ Object
-
.return_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
-
.ship_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
-
.submit_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted.
Instance Method Summary collapse
-
#deliver_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
-
#fail_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
-
#return_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
-
#ship_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
-
#submit_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted.
Methods inherited from APIResourceTestHelpers
custom_method, #initialize, resource_url, #resource_url
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Stripe::APIResourceTestHelpers
Class Method Details
.deliver_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
321 322 323 324 325 326 327 328 |
# File 'lib/stripe/resources/issuing/card.rb', line 321 def self.deliver_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/deliver", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.fail_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
341 342 343 344 345 346 347 348 |
# File 'lib/stripe/resources/issuing/card.rb', line 341 def self.fail_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/fail", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.resource_class ⇒ Object
316 317 318 |
# File 'lib/stripe/resources/issuing/card.rb', line 316 def self.resource_class "Card" end |
.return_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
361 362 363 364 365 366 367 368 |
# File 'lib/stripe/resources/issuing/card.rb', line 361 def self.return_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/return", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.ship_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
381 382 383 384 385 386 387 388 |
# File 'lib/stripe/resources/issuing/card.rb', line 381 def self.ship_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/ship", { card: CGI.escape(card) }), params: params, opts: opts ) end |
.submit_card(card, params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted. This method requires Stripe Version ‘2024-09-30.acacia’ or later.
401 402 403 404 405 406 407 408 |
# File 'lib/stripe/resources/issuing/card.rb', line 401 def self.submit_card(card, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/submit", { card: CGI.escape(card) }), params: params, opts: opts ) end |
Instance Method Details
#deliver_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to delivered.
331 332 333 334 335 336 337 338 |
# File 'lib/stripe/resources/issuing/card.rb', line 331 def deliver_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/deliver", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#fail_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to failure.
351 352 353 354 355 356 357 358 |
# File 'lib/stripe/resources/issuing/card.rb', line 351 def fail_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/fail", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#return_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to returned.
371 372 373 374 375 376 377 378 |
# File 'lib/stripe/resources/issuing/card.rb', line 371 def return_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/return", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#ship_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to shipped.
391 392 393 394 395 396 397 398 |
# File 'lib/stripe/resources/issuing/card.rb', line 391 def ship_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/ship", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |
#submit_card(params = {}, opts = {}) ⇒ Object
Updates the shipping status of the specified Issuing Card object to submitted. This method requires Stripe Version ‘2024-09-30.acacia’ or later.
411 412 413 414 415 416 417 418 |
# File 'lib/stripe/resources/issuing/card.rb', line 411 def submit_card(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/submit", { card: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |