Class: Stripe::Issuing::Card::TestHelpers

Inherits:
APIResourceTestHelpers show all
Defined in:
lib/stripe/resources/issuing/card.rb

Constant Summary collapse

RESOURCE_CLASS =
Card

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResourceTestHelpers

custom_method, #initialize, resource_url, #resource_url

Methods included from APIOperations::Request

included

Constructor Details

This class inherits a constructor from Stripe::APIResourceTestHelpers

Class Method Details

.deliver_card(card, params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to delivered.



842
843
844
845
846
847
848
849
# File 'lib/stripe/resources/issuing/card.rb', line 842

def self.deliver_card(card, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/deliver", { card: CGI.escape(card) }),
    params: params,
    opts: opts
  )
end

.fail_card(card, params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to failure.



862
863
864
865
866
867
868
869
# File 'lib/stripe/resources/issuing/card.rb', line 862

def self.fail_card(card, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/fail", { card: CGI.escape(card) }),
    params: params,
    opts: opts
  )
end

.resource_classObject



837
838
839
# File 'lib/stripe/resources/issuing/card.rb', line 837

def self.resource_class
  "Card"
end

.return_card(card, params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to returned.



882
883
884
885
886
887
888
889
# File 'lib/stripe/resources/issuing/card.rb', line 882

def self.return_card(card, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/return", { card: CGI.escape(card) }),
    params: params,
    opts: opts
  )
end

.ship_card(card, params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to shipped.



902
903
904
905
906
907
908
909
# File 'lib/stripe/resources/issuing/card.rb', line 902

def self.ship_card(card, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/ship", { card: CGI.escape(card) }),
    params: params,
    opts: opts
  )
end

.submit_card(card, params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to submitted. This method requires Stripe Version ‘2024-09-30.acacia’ or later.



922
923
924
925
926
927
928
929
# File 'lib/stripe/resources/issuing/card.rb', line 922

def self.submit_card(card, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/submit", { card: CGI.escape(card) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#deliver_card(params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to delivered.



852
853
854
855
856
857
858
859
# File 'lib/stripe/resources/issuing/card.rb', line 852

def deliver_card(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/deliver", { card: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#fail_card(params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to failure.



872
873
874
875
876
877
878
879
# File 'lib/stripe/resources/issuing/card.rb', line 872

def fail_card(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/fail", { card: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#return_card(params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to returned.



892
893
894
895
896
897
898
899
# File 'lib/stripe/resources/issuing/card.rb', line 892

def return_card(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/return", { card: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#ship_card(params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to shipped.



912
913
914
915
916
917
918
919
# File 'lib/stripe/resources/issuing/card.rb', line 912

def ship_card(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/ship", { card: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end

#submit_card(params = {}, opts = {}) ⇒ Object

Updates the shipping status of the specified Issuing Card object to submitted. This method requires Stripe Version ‘2024-09-30.acacia’ or later.



932
933
934
935
936
937
938
939
# File 'lib/stripe/resources/issuing/card.rb', line 932

def submit_card(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/cards/%<card>s/shipping/submit", { card: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end