Class: Stripe::Issuing::CardCreateParams::SpendingControls
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardCreateParams::SpendingControls
- Defined in:
- lib/stripe/params/issuing/card_create_params.rb
Defined Under Namespace
Classes: SpendingLimit
Instance Attribute Summary collapse
-
#allowed_card_presences ⇒ Object
Array of card presence statuses from which authorizations will be allowed.
-
#allowed_categories ⇒ Object
Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to allow.
-
#allowed_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be allowed.
-
#blocked_card_presences ⇒ Object
Array of card presence statuses from which authorizations will be declined.
-
#blocked_categories ⇒ Object
Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to decline.
-
#blocked_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be declined.
-
#spending_limits ⇒ Object
Limit spending with amount-based rules that apply across any cards this card replaced (i.e., its ‘replacement_for` card and that card’s ‘replacement_for` card, up the chain).
Instance Method Summary collapse
-
#initialize(allowed_card_presences: nil, allowed_categories: nil, allowed_merchant_countries: nil, blocked_card_presences: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil) ⇒ SpendingControls
constructor
A new instance of SpendingControls.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(allowed_card_presences: nil, allowed_categories: nil, allowed_merchant_countries: nil, blocked_card_presences: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil) ⇒ SpendingControls
Returns a new instance of SpendingControls.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 150 def initialize( allowed_card_presences: nil, allowed_categories: nil, allowed_merchant_countries: nil, blocked_card_presences: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil ) @allowed_card_presences = allowed_card_presences @allowed_categories = allowed_categories @allowed_merchant_countries = allowed_merchant_countries @blocked_card_presences = blocked_card_presences @blocked_categories = blocked_categories @blocked_merchant_countries = blocked_merchant_countries @spending_limits = spending_limits end |
Instance Attribute Details
#allowed_card_presences ⇒ Object
Array of card presence statuses from which authorizations will be allowed. Possible options are ‘present`, `not_present`. All other statuses will be blocked. Cannot be set with `blocked_card_presences`. Provide an empty value to unset this control.
136 137 138 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 136 def allowed_card_presences @allowed_card_presences end |
#allowed_categories ⇒ Object
Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to allow. All other categories will be blocked. Cannot be set with ‘blocked_categories`.
138 139 140 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 138 def allowed_categories @allowed_categories end |
#allowed_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `blocked_merchant_countries`. Provide an empty value to unset this control.
140 141 142 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 140 def allowed_merchant_countries @allowed_merchant_countries end |
#blocked_card_presences ⇒ Object
Array of card presence statuses from which authorizations will be declined. Possible options are ‘present`, `not_present`. Cannot be set with `allowed_card_presences`. Provide an empty value to unset this control.
142 143 144 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 142 def blocked_card_presences @blocked_card_presences end |
#blocked_categories ⇒ Object
Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to decline. All other categories will be allowed. Cannot be set with ‘allowed_categories`.
144 145 146 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 144 def blocked_categories @blocked_categories end |
#blocked_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `allowed_merchant_countries`. Provide an empty value to unset this control.
146 147 148 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 146 def blocked_merchant_countries @blocked_merchant_countries end |
#spending_limits ⇒ Object
Limit spending with amount-based rules that apply across any cards this card replaced (i.e., its ‘replacement_for` card and that card’s ‘replacement_for` card, up the chain).
148 149 150 |
# File 'lib/stripe/params/issuing/card_create_params.rb', line 148 def spending_limits @spending_limits end |