Class: Stripe::Issuing::CardService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardService::CreateParams
- Defined in:
- lib/stripe/services/issuing/card_service.rb
Defined Under Namespace
Classes: Pin, Shipping, SpendingControls
Instance Attribute Summary collapse
-
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
-
#currency ⇒ Object
The currency for the card.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#financial_account ⇒ Object
Attribute for param field financial_account.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#personalization_design ⇒ Object
The personalization design object belonging to this card.
-
#pin ⇒ Object
The desired PIN for this card.
-
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
-
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
-
#second_line ⇒ Object
The second line to print on the card.
-
#shipping ⇒ Object
The address where the card will be shipped.
-
#spending_controls ⇒ Object
Rules that control spending for this card.
-
#status ⇒ Object
Whether authorizations can be approved on this card.
-
#type ⇒ Object
The type of card to issue.
Instance Method Summary collapse
-
#initialize(cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/stripe/services/issuing/card_service.rb', line 290 def initialize( cardholder: nil, currency: nil, expand: nil, financial_account: nil, metadata: nil, personalization_design: nil, pin: nil, replacement_for: nil, replacement_reason: nil, second_line: nil, shipping: nil, spending_controls: nil, status: nil, type: nil ) @cardholder = cardholder @currency = currency @expand = @financial_account = financial_account @metadata = @personalization_design = personalization_design @pin = pin @replacement_for = replacement_for @replacement_reason = replacement_reason @second_line = second_line @shipping = shipping @spending_controls = spending_controls @status = status @type = type end |
Instance Attribute Details
#cardholder ⇒ Object
The [Cardholder](stripe.com/docs/api#issuing_cardholder_object) object with which the card will be associated.
249 250 251 |
# File 'lib/stripe/services/issuing/card_service.rb', line 249 def cardholder @cardholder end |
#currency ⇒ Object
The currency for the card.
252 253 254 |
# File 'lib/stripe/services/issuing/card_service.rb', line 252 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
255 256 257 |
# File 'lib/stripe/services/issuing/card_service.rb', line 255 def @expand end |
#financial_account ⇒ Object
Attribute for param field financial_account
258 259 260 |
# File 'lib/stripe/services/issuing/card_service.rb', line 258 def financial_account @financial_account end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
261 262 263 |
# File 'lib/stripe/services/issuing/card_service.rb', line 261 def @metadata end |
#personalization_design ⇒ Object
The personalization design object belonging to this card.
264 265 266 |
# File 'lib/stripe/services/issuing/card_service.rb', line 264 def personalization_design @personalization_design end |
#pin ⇒ Object
The desired PIN for this card.
267 268 269 |
# File 'lib/stripe/services/issuing/card_service.rb', line 267 def pin @pin end |
#replacement_for ⇒ Object
The card this is meant to be a replacement for (if any).
270 271 272 |
# File 'lib/stripe/services/issuing/card_service.rb', line 270 def replacement_for @replacement_for end |
#replacement_reason ⇒ Object
If ‘replacement_for` is specified, this should indicate why that card is being replaced.
273 274 275 |
# File 'lib/stripe/services/issuing/card_service.rb', line 273 def replacement_reason @replacement_reason end |
#second_line ⇒ Object
The second line to print on the card. Max length: 24 characters.
276 277 278 |
# File 'lib/stripe/services/issuing/card_service.rb', line 276 def second_line @second_line end |
#shipping ⇒ Object
The address where the card will be shipped.
279 280 281 |
# File 'lib/stripe/services/issuing/card_service.rb', line 279 def shipping @shipping end |
#spending_controls ⇒ Object
Rules that control spending for this card. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
282 283 284 |
# File 'lib/stripe/services/issuing/card_service.rb', line 282 def spending_controls @spending_controls end |
#status ⇒ Object
Whether authorizations can be approved on this card. May be blocked from activating cards depending on past-due Cardholder requirements. Defaults to ‘inactive`.
285 286 287 |
# File 'lib/stripe/services/issuing/card_service.rb', line 285 def status @status end |
#type ⇒ Object
The type of card to issue. Possible values are ‘physical` or `virtual`.
288 289 290 |
# File 'lib/stripe/services/issuing/card_service.rb', line 288 def type @type end |