Class: Stripe::Issuing::Cardholder
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Cardholder
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Overview
An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](docs.stripe.com/issuing) cards.
Related guide: [How to create a cardholder](docs.stripe.com/issuing/cards/virtual/issue-cards#create-cardholder)
Defined Under Namespace
Classes: Billing, Company, Individual, Requirements, SpendingControls
Constant Summary collapse
- OBJECT_NAME =
"issuing.cardholder"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing ⇒ Object
readonly
Attribute for field billing.
-
#company ⇒ Object
readonly
Additional information about a ‘company` cardholder.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#email ⇒ Object
readonly
The cardholder’s email address.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#individual ⇒ Object
readonly
Additional information about an ‘individual` cardholder.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
The cardholder’s name.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone_number ⇒ Object
readonly
The cardholder’s phone number.
-
#preferred_locales ⇒ Object
readonly
The cardholder’s preferred locales (languages), ordered by preference.
-
#requirements ⇒ Object
readonly
Attribute for field requirements.
-
#spending_controls ⇒ Object
readonly
Rules that control spending across this cardholder’s cards.
-
#status ⇒ Object
readonly
Specifies whether to permit authorizations on this cardholder’s cards.
-
#type ⇒ Object
readonly
One of ‘individual` or `company`.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Issuing Cardholder object that can be issued cards.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Cardholder objects.
- .object_name ⇒ Object
-
.update(cardholder, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Cardholder object by setting the values of the parameters passed.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing ⇒ Object (readonly)
Attribute for field billing
218 219 220 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 218 def billing @billing end |
#company ⇒ Object (readonly)
Additional information about a ‘company` cardholder.
220 221 222 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 220 def company @company end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
222 223 224 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 222 def created @created end |
#email ⇒ Object (readonly)
The cardholder’s email address.
224 225 226 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 224 def email @email end |
#id ⇒ Object (readonly)
Unique identifier for the object.
226 227 228 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 226 def id @id end |
#individual ⇒ Object (readonly)
Additional information about an ‘individual` cardholder.
228 229 230 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 228 def individual @individual end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
230 231 232 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 230 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
232 233 234 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 232 def @metadata end |
#name ⇒ Object (readonly)
The cardholder’s name. This will be printed on cards issued to them.
234 235 236 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 234 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
236 237 238 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 236 def object @object end |
#phone_number ⇒ Object (readonly)
The cardholder’s phone number. This is required for all cardholders who will be creating EU cards. See the [3D Secure documentation](docs.stripe.com/issuing/3d-secure#when-is-3d-secure-applied) for more details.
238 239 240 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 238 def phone_number @phone_number end |
#preferred_locales ⇒ Object (readonly)
The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘da`, `de`, `en`, `es`, `fr`, `it`, `pl`, or `sv`.
This changes the language of the [3D Secure flow](https://docs.stripe.com/issuing/3d-secure) and one-time password messages sent to the cardholder.
241 242 243 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 241 def preferred_locales @preferred_locales end |
#requirements ⇒ Object (readonly)
Attribute for field requirements
243 244 245 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 243 def requirements @requirements end |
#spending_controls ⇒ Object (readonly)
Rules that control spending across this cardholder’s cards. Refer to our [documentation](docs.stripe.com/issuing/controls/spending-controls) for more details.
245 246 247 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 245 def spending_controls @spending_controls end |
#status ⇒ Object (readonly)
Specifies whether to permit authorizations on this cardholder’s cards.
247 248 249 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 247 def status @status end |
#type ⇒ Object (readonly)
One of ‘individual` or `company`. See [Choose a cardholder type](docs.stripe.com/issuing/other/choose-cardholder) for more details.
249 250 251 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 249 def type @type end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Issuing Cardholder object that can be issued cards.
252 253 254 255 256 257 258 259 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 252 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/issuing/cardholders", params: params, opts: opts ) end |
.field_remappings ⇒ Object
291 292 293 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 291 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
281 282 283 284 285 286 287 288 289 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 281 def self.inner_class_types @inner_class_types = { billing: Billing, company: Company, individual: Individual, requirements: Requirements, spending_controls: SpendingControls, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Cardholder objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
262 263 264 265 266 267 268 269 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 262 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/cardholders", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 15 def self.object_name "issuing.cardholder" end |
.update(cardholder, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Cardholder object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
272 273 274 275 276 277 278 279 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 272 def self.update(cardholder, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/cardholders/%<cardholder>s", { cardholder: CGI.escape(cardholder) }), params: params, opts: opts ) end |