Class: Stripe::Issuing::Cardholder
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Cardholder
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Overview
An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](stripe.com/docs/issuing) cards.
Related guide: [How to create a cardholder](stripe.com/docs/issuing/cards/virtual/issue-cards#create-cardholder)
Defined Under Namespace
Classes: Billing, Company, CreateParams, Individual, ListParams, Requirements, SpendingControls, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"issuing.cardholder"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing ⇒ Object
readonly
Attribute for field billing.
-
#company ⇒ Object
readonly
Additional information about a ‘company` cardholder.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#email ⇒ Object
readonly
The cardholder’s email address.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#individual ⇒ Object
readonly
Additional information about an ‘individual` cardholder.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
The cardholder’s name.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone_number ⇒ Object
readonly
The cardholder’s phone number.
-
#preferred_locales ⇒ Object
readonly
The cardholder’s preferred locales (languages), ordered by preference.
-
#requirements ⇒ Object
readonly
Attribute for field requirements.
-
#spending_controls ⇒ Object
readonly
Rules that control spending across this cardholder’s cards.
-
#status ⇒ Object
readonly
Specifies whether to permit authorizations on this cardholder’s cards.
-
#type ⇒ Object
readonly
One of ‘individual` or `company`.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Issuing Cardholder object that can be issued cards.
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Cardholder objects.
- .object_name ⇒ Object
-
.update(cardholder, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Cardholder object by setting the values of the parameters passed.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing ⇒ Object (readonly)
Attribute for field billing
635 636 637 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 635 def billing @billing end |
#company ⇒ Object (readonly)
Additional information about a ‘company` cardholder.
637 638 639 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 637 def company @company end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
639 640 641 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 639 def created @created end |
#email ⇒ Object (readonly)
The cardholder’s email address.
641 642 643 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 641 def email @email end |
#id ⇒ Object (readonly)
Unique identifier for the object.
643 644 645 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 643 def id @id end |
#individual ⇒ Object (readonly)
Additional information about an ‘individual` cardholder.
645 646 647 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 645 def individual @individual end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
647 648 649 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 647 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
649 650 651 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 649 def @metadata end |
#name ⇒ Object (readonly)
The cardholder’s name. This will be printed on cards issued to them.
651 652 653 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 651 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
653 654 655 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 653 def object @object end |
#phone_number ⇒ Object (readonly)
The cardholder’s phone number. This is required for all cardholders who will be creating EU cards. See the [3D Secure documentation](stripe.com/docs/issuing/3d-secure#when-is-3d-secure-applied) for more details.
655 656 657 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 655 def phone_number @phone_number end |
#preferred_locales ⇒ Object (readonly)
The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.
This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.
658 659 660 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 658 def preferred_locales @preferred_locales end |
#requirements ⇒ Object (readonly)
Attribute for field requirements
660 661 662 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 660 def requirements @requirements end |
#spending_controls ⇒ Object (readonly)
Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
662 663 664 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 662 def spending_controls @spending_controls end |
#status ⇒ Object (readonly)
Specifies whether to permit authorizations on this cardholder’s cards.
664 665 666 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 664 def status @status end |
#type ⇒ Object (readonly)
One of ‘individual` or `company`. See [Choose a cardholder type](stripe.com/docs/issuing/other/choose-cardholder) for more details.
666 667 668 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 666 def type @type end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Issuing Cardholder object that can be issued cards.
669 670 671 672 673 674 675 676 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 669 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/issuing/cardholders", params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Cardholder objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
679 680 681 682 683 684 685 686 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 679 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/cardholders", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 15 def self.object_name "issuing.cardholder" end |
.update(cardholder, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Cardholder object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
689 690 691 692 693 694 695 696 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 689 def self.update(cardholder, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/cardholders/%<cardholder>s", { cardholder: CGI.escape(cardholder) }), params: params, opts: opts ) end |