Class: Stripe::Issuing::Cardholder

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/cardholder.rb

Overview

An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](stripe.com/docs/issuing) cards.

Related guide: [How to create a cardholder](stripe.com/docs/issuing/cards/virtual/issue-cards#create-cardholder)

Defined Under Namespace

Classes: Billing, Company, CreateParams, Individual, ListParams, Requirements, SpendingControls, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"issuing.cardholder"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billingObject (readonly)

Attribute for field billing



634
635
636
# File 'lib/stripe/resources/issuing/cardholder.rb', line 634

def billing
  @billing
end

#companyObject (readonly)

Additional information about a ‘company` cardholder.



636
637
638
# File 'lib/stripe/resources/issuing/cardholder.rb', line 636

def company
  @company
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



638
639
640
# File 'lib/stripe/resources/issuing/cardholder.rb', line 638

def created
  @created
end

#emailObject (readonly)

The cardholder’s email address.



640
641
642
# File 'lib/stripe/resources/issuing/cardholder.rb', line 640

def email
  @email
end

#idObject (readonly)

Unique identifier for the object.



642
643
644
# File 'lib/stripe/resources/issuing/cardholder.rb', line 642

def id
  @id
end

#individualObject (readonly)

Additional information about an ‘individual` cardholder.



644
645
646
# File 'lib/stripe/resources/issuing/cardholder.rb', line 644

def individual
  @individual
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



646
647
648
# File 'lib/stripe/resources/issuing/cardholder.rb', line 646

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



648
649
650
# File 'lib/stripe/resources/issuing/cardholder.rb', line 648

def 
  @metadata
end

#nameObject (readonly)

The cardholder’s name. This will be printed on cards issued to them.



650
651
652
# File 'lib/stripe/resources/issuing/cardholder.rb', line 650

def name
  @name
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



652
653
654
# File 'lib/stripe/resources/issuing/cardholder.rb', line 652

def object
  @object
end

#phone_numberObject (readonly)

The cardholder’s phone number. This is required for all cardholders who will be creating EU cards. See the [3D Secure documentation](stripe.com/docs/issuing/3d-secure#when-is-3d-secure-applied) for more details.



654
655
656
# File 'lib/stripe/resources/issuing/cardholder.rb', line 654

def phone_number
  @phone_number
end

#preferred_localesObject (readonly)

The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.

This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.


657
658
659
# File 'lib/stripe/resources/issuing/cardholder.rb', line 657

def preferred_locales
  @preferred_locales
end

#requirementsObject (readonly)

Attribute for field requirements



659
660
661
# File 'lib/stripe/resources/issuing/cardholder.rb', line 659

def requirements
  @requirements
end

#spending_controlsObject (readonly)

Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.



661
662
663
# File 'lib/stripe/resources/issuing/cardholder.rb', line 661

def spending_controls
  @spending_controls
end

#statusObject (readonly)

Specifies whether to permit authorizations on this cardholder’s cards.



663
664
665
# File 'lib/stripe/resources/issuing/cardholder.rb', line 663

def status
  @status
end

#typeObject (readonly)

One of ‘individual` or `company`. See [Choose a cardholder type](stripe.com/docs/issuing/other/choose-cardholder) for more details.



665
666
667
# File 'lib/stripe/resources/issuing/cardholder.rb', line 665

def type
  @type
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates a new Issuing Cardholder object that can be issued cards.



668
669
670
671
672
673
674
675
# File 'lib/stripe/resources/issuing/cardholder.rb', line 668

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/issuing/cardholders",
    params: params,
    opts: opts
  )
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Cardholder objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



678
679
680
681
682
683
684
685
# File 'lib/stripe/resources/issuing/cardholder.rb', line 678

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/cardholders",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/issuing/cardholder.rb', line 15

def self.object_name
  "issuing.cardholder"
end

.update(cardholder, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Cardholder object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



688
689
690
691
692
693
694
695
# File 'lib/stripe/resources/issuing/cardholder.rb', line 688

def self.update(cardholder, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/cardholders/%<cardholder>s", { cardholder: CGI.escape(cardholder) }),
    params: params,
    opts: opts
  )
end