Class: Stripe::Issuing::Cardholder
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Cardholder
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Overview
An Issuing ‘Cardholder` object represents an individual or business entity who is [issued](stripe.com/docs/issuing) cards.
Related guide: [How to create a cardholder](stripe.com/docs/issuing/cards/virtual/issue-cards#create-cardholder)
Defined Under Namespace
Classes: Billing, Company, Individual, Requirements, SpendingControls
Constant Summary collapse
- OBJECT_NAME =
"issuing.cardholder"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing ⇒ Object
readonly
Attribute for field billing.
-
#company ⇒ Object
readonly
Additional information about a ‘company` cardholder.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#email ⇒ Object
readonly
The cardholder’s email address.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#individual ⇒ Object
readonly
Additional information about an ‘individual` cardholder.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
The cardholder’s name.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#phone_number ⇒ Object
readonly
The cardholder’s phone number.
-
#preferred_locales ⇒ Object
readonly
The cardholder’s preferred locales (languages), ordered by preference.
-
#requirements ⇒ Object
readonly
Attribute for field requirements.
-
#spending_controls ⇒ Object
readonly
Rules that control spending across this cardholder’s cards.
-
#status ⇒ Object
readonly
Specifies whether to permit authorizations on this cardholder’s cards.
-
#type ⇒ Object
readonly
One of ‘individual` or `company`.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a new Issuing Cardholder object that can be issued cards.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Issuing Cardholder objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Cardholder object by setting the values of the parameters passed.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing ⇒ Object (readonly)
Attribute for field billing
62 63 64 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 62 def billing @billing end |
#company ⇒ Object (readonly)
Additional information about a ‘company` cardholder.
64 65 66 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 64 def company @company end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
66 67 68 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 66 def created @created end |
#email ⇒ Object (readonly)
The cardholder’s email address.
68 69 70 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 68 def email @email end |
#id ⇒ Object (readonly)
Unique identifier for the object.
70 71 72 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 70 def id @id end |
#individual ⇒ Object (readonly)
Additional information about an ‘individual` cardholder.
72 73 74 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 72 def individual @individual end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
74 75 76 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 74 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
76 77 78 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 76 def @metadata end |
#name ⇒ Object (readonly)
The cardholder’s name. This will be printed on cards issued to them.
78 79 80 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 78 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
80 81 82 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 80 def object @object end |
#phone_number ⇒ Object (readonly)
The cardholder’s phone number. This is required for all cardholders who will be creating EU cards. See the [3D Secure documentation](stripe.com/docs/issuing/3d-secure#when-is-3d-secure-applied) for more details.
82 83 84 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 82 def phone_number @phone_number end |
#preferred_locales ⇒ Object (readonly)
The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.
This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.
85 86 87 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 85 def preferred_locales @preferred_locales end |
#requirements ⇒ Object (readonly)
Attribute for field requirements
87 88 89 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 87 def requirements @requirements end |
#spending_controls ⇒ Object (readonly)
Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
89 90 91 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 89 def spending_controls @spending_controls end |
#status ⇒ Object (readonly)
Specifies whether to permit authorizations on this cardholder’s cards.
91 92 93 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 91 def status @status end |
#type ⇒ Object (readonly)
One of ‘individual` or `company`. See [Choose a cardholder type](stripe.com/docs/issuing/other/choose-cardholder) for more details.
93 94 95 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 93 def type @type end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a new Issuing Cardholder object that can be issued cards.
96 97 98 99 100 101 102 103 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 96 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/issuing/cardholders", params: params, opts: opts ) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Issuing Cardholder objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
106 107 108 109 110 111 112 113 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 106 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/cardholders", params: filters, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 15 def self.object_name "issuing.cardholder" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Cardholder object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
116 117 118 119 120 121 122 123 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 116 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/cardholders/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |