Class: Stripe::Issuing::Cardholder::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Cardholder::CreateParams
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Defined Under Namespace
Classes: Billing, Company, Individual, SpendingControls
Instance Attribute Summary collapse
-
#billing ⇒ Object
The cardholder’s billing address.
-
#company ⇒ Object
Additional information about a ‘company` cardholder.
-
#email ⇒ Object
The cardholder’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#individual ⇒ Object
Additional information about an ‘individual` cardholder.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The cardholder’s name.
-
#phone_number ⇒ Object
The cardholder’s phone number.
-
#preferred_locales ⇒ Object
The cardholder’s preferred locales (languages), ordered by preference.
-
#spending_controls ⇒ Object
Rules that control spending across this cardholder’s cards.
-
#status ⇒ Object
Specifies whether to permit authorizations on this cardholder’s cards.
-
#type ⇒ Object
One of ‘individual` or `company`.
Instance Method Summary collapse
-
#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 382 def initialize( billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil ) @billing = billing @company = company @email = email @expand = @individual = individual @metadata = @name = name @phone_number = phone_number @preferred_locales = preferred_locales @spending_controls = spending_controls @status = status @type = type end |
Instance Attribute Details
#billing ⇒ Object
The cardholder’s billing address.
356 357 358 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 356 def billing @billing end |
#company ⇒ Object
Additional information about a ‘company` cardholder.
358 359 360 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 358 def company @company end |
#email ⇒ Object
The cardholder’s email address.
360 361 362 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 360 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
362 363 364 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 362 def @expand end |
#individual ⇒ Object
Additional information about an ‘individual` cardholder.
364 365 366 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 364 def individual @individual end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
366 367 368 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 366 def @metadata end |
#name ⇒ Object
The cardholder’s name. This will be printed on cards issued to them. The maximum length of this field is 24 characters. This field cannot contain any special characters or numbers.
368 369 370 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 368 def name @name end |
#phone_number ⇒ Object
The cardholder’s phone number. This will be transformed to [E.164](en.wikipedia.org/wiki/E.164) if it is not provided in that format already. This is required for all cardholders who will be creating EU cards.
While phone number is optional if the cardholder will not be creating EU cards, note that this cardholder will not be eligible for 3DS without a phone number. See the [3D Secure documentation](https://stripe.com/docs/issuing/3d-secure#when-is-3d-secure-applied) for more details.
371 372 373 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 371 def phone_number @phone_number end |
#preferred_locales ⇒ Object
The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.
This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.
374 375 376 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 374 def preferred_locales @preferred_locales end |
#spending_controls ⇒ Object
Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
376 377 378 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 376 def spending_controls @spending_controls end |
#status ⇒ Object
Specifies whether to permit authorizations on this cardholder’s cards. Defaults to ‘active`.
378 379 380 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 378 def status @status end |
#type ⇒ Object
One of ‘individual` or `company`. See [Choose a cardholder type](stripe.com/docs/issuing/other/choose-cardholder) for more details.
380 381 382 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 380 def type @type end |