Class: Stripe::Issuing::Cardholder::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/cardholder.rb

Defined Under Namespace

Classes: Billing, Company, Individual, SpendingControls

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/stripe/resources/issuing/cardholder.rb', line 447

def initialize(
  billing: nil,
  company: nil,
  email: nil,
  expand: nil,
  individual: nil,
  metadata: nil,
  name: nil,
  phone_number: nil,
  preferred_locales: nil,
  spending_controls: nil,
  status: nil,
  type: nil
)
  @billing = billing
  @company = company
  @email = email
  @expand = expand
  @individual = individual
  @metadata = 
  @name = name
  @phone_number = phone_number
  @preferred_locales = preferred_locales
  @spending_controls = spending_controls
  @status = status
  @type = type
end

Instance Attribute Details

#billingObject

The cardholder’s billing address.



410
411
412
# File 'lib/stripe/resources/issuing/cardholder.rb', line 410

def billing
  @billing
end

#companyObject

Additional information about a ‘company` cardholder.



413
414
415
# File 'lib/stripe/resources/issuing/cardholder.rb', line 413

def company
  @company
end

#emailObject

The cardholder’s email address.



416
417
418
# File 'lib/stripe/resources/issuing/cardholder.rb', line 416

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



419
420
421
# File 'lib/stripe/resources/issuing/cardholder.rb', line 419

def expand
  @expand
end

#individualObject

Additional information about an ‘individual` cardholder.



422
423
424
# File 'lib/stripe/resources/issuing/cardholder.rb', line 422

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



425
426
427
# File 'lib/stripe/resources/issuing/cardholder.rb', line 425

def 
  @metadata
end

#nameObject

The cardholder’s name. This will be printed on cards issued to them. The maximum length of this field is 24 characters. This field cannot contain any special characters or numbers.



428
429
430
# File 'lib/stripe/resources/issuing/cardholder.rb', line 428

def name
  @name
end

#phone_numberObject

The cardholder’s phone number. This will be transformed to [E.164](en.wikipedia.org/wiki/E.164) if it is not provided in that format already. This is required for all cardholders who will be creating EU cards.

While phone number is optional if the cardholder will not be creating EU cards, note that this cardholder will not be eligible for 3DS without a phone number. See the [3D Secure documentation](https://stripe.com/docs/issuing/3d-secure#when-is-3d-secure-applied) for more details.


432
433
434
# File 'lib/stripe/resources/issuing/cardholder.rb', line 432

def phone_number
  @phone_number
end

#preferred_localesObject

The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.

This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.


436
437
438
# File 'lib/stripe/resources/issuing/cardholder.rb', line 436

def preferred_locales
  @preferred_locales
end

#spending_controlsObject

Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.



439
440
441
# File 'lib/stripe/resources/issuing/cardholder.rb', line 439

def spending_controls
  @spending_controls
end

#statusObject

Specifies whether to permit authorizations on this cardholder’s cards. Defaults to ‘active`.



442
443
444
# File 'lib/stripe/resources/issuing/cardholder.rb', line 442

def status
  @status
end

#typeObject

One of ‘individual` or `company`. See [Choose a cardholder type](stripe.com/docs/issuing/other/choose-cardholder) for more details.



445
446
447
# File 'lib/stripe/resources/issuing/cardholder.rb', line 445

def type
  @type
end