Class: Stripe::Issuing::Cardholder::CreateParams::Individual
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Cardholder::CreateParams::Individual
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Defined Under Namespace
Classes: CardIssuing, Dob, Verification
Instance Attribute Summary collapse
-
#card_issuing ⇒ Object
Information related to the card_issuing program for this cardholder.
-
#dob ⇒ Object
The date of birth of this cardholder.
-
#first_name ⇒ Object
The first name of this cardholder.
-
#last_name ⇒ Object
The last name of this cardholder.
-
#verification ⇒ Object
Government-issued ID document for this cardholder.
Instance Method Summary collapse
-
#initialize(card_issuing: nil, dob: nil, first_name: nil, last_name: nil, verification: nil) ⇒ Individual
constructor
A new instance of Individual.
Methods inherited from RequestParams
Constructor Details
#initialize(card_issuing: nil, dob: nil, first_name: nil, last_name: nil, verification: nil) ⇒ Individual
Returns a new instance of Individual.
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 343 def initialize( card_issuing: nil, dob: nil, first_name: nil, last_name: nil, verification: nil ) @card_issuing = card_issuing @dob = dob @first_name = first_name @last_name = last_name @verification = verification end |
Instance Attribute Details
#card_issuing ⇒ Object
Information related to the card_issuing program for this cardholder.
329 330 331 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 329 def card_issuing @card_issuing end |
#dob ⇒ Object
The date of birth of this cardholder. Cardholders must be older than 13 years old.
332 333 334 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 332 def dob @dob end |
#first_name ⇒ Object
The first name of this cardholder. Required before activating Cards. This field cannot contain any numbers, special characters (except periods, commas, hyphens, spaces and apostrophes) or non-latin letters.
335 336 337 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 335 def first_name @first_name end |
#last_name ⇒ Object
The last name of this cardholder. Required before activating Cards. This field cannot contain any numbers, special characters (except periods, commas, hyphens, spaces and apostrophes) or non-latin letters.
338 339 340 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 338 def last_name @last_name end |
#verification ⇒ Object
Government-issued ID document for this cardholder.
341 342 343 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 341 def verification @verification end |