Class: Stripe::Issuing::Cardholder::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/cardholder.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, phone_number: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams

Returns a new instance of ListParams.



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/stripe/resources/issuing/cardholder.rb', line 188

def initialize(
  created: nil,
  email: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  phone_number: nil,
  starting_after: nil,
  status: nil,
  type: nil
)
  @created = created
  @email = email
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @phone_number = phone_number
  @starting_after = starting_after
  @status = status
  @type = type
end

Instance Attribute Details

#createdObject

Only return cardholders that were created during the given date interval.



162
163
164
# File 'lib/stripe/resources/issuing/cardholder.rb', line 162

def created
  @created
end

#emailObject

Only return cardholders that have the given email address.



165
166
167
# File 'lib/stripe/resources/issuing/cardholder.rb', line 165

def email
  @email
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



168
169
170
# File 'lib/stripe/resources/issuing/cardholder.rb', line 168

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



171
172
173
# File 'lib/stripe/resources/issuing/cardholder.rb', line 171

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



174
175
176
# File 'lib/stripe/resources/issuing/cardholder.rb', line 174

def limit
  @limit
end

#phone_numberObject

Only return cardholders that have the given phone number.



177
178
179
# File 'lib/stripe/resources/issuing/cardholder.rb', line 177

def phone_number
  @phone_number
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



180
181
182
# File 'lib/stripe/resources/issuing/cardholder.rb', line 180

def starting_after
  @starting_after
end

#statusObject

Only return cardholders that have the given status. One of ‘active`, `inactive`, or `blocked`.



183
184
185
# File 'lib/stripe/resources/issuing/cardholder.rb', line 183

def status
  @status
end

#typeObject

Only return cardholders that have the given type. One of ‘individual` or `company`.



186
187
188
# File 'lib/stripe/resources/issuing/cardholder.rb', line 186

def type
  @type
end