Class: Stripe::Issuing::Cardholder::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Cardholder::ListParams
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return cardholders that were created during the given date interval.
-
#email ⇒ Object
Only return cardholders that have the given email address.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#phone_number ⇒ Object
Only return cardholders that have the given phone number.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Only return cardholders that have the given status.
-
#type ⇒ Object
Only return cardholders that have the given type.
Instance Method Summary collapse
-
#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, phone_number: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, phone_number: nil, starting_after: nil, status: nil, type: nil) ⇒ ListParams
Returns a new instance of ListParams.
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 188 def initialize( created: nil, email: nil, ending_before: nil, expand: nil, limit: nil, phone_number: nil, starting_after: nil, status: nil, type: nil ) @created = created @email = email @ending_before = ending_before @expand = @limit = limit @phone_number = phone_number @starting_after = starting_after @status = status @type = type end |
Instance Attribute Details
#created ⇒ Object
Only return cardholders that were created during the given date interval.
162 163 164 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 162 def created @created end |
#email ⇒ Object
Only return cardholders that have the given email address.
165 166 167 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 165 def email @email end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
168 169 170 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 168 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
171 172 173 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 171 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
174 175 176 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 174 def limit @limit end |
#phone_number ⇒ Object
Only return cardholders that have the given phone number.
177 178 179 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 177 def phone_number @phone_number end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
180 181 182 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 180 def starting_after @starting_after end |
#status ⇒ Object
Only return cardholders that have the given status. One of ‘active`, `inactive`, or `blocked`.
183 184 185 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 183 def status @status end |
#type ⇒ Object
Only return cardholders that have the given type. One of ‘individual` or `company`.
186 187 188 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 186 def type @type end |