Class: Stripe::Issuing::Cardholder::SpendingControls
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Cardholder::SpendingControls
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Defined Under Namespace
Classes: SpendingLimit
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#allowed_card_presences ⇒ Object
readonly
Array of card presence statuses from which authorizations will be allowed.
-
#allowed_categories ⇒ Object
readonly
Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to allow.
-
#allowed_merchant_countries ⇒ Object
readonly
Array of strings containing representing countries from which authorizations will be allowed.
-
#blocked_card_presences ⇒ Object
readonly
Array of card presence statuses from which authorizations will be declined.
-
#blocked_categories ⇒ Object
readonly
Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to decline.
-
#blocked_merchant_countries ⇒ Object
readonly
Array of strings containing representing countries from which authorizations will be declined.
-
#spending_limits ⇒ Object
readonly
Limit spending with amount-based rules that apply across this cardholder’s cards.
-
#spending_limits_currency ⇒ Object
readonly
Currency of the amounts within ‘spending_limits`.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#allowed_card_presences ⇒ Object (readonly)
Array of card presence statuses from which authorizations will be allowed. Possible options are ‘present`, `not_present`. All other statuses will be blocked. Cannot be set with `blocked_card_presences`. Provide an empty value to unset this control.
193 194 195 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 193 def allowed_card_presences @allowed_card_presences end |
#allowed_categories ⇒ Object (readonly)
Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to allow. All other categories will be blocked. Cannot be set with ‘blocked_categories`.
195 196 197 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 195 def allowed_categories @allowed_categories end |
#allowed_merchant_countries ⇒ Object (readonly)
Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `blocked_merchant_countries`. Provide an empty value to unset this control.
197 198 199 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 197 def allowed_merchant_countries @allowed_merchant_countries end |
#blocked_card_presences ⇒ Object (readonly)
Array of card presence statuses from which authorizations will be declined. Possible options are ‘present`, `not_present`. Cannot be set with `allowed_card_presences`. Provide an empty value to unset this control.
199 200 201 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 199 def blocked_card_presences @blocked_card_presences end |
#blocked_categories ⇒ Object (readonly)
Array of strings containing [categories](docs.stripe.com/api#issuing_authorization_object-merchant_data-category) of authorizations to decline. All other categories will be allowed. Cannot be set with ‘allowed_categories`.
201 202 203 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 201 def blocked_categories @blocked_categories end |
#blocked_merchant_countries ⇒ Object (readonly)
Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `allowed_merchant_countries`. Provide an empty value to unset this control.
203 204 205 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 203 def blocked_merchant_countries @blocked_merchant_countries end |
#spending_limits ⇒ Object (readonly)
Limit spending with amount-based rules that apply across this cardholder’s cards.
205 206 207 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 205 def spending_limits @spending_limits end |
#spending_limits_currency ⇒ Object (readonly)
Currency of the amounts within ‘spending_limits`.
207 208 209 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 207 def spending_limits_currency @spending_limits_currency end |
Class Method Details
.field_remappings ⇒ Object
213 214 215 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 213 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
209 210 211 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 209 def self.inner_class_types @inner_class_types = { spending_limits: SpendingLimit } end |