Class: Stripe::Issuing::Cardholder::SpendingControls
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Cardholder::SpendingControls
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Defined Under Namespace
Classes: SpendingLimit
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#allowed_categories ⇒ Object
readonly
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to allow.
-
#allowed_merchant_countries ⇒ Object
readonly
Array of strings containing representing countries from which authorizations will be allowed.
-
#blocked_categories ⇒ Object
readonly
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to decline.
-
#blocked_merchant_countries ⇒ Object
readonly
Array of strings containing representing countries from which authorizations will be declined.
-
#spending_limits ⇒ Object
readonly
Limit spending with amount-based rules that apply across this cardholder’s cards.
-
#spending_limits_currency ⇒ Object
readonly
Currency of the amounts within ‘spending_limits`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#allowed_categories ⇒ Object (readonly)
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to allow. All other categories will be blocked. Cannot be set with ‘blocked_categories`.
105 106 107 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 105 def allowed_categories @allowed_categories end |
#allowed_merchant_countries ⇒ Object (readonly)
Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `blocked_merchant_countries`. Provide an empty value to unset this control.
107 108 109 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 107 def allowed_merchant_countries @allowed_merchant_countries end |
#blocked_categories ⇒ Object (readonly)
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to decline. All other categories will be allowed. Cannot be set with ‘allowed_categories`.
109 110 111 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 109 def blocked_categories @blocked_categories end |
#blocked_merchant_countries ⇒ Object (readonly)
Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `allowed_merchant_countries`. Provide an empty value to unset this control.
111 112 113 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 111 def blocked_merchant_countries @blocked_merchant_countries end |
#spending_limits ⇒ Object (readonly)
Limit spending with amount-based rules that apply across this cardholder’s cards.
113 114 115 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 113 def spending_limits @spending_limits end |
#spending_limits_currency ⇒ Object (readonly)
Currency of the amounts within ‘spending_limits`.
115 116 117 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 115 def spending_limits_currency @spending_limits_currency end |