Class: Stripe::Issuing::Cardholder::SpendingControls

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/cardholder.rb

Defined Under Namespace

Classes: SpendingLimit

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allowed_categoriesObject (readonly)

Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to allow. All other categories will be blocked. Cannot be set with ‘blocked_categories`.



122
123
124
# File 'lib/stripe/resources/issuing/cardholder.rb', line 122

def allowed_categories
  @allowed_categories
end

#allowed_merchant_countriesObject (readonly)

Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `blocked_merchant_countries`. Provide an empty value to unset this control.



125
126
127
# File 'lib/stripe/resources/issuing/cardholder.rb', line 125

def allowed_merchant_countries
  @allowed_merchant_countries
end

#blocked_categoriesObject (readonly)

Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to decline. All other categories will be allowed. Cannot be set with ‘allowed_categories`.



128
129
130
# File 'lib/stripe/resources/issuing/cardholder.rb', line 128

def blocked_categories
  @blocked_categories
end

#blocked_merchant_countriesObject (readonly)

Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `allowed_merchant_countries`. Provide an empty value to unset this control.



131
132
133
# File 'lib/stripe/resources/issuing/cardholder.rb', line 131

def blocked_merchant_countries
  @blocked_merchant_countries
end

#spending_limitsObject (readonly)

Limit spending with amount-based rules that apply across this cardholder’s cards.



134
135
136
# File 'lib/stripe/resources/issuing/cardholder.rb', line 134

def spending_limits
  @spending_limits
end

#spending_limits_currencyObject (readonly)

Currency of the amounts within ‘spending_limits`.



137
138
139
# File 'lib/stripe/resources/issuing/cardholder.rb', line 137

def spending_limits_currency
  @spending_limits_currency
end