Class: Stripe::Issuing::Cardholder::UpdateParams::SpendingControls
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Cardholder::UpdateParams::SpendingControls
- Defined in:
- lib/stripe/resources/issuing/cardholder.rb
Defined Under Namespace
Classes: SpendingLimit
Instance Attribute Summary collapse
-
#allowed_categories ⇒ Object
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to allow.
-
#allowed_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be allowed.
-
#blocked_categories ⇒ Object
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to decline.
-
#blocked_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be declined.
-
#spending_limits ⇒ Object
Limit spending with amount-based rules that apply across this cardholder’s cards.
-
#spending_limits_currency ⇒ Object
Currency of amounts within ‘spending_limits`.
Instance Method Summary collapse
-
#initialize(allowed_categories: nil, allowed_merchant_countries: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil, spending_limits_currency: nil) ⇒ SpendingControls
constructor
A new instance of SpendingControls.
Methods inherited from RequestParams
Constructor Details
#initialize(allowed_categories: nil, allowed_merchant_countries: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil, spending_limits_currency: nil) ⇒ SpendingControls
Returns a new instance of SpendingControls.
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 581 def initialize( allowed_categories: nil, allowed_merchant_countries: nil, blocked_categories: nil, blocked_merchant_countries: nil, spending_limits: nil, spending_limits_currency: nil ) @allowed_categories = allowed_categories @allowed_merchant_countries = allowed_merchant_countries @blocked_categories = blocked_categories @blocked_merchant_countries = blocked_merchant_countries @spending_limits = spending_limits @spending_limits_currency = spending_limits_currency end |
Instance Attribute Details
#allowed_categories ⇒ Object
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to allow. All other categories will be blocked. Cannot be set with ‘blocked_categories`.
569 570 571 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 569 def allowed_categories @allowed_categories end |
#allowed_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be allowed. Authorizations from merchants in all other countries will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `blocked_merchant_countries`. Provide an empty value to unset this control.
571 572 573 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 571 def allowed_merchant_countries @allowed_merchant_countries end |
#blocked_categories ⇒ Object
Array of strings containing [categories](stripe.com/docs/api#issuing_authorization_object-merchant_data-category) of authorizations to decline. All other categories will be allowed. Cannot be set with ‘allowed_categories`.
573 574 575 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 573 def blocked_categories @blocked_categories end |
#blocked_merchant_countries ⇒ Object
Array of strings containing representing countries from which authorizations will be declined. Country codes should be ISO 3166 alpha-2 country codes (e.g. ‘US`). Cannot be set with `allowed_merchant_countries`. Provide an empty value to unset this control.
575 576 577 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 575 def blocked_merchant_countries @blocked_merchant_countries end |
#spending_limits ⇒ Object
Limit spending with amount-based rules that apply across this cardholder’s cards.
577 578 579 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 577 def spending_limits @spending_limits end |
#spending_limits_currency ⇒ Object
Currency of amounts within ‘spending_limits`. Defaults to your merchant country’s currency.
579 580 581 |
# File 'lib/stripe/resources/issuing/cardholder.rb', line 579 def spending_limits_currency @spending_limits_currency end |