Class: Stripe::Issuing::CardholderCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardholderCreateParams
- Defined in:
- lib/stripe/params/issuing/cardholder_create_params.rb
Defined Under Namespace
Classes: Billing, Company, Individual, SpendingControls
Instance Attribute Summary collapse
-
#billing ⇒ Object
The cardholder’s billing address.
-
#company ⇒ Object
Additional information about a ‘company` cardholder.
-
#email ⇒ Object
The cardholder’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#individual ⇒ Object
Additional information about an ‘individual` cardholder.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The cardholder’s name.
-
#phone_number ⇒ Object
The cardholder’s phone number.
-
#preferred_locales ⇒ Object
The cardholder’s preferred locales (languages), ordered by preference.
-
#spending_controls ⇒ Object
Rules that control spending across this cardholder’s cards.
-
#status ⇒ Object
Specifies whether to permit authorizations on this cardholder’s cards.
-
#type ⇒ Object
One of ‘individual` or `company`.
Instance Method Summary collapse
-
#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CardholderCreateParams
constructor
A new instance of CardholderCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CardholderCreateParams
Returns a new instance of CardholderCreateParams.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 210 def initialize( billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil ) @billing = billing @company = company @email = email @expand = @individual = individual @metadata = @name = name @phone_number = phone_number @preferred_locales = preferred_locales @spending_controls = spending_controls @status = status @type = type end |
Instance Attribute Details
#billing ⇒ Object
The cardholder’s billing address.
184 185 186 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 184 def billing @billing end |
#company ⇒ Object
Additional information about a ‘company` cardholder.
186 187 188 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 186 def company @company end |
#email ⇒ Object
The cardholder’s email address.
188 189 190 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 188 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
190 191 192 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 190 def @expand end |
#individual ⇒ Object
Additional information about an ‘individual` cardholder.
192 193 194 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 192 def individual @individual end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
194 195 196 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 194 def @metadata end |
#name ⇒ Object
The cardholder’s name. This will be printed on cards issued to them. The maximum length of this field is 24 characters. This field cannot contain any special characters or numbers.
196 197 198 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 196 def name @name end |
#phone_number ⇒ Object
The cardholder’s phone number. This will be transformed to [E.164](en.wikipedia.org/wiki/E.164) if it is not provided in that format already. This is required for all cardholders who will be creating EU cards.
While phone number is optional if the cardholder will not be creating EU cards, note that this cardholder will not be eligible for 3DS without a phone number. See the [3D Secure documentation](https://stripe.com/docs/issuing/3d-secure#when-is-3d-secure-applied) for more details.
199 200 201 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 199 def phone_number @phone_number end |
#preferred_locales ⇒ Object
The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.
This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.
202 203 204 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 202 def preferred_locales @preferred_locales end |
#spending_controls ⇒ Object
Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
204 205 206 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 204 def spending_controls @spending_controls end |
#status ⇒ Object
Specifies whether to permit authorizations on this cardholder’s cards. Defaults to ‘active`.
206 207 208 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 206 def status @status end |
#type ⇒ Object
One of ‘individual` or `company`. See [Choose a cardholder type](stripe.com/docs/issuing/other/choose-cardholder) for more details.
208 209 210 |
# File 'lib/stripe/params/issuing/cardholder_create_params.rb', line 208 def type @type end |