Class: Stripe::Issuing::CardholderService::CreateParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/cardholder_service.rb

Defined Under Namespace

Classes: Billing, Company, Individual, SpendingControls

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 271

def initialize(
  billing: nil,
  company: nil,
  email: nil,
  expand: nil,
  individual: nil,
  metadata: nil,
  name: nil,
  phone_number: nil,
  preferred_locales: nil,
  spending_controls: nil,
  status: nil,
  type: nil
)
  @billing = billing
  @company = company
  @email = email
  @expand = expand
  @individual = individual
  @metadata = 
  @name = name
  @phone_number = phone_number
  @preferred_locales = preferred_locales
  @spending_controls = spending_controls
  @status = status
  @type = type
end

Instance Attribute Details

#billingObject

The cardholder’s billing address.



245
246
247
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 245

def billing
  @billing
end

#companyObject

Additional information about a ‘company` cardholder.



247
248
249
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 247

def company
  @company
end

#emailObject

The cardholder’s email address.



249
250
251
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 249

def email
  @email
end

#expandObject

Specifies which fields in the response should be expanded.



251
252
253
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 251

def expand
  @expand
end

#individualObject

Additional information about an ‘individual` cardholder.



253
254
255
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 253

def individual
  @individual
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



255
256
257
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 255

def 
  @metadata
end

#nameObject

The cardholder’s name. This will be printed on cards issued to them. The maximum length of this field is 24 characters. This field cannot contain any special characters or numbers.



257
258
259
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 257

def name
  @name
end

#phone_numberObject

The cardholder’s phone number. This will be transformed to [E.164](en.wikipedia.org/wiki/E.164) if it is not provided in that format already. This is required for all cardholders who will be creating EU cards.

While phone number is optional if the cardholder will not be creating EU cards, note that this cardholder will not be eligible for 3DS without a phone number. See the [3D Secure documentation](https://stripe.com/docs/issuing/3d-secure#when-is-3d-secure-applied) for more details.


260
261
262
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 260

def phone_number
  @phone_number
end

#preferred_localesObject

The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.

This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.


263
264
265
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 263

def preferred_locales
  @preferred_locales
end

#spending_controlsObject

Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.



265
266
267
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 265

def spending_controls
  @spending_controls
end

#statusObject

Specifies whether to permit authorizations on this cardholder’s cards. Defaults to ‘active`.



267
268
269
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 267

def status
  @status
end

#typeObject

One of ‘individual` or `company`. See [Choose a cardholder type](stripe.com/docs/issuing/other/choose-cardholder) for more details.



269
270
271
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 269

def type
  @type
end