Class: Stripe::Issuing::CardholderService::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CardholderService::CreateParams
- Defined in:
- lib/stripe/services/issuing/cardholder_service.rb
Defined Under Namespace
Classes: Billing, Company, Individual, SpendingControls
Instance Attribute Summary collapse
-
#billing ⇒ Object
The cardholder’s billing address.
-
#company ⇒ Object
Additional information about a ‘company` cardholder.
-
#email ⇒ Object
The cardholder’s email address.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#individual ⇒ Object
Additional information about an ‘individual` cardholder.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
The cardholder’s name.
-
#phone_number ⇒ Object
The cardholder’s phone number.
-
#preferred_locales ⇒ Object
The cardholder’s preferred locales (languages), ordered by preference.
-
#spending_controls ⇒ Object
Rules that control spending across this cardholder’s cards.
-
#status ⇒ Object
Specifies whether to permit authorizations on this cardholder’s cards.
-
#type ⇒ Object
One of ‘individual` or `company`.
Instance Method Summary collapse
-
#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 314 def initialize( billing: nil, company: nil, email: nil, expand: nil, individual: nil, metadata: nil, name: nil, phone_number: nil, preferred_locales: nil, spending_controls: nil, status: nil, type: nil ) @billing = billing @company = company @email = email @expand = @individual = individual @metadata = @name = name @phone_number = phone_number @preferred_locales = preferred_locales @spending_controls = spending_controls @status = status @type = type end |
Instance Attribute Details
#billing ⇒ Object
The cardholder’s billing address.
277 278 279 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 277 def billing @billing end |
#company ⇒ Object
Additional information about a ‘company` cardholder.
280 281 282 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 280 def company @company end |
#email ⇒ Object
The cardholder’s email address.
283 284 285 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 283 def email @email end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
286 287 288 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 286 def @expand end |
#individual ⇒ Object
Additional information about an ‘individual` cardholder.
289 290 291 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 289 def individual @individual end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
292 293 294 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 292 def @metadata end |
#name ⇒ Object
The cardholder’s name. This will be printed on cards issued to them. The maximum length of this field is 24 characters. This field cannot contain any special characters or numbers.
295 296 297 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 295 def name @name end |
#phone_number ⇒ Object
The cardholder’s phone number. This will be transformed to [E.164](en.wikipedia.org/wiki/E.164) if it is not provided in that format already. This is required for all cardholders who will be creating EU cards.
While phone number is optional if the cardholder will not be creating EU cards, note that this cardholder will not be eligible for 3DS without a phone number. See the [3D Secure documentation](https://stripe.com/docs/issuing/3d-secure#when-is-3d-secure-applied) for more details.
299 300 301 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 299 def phone_number @phone_number end |
#preferred_locales ⇒ Object
The cardholder’s preferred locales (languages), ordered by preference. Locales can be ‘de`, `en`, `es`, `fr`, or `it`.
This changes the language of the [3D Secure flow](https://stripe.com/docs/issuing/3d-secure) and one-time password messages sent to the cardholder.
303 304 305 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 303 def preferred_locales @preferred_locales end |
#spending_controls ⇒ Object
Rules that control spending across this cardholder’s cards. Refer to our [documentation](stripe.com/docs/issuing/controls/spending-controls) for more details.
306 307 308 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 306 def spending_controls @spending_controls end |
#status ⇒ Object
Specifies whether to permit authorizations on this cardholder’s cards. Defaults to ‘active`.
309 310 311 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 309 def status @status end |
#type ⇒ Object
One of ‘individual` or `company`. See [Choose a cardholder type](stripe.com/docs/issuing/other/choose-cardholder) for more details.
312 313 314 |
# File 'lib/stripe/services/issuing/cardholder_service.rb', line 312 def type @type end |