Class: Stripe::Issuing::CreditUnderwritingRecord::CorrectParams::Decision::CreditLimitDecreased

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/credit_underwriting_record.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased

Returns a new instance of CreditLimitDecreased.



199
200
201
202
203
204
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 199

def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil)
  @amount = amount
  @currency = currency
  @reason_other_explanation = reason_other_explanation
  @reasons = reasons
end

Instance Attribute Details

#amountObject

The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



188
189
190
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 188

def amount
  @amount
end

#currencyObject

The currency of the credit approved, will default to the Account’s Issuing currency.



191
192
193
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 191

def currency
  @currency
end

#reason_other_explanationObject

Details about the ‘reasons.other` when present.



194
195
196
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 194

def reason_other_explanation
  @reason_other_explanation
end

#reasonsObject

List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.



197
198
199
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 197

def reasons
  @reasons
end