Class: Stripe::Issuing::CreditUnderwritingRecord::CorrectParams::Decision::CreditLimitDecreased
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecord::CorrectParams::Decision::CreditLimitDecreased
- Defined in:
- lib/stripe/resources/issuing/credit_underwriting_record.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased
constructor
A new instance of CreditLimitDecreased.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased
Returns a new instance of CreditLimitDecreased.
174 175 176 177 178 179 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 174 def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) @amount = amount @currency = currency @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
166 167 168 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 166 def amount @amount end |
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
168 169 170 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 168 def currency @currency end |
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
170 171 172 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 170 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
172 173 174 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 172 def reasons @reasons end |