Class: Stripe::Issuing::CreditUnderwritingRecord::CreateFromProactiveReviewParams::Decision::CreditLimitApproved
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecord::CreateFromProactiveReviewParams::Decision::CreditLimitApproved
- Defined in:
- lib/stripe/resources/issuing/credit_underwriting_record.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil) ⇒ CreditLimitApproved
constructor
A new instance of CreditLimitApproved.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, currency: nil) ⇒ CreditLimitApproved
Returns a new instance of CreditLimitApproved.
412 413 414 415 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 412 def initialize(amount: nil, currency: nil) @amount = amount @currency = currency end |
Instance Attribute Details
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
408 409 410 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 408 def amount @amount end |
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
410 411 412 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 410 def currency @currency end |