Class: Stripe::Issuing::CreditUnderwritingRecord::CreateFromProactiveReviewParams::Decision::CreditLimitDecreased

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/credit_underwriting_record.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased

Returns a new instance of CreditLimitDecreased.



428
429
430
431
432
433
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 428

def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil)
  @amount = amount
  @currency = currency
  @reason_other_explanation = reason_other_explanation
  @reasons = reasons
end

Instance Attribute Details

#amountObject

The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



420
421
422
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 420

def amount
  @amount
end

#currencyObject

The currency of the credit approved, will default to the Account’s Issuing currency.



422
423
424
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 422

def currency
  @currency
end

#reason_other_explanationObject

Details about the ‘reasons.other` when present.



424
425
426
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 424

def reason_other_explanation
  @reason_other_explanation
end

#reasonsObject

List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.



426
427
428
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 426

def reasons
  @reasons
end