Class: Stripe::Issuing::CreditUnderwritingRecord::Decision::CreditLimitDecreased
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::CreditUnderwritingRecord::Decision::CreditLimitDecreased
- Defined in:
- lib/stripe/resources/issuing/credit_underwriting_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Credit amount approved after decrease.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#reason_other_explanation ⇒ Object
readonly
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
readonly
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Credit amount approved after decrease. An approved credit limit is required before you can set a amount in the [CreditPolicy API](stripe.com/docs/api/issuing/credit_policy).
55 56 57 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 55 def amount @amount end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
58 59 60 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 58 def currency @currency end |
#reason_other_explanation ⇒ Object (readonly)
Details about the ‘reasons.other` when present.
61 62 63 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 61 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object (readonly)
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
64 65 66 |
# File 'lib/stripe/resources/issuing/credit_underwriting_record.rb', line 64 def reasons @reasons end |