Class: Stripe::Issuing::CreditUnderwritingRecordCorrectParams::Decision::CreditLimitDecreased
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordCorrectParams::Decision::CreditLimitDecreased
- Defined in:
- lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased
constructor
A new instance of CreditLimitDecreased.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased
Returns a new instance of CreditLimitDecreased.
69 70 71 72 73 74 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 69 def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) @amount = amount @currency = currency @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
61 62 63 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 61 def amount @amount end |
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
63 64 65 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 63 def currency @currency end |
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
65 66 67 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 65 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
67 68 69 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_correct_params.rb', line 67 def reasons @reasons end |