Class: Stripe::Issuing::CreditUnderwritingRecordCreateFromProactiveReviewParams::Decision::CreditLimitDecreased
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordCreateFromProactiveReviewParams::Decision::CreditLimitDecreased
- Defined in:
- lib/stripe/params/issuing/credit_underwriting_record_create_from_proactive_review_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased
constructor
A new instance of CreditLimitDecreased.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased
Returns a new instance of CreditLimitDecreased.
42 43 44 45 46 47 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_proactive_review_params.rb', line 42 def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) @amount = amount @currency = currency @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#amount ⇒ Object
The credit approved, in the currency of the account and [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
34 35 36 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_proactive_review_params.rb', line 34 def amount @amount end |
#currency ⇒ Object
The currency of the credit approved, will default to the Account’s Issuing currency.
36 37 38 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_proactive_review_params.rb', line 36 def currency @currency end |
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
38 39 40 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_proactive_review_params.rb', line 38 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.
40 41 42 |
# File 'lib/stripe/params/issuing/credit_underwriting_record_create_from_proactive_review_params.rb', line 40 def reasons @reasons end |