Class: Stripe::Issuing::CreditUnderwritingRecordService::CorrectParams::Decision::CreditLimitDecreased

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/credit_underwriting_record_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased

Returns a new instance of CreditLimitDecreased.



108
109
110
111
112
113
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 108

def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil)
  @amount = amount
  @currency = currency
  @reason_other_explanation = reason_other_explanation
  @reasons = reasons
end

Instance Attribute Details

#amountObject

The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



97
98
99
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 97

def amount
  @amount
end

#currencyObject

The currency of the credit approved, will default to the Account’s Issuing currency.



100
101
102
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 100

def currency
  @currency
end

#reason_other_explanationObject

Details about the ‘reasons.other` when present.



103
104
105
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 103

def reason_other_explanation
  @reason_other_explanation
end

#reasonsObject

List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.



106
107
108
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 106

def reasons
  @reasons
end