Class: Stripe::Issuing::CreditUnderwritingRecordService::CreateFromApplicationParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/credit_underwriting_record_service.rb

Defined Under Namespace

Classes: Application, CreditUser

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application: nil, credit_user: nil, expand: nil, metadata: nil) ⇒ CreateFromApplicationParams

Returns a new instance of CreateFromApplicationParams.



347
348
349
350
351
352
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 347

def initialize(application: nil, credit_user: nil, expand: nil, metadata: nil)
  @application = application
  @credit_user = credit_user
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#applicationObject

Details about the application submission.



336
337
338
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 336

def application
  @application
end

#credit_userObject

Information about the company or person applying or holding the account.



339
340
341
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 339

def credit_user
  @credit_user
end

#expandObject

Specifies which fields in the response should be expanded.



342
343
344
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 342

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



345
346
347
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 345

def 
  @metadata
end