Class: Stripe::Issuing::CreditUnderwritingRecordService::CreateFromProactiveReviewParams::Decision::CreditLimitDecreased

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/issuing/credit_underwriting_record_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil) ⇒ CreditLimitDecreased

Returns a new instance of CreditLimitDecreased.



396
397
398
399
400
401
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 396

def initialize(amount: nil, currency: nil, reason_other_explanation: nil, reasons: nil)
  @amount = amount
  @currency = currency
  @reason_other_explanation = reason_other_explanation
  @reasons = reasons
end

Instance Attribute Details

#amountObject

The credit approved, in the currency of the account and [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



385
386
387
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 385

def amount
  @amount
end

#currencyObject

The currency of the credit approved, will default to the Account’s Issuing currency.



388
389
390
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 388

def currency
  @currency
end

#reason_other_explanationObject

Details about the ‘reasons.other` when present.



391
392
393
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 391

def reason_other_explanation
  @reason_other_explanation
end

#reasonsObject

List of reasons why the existing credit was decreased, up to 4 reasons, in order of importance.



394
395
396
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 394

def reasons
  @reasons
end