Class: Stripe::Issuing::CreditUnderwritingRecordService::CreateFromProactiveReviewParams::Decision::CreditLineClosed
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::CreditUnderwritingRecordService::CreateFromProactiveReviewParams::Decision::CreditLineClosed
- Defined in:
- lib/stripe/services/issuing/credit_underwriting_record_service.rb
Instance Attribute Summary collapse
-
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
-
#reasons ⇒ Object
List of reasons why the credit line was closed, up to 4 reasons, in order of importance.
Instance Method Summary collapse
-
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ CreditLineClosed
constructor
A new instance of CreditLineClosed.
Methods inherited from RequestParams
Constructor Details
#initialize(reason_other_explanation: nil, reasons: nil) ⇒ CreditLineClosed
Returns a new instance of CreditLineClosed.
365 366 367 368 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 365 def initialize(reason_other_explanation: nil, reasons: nil) @reason_other_explanation = reason_other_explanation @reasons = reasons end |
Instance Attribute Details
#reason_other_explanation ⇒ Object
Details about the ‘reasons.other` when present.
361 362 363 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 361 def reason_other_explanation @reason_other_explanation end |
#reasons ⇒ Object
List of reasons why the credit line was closed, up to 4 reasons, in order of importance.
363 364 365 |
# File 'lib/stripe/services/issuing/credit_underwriting_record_service.rb', line 363 def reasons @reasons end |