Class: Stripe::Issuing::Dispute
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Dispute
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Overview
As a [card issuer](docs.stripe.com/issuing), you can dispute transactions that the cardholder does not recognize, suspects to be fraudulent, or has other issues with.
Related guide: [Issuing disputes](docs.stripe.com/issuing/purchases/disputes)
Defined Under Namespace
Classes: CryptoTransaction, Evidence, NetworkLifecycle, TestHelpers, Treasury
Constant Summary collapse
- OBJECT_NAME =
"issuing.dispute"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Disputed amount in the card’s currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#balance_transactions ⇒ Object
readonly
List of balance transactions associated with the dispute.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#crypto_transactions ⇒ Object
readonly
Array of onchain crypto transactions linked to this resource.
-
#currency ⇒ Object
readonly
The currency the ‘transaction` was made in.
-
#evidence ⇒ Object
readonly
Attribute for field evidence.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#loss_reason ⇒ Object
readonly
The enum that describes the dispute loss outcome.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#network_lifecycle ⇒ Object
readonly
Incoming information from the card network for this dispute.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
Current status of the dispute.
-
#transaction ⇒ Object
readonly
The transaction being disputed.
-
#treasury ⇒ Object
readonly
[Treasury](docs.stripe.com/api/treasury) details related to this dispute if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates an Issuing Dispute object.
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Dispute objects.
- .object_name ⇒ Object
-
.submit(dispute, params = {}, opts = {}) ⇒ Object
Submits an Issuing Dispute to the card network.
-
.update(dispute, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Dispute object by setting the values of the parameters passed.
Instance Method Summary collapse
-
#submit(params = {}, opts = {}) ⇒ Object
Submits an Issuing Dispute to the card network.
- #test_helpers ⇒ Object
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Disputed amount in the card’s currency and in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). Usually the amount of the ‘transaction`, but can differ (usually because of currency fluctuation).
419 420 421 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 419 def amount @amount end |
#balance_transactions ⇒ Object (readonly)
List of balance transactions associated with the dispute.
421 422 423 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 421 def balance_transactions @balance_transactions end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
423 424 425 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 423 def created @created end |
#crypto_transactions ⇒ Object (readonly)
Array of onchain crypto transactions linked to this resource.
425 426 427 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 425 def crypto_transactions @crypto_transactions end |
#currency ⇒ Object (readonly)
The currency the ‘transaction` was made in.
427 428 429 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 427 def currency @currency end |
#evidence ⇒ Object (readonly)
Attribute for field evidence
429 430 431 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 429 def evidence @evidence end |
#id ⇒ Object (readonly)
Unique identifier for the object.
431 432 433 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 431 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
433 434 435 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 433 def livemode @livemode end |
#loss_reason ⇒ Object (readonly)
The enum that describes the dispute loss outcome. If the dispute is not lost, this field will be absent. New enum values may be added in the future, so be sure to handle unknown values.
435 436 437 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 435 def loss_reason @loss_reason end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
437 438 439 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 437 def @metadata end |
#network_lifecycle ⇒ Object (readonly)
Incoming information from the card network for this dispute. Includes the acquiring merchant’s initial response, pre-arbitration submission, and pre-arbitration response to the dispute.
439 440 441 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 439 def network_lifecycle @network_lifecycle end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
441 442 443 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 441 def object @object end |
#status ⇒ Object (readonly)
Current status of the dispute.
443 444 445 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 443 def status @status end |
#transaction ⇒ Object (readonly)
The transaction being disputed.
445 446 447 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 445 def transaction @transaction end |
#treasury ⇒ Object (readonly)
[Treasury](docs.stripe.com/api/treasury) details related to this dispute if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts
447 448 449 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 447 def treasury @treasury end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates an Issuing Dispute object. Individual pieces of evidence within the evidence object are optional at this point. Stripe only validates that required evidence is present during submission. Refer to [Dispute reasons and evidence](docs.stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence) for more details about evidence requirements.
450 451 452 453 454 455 456 457 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 450 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/issuing/disputes", params: params, opts: opts ) end |
.field_remappings ⇒ Object
607 608 609 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 607 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
598 599 600 601 602 603 604 605 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 598 def self.inner_class_types @inner_class_types = { crypto_transactions: CryptoTransaction, evidence: Evidence, network_lifecycle: NetworkLifecycle, treasury: Treasury, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Dispute objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
460 461 462 463 464 465 466 467 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 460 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/disputes", params: params, opts: opts ) end |
.object_name ⇒ Object
15 16 17 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 15 def self.object_name "issuing.dispute" end |
.submit(dispute, params = {}, opts = {}) ⇒ Object
Submits an Issuing Dispute to the card network. Stripe validates that all evidence fields required for the dispute’s reason are present. For more details, see [Dispute reasons and evidence](docs.stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence).
480 481 482 483 484 485 486 487 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 480 def self.submit(dispute, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/disputes/%<dispute>s/submit", { dispute: CGI.escape(dispute) }), params: params, opts: opts ) end |
.update(dispute, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Dispute object by setting the values of the parameters passed. Any parameters not provided will be left unchanged. Properties on the evidence object can be unset by passing in an empty string.
490 491 492 493 494 495 496 497 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 490 def self.update(dispute, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/disputes/%<dispute>s", { dispute: CGI.escape(dispute) }), params: params, opts: opts ) end |
Instance Method Details
#submit(params = {}, opts = {}) ⇒ Object
Submits an Issuing Dispute to the card network. Stripe validates that all evidence fields required for the dispute’s reason are present. For more details, see [Dispute reasons and evidence](docs.stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence).
470 471 472 473 474 475 476 477 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 470 def submit(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/disputes/%<dispute>s/submit", { dispute: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#test_helpers ⇒ Object
499 500 501 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 499 def test_helpers TestHelpers.new(self) end |