Class: Stripe::Issuing::Dispute

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/dispute.rb

Overview

As a [card issuer](stripe.com/docs/issuing), you can dispute transactions that the cardholder does not recognize, suspects to be fraudulent, or has other issues with.

Related guide: [Issuing disputes](stripe.com/docs/issuing/purchases/disputes)

Defined Under Namespace

Classes: CreateParams, Evidence, ListParams, SubmitParams, Treasury, UpdateParams

Constant Summary collapse

OBJECT_NAME =
"issuing.dispute"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Disputed amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). Usually the amount of the ‘transaction`, but can differ (usually because of currency fluctuation).



863
864
865
# File 'lib/stripe/resources/issuing/dispute.rb', line 863

def amount
  @amount
end

#balance_transactionsObject (readonly)

List of balance transactions associated with the dispute.



865
866
867
# File 'lib/stripe/resources/issuing/dispute.rb', line 865

def balance_transactions
  @balance_transactions
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



867
868
869
# File 'lib/stripe/resources/issuing/dispute.rb', line 867

def created
  @created
end

#currencyObject (readonly)

The currency the ‘transaction` was made in.



869
870
871
# File 'lib/stripe/resources/issuing/dispute.rb', line 869

def currency
  @currency
end

#evidenceObject (readonly)

Attribute for field evidence



871
872
873
# File 'lib/stripe/resources/issuing/dispute.rb', line 871

def evidence
  @evidence
end

#idObject (readonly)

Unique identifier for the object.



873
874
875
# File 'lib/stripe/resources/issuing/dispute.rb', line 873

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



875
876
877
# File 'lib/stripe/resources/issuing/dispute.rb', line 875

def livemode
  @livemode
end

#loss_reasonObject (readonly)

The enum that describes the dispute loss outcome. If the dispute is not lost, this field will be absent. New enum values may be added in the future, so be sure to handle unknown values.



877
878
879
# File 'lib/stripe/resources/issuing/dispute.rb', line 877

def loss_reason
  @loss_reason
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



879
880
881
# File 'lib/stripe/resources/issuing/dispute.rb', line 879

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



881
882
883
# File 'lib/stripe/resources/issuing/dispute.rb', line 881

def object
  @object
end

#statusObject (readonly)

Current status of the dispute.



883
884
885
# File 'lib/stripe/resources/issuing/dispute.rb', line 883

def status
  @status
end

#transactionObject (readonly)

The transaction being disputed.



885
886
887
# File 'lib/stripe/resources/issuing/dispute.rb', line 885

def transaction
  @transaction
end

#treasuryObject (readonly)

[Treasury](stripe.com/docs/api/treasury) details related to this dispute if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts



887
888
889
# File 'lib/stripe/resources/issuing/dispute.rb', line 887

def treasury
  @treasury
end

Class Method Details

.create(params = {}, opts = {}) ⇒ Object

Creates an Issuing Dispute object. Individual pieces of evidence within the evidence object are optional at this point. Stripe only validates that required evidence is present during submission. Refer to [Dispute reasons and evidence](docs.stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence) for more details about evidence requirements.



890
891
892
893
894
895
896
897
# File 'lib/stripe/resources/issuing/dispute.rb', line 890

def self.create(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/issuing/disputes",
    params: params,
    opts: opts
  )
end

.field_remappingsObject



943
944
945
# File 'lib/stripe/resources/issuing/dispute.rb', line 943

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



939
940
941
# File 'lib/stripe/resources/issuing/dispute.rb', line 939

def self.inner_class_types
  @inner_class_types = { evidence: Evidence, treasury: Treasury }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Dispute objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



900
901
902
903
904
905
906
907
# File 'lib/stripe/resources/issuing/dispute.rb', line 900

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/disputes",
    params: params,
    opts: opts
  )
end

.object_nameObject



15
16
17
# File 'lib/stripe/resources/issuing/dispute.rb', line 15

def self.object_name
  "issuing.dispute"
end

.submit(dispute, params = {}, opts = {}) ⇒ Object

Submits an Issuing Dispute to the card network. Stripe validates that all evidence fields required for the dispute’s reason are present. For more details, see [Dispute reasons and evidence](docs.stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence).



920
921
922
923
924
925
926
927
# File 'lib/stripe/resources/issuing/dispute.rb', line 920

def self.submit(dispute, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/disputes/%<dispute>s/submit", { dispute: CGI.escape(dispute) }),
    params: params,
    opts: opts
  )
end

.update(dispute, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Dispute object by setting the values of the parameters passed. Any parameters not provided will be left unchanged. Properties on the evidence object can be unset by passing in an empty string.



930
931
932
933
934
935
936
937
# File 'lib/stripe/resources/issuing/dispute.rb', line 930

def self.update(dispute, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/disputes/%<dispute>s", { dispute: CGI.escape(dispute) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#submit(params = {}, opts = {}) ⇒ Object

Submits an Issuing Dispute to the card network. Stripe validates that all evidence fields required for the dispute’s reason are present. For more details, see [Dispute reasons and evidence](docs.stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence).



910
911
912
913
914
915
916
917
# File 'lib/stripe/resources/issuing/dispute.rb', line 910

def submit(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/disputes/%<dispute>s/submit", { dispute: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end