Class: Stripe::Issuing::Dispute::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Dispute::ListParams
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Defined Under Namespace
Classes: Created
Instance Attribute Summary collapse
-
#created ⇒ Object
Only return Issuing disputes that were created during the given date interval.
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
Select Issuing disputes with the given status.
-
#transaction ⇒ Object
Select the Issuing dispute for the given transaction.
Instance Method Summary collapse
-
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, transaction: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, transaction: nil) ⇒ ListParams
Returns a new instance of ListParams.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 183 def initialize( created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, transaction: nil ) @created = created @ending_before = ending_before @expand = @limit = limit @starting_after = starting_after @status = status @transaction = transaction end |
Instance Attribute Details
#created ⇒ Object
Only return Issuing disputes that were created during the given date interval.
169 170 171 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 169 def created @created end |
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
171 172 173 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 171 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
173 174 175 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 173 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
175 176 177 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 175 def limit @limit end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
177 178 179 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 177 def starting_after @starting_after end |
#status ⇒ Object
Select Issuing disputes with the given status.
179 180 181 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 179 def status @status end |
#transaction ⇒ Object
Select the Issuing dispute for the given transaction.
181 182 183 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 181 def transaction @transaction end |