Class: Stripe::Issuing::Dispute::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/dispute.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, transaction: nil) ⇒ ListParams

Returns a new instance of ListParams.



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/stripe/resources/issuing/dispute.rb', line 183

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  transaction: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @transaction = transaction
end

Instance Attribute Details

#createdObject

Only return Issuing disputes that were created during the given date interval.



169
170
171
# File 'lib/stripe/resources/issuing/dispute.rb', line 169

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



171
172
173
# File 'lib/stripe/resources/issuing/dispute.rb', line 171

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



173
174
175
# File 'lib/stripe/resources/issuing/dispute.rb', line 173

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



175
176
177
# File 'lib/stripe/resources/issuing/dispute.rb', line 175

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



177
178
179
# File 'lib/stripe/resources/issuing/dispute.rb', line 177

def starting_after
  @starting_after
end

#statusObject

Select Issuing disputes with the given status.



179
180
181
# File 'lib/stripe/resources/issuing/dispute.rb', line 179

def status
  @status
end

#transactionObject

Select the Issuing dispute for the given transaction.



181
182
183
# File 'lib/stripe/resources/issuing/dispute.rb', line 181

def transaction
  @transaction
end