Class: Stripe::Issuing::Dispute::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/dispute.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil, transaction: nil) ⇒ ListParams

Returns a new instance of ListParams.



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/stripe/resources/issuing/dispute.rb', line 233

def initialize(
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil,
  transaction: nil
)
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
  @transaction = transaction
end

Instance Attribute Details

#createdObject

Only return Issuing disputes that were created during the given date interval.



213
214
215
# File 'lib/stripe/resources/issuing/dispute.rb', line 213

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



216
217
218
# File 'lib/stripe/resources/issuing/dispute.rb', line 216

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



219
220
221
# File 'lib/stripe/resources/issuing/dispute.rb', line 219

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



222
223
224
# File 'lib/stripe/resources/issuing/dispute.rb', line 222

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



225
226
227
# File 'lib/stripe/resources/issuing/dispute.rb', line 225

def starting_after
  @starting_after
end

#statusObject

Select Issuing disputes with the given status.



228
229
230
# File 'lib/stripe/resources/issuing/dispute.rb', line 228

def status
  @status
end

#transactionObject

Select the Issuing dispute for the given transaction.



231
232
233
# File 'lib/stripe/resources/issuing/dispute.rb', line 231

def transaction
  @transaction
end