Class: Stripe::Issuing::Dispute::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/dispute.rb

Defined Under Namespace

Classes: Evidence

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



763
764
765
766
767
768
# File 'lib/stripe/resources/issuing/dispute.rb', line 763

def initialize(amount: nil, evidence: nil, expand: nil, metadata: nil)
  @amount = amount
  @evidence = evidence
  @expand = expand
  @metadata = 
end

Instance Attribute Details

#amountObject

The dispute amount in the card’s currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



755
756
757
# File 'lib/stripe/resources/issuing/dispute.rb', line 755

def amount
  @amount
end

#evidenceObject

Evidence provided for the dispute.



757
758
759
# File 'lib/stripe/resources/issuing/dispute.rb', line 757

def evidence
  @evidence
end

#expandObject

Specifies which fields in the response should be expanded.



759
760
761
# File 'lib/stripe/resources/issuing/dispute.rb', line 759

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



761
762
763
# File 'lib/stripe/resources/issuing/dispute.rb', line 761

def 
  @metadata
end