Class: Stripe::Issuing::Dispute::UpdateParams::Evidence::NotReceived
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Dispute::UpdateParams::Evidence::NotReceived
- Defined in:
- lib/stripe/resources/issuing/dispute.rb
Instance Attribute Summary collapse
-
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
-
#expected_at ⇒ Object
Date when the cardholder expected to receive the product.
-
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
-
#product_description ⇒ Object
Description of the merchandise or service that was purchased.
-
#product_type ⇒ Object
Whether the product was a merchandise or service.
Instance Method Summary collapse
-
#initialize(additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil) ⇒ NotReceived
constructor
A new instance of NotReceived.
Methods inherited from RequestParams
Constructor Details
#initialize(additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil) ⇒ NotReceived
Returns a new instance of NotReceived.
649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 649 def initialize( additional_documentation: nil, expected_at: nil, explanation: nil, product_description: nil, product_type: nil ) @additional_documentation = additional_documentation @expected_at = expected_at @explanation = explanation @product_description = product_description @product_type = product_type end |
Instance Attribute Details
#additional_documentation ⇒ Object
(ID of a [file upload](stripe.com/docs/guides/file-upload)) Additional documentation supporting the dispute.
639 640 641 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 639 def additional_documentation @additional_documentation end |
#expected_at ⇒ Object
Date when the cardholder expected to receive the product.
641 642 643 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 641 def expected_at @expected_at end |
#explanation ⇒ Object
Explanation of why the cardholder is disputing this transaction.
643 644 645 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 643 def explanation @explanation end |
#product_description ⇒ Object
Description of the merchandise or service that was purchased.
645 646 647 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 645 def product_description @product_description end |
#product_type ⇒ Object
Whether the product was a merchandise or service.
647 648 649 |
# File 'lib/stripe/resources/issuing/dispute.rb', line 647 def product_type @product_type end |