Class: Stripe::Issuing::DisputeService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Issuing::DisputeService
- Defined in:
- lib/stripe/services/issuing/dispute_service.rb
Defined Under Namespace
Classes: CreateParams, ListParams, RetrieveParams, SubmitParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates an Issuing Dispute object.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Dispute objects.
-
#retrieve(dispute, params = {}, opts = {}) ⇒ Object
Retrieves an Issuing Dispute object.
-
#submit(dispute, params = {}, opts = {}) ⇒ Object
Submits an Issuing Dispute to the card network.
-
#update(dispute, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Dispute object by setting the values of the parameters passed.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates an Issuing Dispute object. Individual pieces of evidence within the evidence object are optional at this point. Stripe only validates that required evidence is present during submission. Refer to [Dispute reasons and evidence](docs.stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence) for more details about evidence requirements.
641 642 643 644 645 646 647 648 649 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 641 def create(params = {}, opts = {}) request( method: :post, path: "/v1/issuing/disputes", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Dispute objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
652 653 654 655 656 657 658 659 660 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 652 def list(params = {}, opts = {}) request( method: :get, path: "/v1/issuing/disputes", params: params, opts: opts, base_address: :api ) end |
#retrieve(dispute, params = {}, opts = {}) ⇒ Object
Retrieves an Issuing Dispute object.
663 664 665 666 667 668 669 670 671 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 663 def retrieve(dispute, params = {}, opts = {}) request( method: :get, path: format("/v1/issuing/disputes/%<dispute>s", { dispute: CGI.escape(dispute) }), params: params, opts: opts, base_address: :api ) end |
#submit(dispute, params = {}, opts = {}) ⇒ Object
Submits an Issuing Dispute to the card network. Stripe validates that all evidence fields required for the dispute’s reason are present. For more details, see [Dispute reasons and evidence](docs.stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence).
674 675 676 677 678 679 680 681 682 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 674 def submit(dispute, params = {}, opts = {}) request( method: :post, path: format("/v1/issuing/disputes/%<dispute>s/submit", { dispute: CGI.escape(dispute) }), params: params, opts: opts, base_address: :api ) end |
#update(dispute, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Dispute object by setting the values of the parameters passed. Any parameters not provided will be left unchanged. Properties on the evidence object can be unset by passing in an empty string.
685 686 687 688 689 690 691 692 693 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 685 def update(dispute, params = {}, opts = {}) request( method: :post, path: format("/v1/issuing/disputes/%<dispute>s", { dispute: CGI.escape(dispute) }), params: params, opts: opts, base_address: :api ) end |