Class: Stripe::Issuing::DisputeService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::Issuing::DisputeService
- Defined in:
- lib/stripe/services/issuing/dispute_service.rb
Defined Under Namespace
Classes: CreateParams, ListParams, RetrieveParams, SubmitParams, UpdateParams
Instance Method Summary collapse
-
#create(params = {}, opts = {}) ⇒ Object
Creates an Issuing Dispute object.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Dispute objects.
-
#retrieve(dispute, params = {}, opts = {}) ⇒ Object
Retrieves an Issuing Dispute object.
-
#submit(dispute, params = {}, opts = {}) ⇒ Object
Submits an Issuing Dispute to the card network.
-
#update(dispute, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Dispute object by setting the values of the parameters passed.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#create(params = {}, opts = {}) ⇒ Object
Creates an Issuing Dispute object. Individual pieces of evidence within the evidence object are optional at this point. Stripe only validates that required evidence is present during submission. Refer to [Dispute reasons and evidence](stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence) for more details about evidence requirements.
739 740 741 742 743 744 745 746 747 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 739 def create(params = {}, opts = {}) request( method: :post, path: "/v1/issuing/disputes", params: params, opts: opts, base_address: :api ) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Dispute objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
750 751 752 753 754 755 756 757 758 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 750 def list(params = {}, opts = {}) request( method: :get, path: "/v1/issuing/disputes", params: params, opts: opts, base_address: :api ) end |
#retrieve(dispute, params = {}, opts = {}) ⇒ Object
Retrieves an Issuing Dispute object.
761 762 763 764 765 766 767 768 769 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 761 def retrieve(dispute, params = {}, opts = {}) request( method: :get, path: format("/v1/issuing/disputes/%<dispute>s", { dispute: CGI.escape(dispute) }), params: params, opts: opts, base_address: :api ) end |
#submit(dispute, params = {}, opts = {}) ⇒ Object
Submits an Issuing Dispute to the card network. Stripe validates that all evidence fields required for the dispute’s reason are present. For more details, see [Dispute reasons and evidence](stripe.com/docs/issuing/purchases/disputes#dispute-reasons-and-evidence).
772 773 774 775 776 777 778 779 780 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 772 def submit(dispute, params = {}, opts = {}) request( method: :post, path: format("/v1/issuing/disputes/%<dispute>s/submit", { dispute: CGI.escape(dispute) }), params: params, opts: opts, base_address: :api ) end |
#update(dispute, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Dispute object by setting the values of the parameters passed. Any parameters not provided will be left unchanged. Properties on the evidence object can be unset by passing in an empty string.
783 784 785 786 787 788 789 790 791 |
# File 'lib/stripe/services/issuing/dispute_service.rb', line 783 def update(dispute, params = {}, opts = {}) request( method: :post, path: format("/v1/issuing/disputes/%<dispute>s", { dispute: CGI.escape(dispute) }), params: params, opts: opts, base_address: :api ) end |