Class: Stripe::Issuing::DisputeSettlementDetail
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::DisputeSettlementDetail
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/issuing/dispute_settlement_detail.rb
Overview
Represents a record from the card network of a money movement or change in state for an Issuing dispute. These records are included in the settlement reports that we receive from networks and expose to users as Settlement objects.
Defined Under Namespace
Classes: NetworkData
Constant Summary collapse
- OBJECT_NAME =
"issuing.dispute_settlement_detail"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Disputed amount in the card’s currency and in the smallest currency unit.
-
#card ⇒ Object
readonly
The card used to make the original transaction.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
The currency the original transaction was made in.
-
#dispute ⇒ Object
readonly
The ID of the linked dispute.
-
#event_type ⇒ Object
readonly
The type of event corresponding to this dispute settlement detail, representing the stage in the dispute network lifecycle.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#network ⇒ Object
readonly
The card network for this dispute settlement detail.
-
#network_data ⇒ Object
readonly
Details about the transaction, such as processing dates, set by the card network.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#settlement ⇒ Object
readonly
The ID of the linked card network settlement.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing DisputeSettlementDetail objects.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Disputed amount in the card’s currency and in the smallest currency unit. Usually the amount of the transaction, but can differ (usually because of currency fluctuation).
28 29 30 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 28 def amount @amount end |
#card ⇒ Object (readonly)
The card used to make the original transaction.
30 31 32 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 30 def card @card end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
32 33 34 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 32 def created @created end |
#currency ⇒ Object (readonly)
The currency the original transaction was made in. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
34 35 36 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 34 def currency @currency end |
#dispute ⇒ Object (readonly)
The ID of the linked dispute.
36 37 38 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 36 def dispute @dispute end |
#event_type ⇒ Object (readonly)
The type of event corresponding to this dispute settlement detail, representing the stage in the dispute network lifecycle.
38 39 40 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 38 def event_type @event_type end |
#id ⇒ Object (readonly)
Unique identifier for the object.
40 41 42 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 40 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
42 43 44 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 42 def livemode @livemode end |
#network ⇒ Object (readonly)
The card network for this dispute settlement detail. One of [“visa”, “mastercard”, “maestro”]
44 45 46 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 44 def network @network end |
#network_data ⇒ Object (readonly)
Details about the transaction, such as processing dates, set by the card network.
46 47 48 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 46 def network_data @network_data end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
48 49 50 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 48 def object @object end |
#settlement ⇒ Object (readonly)
The ID of the linked card network settlement.
50 51 52 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 50 def settlement @settlement end |
Class Method Details
.field_remappings ⇒ Object
66 67 68 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 66 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
62 63 64 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 62 def self.inner_class_types @inner_class_types = { network_data: NetworkData } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing DisputeSettlementDetail objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
53 54 55 56 57 58 59 60 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 53 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/dispute_settlement_details", params: params, opts: opts ) end |
.object_name ⇒ Object
11 12 13 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 11 def self.object_name "issuing.dispute_settlement_detail" end |