Class: Stripe::Issuing::DisputeSettlementDetail::NetworkData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::DisputeSettlementDetail::NetworkData
- Defined in:
- lib/stripe/resources/issuing/dispute_settlement_detail.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#processing_date ⇒ Object
readonly
The date the transaction was processed by the card network.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#processing_date ⇒ Object (readonly)
The date the transaction was processed by the card network. This can be different from the date the seller recorded the transaction depending on when the acquirer submits the transaction to the network.
17 18 19 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 17 def processing_date @processing_date end |
Class Method Details
.field_remappings ⇒ Object
23 24 25 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 23 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
19 20 21 |
# File 'lib/stripe/resources/issuing/dispute_settlement_detail.rb', line 19 def self.inner_class_types @inner_class_types = {} end |