Class: Stripe::Issuing::DisputeUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::DisputeUpdateParams
- Defined in:
- lib/stripe/params/issuing/dispute_update_params.rb
Defined Under Namespace
Classes: Evidence, ProvisionalCredit
Instance Attribute Summary collapse
-
#amount ⇒ Object
The dispute amount in the card's currency and in the smallest currency unit.
-
#evidence ⇒ Object
Evidence provided for the dispute.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object.
-
#provisional_credit ⇒ Object
Provisional credit information for this dispute.
Instance Method Summary collapse
-
#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil, provisional_credit: nil) ⇒ DisputeUpdateParams
constructor
A new instance of DisputeUpdateParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, evidence: nil, expand: nil, metadata: nil, provisional_credit: nil) ⇒ DisputeUpdateParams
Returns a new instance of DisputeUpdateParams.
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 281 def initialize( amount: nil, evidence: nil, expand: nil, metadata: nil, provisional_credit: nil ) @amount = amount @evidence = evidence @expand = @metadata = @provisional_credit = provisional_credit end |
Instance Attribute Details
#amount ⇒ Object
The dispute amount in the card's currency and in the smallest currency unit.
271 272 273 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 271 def amount @amount end |
#evidence ⇒ Object
Evidence provided for the dispute.
273 274 275 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 273 def evidence @evidence end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
275 276 277 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 275 def @expand end |
#metadata ⇒ Object
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to metadata.
277 278 279 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 277 def @metadata end |
#provisional_credit ⇒ Object
Provisional credit information for this dispute.
279 280 281 |
# File 'lib/stripe/params/issuing/dispute_update_params.rb', line 279 def provisional_credit @provisional_credit end |