Class: Stripe::Issuing::FraudLiabilityDebit

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/issuing/fraud_liability_debit.rb

Overview

A fraud liability debit occurs when Stripe debits a platform’s account for fraud losses on Issuing transactions.

Defined Under Namespace

Classes: ListParams

Constant Summary collapse

OBJECT_NAME =
"issuing.fraud_liability_debit"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Debited amount. This is equal to the disputed amount and is given in the card’s currency and in the smallest currency unit.



59
60
61
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 59

def amount
  @amount
end

#balance_transactionObject (readonly)

ID of the [balance transaction](stripe.com/docs/api/balance_transactions) associated with this debit.



61
62
63
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 61

def balance_transaction
  @balance_transaction
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



63
64
65
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 63

def created
  @created
end

#currencyObject (readonly)

The currency of the debit. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



65
66
67
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 65

def currency
  @currency
end

#disputeObject (readonly)

The ID of the linked dispute.



67
68
69
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 67

def dispute
  @dispute
end

#idObject (readonly)

Unique identifier for the object.



69
70
71
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 69

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



71
72
73
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 71

def livemode
  @livemode
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



73
74
75
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 73

def object
  @object
end

Class Method Details

.field_remappingsObject



89
90
91
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 89

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



85
86
87
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 85

def self.inner_class_types
  @inner_class_types = {}
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing FraudLiabilityDebit objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



76
77
78
79
80
81
82
83
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 76

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/issuing/fraud_liability_debits",
    params: params,
    opts: opts
  )
end

.object_nameObject



11
12
13
# File 'lib/stripe/resources/issuing/fraud_liability_debit.rb', line 11

def self.object_name
  "issuing.fraud_liability_debit"
end