Class: Stripe::Issuing::PersonalizationDesign
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::PersonalizationDesign
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/personalization_design.rb
Overview
A Personalization Design is a logical grouping of a Physical Bundle, card logo, and carrier text that represents a product line.
Defined Under Namespace
Classes: CarrierText, Preferences, RejectionReasons, TestHelpers
Constant Summary collapse
- OBJECT_NAME =
"issuing.personalization_design"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card_logo ⇒ Object
readonly
The file for the card logo to use with physical bundles that support card logos.
-
#carrier_text ⇒ Object
readonly
Hash containing carrier text, for use with physical bundles that support carrier text.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#lookup_key ⇒ Object
readonly
A lookup key used to retrieve personalization designs dynamically from a static string.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
Friendly display name.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#physical_bundle ⇒ Object
readonly
The physical bundle object belonging to this personalization design.
-
#preferences ⇒ Object
readonly
Attribute for field preferences.
-
#rejection_reasons ⇒ Object
readonly
Attribute for field rejection_reasons.
-
#status ⇒ Object
readonly
Whether this personalization design can be used to create cards.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Creates a personalization design object.
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of personalization design objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates a card personalization object.
Instance Method Summary collapse
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card_logo ⇒ Object (readonly)
The file for the card logo to use with physical bundles that support card logos. Must have a ‘purpose` value of `issuing_logo`.
29 30 31 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 29 def card_logo @card_logo end |
#carrier_text ⇒ Object (readonly)
Hash containing carrier text, for use with physical bundles that support carrier text.
31 32 33 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 31 def carrier_text @carrier_text end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
33 34 35 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 33 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
35 36 37 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 35 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
37 38 39 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 37 def livemode @livemode end |
#lookup_key ⇒ Object (readonly)
A lookup key used to retrieve personalization designs dynamically from a static string. This may be up to 200 characters.
39 40 41 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 39 def lookup_key @lookup_key end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
41 42 43 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 41 def @metadata end |
#name ⇒ Object (readonly)
Friendly display name.
43 44 45 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 43 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
45 46 47 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 45 def object @object end |
#physical_bundle ⇒ Object (readonly)
The physical bundle object belonging to this personalization design.
47 48 49 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 47 def physical_bundle @physical_bundle end |
#preferences ⇒ Object (readonly)
Attribute for field preferences
49 50 51 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 49 def preferences @preferences end |
#rejection_reasons ⇒ Object (readonly)
Attribute for field rejection_reasons
51 52 53 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 51 def rejection_reasons @rejection_reasons end |
#status ⇒ Object (readonly)
Whether this personalization design can be used to create cards.
53 54 55 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 53 def status @status end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Creates a personalization design object.
56 57 58 59 60 61 62 63 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 56 def self.create(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/issuing/personalization_designs", params: params, opts: opts ) end |
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of personalization design objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
66 67 68 69 70 71 72 73 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 66 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/personalization_designs", params: filters, opts: opts ) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 13 def self.object_name "issuing.personalization_design" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates a card personalization object.
76 77 78 79 80 81 82 83 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 76 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/personalization_designs/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#test_helpers ⇒ Object
85 86 87 |
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 85 def test_helpers TestHelpers.new(self) end |