Class: Stripe::Issuing::PersonalizationDesign::ListParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/personalization_design.rb

Defined Under Namespace

Classes: Preferences

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ending_before: nil, expand: nil, limit: nil, lookup_keys: nil, preferences: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 81

def initialize(
  ending_before: nil,
  expand: nil,
  limit: nil,
  lookup_keys: nil,
  preferences: nil,
  starting_after: nil,
  status: nil
)
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @lookup_keys = lookup_keys
  @preferences = preferences
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



61
62
63
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 61

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



64
65
66
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 64

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



67
68
69
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 67

def limit
  @limit
end

#lookup_keysObject

Only return personalization designs with the given lookup keys.



70
71
72
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 70

def lookup_keys
  @lookup_keys
end

#preferencesObject

Only return personalization designs with the given preferences.



73
74
75
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 73

def preferences
  @preferences
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



76
77
78
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 76

def starting_after
  @starting_after
end

#statusObject

Only return personalization designs with the given status.



79
80
81
# File 'lib/stripe/resources/issuing/personalization_design.rb', line 79

def status
  @status
end