Class: Stripe::Issuing::ProgramCreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::ProgramCreateParams
- Defined in:
- lib/stripe/params/issuing/program_create_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#is_default ⇒ Object
If true, makes the specified program the default for the given account.
-
#platform_program ⇒ Object
The program to use as the parent for the new program to create.
Instance Method Summary collapse
-
#initialize(expand: nil, is_default: nil, platform_program: nil) ⇒ ProgramCreateParams
constructor
A new instance of ProgramCreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, is_default: nil, platform_program: nil) ⇒ ProgramCreateParams
Returns a new instance of ProgramCreateParams.
14 15 16 17 18 |
# File 'lib/stripe/params/issuing/program_create_params.rb', line 14 def initialize(expand: nil, is_default: nil, platform_program: nil) @expand = @is_default = is_default @platform_program = platform_program end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8 9 10 |
# File 'lib/stripe/params/issuing/program_create_params.rb', line 8 def @expand end |
#is_default ⇒ Object
If true, makes the specified program the default for the given account.
10 11 12 |
# File 'lib/stripe/params/issuing/program_create_params.rb', line 10 def is_default @is_default end |
#platform_program ⇒ Object
The program to use as the parent for the new program to create.
12 13 14 |
# File 'lib/stripe/params/issuing/program_create_params.rb', line 12 def platform_program @platform_program end |