Class: Stripe::Issuing::Settlement

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/issuing/settlement.rb

Overview

When a non-stripe BIN is used, any use of an [issued card](stripe.com/docs/issuing) must be settled directly with the card network. The net amount owed is represented by an Issuing ‘Settlement` object.

Constant Summary collapse

OBJECT_NAME =
"issuing.settlement"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#binObject (readonly)

The Bank Identification Number reflecting this settlement record.



14
15
16
# File 'lib/stripe/resources/issuing/settlement.rb', line 14

def bin
  @bin
end

#clearing_dateObject (readonly)

The date that the transactions are cleared and posted to user’s accounts.



17
18
19
# File 'lib/stripe/resources/issuing/settlement.rb', line 17

def clearing_date
  @clearing_date
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



20
21
22
# File 'lib/stripe/resources/issuing/settlement.rb', line 20

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



23
24
25
# File 'lib/stripe/resources/issuing/settlement.rb', line 23

def currency
  @currency
end

#idObject (readonly)

Unique identifier for the object.



26
27
28
# File 'lib/stripe/resources/issuing/settlement.rb', line 26

def id
  @id
end

#interchange_feesObject (readonly)

The total interchange received as reimbursement for the transactions.



29
30
31
# File 'lib/stripe/resources/issuing/settlement.rb', line 29

def interchange_fees
  @interchange_fees
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



32
33
34
# File 'lib/stripe/resources/issuing/settlement.rb', line 32

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



35
36
37
# File 'lib/stripe/resources/issuing/settlement.rb', line 35

def 
  @metadata
end

#net_totalObject (readonly)

The total net amount required to settle with the network.



38
39
40
# File 'lib/stripe/resources/issuing/settlement.rb', line 38

def net_total
  @net_total
end

#networkObject (readonly)

The card network for this settlement report. One of [“visa”, “maestro”]



41
42
43
# File 'lib/stripe/resources/issuing/settlement.rb', line 41

def network
  @network
end

#network_feesObject (readonly)

The total amount of fees owed to the network.



44
45
46
# File 'lib/stripe/resources/issuing/settlement.rb', line 44

def network_fees
  @network_fees
end

#network_settlement_identifierObject (readonly)

The Settlement Identification Number assigned by the network.



47
48
49
# File 'lib/stripe/resources/issuing/settlement.rb', line 47

def network_settlement_identifier
  @network_settlement_identifier
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



50
51
52
# File 'lib/stripe/resources/issuing/settlement.rb', line 50

def object
  @object
end

#settlement_serviceObject (readonly)

One of ‘international` or `uk_national_net`.



53
54
55
# File 'lib/stripe/resources/issuing/settlement.rb', line 53

def settlement_service
  @settlement_service
end

#statusObject (readonly)

The current processing status of this settlement.



56
57
58
# File 'lib/stripe/resources/issuing/settlement.rb', line 56

def status
  @status
end

#transaction_countObject (readonly)

The total number of transactions reflected in this settlement.



59
60
61
# File 'lib/stripe/resources/issuing/settlement.rb', line 59

def transaction_count
  @transaction_count
end

#transaction_volumeObject (readonly)

The total transaction amount reflected in this settlement.



62
63
64
# File 'lib/stripe/resources/issuing/settlement.rb', line 62

def transaction_volume
  @transaction_volume
end

Class Method Details

.object_nameObject



9
10
11
# File 'lib/stripe/resources/issuing/settlement.rb', line 9

def self.object_name
  "issuing.settlement"
end