Class: Stripe::Issuing::Token
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Token
- Extended by:
- APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/token.rb
Overview
An issuing token object is created when an issued card is added to a digital wallet. As a [card issuer](stripe.com/docs/issuing), you can [view and manage these tokens](stripe.com/docs/issuing/controls/token-management) through Stripe.
Defined Under Namespace
Classes: ListParams, NetworkData, RetrieveParams, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"issuing.token"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#card ⇒ Object
readonly
Card associated with this token.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#device_fingerprint ⇒ Object
readonly
The hashed ID derived from the device ID from the card network associated with the token.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last4 ⇒ Object
readonly
The last four digits of the token.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#network ⇒ Object
readonly
The token service provider / card network associated with the token.
-
#network_data ⇒ Object
readonly
Attribute for field network_data.
-
#network_updated_at ⇒ Object
readonly
Time at which the token was last updated by the card network.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#status ⇒ Object
readonly
The usage state of the token.
-
#wallet_provider ⇒ Object
readonly
The digital wallet for this token, if one was used.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(params = {}, opts = {}) ⇒ Object
Lists all Issuing Token objects for a given card.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Attempts to update the specified Issuing Token object to the status specified.
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#card ⇒ Object (readonly)
Card associated with this token.
202 203 204 |
# File 'lib/stripe/resources/issuing/token.rb', line 202 def card @card end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
205 206 207 |
# File 'lib/stripe/resources/issuing/token.rb', line 205 def created @created end |
#device_fingerprint ⇒ Object (readonly)
The hashed ID derived from the device ID from the card network associated with the token.
208 209 210 |
# File 'lib/stripe/resources/issuing/token.rb', line 208 def device_fingerprint @device_fingerprint end |
#id ⇒ Object (readonly)
Unique identifier for the object.
211 212 213 |
# File 'lib/stripe/resources/issuing/token.rb', line 211 def id @id end |
#last4 ⇒ Object (readonly)
The last four digits of the token.
214 215 216 |
# File 'lib/stripe/resources/issuing/token.rb', line 214 def last4 @last4 end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
217 218 219 |
# File 'lib/stripe/resources/issuing/token.rb', line 217 def livemode @livemode end |
#network ⇒ Object (readonly)
The token service provider / card network associated with the token.
220 221 222 |
# File 'lib/stripe/resources/issuing/token.rb', line 220 def network @network end |
#network_data ⇒ Object (readonly)
Attribute for field network_data
223 224 225 |
# File 'lib/stripe/resources/issuing/token.rb', line 223 def network_data @network_data end |
#network_updated_at ⇒ Object (readonly)
Time at which the token was last updated by the card network. Measured in seconds since the Unix epoch.
226 227 228 |
# File 'lib/stripe/resources/issuing/token.rb', line 226 def network_updated_at @network_updated_at end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
229 230 231 |
# File 'lib/stripe/resources/issuing/token.rb', line 229 def object @object end |
#status ⇒ Object (readonly)
The usage state of the token.
232 233 234 |
# File 'lib/stripe/resources/issuing/token.rb', line 232 def status @status end |
#wallet_provider ⇒ Object (readonly)
The digital wallet for this token, if one was used.
235 236 237 |
# File 'lib/stripe/resources/issuing/token.rb', line 235 def wallet_provider @wallet_provider end |
Class Method Details
.list(params = {}, opts = {}) ⇒ Object
Lists all Issuing Token objects for a given card.
238 239 240 |
# File 'lib/stripe/resources/issuing/token.rb', line 238 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/issuing/tokens", params: params, opts: opts) end |
.object_name ⇒ Object
12 13 14 |
# File 'lib/stripe/resources/issuing/token.rb', line 12 def self.object_name "issuing.token" end |
.update(id, params = {}, opts = {}) ⇒ Object
Attempts to update the specified Issuing Token object to the status specified.
243 244 245 246 247 248 249 250 |
# File 'lib/stripe/resources/issuing/token.rb', line 243 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/tokens/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |