Class: Stripe::Issuing::Token

Inherits:
APIResource show all
Extended by:
APIOperations::List
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/issuing/token.rb

Overview

An issuing token object is created when an issued card is added to a digital wallet. As a [card issuer](stripe.com/docs/issuing), you can [view and manage these tokens](stripe.com/docs/issuing/controls/token-management) through Stripe.

Defined Under Namespace

Classes: NetworkData

Constant Summary collapse

OBJECT_NAME =
"issuing.token"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardObject (readonly)

Card associated with this token.



38
39
40
# File 'lib/stripe/resources/issuing/token.rb', line 38

def card
  @card
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



40
41
42
# File 'lib/stripe/resources/issuing/token.rb', line 40

def created
  @created
end

#device_fingerprintObject (readonly)

The hashed ID derived from the device ID from the card network associated with the token.



42
43
44
# File 'lib/stripe/resources/issuing/token.rb', line 42

def device_fingerprint
  @device_fingerprint
end

#idObject (readonly)

Unique identifier for the object.



44
45
46
# File 'lib/stripe/resources/issuing/token.rb', line 44

def id
  @id
end

#last4Object (readonly)

The last four digits of the token.



46
47
48
# File 'lib/stripe/resources/issuing/token.rb', line 46

def last4
  @last4
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



48
49
50
# File 'lib/stripe/resources/issuing/token.rb', line 48

def livemode
  @livemode
end

#networkObject (readonly)

The token service provider / card network associated with the token.



50
51
52
# File 'lib/stripe/resources/issuing/token.rb', line 50

def network
  @network
end

#network_dataObject (readonly)

Attribute for field network_data



52
53
54
# File 'lib/stripe/resources/issuing/token.rb', line 52

def network_data
  @network_data
end

#network_updated_atObject (readonly)

Time at which the token was last updated by the card network. Measured in seconds since the Unix epoch.



54
55
56
# File 'lib/stripe/resources/issuing/token.rb', line 54

def network_updated_at
  @network_updated_at
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



56
57
58
# File 'lib/stripe/resources/issuing/token.rb', line 56

def object
  @object
end

#statusObject (readonly)

The usage state of the token.



58
59
60
# File 'lib/stripe/resources/issuing/token.rb', line 58

def status
  @status
end

#wallet_providerObject (readonly)

The digital wallet for this token, if one was used.



60
61
62
# File 'lib/stripe/resources/issuing/token.rb', line 60

def wallet_provider
  @wallet_provider
end

Class Method Details

.list(filters = {}, opts = {}) ⇒ Object

Lists all Issuing Token objects for a given card.



63
64
65
# File 'lib/stripe/resources/issuing/token.rb', line 63

def self.list(filters = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/issuing/tokens", params: filters, opts: opts)
end

.object_nameObject



12
13
14
# File 'lib/stripe/resources/issuing/token.rb', line 12

def self.object_name
  "issuing.token"
end

.update(id, params = {}, opts = {}) ⇒ Object

Attempts to update the specified Issuing Token object to the status specified.



68
69
70
71
72
73
74
75
# File 'lib/stripe/resources/issuing/token.rb', line 68

def self.update(id, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/issuing/tokens/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts
  )
end