Class: Stripe::Issuing::Token::ListParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/token.rb

Defined Under Namespace

Classes: Created

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(card: nil, created: nil, ending_before: nil, expand: nil, limit: nil, starting_after: nil, status: nil) ⇒ ListParams

Returns a new instance of ListParams.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/stripe/resources/issuing/token.rb', line 127

def initialize(
  card: nil,
  created: nil,
  ending_before: nil,
  expand: nil,
  limit: nil,
  starting_after: nil,
  status: nil
)
  @card = card
  @created = created
  @ending_before = ending_before
  @expand = expand
  @limit = limit
  @starting_after = starting_after
  @status = status
end

Instance Attribute Details

#cardObject

The Issuing card identifier to list tokens for.



113
114
115
# File 'lib/stripe/resources/issuing/token.rb', line 113

def card
  @card
end

#createdObject

Only return Issuing tokens that were created during the given date interval.



115
116
117
# File 'lib/stripe/resources/issuing/token.rb', line 115

def created
  @created
end

#ending_beforeObject

A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.



117
118
119
# File 'lib/stripe/resources/issuing/token.rb', line 117

def ending_before
  @ending_before
end

#expandObject

Specifies which fields in the response should be expanded.



119
120
121
# File 'lib/stripe/resources/issuing/token.rb', line 119

def expand
  @expand
end

#limitObject

A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.



121
122
123
# File 'lib/stripe/resources/issuing/token.rb', line 121

def limit
  @limit
end

#starting_afterObject

A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.



123
124
125
# File 'lib/stripe/resources/issuing/token.rb', line 123

def starting_after
  @starting_after
end

#statusObject

Select Issuing tokens with the given status.



125
126
127
# File 'lib/stripe/resources/issuing/token.rb', line 125

def status
  @status
end