Class: Stripe::Issuing::Token::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, status: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



152
153
154
155
# File 'lib/stripe/resources/issuing/token.rb', line 152

def initialize(expand: nil, status: nil)
  @expand = expand
  @status = status
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



148
149
150
# File 'lib/stripe/resources/issuing/token.rb', line 148

def expand
  @expand
end

#statusObject

Specifies which status the token should be updated to.



150
151
152
# File 'lib/stripe/resources/issuing/token.rb', line 150

def status
  @status
end