Class: Stripe::Issuing::Token::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/issuing/token.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, status: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



161
162
163
164
# File 'lib/stripe/resources/issuing/token.rb', line 161

def initialize(expand: nil, status: nil)
  @expand = expand
  @status = status
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



157
158
159
# File 'lib/stripe/resources/issuing/token.rb', line 157

def expand
  @expand
end

#statusObject

Specifies which status the token should be updated to.



159
160
161
# File 'lib/stripe/resources/issuing/token.rb', line 159

def status
  @status
end