Class: Stripe::Issuing::Token::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Token::UpdateParams
- Defined in:
- lib/stripe/resources/issuing/token.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#status ⇒ Object
Specifies which status the token should be updated to.
Instance Method Summary collapse
-
#initialize(expand: nil, status: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, status: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
161 162 163 164 |
# File 'lib/stripe/resources/issuing/token.rb', line 161 def initialize(expand: nil, status: nil) @expand = @status = status end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
157 158 159 |
# File 'lib/stripe/resources/issuing/token.rb', line 157 def @expand end |
#status ⇒ Object
Specifies which status the token should be updated to.
159 160 161 |
# File 'lib/stripe/resources/issuing/token.rb', line 159 def status @status end |