Class: Stripe::Issuing::Transaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Transaction
- Extended by:
- APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Overview
Any use of an [issued card](stripe.com/docs/issuing) that results in funds entering or leaving your Stripe account, such as a completed purchase or refund, is represented by an Issuing ‘Transaction` object.
Related guide: [Issued card transactions](stripe.com/docs/issuing/purchases/transactions)
Defined Under Namespace
Classes: AmountDetails, CreateForceCaptureParams, CreateUnlinkedRefundParams, ListParams, MerchantData, NetworkData, PurchaseDetails, RefundParams, TestHelpers, Treasury, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"issuing.transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The transaction amount, which will be reflected in your balance.
-
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#authorization ⇒ Object
readonly
The ‘Authorization` object that led to this transaction.
-
#balance_transaction ⇒ Object
readonly
ID of the [balance transaction](stripe.com/docs/api/balance_transactions) associated with this transaction.
-
#card ⇒ Object
readonly
The card used to make this transaction.
-
#cardholder ⇒ Object
readonly
The cardholder to whom this transaction belongs.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#dispute ⇒ Object
readonly
If you’ve disputed the transaction, the ID of the dispute.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#merchant_amount ⇒ Object
readonly
The amount that the merchant will receive, denominated in ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#merchant_currency ⇒ Object
readonly
The currency with which the merchant is taking payment.
-
#merchant_data ⇒ Object
readonly
Attribute for field merchant_data.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#network_data ⇒ Object
readonly
Details about the transaction, such as processing dates, set by the card network.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#purchase_details ⇒ Object
readonly
Additional purchase information that is optionally provided by the merchant.
-
#settlement ⇒ Object
readonly
The ID of the [settlement](stripe.com/docs/api/issuing/settlements) to which this transaction belongs.
-
#token ⇒ Object
readonly
[Token](stripe.com/docs/api/issuing/tokens/object) object used for this transaction.
-
#treasury ⇒ Object
readonly
[Treasury](stripe.com/docs/api/treasury) details related to this transaction if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts.
-
#type ⇒ Object
readonly
The nature of the transaction.
-
#wallet ⇒ Object
readonly
The digital wallet used for this transaction.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Transaction objects.
- .object_name ⇒ Object
-
.update(transaction, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Transaction object by setting the values of the parameters passed.
Instance Method Summary collapse
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The transaction amount, which will be reflected in your balance. This amount is in your currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
892 893 894 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 892 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
894 895 896 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 894 def amount_details @amount_details end |
#authorization ⇒ Object (readonly)
The ‘Authorization` object that led to this transaction.
896 897 898 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 896 def @authorization end |
#balance_transaction ⇒ Object (readonly)
ID of the [balance transaction](stripe.com/docs/api/balance_transactions) associated with this transaction.
898 899 900 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 898 def balance_transaction @balance_transaction end |
#card ⇒ Object (readonly)
The card used to make this transaction.
900 901 902 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 900 def card @card end |
#cardholder ⇒ Object (readonly)
The cardholder to whom this transaction belongs.
902 903 904 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 902 def cardholder @cardholder end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
904 905 906 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 904 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
906 907 908 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 906 def currency @currency end |
#dispute ⇒ Object (readonly)
If you’ve disputed the transaction, the ID of the dispute.
908 909 910 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 908 def dispute @dispute end |
#id ⇒ Object (readonly)
Unique identifier for the object.
910 911 912 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 910 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
912 913 914 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 912 def livemode @livemode end |
#merchant_amount ⇒ Object (readonly)
The amount that the merchant will receive, denominated in ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). It will be different from `amount` if the merchant is taking payment in a different currency.
914 915 916 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 914 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The currency with which the merchant is taking payment.
916 917 918 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 916 def merchant_currency @merchant_currency end |
#merchant_data ⇒ Object (readonly)
Attribute for field merchant_data
918 919 920 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 918 def merchant_data @merchant_data end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
920 921 922 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 920 def @metadata end |
#network_data ⇒ Object (readonly)
Details about the transaction, such as processing dates, set by the card network.
922 923 924 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 922 def network_data @network_data end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
924 925 926 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 924 def object @object end |
#purchase_details ⇒ Object (readonly)
Additional purchase information that is optionally provided by the merchant.
926 927 928 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 926 def purchase_details @purchase_details end |
#settlement ⇒ Object (readonly)
The ID of the [settlement](stripe.com/docs/api/issuing/settlements) to which this transaction belongs.
928 929 930 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 928 def settlement @settlement end |
#token ⇒ Object (readonly)
[Token](stripe.com/docs/api/issuing/tokens/object) object used for this transaction. If a network token was not used for this transaction, this field will be null.
930 931 932 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 930 def token @token end |
#treasury ⇒ Object (readonly)
[Treasury](stripe.com/docs/api/treasury) details related to this transaction if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts
932 933 934 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 932 def treasury @treasury end |
#type ⇒ Object (readonly)
The nature of the transaction.
934 935 936 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 934 def type @type end |
#wallet ⇒ Object (readonly)
The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`.
936 937 938 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 936 def wallet @wallet end |
Class Method Details
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Transaction objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
939 940 941 942 943 944 945 946 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 939 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/transactions", params: params, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 16 def self.object_name "issuing.transaction" end |
.update(transaction, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Transaction object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
949 950 951 952 953 954 955 956 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 949 def self.update(transaction, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/transactions/%<transaction>s", { transaction: CGI.escape(transaction) }), params: params, opts: opts ) end |
Instance Method Details
#test_helpers ⇒ Object
958 959 960 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 958 def test_helpers TestHelpers.new(self) end |