Class: Stripe::Issuing::Transaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Transaction
- Extended by:
- APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Overview
Any use of an [issued card](stripe.com/docs/issuing) that results in funds entering or leaving your Stripe account, such as a completed purchase or refund, is represented by an Issuing ‘Transaction` object.
Related guide: [Issued card transactions](stripe.com/docs/issuing/purchases/transactions)
Defined Under Namespace
Classes: AmountDetails, CreateForceCaptureParams, CreateUnlinkedRefundParams, ListParams, MerchantData, NetworkData, PurchaseDetails, RefundParams, RetrieveParams, TestHelpers, Treasury, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"issuing.transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The transaction amount, which will be reflected in your balance.
-
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#authorization ⇒ Object
readonly
The ‘Authorization` object that led to this transaction.
-
#balance_transaction ⇒ Object
readonly
ID of the [balance transaction](stripe.com/docs/api/balance_transactions) associated with this transaction.
-
#card ⇒ Object
readonly
The card used to make this transaction.
-
#cardholder ⇒ Object
readonly
The cardholder to whom this transaction belongs.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#dispute ⇒ Object
readonly
If you’ve disputed the transaction, the ID of the dispute.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#merchant_amount ⇒ Object
readonly
The amount that the merchant will receive, denominated in ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#merchant_currency ⇒ Object
readonly
The currency with which the merchant is taking payment.
-
#merchant_data ⇒ Object
readonly
Attribute for field merchant_data.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#network_data ⇒ Object
readonly
Details about the transaction, such as processing dates, set by the card network.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#purchase_details ⇒ Object
readonly
Additional purchase information that is optionally provided by the merchant.
-
#settlement ⇒ Object
readonly
Attribute for field settlement.
-
#token ⇒ Object
readonly
[Token](stripe.com/docs/api/issuing/tokens/object) object used for this transaction.
-
#treasury ⇒ Object
readonly
[Treasury](stripe.com/docs/api/treasury) details related to this transaction if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts.
-
#type ⇒ Object
readonly
The nature of the transaction.
-
#wallet ⇒ Object
readonly
The digital wallet used for this transaction.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Transaction objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Transaction object by setting the values of the parameters passed.
Instance Method Summary collapse
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The transaction amount, which will be reflected in your balance. This amount is in your currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
1050 1051 1052 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1050 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
1053 1054 1055 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1053 def amount_details @amount_details end |
#authorization ⇒ Object (readonly)
The ‘Authorization` object that led to this transaction.
1056 1057 1058 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1056 def @authorization end |
#balance_transaction ⇒ Object (readonly)
ID of the [balance transaction](stripe.com/docs/api/balance_transactions) associated with this transaction.
1059 1060 1061 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1059 def balance_transaction @balance_transaction end |
#card ⇒ Object (readonly)
The card used to make this transaction.
1062 1063 1064 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1062 def card @card end |
#cardholder ⇒ Object (readonly)
The cardholder to whom this transaction belongs.
1065 1066 1067 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1065 def cardholder @cardholder end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
1068 1069 1070 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1068 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1071 1072 1073 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1071 def currency @currency end |
#dispute ⇒ Object (readonly)
If you’ve disputed the transaction, the ID of the dispute.
1074 1075 1076 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1074 def dispute @dispute end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1077 1078 1079 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1077 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
1080 1081 1082 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1080 def livemode @livemode end |
#merchant_amount ⇒ Object (readonly)
The amount that the merchant will receive, denominated in ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). It will be different from `amount` if the merchant is taking payment in a different currency.
1083 1084 1085 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1083 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The currency with which the merchant is taking payment.
1086 1087 1088 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1086 def merchant_currency @merchant_currency end |
#merchant_data ⇒ Object (readonly)
Attribute for field merchant_data
1089 1090 1091 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1089 def merchant_data @merchant_data end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
1092 1093 1094 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1092 def @metadata end |
#network_data ⇒ Object (readonly)
Details about the transaction, such as processing dates, set by the card network.
1095 1096 1097 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1095 def network_data @network_data end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1098 1099 1100 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1098 def object @object end |
#purchase_details ⇒ Object (readonly)
Additional purchase information that is optionally provided by the merchant.
1101 1102 1103 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1101 def purchase_details @purchase_details end |
#settlement ⇒ Object (readonly)
Attribute for field settlement
1104 1105 1106 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1104 def settlement @settlement end |
#token ⇒ Object (readonly)
[Token](stripe.com/docs/api/issuing/tokens/object) object used for this transaction. If a network token was not used for this transaction, this field will be null.
1107 1108 1109 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1107 def token @token end |
#treasury ⇒ Object (readonly)
[Treasury](stripe.com/docs/api/treasury) details related to this transaction if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts
1110 1111 1112 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1110 def treasury @treasury end |
#type ⇒ Object (readonly)
The nature of the transaction.
1113 1114 1115 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1113 def type @type end |
#wallet ⇒ Object (readonly)
The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`.
1116 1117 1118 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1116 def wallet @wallet end |
Class Method Details
.list(params = {}, opts = {}) ⇒ Object
Returns a list of Issuing Transaction objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
1119 1120 1121 1122 1123 1124 1125 1126 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1119 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/transactions", params: params, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 16 def self.object_name "issuing.transaction" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Transaction object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
1129 1130 1131 1132 1133 1134 1135 1136 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1129 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/transactions/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#test_helpers ⇒ Object
1138 1139 1140 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 1138 def test_helpers TestHelpers.new(self) end |