Class: Stripe::Issuing::Transaction
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Issuing::Transaction
- Extended by:
- APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Overview
Any use of an [issued card](stripe.com/docs/issuing) that results in funds entering or leaving your Stripe account, such as a completed purchase or refund, is represented by an Issuing ‘Transaction` object.
Related guide: [Issued card transactions](stripe.com/docs/issuing/purchases/transactions)
Defined Under Namespace
Classes: AmountDetails, MerchantData, NetworkData, PurchaseDetails, TestHelpers, Treasury
Constant Summary collapse
- OBJECT_NAME =
"issuing.transaction"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The transaction amount, which will be reflected in your balance.
-
#amount_details ⇒ Object
readonly
Detailed breakdown of amount components.
-
#authorization ⇒ Object
readonly
The ‘Authorization` object that led to this transaction.
-
#balance_transaction ⇒ Object
readonly
ID of the [balance transaction](stripe.com/docs/api/balance_transactions) associated with this transaction.
-
#card ⇒ Object
readonly
The card used to make this transaction.
-
#cardholder ⇒ Object
readonly
The cardholder to whom this transaction belongs.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#dispute ⇒ Object
readonly
If you’ve disputed the transaction, the ID of the dispute.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#merchant_amount ⇒ Object
readonly
The amount that the merchant will receive, denominated in ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
-
#merchant_currency ⇒ Object
readonly
The currency with which the merchant is taking payment.
-
#merchant_data ⇒ Object
readonly
Attribute for field merchant_data.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#network_data ⇒ Object
readonly
Details about the transaction, such as processing dates, set by the card network.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#purchase_details ⇒ Object
readonly
Additional purchase information that is optionally provided by the merchant.
-
#settlement ⇒ Object
readonly
Attribute for field settlement.
-
#token ⇒ Object
readonly
[Token](stripe.com/docs/api/issuing/tokens/object) object used for this transaction.
-
#treasury ⇒ Object
readonly
[Treasury](stripe.com/docs/api/treasury) details related to this transaction if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts.
-
#type ⇒ Object
readonly
The nature of the transaction.
-
#wallet ⇒ Object
readonly
The digital wallet used for this transaction.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Issuing Transaction objects.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Transaction object by setting the values of the parameters passed.
Instance Method Summary collapse
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The transaction amount, which will be reflected in your balance. This amount is in your currency and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
80 81 82 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 80 def amount @amount end |
#amount_details ⇒ Object (readonly)
Detailed breakdown of amount components. These amounts are denominated in ‘currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
82 83 84 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 82 def amount_details @amount_details end |
#authorization ⇒ Object (readonly)
The ‘Authorization` object that led to this transaction.
84 85 86 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 84 def @authorization end |
#balance_transaction ⇒ Object (readonly)
ID of the [balance transaction](stripe.com/docs/api/balance_transactions) associated with this transaction.
86 87 88 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 86 def balance_transaction @balance_transaction end |
#card ⇒ Object (readonly)
The card used to make this transaction.
88 89 90 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 88 def card @card end |
#cardholder ⇒ Object (readonly)
The cardholder to whom this transaction belongs.
90 91 92 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 90 def cardholder @cardholder end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
92 93 94 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 92 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
94 95 96 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 94 def currency @currency end |
#dispute ⇒ Object (readonly)
If you’ve disputed the transaction, the ID of the dispute.
96 97 98 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 96 def dispute @dispute end |
#id ⇒ Object (readonly)
Unique identifier for the object.
98 99 100 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 98 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
100 101 102 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 100 def livemode @livemode end |
#merchant_amount ⇒ Object (readonly)
The amount that the merchant will receive, denominated in ‘merchant_currency` and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal). It will be different from `amount` if the merchant is taking payment in a different currency.
102 103 104 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 102 def merchant_amount @merchant_amount end |
#merchant_currency ⇒ Object (readonly)
The currency with which the merchant is taking payment.
104 105 106 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 104 def merchant_currency @merchant_currency end |
#merchant_data ⇒ Object (readonly)
Attribute for field merchant_data
106 107 108 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 106 def merchant_data @merchant_data end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
108 109 110 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 108 def @metadata end |
#network_data ⇒ Object (readonly)
Details about the transaction, such as processing dates, set by the card network.
110 111 112 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 110 def network_data @network_data end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
112 113 114 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 112 def object @object end |
#purchase_details ⇒ Object (readonly)
Additional purchase information that is optionally provided by the merchant.
114 115 116 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 114 def purchase_details @purchase_details end |
#settlement ⇒ Object (readonly)
Attribute for field settlement
116 117 118 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 116 def settlement @settlement end |
#token ⇒ Object (readonly)
[Token](stripe.com/docs/api/issuing/tokens/object) object used for this transaction. If a network token was not used for this transaction, this field will be null.
118 119 120 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 118 def token @token end |
#treasury ⇒ Object (readonly)
[Treasury](stripe.com/docs/api/treasury) details related to this transaction if it was created on a [FinancialAccount](/docs/api/treasury/financial_accounts
120 121 122 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 120 def treasury @treasury end |
#type ⇒ Object (readonly)
The nature of the transaction.
122 123 124 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 122 def type @type end |
#wallet ⇒ Object (readonly)
The digital wallet used for this transaction. One of ‘apple_pay`, `google_pay`, or `samsung_pay`.
124 125 126 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 124 def wallet @wallet end |
Class Method Details
.list(filters = {}, opts = {}) ⇒ Object
Returns a list of Issuing Transaction objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.
127 128 129 130 131 132 133 134 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 127 def self.list(filters = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/issuing/transactions", params: filters, opts: opts ) end |
.object_name ⇒ Object
16 17 18 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 16 def self.object_name "issuing.transaction" end |
.update(id, params = {}, opts = {}) ⇒ Object
Updates the specified Issuing Transaction object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
137 138 139 140 141 142 143 144 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 137 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/issuing/transactions/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |
Instance Method Details
#test_helpers ⇒ Object
146 147 148 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 146 def test_helpers TestHelpers.new(self) end |