Class: Stripe::Issuing::Transaction::CreateForceCaptureParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateForceCaptureParams
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: MerchantData, PurchaseDetails
Instance Attribute Summary collapse
-
#amount ⇒ Object
The total amount to attempt to capture.
-
#card ⇒ Object
Card associated with this transaction.
-
#currency ⇒ Object
The currency of the capture.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
-
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
Instance Method Summary collapse
-
#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil) ⇒ CreateForceCaptureParams
constructor
A new instance of CreateForceCaptureParams.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil) ⇒ CreateForceCaptureParams
Returns a new instance of CreateForceCaptureParams.
574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 574 def initialize( amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil ) @amount = amount @card = card @currency = currency @expand = @merchant_data = merchant_data @purchase_details = purchase_details end |
Instance Attribute Details
#amount ⇒ Object
The total amount to attempt to capture. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).
562 563 564 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 562 def amount @amount end |
#card ⇒ Object
Card associated with this transaction.
564 565 566 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 564 def card @card end |
#currency ⇒ Object
The currency of the capture. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
566 567 568 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 566 def currency @currency end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
568 569 570 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 568 def @expand end |
#merchant_data ⇒ Object
Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.
570 571 572 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 570 def merchant_data @merchant_data end |
#purchase_details ⇒ Object
Additional purchase information that is optionally provided by the merchant.
572 573 574 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 572 def purchase_details @purchase_details end |