Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::MerchantData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateForceCaptureParams::MerchantData
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
A categorization of the seller’s type of business.
-
#city ⇒ Object
City where the seller is located.
-
#country ⇒ Object
Country where the seller is located.
-
#name ⇒ Object
Name of the seller.
-
#network_id ⇒ Object
Identifier assigned to the seller by the card network.
-
#postal_code ⇒ Object
Postal code where the seller is located.
-
#state ⇒ Object
State where the seller is located.
-
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
-
#url ⇒ Object
URL provided by the merchant on a 3DS request.
Instance Method Summary collapse
-
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData
constructor
A new instance of MerchantData.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData
Returns a new instance of MerchantData.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 369 def initialize( category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil ) @category = category @city = city @country = country @name = name @network_id = network_id @postal_code = postal_code @state = state @terminal_id = terminal_id @url = url end |
Instance Attribute Details
#category ⇒ Object
A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.
343 344 345 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 343 def category @category end |
#city ⇒ Object
City where the seller is located
346 347 348 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 346 def city @city end |
#country ⇒ Object
Country where the seller is located
349 350 351 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 349 def country @country end |
#name ⇒ Object
Name of the seller
352 353 354 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 352 def name @name end |
#network_id ⇒ Object
Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
355 356 357 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 355 def network_id @network_id end |
#postal_code ⇒ Object
Postal code where the seller is located
358 359 360 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 358 def postal_code @postal_code end |
#state ⇒ Object
State where the seller is located
361 362 363 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 361 def state @state end |
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
364 365 366 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 364 def terminal_id @terminal_id end |
#url ⇒ Object
URL provided by the merchant on a 3DS request
367 368 369 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 367 def url @url end |