Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 536 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
524 525 526 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 524 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
526 527 528 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 526 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
528 529 530 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 528 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
530 531 532 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 530 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
532 533 534 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 532 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
534 535 536 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 534 def reference @reference end |