Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 644 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
627 628 629 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 627 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
630 631 632 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 630 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
633 634 635 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 633 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
636 637 638 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 636 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
639 640 641 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 639 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
642 643 644 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 642 def reference @reference end |