Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails::Fuel

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel

Returns a new instance of Fuel.



488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/stripe/resources/issuing/transaction.rb', line 488

def initialize(
  industry_product_code: nil,
  quantity_decimal: nil,
  type: nil,
  unit: nil,
  unit_cost_decimal: nil
)
  @industry_product_code = industry_product_code
  @quantity_decimal = quantity_decimal
  @type = type
  @unit = unit
  @unit_cost_decimal = unit_cost_decimal
end

Instance Attribute Details

#industry_product_codeObject

[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.



478
479
480
# File 'lib/stripe/resources/issuing/transaction.rb', line 478

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject

The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



480
481
482
# File 'lib/stripe/resources/issuing/transaction.rb', line 480

def quantity_decimal
  @quantity_decimal
end

#typeObject

The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.



482
483
484
# File 'lib/stripe/resources/issuing/transaction.rb', line 482

def type
  @type
end

#unitObject

The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.



484
485
486
# File 'lib/stripe/resources/issuing/transaction.rb', line 484

def unit
  @unit
end

#unit_cost_decimalObject

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



486
487
488
# File 'lib/stripe/resources/issuing/transaction.rb', line 486

def unit_cost_decimal
  @unit_cost_decimal
end