Class: Stripe::Issuing::Transaction::CreateForceCaptureParams::PurchaseDetails::Fuel

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(industry_product_code: nil, quantity_decimal: nil, type: nil, unit: nil, unit_cost_decimal: nil) ⇒ Fuel

Returns a new instance of Fuel.



578
579
580
581
582
583
584
585
586
587
588
589
590
# File 'lib/stripe/resources/issuing/transaction.rb', line 578

def initialize(
  industry_product_code: nil,
  quantity_decimal: nil,
  type: nil,
  unit: nil,
  unit_cost_decimal: nil
)
  @industry_product_code = industry_product_code
  @quantity_decimal = quantity_decimal
  @type = type
  @unit = unit
  @unit_cost_decimal = unit_cost_decimal
end

Instance Attribute Details

#industry_product_codeObject

[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.



564
565
566
# File 'lib/stripe/resources/issuing/transaction.rb', line 564

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject

The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



567
568
569
# File 'lib/stripe/resources/issuing/transaction.rb', line 567

def quantity_decimal
  @quantity_decimal
end

#typeObject

The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.



570
571
572
# File 'lib/stripe/resources/issuing/transaction.rb', line 570

def type
  @type
end

#unitObject

The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.



573
574
575
# File 'lib/stripe/resources/issuing/transaction.rb', line 573

def unit
  @unit
end

#unit_cost_decimalObject

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



576
577
578
# File 'lib/stripe/resources/issuing/transaction.rb', line 576

def unit_cost_decimal
  @unit_cost_decimal
end