Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: MerchantData, PurchaseDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, card: nil, currency: nil, expand: nil, merchant_data: nil, purchase_details: nil) ⇒ CreateUnlinkedRefundParams

Returns a new instance of CreateUnlinkedRefundParams.



1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
# File 'lib/stripe/resources/issuing/transaction.rb', line 1033

def initialize(
  amount: nil,
  card: nil,
  currency: nil,
  expand: nil,
  merchant_data: nil,
  purchase_details: nil
)
  @amount = amount
  @card = card
  @currency = currency
  @expand = expand
  @merchant_data = merchant_data
  @purchase_details = purchase_details
end

Instance Attribute Details

#amountObject

The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



1016
1017
1018
# File 'lib/stripe/resources/issuing/transaction.rb', line 1016

def amount
  @amount
end

#cardObject

Card associated with this unlinked refund transaction.



1019
1020
1021
# File 'lib/stripe/resources/issuing/transaction.rb', line 1019

def card
  @card
end

#currencyObject

The currency of the unlinked refund. If not provided, defaults to the currency of the card. Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1022
1023
1024
# File 'lib/stripe/resources/issuing/transaction.rb', line 1022

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



1025
1026
1027
# File 'lib/stripe/resources/issuing/transaction.rb', line 1025

def expand
  @expand
end

#merchant_dataObject

Details about the seller (grocery store, e-commerce website, etc.) where the card authorization happened.



1028
1029
1030
# File 'lib/stripe/resources/issuing/transaction.rb', line 1028

def merchant_data
  @merchant_data
end

#purchase_detailsObject

Additional purchase information that is optionally provided by the merchant.



1031
1032
1033
# File 'lib/stripe/resources/issuing/transaction.rb', line 1031

def purchase_details
  @purchase_details
end