Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::MerchantData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData

Returns a new instance of MerchantData.



724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
# File 'lib/stripe/resources/issuing/transaction.rb', line 724

def initialize(
  category: nil,
  city: nil,
  country: nil,
  name: nil,
  network_id: nil,
  postal_code: nil,
  state: nil,
  terminal_id: nil,
  url: nil
)
  @category = category
  @city = city
  @country = country
  @name = name
  @network_id = network_id
  @postal_code = postal_code
  @state = state
  @terminal_id = terminal_id
  @url = url
end

Instance Attribute Details

#categoryObject

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



698
699
700
# File 'lib/stripe/resources/issuing/transaction.rb', line 698

def category
  @category
end

#cityObject

City where the seller is located



701
702
703
# File 'lib/stripe/resources/issuing/transaction.rb', line 701

def city
  @city
end

#countryObject

Country where the seller is located



704
705
706
# File 'lib/stripe/resources/issuing/transaction.rb', line 704

def country
  @country
end

#nameObject

Name of the seller



707
708
709
# File 'lib/stripe/resources/issuing/transaction.rb', line 707

def name
  @name
end

#network_idObject

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



710
711
712
# File 'lib/stripe/resources/issuing/transaction.rb', line 710

def network_id
  @network_id
end

#postal_codeObject

Postal code where the seller is located



713
714
715
# File 'lib/stripe/resources/issuing/transaction.rb', line 713

def postal_code
  @postal_code
end

#stateObject

State where the seller is located



716
717
718
# File 'lib/stripe/resources/issuing/transaction.rb', line 716

def state
  @state
end

#terminal_idObject

An ID assigned by the seller to the location of the sale.



719
720
721
# File 'lib/stripe/resources/issuing/transaction.rb', line 719

def terminal_id
  @terminal_id
end

#urlObject

URL provided by the merchant on a 3DS request



722
723
724
# File 'lib/stripe/resources/issuing/transaction.rb', line 722

def url
  @url
end