Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::MerchantData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::MerchantData
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
A categorization of the seller’s type of business.
-
#city ⇒ Object
City where the seller is located.
-
#country ⇒ Object
Country where the seller is located.
-
#name ⇒ Object
Name of the seller.
-
#network_id ⇒ Object
Identifier assigned to the seller by the card network.
-
#postal_code ⇒ Object
Postal code where the seller is located.
-
#state ⇒ Object
State where the seller is located.
-
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
-
#url ⇒ Object
URL provided by the merchant on a 3DS request.
Instance Method Summary collapse
-
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData
constructor
A new instance of MerchantData.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil) ⇒ MerchantData
Returns a new instance of MerchantData.
612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 612 def initialize( category: nil, city: nil, country: nil, name: nil, network_id: nil, postal_code: nil, state: nil, terminal_id: nil, url: nil ) @category = category @city = city @country = country @name = name @network_id = network_id @postal_code = postal_code @state = state @terminal_id = terminal_id @url = url end |
Instance Attribute Details
#category ⇒ Object
A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.
594 595 596 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 594 def category @category end |
#city ⇒ Object
City where the seller is located
596 597 598 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 596 def city @city end |
#country ⇒ Object
Country where the seller is located
598 599 600 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 598 def country @country end |
#name ⇒ Object
Name of the seller
600 601 602 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 600 def name @name end |
#network_id ⇒ Object
Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.
602 603 604 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 602 def network_id @network_id end |
#postal_code ⇒ Object
Postal code where the seller is located
604 605 606 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 604 def postal_code @postal_code end |
#state ⇒ Object
State where the seller is located
606 607 608 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 606 def state @state end |
#terminal_id ⇒ Object
An ID assigned by the seller to the location of the sale.
608 609 610 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 608 def terminal_id @terminal_id end |
#url ⇒ Object
URL provided by the merchant on a 3DS request
610 611 612 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 610 def url @url end |