Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 846 def initialize( fleet: nil, flight: nil, fuel: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
834 835 836 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 834 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
836 837 838 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 836 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
838 839 840 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 838 def fuel @fuel end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
840 841 842 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 840 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
842 843 844 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 842 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
844 845 846 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 844 def reference @reference end |