Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::PurchaseDetails::Fleet
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::PurchaseDetails::Fleet
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: CardholderPromptData, ReportedBreakdown
Instance Attribute Summary collapse
-
#cardholder_prompt_data ⇒ Object
Answers to prompts presented to the cardholder at the point of sale.
-
#purchase_type ⇒ Object
The type of purchase.
-
#reported_breakdown ⇒ Object
More information about the total amount.
-
#service_type ⇒ Object
The type of fuel service.
Instance Method Summary collapse
-
#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet
constructor
A new instance of Fleet.
Methods inherited from RequestParams
Constructor Details
#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet
Returns a new instance of Fleet.
844 845 846 847 848 849 850 851 852 853 854 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 844 def initialize( cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil ) @cardholder_prompt_data = cardholder_prompt_data @purchase_type = purchase_type @reported_breakdown = reported_breakdown @service_type = service_type end |
Instance Attribute Details
#cardholder_prompt_data ⇒ Object
Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.
836 837 838 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 836 def cardholder_prompt_data @cardholder_prompt_data end |
#purchase_type ⇒ Object
The type of purchase. One of ‘fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.
838 839 840 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 838 def purchase_type @purchase_type end |
#reported_breakdown ⇒ Object
More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
840 841 842 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 840 def reported_breakdown @reported_breakdown end |
#service_type ⇒ Object
The type of fuel service. One of ‘non_fuel_transaction`, `full_service`, or `self_service`.
842 843 844 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 842 def service_type @service_type end |