Class: Stripe::Issuing::Transaction::CreateUnlinkedRefundParams::PurchaseDetails::Fleet

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cardholder_prompt_data: nil, purchase_type: nil, reported_breakdown: nil, service_type: nil) ⇒ Fleet

Returns a new instance of Fleet.



838
839
840
841
842
843
844
845
846
847
848
# File 'lib/stripe/resources/issuing/transaction.rb', line 838

def initialize(
  cardholder_prompt_data: nil,
  purchase_type: nil,
  reported_breakdown: nil,
  service_type: nil
)
  @cardholder_prompt_data = cardholder_prompt_data
  @purchase_type = purchase_type
  @reported_breakdown = reported_breakdown
  @service_type = service_type
end

Instance Attribute Details

#cardholder_prompt_dataObject

Answers to prompts presented to the cardholder at the point of sale. Prompted fields vary depending on the configuration of your physical fleet cards. Typical points of sale support only numeric entry.



827
828
829
# File 'lib/stripe/resources/issuing/transaction.rb', line 827

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject

The type of purchase. One of ‘fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.



830
831
832
# File 'lib/stripe/resources/issuing/transaction.rb', line 830

def purchase_type
  @purchase_type
end

#reported_breakdownObject

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



833
834
835
# File 'lib/stripe/resources/issuing/transaction.rb', line 833

def reported_breakdown
  @reported_breakdown
end

#service_typeObject

The type of fuel service. One of ‘non_fuel_transaction`, `full_service`, or `self_service`.



836
837
838
# File 'lib/stripe/resources/issuing/transaction.rb', line 836

def service_type
  @service_type
end