Class: Stripe::Issuing::Transaction::MerchantData

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#categoryObject (readonly)

A categorization of the seller’s type of business. See our [merchant categories guide](stripe.com/docs/issuing/merchant-categories) for a list of possible values.



30
31
32
# File 'lib/stripe/resources/issuing/transaction.rb', line 30

def category
  @category
end

#category_codeObject (readonly)

The merchant category code for the seller’s business



33
34
35
# File 'lib/stripe/resources/issuing/transaction.rb', line 33

def category_code
  @category_code
end

#cityObject (readonly)

City where the seller is located



36
37
38
# File 'lib/stripe/resources/issuing/transaction.rb', line 36

def city
  @city
end

#countryObject (readonly)

Country where the seller is located



39
40
41
# File 'lib/stripe/resources/issuing/transaction.rb', line 39

def country
  @country
end

#nameObject (readonly)

Name of the seller



42
43
44
# File 'lib/stripe/resources/issuing/transaction.rb', line 42

def name
  @name
end

#network_idObject (readonly)

Identifier assigned to the seller by the card network. Different card networks may assign different network_id fields to the same merchant.



45
46
47
# File 'lib/stripe/resources/issuing/transaction.rb', line 45

def network_id
  @network_id
end

#postal_codeObject (readonly)

Postal code where the seller is located



48
49
50
# File 'lib/stripe/resources/issuing/transaction.rb', line 48

def postal_code
  @postal_code
end

#stateObject (readonly)

State where the seller is located



51
52
53
# File 'lib/stripe/resources/issuing/transaction.rb', line 51

def state
  @state
end

#tax_idObject (readonly)

The seller’s tax identification number. Currently populated for French merchants only.



54
55
56
# File 'lib/stripe/resources/issuing/transaction.rb', line 54

def tax_id
  @tax_id
end

#terminal_idObject (readonly)

An ID assigned by the seller to the location of the sale.



57
58
59
# File 'lib/stripe/resources/issuing/transaction.rb', line 57

def terminal_id
  @terminal_id
end

#urlObject (readonly)

URL provided by the merchant on a 3DS request



60
61
62
# File 'lib/stripe/resources/issuing/transaction.rb', line 60

def url
  @url
end