Class: Stripe::Issuing::Transaction::NetworkData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Transaction::NetworkData
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authorization_code ⇒ Object
readonly
A code created by Stripe which is shared with the merchant to validate the authorization.
-
#processing_date ⇒ Object
readonly
The date the transaction was processed by the card network.
-
#transaction_id ⇒ Object
readonly
Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authorization_code ⇒ Object (readonly)
A code created by Stripe which is shared with the merchant to validate the authorization. This field will be populated if the authorization message was approved. The code typically starts with the letter āSā, followed by a six-digit number. For example, āS498162ā. Please note that the code is not guaranteed to be unique across authorizations.
189 190 191 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 189 def @authorization_code end |
#processing_date ⇒ Object (readonly)
The date the transaction was processed by the card network. This can be different from the date the seller recorded the transaction depending on when the acquirer submits the transaction to the network.
191 192 193 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 191 def processing_date @processing_date end |
#transaction_id ⇒ Object (readonly)
Unique identifier for the authorization assigned by the card network used to match subsequent messages, disputes, and transactions.
193 194 195 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 193 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
199 200 201 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 199 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
195 196 197 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 195 def self.inner_class_types @inner_class_types = {} end |