Class: Stripe::Issuing::Transaction::PurchaseDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Transaction::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fleet ⇒ Object
readonly
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
readonly
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
readonly
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
readonly
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
readonly
The line items in the purchase.
-
#reference ⇒ Object
readonly
A merchant-specific order number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fleet ⇒ Object (readonly)
Fleet-specific information for transactions using Fleet cards.
371 372 373 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 371 def fleet @fleet end |
#flight ⇒ Object (readonly)
Information about the flight that was purchased with this transaction.
373 374 375 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 373 def flight @flight end |
#fuel ⇒ Object (readonly)
Information about fuel that was purchased with this transaction.
375 376 377 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 375 def fuel @fuel end |
#lodging ⇒ Object (readonly)
Information about lodging that was purchased with this transaction.
377 378 379 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 377 def lodging @lodging end |
#receipt ⇒ Object (readonly)
The line items in the purchase.
379 380 381 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 379 def receipt @receipt end |
#reference ⇒ Object (readonly)
A merchant-specific order number.
381 382 383 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 381 def reference @reference end |
Class Method Details
.field_encodings ⇒ Object
397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 397 def self.field_encodings @field_encodings = { fleet: { kind: :nullable, inner: { kind: :object, fields: { reported_breakdown: { kind: :nullable, inner: { kind: :object, fields: { fuel: { kind: :nullable, inner: { kind: :object, fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string }, }, }, }, non_fuel: { kind: :nullable, inner: { kind: :object, fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string }, }, }, }, tax: { kind: :nullable, inner: { kind: :object, fields: { local_amount_decimal: { kind: :nullable, inner: :decimal_string }, national_amount_decimal: { kind: :nullable, inner: :decimal_string }, }, }, }, }, }, }, }, }, }, fuel: { kind: :nullable, inner: { kind: :object, fields: { quantity_decimal: { kind: :nullable, inner: :decimal_string }, unit_cost_decimal: :decimal_string, }, }, }, } end |
.field_remappings ⇒ Object
393 394 395 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 393 def self.field_remappings @field_remappings = {} end |