Class: Stripe::Issuing::Transaction::PurchaseDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: Fleet, Flight, Fuel, Lodging, Receipt

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#fleetObject (readonly)

Fleet-specific information for transactions using Fleet cards.



485
486
487
# File 'lib/stripe/resources/issuing/transaction.rb', line 485

def fleet
  @fleet
end

#flightObject (readonly)

Information about the flight that was purchased with this transaction.



487
488
489
# File 'lib/stripe/resources/issuing/transaction.rb', line 487

def flight
  @flight
end

#fuelObject (readonly)

Information about fuel that was purchased with this transaction.



489
490
491
# File 'lib/stripe/resources/issuing/transaction.rb', line 489

def fuel
  @fuel
end

#lodgingObject (readonly)

Information about lodging that was purchased with this transaction.



491
492
493
# File 'lib/stripe/resources/issuing/transaction.rb', line 491

def lodging
  @lodging
end

#receiptObject (readonly)

The line items in the purchase.



493
494
495
# File 'lib/stripe/resources/issuing/transaction.rb', line 493

def receipt
  @receipt
end

#referenceObject (readonly)

A merchant-specific order number.



495
496
497
# File 'lib/stripe/resources/issuing/transaction.rb', line 495

def reference
  @reference
end

Class Method Details

.field_encodingsObject



511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
# File 'lib/stripe/resources/issuing/transaction.rb', line 511

def self.field_encodings
  @field_encodings = {
    fleet: {
      kind: :object,
      fields: {
        reported_breakdown: {
          kind: :object,
          fields: {
            fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
            non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } },
            tax: {
              kind: :object,
              fields: {
                local_amount_decimal: :decimal_string,
                national_amount_decimal: :decimal_string,
              },
            },
          },
        },
      },
    },
    fuel: {
      kind: :object,
      fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string },
    },
  }
end

.field_remappingsObject



507
508
509
# File 'lib/stripe/resources/issuing/transaction.rb', line 507

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



497
498
499
500
501
502
503
504
505
# File 'lib/stripe/resources/issuing/transaction.rb', line 497

def self.inner_class_types
  @inner_class_types = {
    fleet: Fleet,
    flight: Flight,
    fuel: Fuel,
    lodging: Lodging,
    receipt: Receipt,
  }
end