Class: Stripe::Issuing::Transaction::PurchaseDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Transaction::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fleet ⇒ Object
readonly
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
readonly
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
readonly
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
readonly
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
readonly
The line items in the purchase.
-
#reference ⇒ Object
readonly
A merchant-specific order number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fleet ⇒ Object (readonly)
Fleet-specific information for transactions using Fleet cards.
338 339 340 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 338 def fleet @fleet end |
#flight ⇒ Object (readonly)
Information about the flight that was purchased with this transaction.
340 341 342 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 340 def flight @flight end |
#fuel ⇒ Object (readonly)
Information about fuel that was purchased with this transaction.
342 343 344 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 342 def fuel @fuel end |
#lodging ⇒ Object (readonly)
Information about lodging that was purchased with this transaction.
344 345 346 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 344 def lodging @lodging end |
#receipt ⇒ Object (readonly)
The line items in the purchase.
346 347 348 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 346 def receipt @receipt end |
#reference ⇒ Object (readonly)
A merchant-specific order number.
348 349 350 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 348 def reference @reference end |
Class Method Details
.field_encodings ⇒ Object
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 364 def self.field_encodings @field_encodings = { fleet: { kind: :object, fields: { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, }, }, fuel: { kind: :object, fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }, }, } end |
.field_remappings ⇒ Object
360 361 362 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 360 def self.field_remappings @field_remappings = {} end |