Class: Stripe::Issuing::Transaction::PurchaseDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Transaction::PurchaseDetails
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Lodging, Receipt
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#fleet ⇒ Object
readonly
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
readonly
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
readonly
Information about fuel that was purchased with this transaction.
-
#lodging ⇒ Object
readonly
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
readonly
The line items in the purchase.
-
#reference ⇒ Object
readonly
A merchant-specific order number.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#fleet ⇒ Object (readonly)
Fleet-specific information for transactions using Fleet cards.
208 209 210 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 208 def fleet @fleet end |
#flight ⇒ Object (readonly)
Information about the flight that was purchased with this transaction.
211 212 213 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 211 def flight @flight end |
#fuel ⇒ Object (readonly)
Information about fuel that was purchased with this transaction.
214 215 216 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 214 def fuel @fuel end |
#lodging ⇒ Object (readonly)
Information about lodging that was purchased with this transaction.
217 218 219 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 217 def lodging @lodging end |
#receipt ⇒ Object (readonly)
The line items in the purchase.
220 221 222 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 220 def receipt @receipt end |
#reference ⇒ Object (readonly)
A merchant-specific order number.
223 224 225 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 223 def reference @reference end |