Class: Stripe::Issuing::Transaction::PurchaseDetails::Fleet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, #_get_union_variant_class, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, inner_class_union_variant_types, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardholder_prompt_dataObject (readonly)

Answers to prompts presented to cardholder at point of sale.



209
210
211
# File 'lib/stripe/resources/issuing/transaction.rb', line 209

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject (readonly)

The type of purchase. One of fuel_purchase, non_fuel_purchase, or fuel_and_non_fuel_purchase.



211
212
213
# File 'lib/stripe/resources/issuing/transaction.rb', line 211

def purchase_type
  @purchase_type
end

#reported_breakdownObject (readonly)

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



213
214
215
# File 'lib/stripe/resources/issuing/transaction.rb', line 213

def reported_breakdown
  @reported_breakdown
end

#service_typeObject (readonly)

The type of fuel service. One of non_fuel_transaction, full_service, or self_service.



215
216
217
# File 'lib/stripe/resources/issuing/transaction.rb', line 215

def service_type
  @service_type
end

Class Method Details

.field_encodingsObject



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/stripe/resources/issuing/transaction.rb', line 228

def self.field_encodings
  @field_encodings = {
    reported_breakdown: {
      kind: :nullable,
      inner: {
        kind: :object,
        fields: {
          fuel: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string } },
            },
          },
          non_fuel: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string } },
            },
          },
          tax: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: {
                local_amount_decimal: { kind: :nullable, inner: :decimal_string },
                national_amount_decimal: { kind: :nullable, inner: :decimal_string },
              },
            },
          },
        },
      },
    },
  }
end

.field_remappingsObject



224
225
226
# File 'lib/stripe/resources/issuing/transaction.rb', line 224

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



217
218
219
220
221
222
# File 'lib/stripe/resources/issuing/transaction.rb', line 217

def self.inner_class_types
  @inner_class_types = {
    cardholder_prompt_data: CardholderPromptData,
    reported_breakdown: ReportedBreakdown,
  }
end