Class: Stripe::Issuing::Transaction::PurchaseDetails::Fleet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardholder_prompt_dataObject (readonly)

Answers to prompts presented to cardholder at point of sale.



356
357
358
# File 'lib/stripe/resources/issuing/transaction.rb', line 356

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject (readonly)

The type of purchase. One of fuel_purchase, non_fuel_purchase, or fuel_and_non_fuel_purchase.



358
359
360
# File 'lib/stripe/resources/issuing/transaction.rb', line 358

def purchase_type
  @purchase_type
end

#reported_breakdownObject (readonly)

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



360
361
362
# File 'lib/stripe/resources/issuing/transaction.rb', line 360

def reported_breakdown
  @reported_breakdown
end

#service_typeObject (readonly)

The type of fuel service. One of non_fuel_transaction, full_service, or self_service.



362
363
364
# File 'lib/stripe/resources/issuing/transaction.rb', line 362

def service_type
  @service_type
end

Class Method Details

.field_encodingsObject



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/stripe/resources/issuing/transaction.rb', line 375

def self.field_encodings
  @field_encodings = {
    reported_breakdown: {
      kind: :nullable,
      inner: {
        kind: :object,
        fields: {
          fuel: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string } },
            },
          },
          non_fuel: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: { gross_amount_decimal: { kind: :nullable, inner: :decimal_string } },
            },
          },
          tax: {
            kind: :nullable,
            inner: {
              kind: :object,
              fields: {
                local_amount_decimal: { kind: :nullable, inner: :decimal_string },
                national_amount_decimal: { kind: :nullable, inner: :decimal_string },
              },
            },
          },
        },
      },
    },
  }
end

.field_remappingsObject



371
372
373
# File 'lib/stripe/resources/issuing/transaction.rb', line 371

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



364
365
366
367
368
369
# File 'lib/stripe/resources/issuing/transaction.rb', line 364

def self.inner_class_types
  @inner_class_types = {
    cardholder_prompt_data: CardholderPromptData,
    reported_breakdown: ReportedBreakdown,
  }
end