Class: Stripe::Issuing::Transaction::PurchaseDetails::Fleet
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Issuing::Transaction::PurchaseDetails::Fleet
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Defined Under Namespace
Classes: CardholderPromptData, ReportedBreakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#cardholder_prompt_data ⇒ Object
readonly
Answers to prompts presented to cardholder at point of sale.
-
#purchase_type ⇒ Object
readonly
The type of purchase.
-
#reported_breakdown ⇒ Object
readonly
More information about the total amount.
-
#service_type ⇒ Object
readonly
The type of fuel service.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#cardholder_prompt_data ⇒ Object (readonly)
Answers to prompts presented to cardholder at point of sale.
313 314 315 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 313 def cardholder_prompt_data @cardholder_prompt_data end |
#purchase_type ⇒ Object (readonly)
The type of purchase. One of ‘fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.
315 316 317 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 315 def purchase_type @purchase_type end |
#reported_breakdown ⇒ Object (readonly)
More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.
317 318 319 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 317 def reported_breakdown @reported_breakdown end |
#service_type ⇒ Object (readonly)
The type of fuel service. One of ‘non_fuel_transaction`, `full_service`, or `self_service`.
319 320 321 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 319 def service_type @service_type end |
Class Method Details
.field_encodings ⇒ Object
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 332 def self.field_encodings @field_encodings = { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, } end |
.field_remappings ⇒ Object
328 329 330 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 328 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
321 322 323 324 325 326 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 321 def self.inner_class_types @inner_class_types = { cardholder_prompt_data: CardholderPromptData, reported_breakdown: ReportedBreakdown, } end |