Class: Stripe::Issuing::Transaction::PurchaseDetails::Fleet

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Defined Under Namespace

Classes: CardholderPromptData, ReportedBreakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#cardholder_prompt_dataObject (readonly)

Answers to prompts presented to cardholder at point of sale.



101
102
103
# File 'lib/stripe/resources/issuing/transaction.rb', line 101

def cardholder_prompt_data
  @cardholder_prompt_data
end

#purchase_typeObject (readonly)

The type of purchase. One of ‘fuel_purchase`, `non_fuel_purchase`, or `fuel_and_non_fuel_purchase`.



103
104
105
# File 'lib/stripe/resources/issuing/transaction.rb', line 103

def purchase_type
  @purchase_type
end

#reported_breakdownObject (readonly)

More information about the total amount. This information is not guaranteed to be accurate as some merchants may provide unreliable data.



105
106
107
# File 'lib/stripe/resources/issuing/transaction.rb', line 105

def reported_breakdown
  @reported_breakdown
end

#service_typeObject (readonly)

The type of fuel service. One of ‘non_fuel_transaction`, `full_service`, or `self_service`.



107
108
109
# File 'lib/stripe/resources/issuing/transaction.rb', line 107

def service_type
  @service_type
end