Class: Stripe::Issuing::Transaction::PurchaseDetails::Fuel

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#industry_product_codeObject (readonly)

Conexxus Payment System Product Code identifying the primary fuel product purchased.



425
426
427
# File 'lib/stripe/resources/issuing/transaction.rb', line 425

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject (readonly)

The quantity of units of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



427
428
429
# File 'lib/stripe/resources/issuing/transaction.rb', line 427

def quantity_decimal
  @quantity_decimal
end

#typeObject (readonly)

The type of fuel that was purchased. One of diesel, unleaded_plus, unleaded_regular, unleaded_super, or other.



429
430
431
# File 'lib/stripe/resources/issuing/transaction.rb', line 429

def type
  @type
end

#unitObject (readonly)

The units for quantity_decimal. One of charging_minute, imperial_gallon, kilogram, kilowatt_hour, liter, pound, us_gallon, or other.



431
432
433
# File 'lib/stripe/resources/issuing/transaction.rb', line 431

def unit
  @unit
end

#unit_cost_decimalObject (readonly)

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



433
434
435
# File 'lib/stripe/resources/issuing/transaction.rb', line 433

def unit_cost_decimal
  @unit_cost_decimal
end

Class Method Details

.field_encodingsObject



443
444
445
446
447
448
# File 'lib/stripe/resources/issuing/transaction.rb', line 443

def self.field_encodings
  @field_encodings = {
    quantity_decimal: :decimal_string,
    unit_cost_decimal: :decimal_string,
  }
end

.field_remappingsObject



439
440
441
# File 'lib/stripe/resources/issuing/transaction.rb', line 439

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



435
436
437
# File 'lib/stripe/resources/issuing/transaction.rb', line 435

def self.inner_class_types
  @inner_class_types = {}
end