Class: Stripe::Issuing::Transaction::PurchaseDetails::Fuel

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#industry_product_codeObject (readonly)

[Conexxus Payment System Product Code](www.conexxus.org/conexxus-payment-system-product-codes) identifying the primary fuel product purchased.



171
172
173
# File 'lib/stripe/resources/issuing/transaction.rb', line 171

def industry_product_code
  @industry_product_code
end

#quantity_decimalObject (readonly)

The quantity of ‘unit`s of fuel that was dispensed, represented as a decimal string with at most 12 decimal places.



174
175
176
# File 'lib/stripe/resources/issuing/transaction.rb', line 174

def quantity_decimal
  @quantity_decimal
end

#typeObject (readonly)

The type of fuel that was purchased. One of ‘diesel`, `unleaded_plus`, `unleaded_regular`, `unleaded_super`, or `other`.



177
178
179
# File 'lib/stripe/resources/issuing/transaction.rb', line 177

def type
  @type
end

#unitObject (readonly)

The units for ‘quantity_decimal`. One of `charging_minute`, `imperial_gallon`, `kilogram`, `kilowatt_hour`, `liter`, `pound`, `us_gallon`, or `other`.



180
181
182
# File 'lib/stripe/resources/issuing/transaction.rb', line 180

def unit
  @unit
end

#unit_cost_decimalObject (readonly)

The cost in cents per each unit of fuel, represented as a decimal string with at most 12 decimal places.



183
184
185
# File 'lib/stripe/resources/issuing/transaction.rb', line 183

def unit_cost_decimal
  @unit_cost_decimal
end