Class: Stripe::Issuing::Transaction::RefundParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, refund_amount: nil) ⇒ RefundParams

Returns a new instance of RefundParams.



275
276
277
278
# File 'lib/stripe/resources/issuing/transaction.rb', line 275

def initialize(expand: nil, refund_amount: nil)
  @expand = expand
  @refund_amount = refund_amount
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



271
272
273
# File 'lib/stripe/resources/issuing/transaction.rb', line 271

def expand
  @expand
end

#refund_amountObject

The total amount to attempt to refund. This amount is in the provided currency, or defaults to the cards currency, and in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal).



273
274
275
# File 'lib/stripe/resources/issuing/transaction.rb', line 273

def refund_amount
  @refund_amount
end