Class: Stripe::Issuing::Transaction::TestHelpers
- Inherits:
-
APIResourceTestHelpers
- Object
- APIResourceTestHelpers
- Stripe::Issuing::Transaction::TestHelpers
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Constant Summary collapse
- RESOURCE_CLASS =
Transaction
Class Method Summary collapse
-
.create_force_capture(params = {}, opts = {}) ⇒ Object
Allows the user to capture an arbitrary amount, also known as a forced capture.
-
.create_unlinked_refund(params = {}, opts = {}) ⇒ Object
Allows the user to refund an arbitrary amount, also known as a unlinked refund.
-
.refund(transaction, params = {}, opts = {}) ⇒ Object
Refund a test-mode Transaction.
- .resource_class ⇒ Object
Instance Method Summary collapse
-
#refund(params = {}, opts = {}) ⇒ Object
Refund a test-mode Transaction.
Methods inherited from APIResourceTestHelpers
custom_method, #initialize, resource_url, #resource_url
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Stripe::APIResourceTestHelpers
Class Method Details
.create_force_capture(params = {}, opts = {}) ⇒ Object
Allows the user to capture an arbitrary amount, also known as a forced capture.
606 607 608 609 610 611 612 613 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 606 def self.create_force_capture(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/test_helpers/issuing/transactions/create_force_capture", params: params, opts: opts ) end |
.create_unlinked_refund(params = {}, opts = {}) ⇒ Object
Allows the user to refund an arbitrary amount, also known as a unlinked refund.
616 617 618 619 620 621 622 623 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 616 def self.create_unlinked_refund(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/test_helpers/issuing/transactions/create_unlinked_refund", params: params, opts: opts ) end |
.refund(transaction, params = {}, opts = {}) ⇒ Object
Refund a test-mode Transaction.
626 627 628 629 630 631 632 633 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 626 def self.refund(transaction, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(transaction) }), params: params, opts: opts ) end |
.resource_class ⇒ Object
601 602 603 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 601 def self.resource_class "Transaction" end |
Instance Method Details
#refund(params = {}, opts = {}) ⇒ Object
Refund a test-mode Transaction.
636 637 638 639 640 641 642 643 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 636 def refund(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |