Class: Stripe::Issuing::Transaction::TestHelpers

Inherits:
APIResourceTestHelpers show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Constant Summary collapse

RESOURCE_CLASS =
Transaction

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResourceTestHelpers

custom_method, #initialize, resource_url, #resource_url

Methods included from APIOperations::Request

included

Constructor Details

This class inherits a constructor from Stripe::APIResourceTestHelpers

Class Method Details

.create_force_capture(params = {}, opts = {}) ⇒ Object

Allows the user to capture an arbitrary amount, also known as a forced capture.



485
486
487
488
489
490
491
492
# File 'lib/stripe/resources/issuing/transaction.rb', line 485

def self.create_force_capture(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/test_helpers/issuing/transactions/create_force_capture",
    params: params,
    opts: opts
  )
end

.create_unlinked_refund(params = {}, opts = {}) ⇒ Object

Allows the user to refund an arbitrary amount, also known as a unlinked refund.



495
496
497
498
499
500
501
502
# File 'lib/stripe/resources/issuing/transaction.rb', line 495

def self.create_unlinked_refund(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/test_helpers/issuing/transactions/create_unlinked_refund",
    params: params,
    opts: opts
  )
end

.refund(transaction, params = {}, opts = {}) ⇒ Object

Refund a test-mode Transaction.



505
506
507
508
509
510
511
512
# File 'lib/stripe/resources/issuing/transaction.rb', line 505

def self.refund(transaction, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(transaction) }),
    params: params,
    opts: opts
  )
end

.resource_classObject



480
481
482
# File 'lib/stripe/resources/issuing/transaction.rb', line 480

def self.resource_class
  "Transaction"
end

Instance Method Details

#refund(params = {}, opts = {}) ⇒ Object

Refund a test-mode Transaction.



515
516
517
518
519
520
521
522
# File 'lib/stripe/resources/issuing/transaction.rb', line 515

def refund(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end