Class: Stripe::Issuing::Transaction::TestHelpers
- Inherits:
-
APIResourceTestHelpers
- Object
- APIResourceTestHelpers
- Stripe::Issuing::Transaction::TestHelpers
- Defined in:
- lib/stripe/resources/issuing/transaction.rb
Constant Summary collapse
- RESOURCE_CLASS =
Transaction
Class Method Summary collapse
-
.create_force_capture(params = {}, opts = {}) ⇒ Object
Allows the user to capture an arbitrary amount, also known as a forced capture.
-
.create_unlinked_refund(params = {}, opts = {}) ⇒ Object
Allows the user to refund an arbitrary amount, also known as a unlinked refund.
-
.refund(transaction, params = {}, opts = {}) ⇒ Object
Refund a test-mode Transaction.
- .resource_class ⇒ Object
Instance Method Summary collapse
-
#refund(params = {}, opts = {}) ⇒ Object
Refund a test-mode Transaction.
Methods inherited from APIResourceTestHelpers
custom_method, #initialize, resource_url, #resource_url
Methods included from APIOperations::Request
Constructor Details
This class inherits a constructor from Stripe::APIResourceTestHelpers
Class Method Details
.create_force_capture(params = {}, opts = {}) ⇒ Object
Allows the user to capture an arbitrary amount, also known as a forced capture.
969 970 971 972 973 974 975 976 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 969 def self.create_force_capture(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/test_helpers/issuing/transactions/create_force_capture", params: params, opts: opts ) end |
.create_unlinked_refund(params = {}, opts = {}) ⇒ Object
Allows the user to refund an arbitrary amount, also known as a unlinked refund.
979 980 981 982 983 984 985 986 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 979 def self.create_unlinked_refund(params = {}, opts = {}) request_stripe_object( method: :post, path: "/v1/test_helpers/issuing/transactions/create_unlinked_refund", params: params, opts: opts ) end |
.refund(transaction, params = {}, opts = {}) ⇒ Object
Refund a test-mode Transaction.
989 990 991 992 993 994 995 996 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 989 def self.refund(transaction, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(transaction) }), params: params, opts: opts ) end |
.resource_class ⇒ Object
964 965 966 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 964 def self.resource_class "Transaction" end |
Instance Method Details
#refund(params = {}, opts = {}) ⇒ Object
Refund a test-mode Transaction.
999 1000 1001 1002 1003 1004 1005 1006 |
# File 'lib/stripe/resources/issuing/transaction.rb', line 999 def refund(params = {}, opts = {}) @resource.request_stripe_object( method: :post, path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(@resource["id"]) }), params: params, opts: opts ) end |