Class: Stripe::Issuing::Transaction::TestHelpers

Inherits:
APIResourceTestHelpers show all
Defined in:
lib/stripe/resources/issuing/transaction.rb

Constant Summary collapse

RESOURCE_CLASS =
Transaction

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from APIResourceTestHelpers

custom_method, #initialize, resource_url, #resource_url

Methods included from APIOperations::Request

included

Constructor Details

This class inherits a constructor from Stripe::APIResourceTestHelpers

Class Method Details

.create_force_capture(params = {}, opts = {}) ⇒ Object

Allows the user to capture an arbitrary amount, also known as a forced capture.



978
979
980
981
982
983
984
985
# File 'lib/stripe/resources/issuing/transaction.rb', line 978

def self.create_force_capture(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/test_helpers/issuing/transactions/create_force_capture",
    params: params,
    opts: opts
  )
end

.create_unlinked_refund(params = {}, opts = {}) ⇒ Object

Allows the user to refund an arbitrary amount, also known as a unlinked refund.



988
989
990
991
992
993
994
995
# File 'lib/stripe/resources/issuing/transaction.rb', line 988

def self.create_unlinked_refund(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: "/v1/test_helpers/issuing/transactions/create_unlinked_refund",
    params: params,
    opts: opts
  )
end

.refund(transaction, params = {}, opts = {}) ⇒ Object

Refund a test-mode Transaction.



998
999
1000
1001
1002
1003
1004
1005
# File 'lib/stripe/resources/issuing/transaction.rb', line 998

def self.refund(transaction, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(transaction) }),
    params: params,
    opts: opts
  )
end

.resource_classObject



973
974
975
# File 'lib/stripe/resources/issuing/transaction.rb', line 973

def self.resource_class
  "Transaction"
end

Instance Method Details

#refund(params = {}, opts = {}) ⇒ Object

Refund a test-mode Transaction.



1008
1009
1010
1011
1012
1013
1014
1015
# File 'lib/stripe/resources/issuing/transaction.rb', line 1008

def refund(params = {}, opts = {})
  @resource.request_stripe_object(
    method: :post,
    path: format("/v1/test_helpers/issuing/transactions/%<transaction>s/refund", { transaction: CGI.escape(@resource["id"]) }),
    params: params,
    opts: opts
  )
end