Class: Stripe::Issuing::TransactionCreateForceCaptureParams::PurchaseDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Issuing::TransactionCreateForceCaptureParams::PurchaseDetails
- Defined in:
- lib/stripe/params/issuing/transaction_create_force_capture_params.rb
Defined Under Namespace
Classes: Fleet, Flight, Fuel, Healthcare, Lodging, Receipt
Instance Attribute Summary collapse
-
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
-
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
-
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
-
#healthcare ⇒ Object
Healthcare sub-amounts for IIAS-eligible transactions.
-
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
-
#receipt ⇒ Object
The line items in the purchase.
-
#reference ⇒ Object
A merchant-specific order number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(fleet: nil, flight: nil, fuel: nil, healthcare: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
constructor
A new instance of PurchaseDetails.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, new, #to_h
Constructor Details
#initialize(fleet: nil, flight: nil, fuel: nil, healthcare: nil, lodging: nil, receipt: nil, reference: nil) ⇒ PurchaseDetails
Returns a new instance of PurchaseDetails.
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 387 def initialize( fleet: nil, flight: nil, fuel: nil, healthcare: nil, lodging: nil, receipt: nil, reference: nil ) @fleet = fleet @flight = flight @fuel = fuel @healthcare = healthcare @lodging = lodging @receipt = receipt @reference = reference end |
Instance Attribute Details
#fleet ⇒ Object
Fleet-specific information for transactions using Fleet cards.
373 374 375 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 373 def fleet @fleet end |
#flight ⇒ Object
Information about the flight that was purchased with this transaction.
375 376 377 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 375 def flight @flight end |
#fuel ⇒ Object
Information about fuel that was purchased with this transaction.
377 378 379 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 377 def fuel @fuel end |
#healthcare ⇒ Object
Healthcare sub-amounts for IIAS-eligible transactions.
379 380 381 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 379 def healthcare @healthcare end |
#lodging ⇒ Object
Information about lodging that was purchased with this transaction.
381 382 383 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 381 def lodging @lodging end |
#receipt ⇒ Object
The line items in the purchase.
383 384 385 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 383 def receipt @receipt end |
#reference ⇒ Object
A merchant-specific order number.
385 386 387 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 385 def reference @reference end |
Class Method Details
.field_encodings ⇒ Object
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/stripe/params/issuing/transaction_create_force_capture_params.rb', line 405 def self.field_encodings @field_encodings = { fleet: { kind: :object, fields: { reported_breakdown: { kind: :object, fields: { fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, non_fuel: { kind: :object, fields: { gross_amount_decimal: :decimal_string } }, tax: { kind: :object, fields: { local_amount_decimal: :decimal_string, national_amount_decimal: :decimal_string, }, }, }, }, }, }, fuel: { kind: :object, fields: { quantity_decimal: :decimal_string, unit_cost_decimal: :decimal_string }, }, receipt: { kind: :array, element: { kind: :object, fields: { quantity: :decimal_string } } }, } end |