Class: Stripe::Issuing::TransactionCreateUnlinkedRefundParams::PurchaseDetails::Fleet::ReportedBreakdown::Tax

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(local_amount_decimal: nil, national_amount_decimal: nil) ⇒ Tax

Returns a new instance of Tax.



120
121
122
123
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 120

def initialize(local_amount_decimal: nil, national_amount_decimal: nil)
  @local_amount_decimal = local_amount_decimal
  @national_amount_decimal = national_amount_decimal
end

Instance Attribute Details

#local_amount_decimalObject

Amount of state or provincial Sales Tax included in the transaction amount. Null if not reported by merchant or not subject to tax.



116
117
118
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 116

def local_amount_decimal
  @local_amount_decimal
end

#national_amount_decimalObject

Amount of national Sales Tax or VAT included in the transaction amount. Null if not reported by merchant or not subject to tax.



118
119
120
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 118

def national_amount_decimal
  @national_amount_decimal
end

Class Method Details

.field_encodingsObject



125
126
127
128
129
130
# File 'lib/stripe/params/issuing/transaction_create_unlinked_refund_params.rb', line 125

def self.field_encodings
  @field_encodings = {
    local_amount_decimal: :decimal_string,
    national_amount_decimal: :decimal_string,
  }
end