Class: Stripe::Issuing::TransactionService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/issuing/transaction_service.rb

Defined Under Namespace

Classes: ListParams, RetrieveParams, UpdateParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#list(params = {}, opts = {}) ⇒ Object

Returns a list of Issuing Transaction objects. The objects are sorted in descending order by creation date, with the most recently created object appearing first.



85
86
87
88
89
90
91
92
93
# File 'lib/stripe/services/issuing/transaction_service.rb', line 85

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/issuing/transactions",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(transaction, params = {}, opts = {}) ⇒ Object

Retrieves an Issuing Transaction object.



96
97
98
99
100
101
102
103
104
# File 'lib/stripe/services/issuing/transaction_service.rb', line 96

def retrieve(transaction, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/issuing/transactions/%<transaction>s", { transaction: CGI.escape(transaction) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#update(transaction, params = {}, opts = {}) ⇒ Object

Updates the specified Issuing Transaction object by setting the values of the parameters passed. Any parameters not provided will be left unchanged.



107
108
109
110
111
112
113
114
115
# File 'lib/stripe/services/issuing/transaction_service.rb', line 107

def update(transaction, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/issuing/transactions/%<transaction>s", { transaction: CGI.escape(transaction) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end