Class: Stripe::LineItem

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/line_item.rb

Overview

A line item.

Defined Under Namespace

Classes: AdjustableQuantity, Discount, Display, Tax, TaxCalculationReference

Constant Summary collapse

OBJECT_NAME =
"item"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#adjustable_quantityObject (readonly)

Attribute for field adjustable_quantity



60
61
62
# File 'lib/stripe/resources/line_item.rb', line 60

def adjustable_quantity
  @adjustable_quantity
end

#amount_discountObject (readonly)

Total discount amount applied. If no discounts were applied, defaults to 0.



62
63
64
# File 'lib/stripe/resources/line_item.rb', line 62

def amount_discount
  @amount_discount
end

#amount_subtotalObject (readonly)

Total before any discounts or taxes are applied.



64
65
66
# File 'lib/stripe/resources/line_item.rb', line 64

def amount_subtotal
  @amount_subtotal
end

#amount_taxObject (readonly)

Total tax amount applied. If no tax was applied, defaults to 0.



66
67
68
# File 'lib/stripe/resources/line_item.rb', line 66

def amount_tax
  @amount_tax
end

#amount_totalObject (readonly)

Total after discounts and taxes.



68
69
70
# File 'lib/stripe/resources/line_item.rb', line 68

def amount_total
  @amount_total
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



70
71
72
# File 'lib/stripe/resources/line_item.rb', line 70

def currency
  @currency
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users. Defaults to product name.



72
73
74
# File 'lib/stripe/resources/line_item.rb', line 72

def description
  @description
end

#discountsObject (readonly)

The discounts applied to the line item.



74
75
76
# File 'lib/stripe/resources/line_item.rb', line 74

def discounts
  @discounts
end

#displayObject (readonly)

Attribute for field display



76
77
78
# File 'lib/stripe/resources/line_item.rb', line 76

def display
  @display
end

#idObject (readonly)

Unique identifier for the object.



78
79
80
# File 'lib/stripe/resources/line_item.rb', line 78

def id
  @id
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



80
81
82
# File 'lib/stripe/resources/line_item.rb', line 80

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



82
83
84
# File 'lib/stripe/resources/line_item.rb', line 82

def object
  @object
end

#priceObject (readonly)

The price used to generate the line item.



84
85
86
# File 'lib/stripe/resources/line_item.rb', line 84

def price
  @price
end

#productObject (readonly)

The ID of the product for this line item.

This will always be the same as ‘price.product`.



88
89
90
# File 'lib/stripe/resources/line_item.rb', line 88

def product
  @product
end

#quantityObject (readonly)

The quantity of products being purchased.



90
91
92
# File 'lib/stripe/resources/line_item.rb', line 90

def quantity
  @quantity
end

#tax_calculation_referenceObject (readonly)

The tax calculation identifiers of the line item.



92
93
94
# File 'lib/stripe/resources/line_item.rb', line 92

def tax_calculation_reference
  @tax_calculation_reference
end

#taxesObject (readonly)

The taxes applied to the line item.



94
95
96
# File 'lib/stripe/resources/line_item.rb', line 94

def taxes
  @taxes
end

Class Method Details

.object_nameObject



8
9
10
# File 'lib/stripe/resources/line_item.rb', line 8

def self.object_name
  "item"
end