Class: Stripe::Mandate

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/mandate.rb

Overview

A Mandate is a record of the permission that your customer gives you to debit their payment method.

Defined Under Namespace

Classes: CustomerAcceptance, MultiUse, PaymentMethodDetails, SingleUse

Constant Summary collapse

OBJECT_NAME =
"mandate"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customer_acceptanceObject (readonly)

Attribute for field customer_acceptance



433
434
435
# File 'lib/stripe/resources/mandate.rb', line 433

def customer_acceptance
  @customer_acceptance
end

#idObject (readonly)

Unique identifier for the object.



435
436
437
# File 'lib/stripe/resources/mandate.rb', line 435

def id
  @id
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



437
438
439
# File 'lib/stripe/resources/mandate.rb', line 437

def livemode
  @livemode
end

#multi_useObject (readonly)

Attribute for field multi_use



439
440
441
# File 'lib/stripe/resources/mandate.rb', line 439

def multi_use
  @multi_use
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



441
442
443
# File 'lib/stripe/resources/mandate.rb', line 441

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) that the mandate is intended for.



443
444
445
# File 'lib/stripe/resources/mandate.rb', line 443

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method associated with this mandate.



445
446
447
# File 'lib/stripe/resources/mandate.rb', line 445

def payment_method
  @payment_method
end

#payment_method_detailsObject (readonly)

Attribute for field payment_method_details



447
448
449
# File 'lib/stripe/resources/mandate.rb', line 447

def payment_method_details
  @payment_method_details
end

#single_useObject (readonly)

Attribute for field single_use



449
450
451
# File 'lib/stripe/resources/mandate.rb', line 449

def single_use
  @single_use
end

#statusObject (readonly)

The mandate status indicates whether or not you can use it to initiate a payment.



451
452
453
# File 'lib/stripe/resources/mandate.rb', line 451

def status
  @status
end

#typeObject (readonly)

The type of the mandate.



453
454
455
# File 'lib/stripe/resources/mandate.rb', line 453

def type
  @type
end

Class Method Details

.field_remappingsObject



464
465
466
# File 'lib/stripe/resources/mandate.rb', line 464

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



455
456
457
458
459
460
461
462
# File 'lib/stripe/resources/mandate.rb', line 455

def self.inner_class_types
  @inner_class_types = {
    customer_acceptance: CustomerAcceptance,
    multi_use: MultiUse,
    payment_method_details: PaymentMethodDetails,
    single_use: SingleUse,
  }
end

.object_nameObject



8
9
10
# File 'lib/stripe/resources/mandate.rb', line 8

def self.object_name
  "mandate"
end