Class: Stripe::Mandate
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Mandate
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/mandate.rb
Overview
A Mandate is a record of the permission that your customer gives you to debit their payment method.
Defined Under Namespace
Classes: CustomerAcceptance, MultiUse, PaymentMethodDetails, SingleUse
Constant Summary collapse
- OBJECT_NAME =
"mandate"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#customer_acceptance ⇒ Object
readonly
Attribute for field customer_acceptance.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#multi_use ⇒ Object
readonly
Attribute for field multi_use.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) that the mandate is intended for.
-
#payment_method ⇒ Object
readonly
ID of the payment method associated with this mandate.
-
#payment_method_details ⇒ Object
readonly
Attribute for field payment_method_details.
-
#single_use ⇒ Object
readonly
Attribute for field single_use.
-
#status ⇒ Object
readonly
The mandate status indicates whether or not you can use it to initiate a payment.
-
#type ⇒ Object
readonly
The type of the mandate.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Retrieves a list of Mandates for a given PaymentMethod.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#customer_acceptance ⇒ Object (readonly)
Attribute for field customer_acceptance
427 428 429 |
# File 'lib/stripe/resources/mandate.rb', line 427 def customer_acceptance @customer_acceptance end |
#id ⇒ Object (readonly)
Unique identifier for the object.
429 430 431 |
# File 'lib/stripe/resources/mandate.rb', line 429 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
431 432 433 |
# File 'lib/stripe/resources/mandate.rb', line 431 def livemode @livemode end |
#multi_use ⇒ Object (readonly)
Attribute for field multi_use
433 434 435 |
# File 'lib/stripe/resources/mandate.rb', line 433 def multi_use @multi_use end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
435 436 437 |
# File 'lib/stripe/resources/mandate.rb', line 435 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) that the mandate is intended for.
437 438 439 |
# File 'lib/stripe/resources/mandate.rb', line 437 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of the payment method associated with this mandate.
439 440 441 |
# File 'lib/stripe/resources/mandate.rb', line 439 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Attribute for field payment_method_details
441 442 443 |
# File 'lib/stripe/resources/mandate.rb', line 441 def payment_method_details @payment_method_details end |
#single_use ⇒ Object (readonly)
Attribute for field single_use
443 444 445 |
# File 'lib/stripe/resources/mandate.rb', line 443 def single_use @single_use end |
#status ⇒ Object (readonly)
The mandate status indicates whether or not you can use it to initiate a payment.
445 446 447 |
# File 'lib/stripe/resources/mandate.rb', line 445 def status @status end |
#type ⇒ Object (readonly)
The type of the mandate.
447 448 449 |
# File 'lib/stripe/resources/mandate.rb', line 447 def type @type end |
Class Method Details
.field_remappings ⇒ Object
463 464 465 |
# File 'lib/stripe/resources/mandate.rb', line 463 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
454 455 456 457 458 459 460 461 |
# File 'lib/stripe/resources/mandate.rb', line 454 def self.inner_class_types @inner_class_types = { customer_acceptance: CustomerAcceptance, multi_use: MultiUse, payment_method_details: PaymentMethodDetails, single_use: SingleUse, } end |
.list(params = {}, opts = {}) ⇒ Object
Retrieves a list of Mandates for a given PaymentMethod.
450 451 452 |
# File 'lib/stripe/resources/mandate.rb', line 450 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/mandates", params: params, opts: opts) end |
.object_name ⇒ Object
10 11 12 |
# File 'lib/stripe/resources/mandate.rb', line 10 def self.object_name "mandate" end |