Class: Stripe::Mandate
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Mandate
- Defined in:
- lib/stripe/resources/mandate.rb
Overview
A Mandate is a record of the permission that your customer gives you to debit their payment method.
Defined Under Namespace
Classes: CustomerAcceptance, MultiUse, PaymentMethodDetails, SingleUse
Constant Summary collapse
- OBJECT_NAME =
"mandate"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#customer_acceptance ⇒ Object
readonly
Attribute for field customer_acceptance.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#multi_use ⇒ Object
readonly
Attribute for field multi_use.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) that the mandate is intended for.
-
#payment_method ⇒ Object
readonly
ID of the payment method associated with this mandate.
-
#payment_method_details ⇒ Object
readonly
Attribute for field payment_method_details.
-
#single_use ⇒ Object
readonly
Attribute for field single_use.
-
#status ⇒ Object
readonly
The mandate status indicates whether or not you can use it to initiate a payment.
-
#type ⇒ Object
readonly
The type of the mandate.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#customer_acceptance ⇒ Object (readonly)
Attribute for field customer_acceptance
389 390 391 |
# File 'lib/stripe/resources/mandate.rb', line 389 def customer_acceptance @customer_acceptance end |
#id ⇒ Object (readonly)
Unique identifier for the object.
391 392 393 |
# File 'lib/stripe/resources/mandate.rb', line 391 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
393 394 395 |
# File 'lib/stripe/resources/mandate.rb', line 393 def livemode @livemode end |
#multi_use ⇒ Object (readonly)
Attribute for field multi_use
395 396 397 |
# File 'lib/stripe/resources/mandate.rb', line 395 def multi_use @multi_use end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
397 398 399 |
# File 'lib/stripe/resources/mandate.rb', line 397 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) that the mandate is intended for.
399 400 401 |
# File 'lib/stripe/resources/mandate.rb', line 399 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of the payment method associated with this mandate.
401 402 403 |
# File 'lib/stripe/resources/mandate.rb', line 401 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Attribute for field payment_method_details
403 404 405 |
# File 'lib/stripe/resources/mandate.rb', line 403 def payment_method_details @payment_method_details end |
#single_use ⇒ Object (readonly)
Attribute for field single_use
405 406 407 |
# File 'lib/stripe/resources/mandate.rb', line 405 def single_use @single_use end |
#status ⇒ Object (readonly)
The mandate status indicates whether or not you can use it to initiate a payment.
407 408 409 |
# File 'lib/stripe/resources/mandate.rb', line 407 def status @status end |
#type ⇒ Object (readonly)
The type of the mandate.
409 410 411 |
# File 'lib/stripe/resources/mandate.rb', line 409 def type @type end |
Class Method Details
.field_remappings ⇒ Object
420 421 422 |
# File 'lib/stripe/resources/mandate.rb', line 420 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
411 412 413 414 415 416 417 418 |
# File 'lib/stripe/resources/mandate.rb', line 411 def self.inner_class_types @inner_class_types = { customer_acceptance: CustomerAcceptance, multi_use: MultiUse, payment_method_details: PaymentMethodDetails, single_use: SingleUse, } end |
.object_name ⇒ Object
8 9 10 |
# File 'lib/stripe/resources/mandate.rb', line 8 def self.object_name "mandate" end |