Class: Stripe::Mandate

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/mandate.rb

Overview

A Mandate is a record of the permission that your customer gives you to debit their payment method.

Defined Under Namespace

Classes: CustomerAcceptance, ListParams, MultiUse, PaymentMethodDetails, SingleUse

Constant Summary collapse

OBJECT_NAME =
"mandate"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customer_acceptanceObject (readonly)

Attribute for field customer_acceptance



218
219
220
# File 'lib/stripe/resources/mandate.rb', line 218

def customer_acceptance
  @customer_acceptance
end

#idObject (readonly)

Unique identifier for the object.



220
221
222
# File 'lib/stripe/resources/mandate.rb', line 220

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



222
223
224
# File 'lib/stripe/resources/mandate.rb', line 222

def livemode
  @livemode
end

#multi_useObject (readonly)

Attribute for field multi_use



224
225
226
# File 'lib/stripe/resources/mandate.rb', line 224

def multi_use
  @multi_use
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



226
227
228
# File 'lib/stripe/resources/mandate.rb', line 226

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) that the mandate is intended for.



228
229
230
# File 'lib/stripe/resources/mandate.rb', line 228

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method associated with this mandate.



230
231
232
# File 'lib/stripe/resources/mandate.rb', line 230

def payment_method
  @payment_method
end

#payment_method_detailsObject (readonly)

Attribute for field payment_method_details



232
233
234
# File 'lib/stripe/resources/mandate.rb', line 232

def payment_method_details
  @payment_method_details
end

#single_useObject (readonly)

Attribute for field single_use



234
235
236
# File 'lib/stripe/resources/mandate.rb', line 234

def single_use
  @single_use
end

#statusObject (readonly)

The mandate status indicates whether or not you can use it to initiate a payment.



236
237
238
# File 'lib/stripe/resources/mandate.rb', line 236

def status
  @status
end

#typeObject (readonly)

The type of the mandate.



238
239
240
# File 'lib/stripe/resources/mandate.rb', line 238

def type
  @type
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

Retrieves a list of Mandates for a given PaymentMethod.



241
242
243
# File 'lib/stripe/resources/mandate.rb', line 241

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/mandates", params: params, opts: opts)
end

.object_nameObject



10
11
12
# File 'lib/stripe/resources/mandate.rb', line 10

def self.object_name
  "mandate"
end