Class: Stripe::Mandate

Inherits:
APIResource show all
Defined in:
lib/stripe/resources/mandate.rb

Overview

A Mandate is a record of the permission that your customer gives you to debit their payment method.

Defined Under Namespace

Classes: CustomerAcceptance, MultiUse, PaymentMethodDetails, SingleUse

Constant Summary collapse

OBJECT_NAME =
"mandate"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customer_acceptanceObject (readonly)

Attribute for field customer_acceptance



159
160
161
# File 'lib/stripe/resources/mandate.rb', line 159

def customer_acceptance
  @customer_acceptance
end

#idObject (readonly)

Unique identifier for the object.



161
162
163
# File 'lib/stripe/resources/mandate.rb', line 161

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



163
164
165
# File 'lib/stripe/resources/mandate.rb', line 163

def livemode
  @livemode
end

#multi_useObject (readonly)

Attribute for field multi_use



165
166
167
# File 'lib/stripe/resources/mandate.rb', line 165

def multi_use
  @multi_use
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



167
168
169
# File 'lib/stripe/resources/mandate.rb', line 167

def object
  @object
end

#on_behalf_ofObject (readonly)

The account (if any) that the mandate is intended for.



169
170
171
# File 'lib/stripe/resources/mandate.rb', line 169

def on_behalf_of
  @on_behalf_of
end

#payment_methodObject (readonly)

ID of the payment method associated with this mandate.



171
172
173
# File 'lib/stripe/resources/mandate.rb', line 171

def payment_method
  @payment_method
end

#payment_method_detailsObject (readonly)

Attribute for field payment_method_details



173
174
175
# File 'lib/stripe/resources/mandate.rb', line 173

def payment_method_details
  @payment_method_details
end

#single_useObject (readonly)

Attribute for field single_use



175
176
177
# File 'lib/stripe/resources/mandate.rb', line 175

def single_use
  @single_use
end

#statusObject (readonly)

The mandate status indicates whether or not you can use it to initiate a payment.



177
178
179
# File 'lib/stripe/resources/mandate.rb', line 177

def status
  @status
end

#typeObject (readonly)

The type of the mandate.



179
180
181
# File 'lib/stripe/resources/mandate.rb', line 179

def type
  @type
end

Class Method Details

.object_nameObject



8
9
10
# File 'lib/stripe/resources/mandate.rb', line 8

def self.object_name
  "mandate"
end