Class: Stripe::Mandate
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Mandate
- Defined in:
- lib/stripe/resources/mandate.rb
Overview
A Mandate is a record of the permission that your customer gives you to debit their payment method.
Defined Under Namespace
Classes: CustomerAcceptance, MultiUse, PaymentMethodDetails, SingleUse
Constant Summary collapse
- OBJECT_NAME =
"mandate"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#customer_acceptance ⇒ Object
readonly
Attribute for field customer_acceptance.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#multi_use ⇒ Object
readonly
Attribute for field multi_use.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) that the mandate is intended for.
-
#payment_method ⇒ Object
readonly
ID of the payment method associated with this mandate.
-
#payment_method_details ⇒ Object
readonly
Attribute for field payment_method_details.
-
#single_use ⇒ Object
readonly
Attribute for field single_use.
-
#status ⇒ Object
readonly
The mandate status indicates whether or not you can use it to initiate a payment.
-
#type ⇒ Object
readonly
The type of the mandate.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#customer_acceptance ⇒ Object (readonly)
Attribute for field customer_acceptance
68 69 70 |
# File 'lib/stripe/resources/mandate.rb', line 68 def customer_acceptance @customer_acceptance end |
#id ⇒ Object (readonly)
Unique identifier for the object.
70 71 72 |
# File 'lib/stripe/resources/mandate.rb', line 70 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
72 73 74 |
# File 'lib/stripe/resources/mandate.rb', line 72 def livemode @livemode end |
#multi_use ⇒ Object (readonly)
Attribute for field multi_use
74 75 76 |
# File 'lib/stripe/resources/mandate.rb', line 74 def multi_use @multi_use end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
76 77 78 |
# File 'lib/stripe/resources/mandate.rb', line 76 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) that the mandate is intended for.
78 79 80 |
# File 'lib/stripe/resources/mandate.rb', line 78 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object (readonly)
ID of the payment method associated with this mandate.
80 81 82 |
# File 'lib/stripe/resources/mandate.rb', line 80 def payment_method @payment_method end |
#payment_method_details ⇒ Object (readonly)
Attribute for field payment_method_details
82 83 84 |
# File 'lib/stripe/resources/mandate.rb', line 82 def payment_method_details @payment_method_details end |
#single_use ⇒ Object (readonly)
Attribute for field single_use
84 85 86 |
# File 'lib/stripe/resources/mandate.rb', line 84 def single_use @single_use end |
#status ⇒ Object (readonly)
The mandate status indicates whether or not you can use it to initiate a payment.
86 87 88 |
# File 'lib/stripe/resources/mandate.rb', line 86 def status @status end |
#type ⇒ Object (readonly)
The type of the mandate.
88 89 90 |
# File 'lib/stripe/resources/mandate.rb', line 88 def type @type end |
Class Method Details
.object_name ⇒ Object
8 9 10 |
# File 'lib/stripe/resources/mandate.rb', line 8 def self.object_name "mandate" end |