Class: Stripe::Mandate::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Mandate::ListParams
- Defined in:
- lib/stripe/resources/mandate.rb
Instance Attribute Summary collapse
-
#ending_before ⇒ Object
A cursor for use in pagination.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#on_behalf_of ⇒ Object
The Stripe account ID that the mandates are intended for.
-
#payment_method ⇒ Object
Attribute for param field payment_method.
-
#starting_after ⇒ Object
A cursor for use in pagination.
-
#status ⇒ Object
The status of the mandates to retrieve.
Instance Method Summary collapse
-
#initialize(ending_before: nil, expand: nil, limit: nil, on_behalf_of: nil, payment_method: nil, starting_after: nil, status: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(ending_before: nil, expand: nil, limit: nil, on_behalf_of: nil, payment_method: nil, starting_after: nil, status: nil) ⇒ ListParams
Returns a new instance of ListParams.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/stripe/resources/mandate.rb', line 199 def initialize( ending_before: nil, expand: nil, limit: nil, on_behalf_of: nil, payment_method: nil, starting_after: nil, status: nil ) @ending_before = ending_before @expand = @limit = limit @on_behalf_of = on_behalf_of @payment_method = payment_method @starting_after = starting_after @status = status end |
Instance Attribute Details
#ending_before ⇒ Object
A cursor for use in pagination. ‘ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
185 186 187 |
# File 'lib/stripe/resources/mandate.rb', line 185 def ending_before @ending_before end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
187 188 189 |
# File 'lib/stripe/resources/mandate.rb', line 187 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
189 190 191 |
# File 'lib/stripe/resources/mandate.rb', line 189 def limit @limit end |
#on_behalf_of ⇒ Object
The Stripe account ID that the mandates are intended for. Learn more about the [use case for connected accounts payments](stripe.com/docs/payments/connected-accounts).
191 192 193 |
# File 'lib/stripe/resources/mandate.rb', line 191 def on_behalf_of @on_behalf_of end |
#payment_method ⇒ Object
Attribute for param field payment_method
193 194 195 |
# File 'lib/stripe/resources/mandate.rb', line 193 def payment_method @payment_method end |
#starting_after ⇒ Object
A cursor for use in pagination. ‘starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
195 196 197 |
# File 'lib/stripe/resources/mandate.rb', line 195 def starting_after @starting_after end |
#status ⇒ Object
The status of the mandates to retrieve. Status indicates whether or not you can use it to initiate a payment, and can have a value of ‘active`, `pending`, or `inactive`.
197 198 199 |
# File 'lib/stripe/resources/mandate.rb', line 197 def status @status end |