Class: Stripe::Mandate::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/mandate.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Card, Cashapp, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Payto, Pix, RevolutPay, SepaDebit, Twint, Upi, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
This mandate corresponds with a specific payment method type.
-
#upi ⇒ Object
readonly
Attribute for field upi.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
346 347 348 |
# File 'lib/stripe/resources/mandate.rb', line 346 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
348 349 350 |
# File 'lib/stripe/resources/mandate.rb', line 348 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
350 351 352 |
# File 'lib/stripe/resources/mandate.rb', line 350 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
352 353 354 |
# File 'lib/stripe/resources/mandate.rb', line 352 def bacs_debit @bacs_debit end |
#card ⇒ Object (readonly)
Attribute for field card
354 355 356 |
# File 'lib/stripe/resources/mandate.rb', line 354 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
356 357 358 |
# File 'lib/stripe/resources/mandate.rb', line 356 def cashapp @cashapp end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
358 359 360 |
# File 'lib/stripe/resources/mandate.rb', line 358 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
360 361 362 |
# File 'lib/stripe/resources/mandate.rb', line 360 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
362 363 364 |
# File 'lib/stripe/resources/mandate.rb', line 362 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
364 365 366 |
# File 'lib/stripe/resources/mandate.rb', line 364 def link @link end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
366 367 368 |
# File 'lib/stripe/resources/mandate.rb', line 366 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
368 369 370 |
# File 'lib/stripe/resources/mandate.rb', line 368 def nz_bank_account @nz_bank_account end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
370 371 372 |
# File 'lib/stripe/resources/mandate.rb', line 370 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
372 373 374 |
# File 'lib/stripe/resources/mandate.rb', line 372 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
374 375 376 |
# File 'lib/stripe/resources/mandate.rb', line 374 def pix @pix end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
376 377 378 |
# File 'lib/stripe/resources/mandate.rb', line 376 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
378 379 380 |
# File 'lib/stripe/resources/mandate.rb', line 378 def sepa_debit @sepa_debit end |
#twint ⇒ Object (readonly)
Attribute for field twint
380 381 382 |
# File 'lib/stripe/resources/mandate.rb', line 380 def twint @twint end |
#type ⇒ Object (readonly)
This mandate corresponds with a specific payment method type. The ‘payment_method_details` includes an additional hash with the same name and contains mandate information that’s specific to that payment method.
382 383 384 |
# File 'lib/stripe/resources/mandate.rb', line 382 def type @type end |
#upi ⇒ Object (readonly)
Attribute for field upi
384 385 386 |
# File 'lib/stripe/resources/mandate.rb', line 384 def upi @upi end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
386 387 388 |
# File 'lib/stripe/resources/mandate.rb', line 386 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
413 414 415 |
# File 'lib/stripe/resources/mandate.rb', line 413 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/stripe/resources/mandate.rb', line 388 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, card: Card, cashapp: Cashapp, kakao_pay: KakaoPay, klarna: Klarna, kr_card: KrCard, link: Link, naver_pay: NaverPay, nz_bank_account: NzBankAccount, paypal: Paypal, payto: Payto, pix: Pix, revolut_pay: RevolutPay, sepa_debit: SepaDebit, twint: Twint, upi: Upi, us_bank_account: UsBankAccount, } end |