Class: Stripe::Mandate::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/mandate.rb

Defined Under Namespace

Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Card, Cashapp, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Payto, Pix, RevolutPay, SepaDebit, Upi, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



343
344
345
# File 'lib/stripe/resources/mandate.rb', line 343

def acss_debit
  @acss_debit
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



345
346
347
# File 'lib/stripe/resources/mandate.rb', line 345

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



347
348
349
# File 'lib/stripe/resources/mandate.rb', line 347

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



349
350
351
# File 'lib/stripe/resources/mandate.rb', line 349

def bacs_debit
  @bacs_debit
end

#cardObject (readonly)

Attribute for field card



351
352
353
# File 'lib/stripe/resources/mandate.rb', line 351

def card
  @card
end

#cashappObject (readonly)

Attribute for field cashapp



353
354
355
# File 'lib/stripe/resources/mandate.rb', line 353

def cashapp
  @cashapp
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



355
356
357
# File 'lib/stripe/resources/mandate.rb', line 355

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



357
358
359
# File 'lib/stripe/resources/mandate.rb', line 357

def klarna
  @klarna
end

#kr_cardObject (readonly)

Attribute for field kr_card



359
360
361
# File 'lib/stripe/resources/mandate.rb', line 359

def kr_card
  @kr_card
end

Attribute for field link



361
362
363
# File 'lib/stripe/resources/mandate.rb', line 361

def link
  @link
end

Attribute for field naver_pay



363
364
365
# File 'lib/stripe/resources/mandate.rb', line 363

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



365
366
367
# File 'lib/stripe/resources/mandate.rb', line 365

def 
  @nz_bank_account
end

#paypalObject (readonly)

Attribute for field paypal



367
368
369
# File 'lib/stripe/resources/mandate.rb', line 367

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



369
370
371
# File 'lib/stripe/resources/mandate.rb', line 369

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



371
372
373
# File 'lib/stripe/resources/mandate.rb', line 371

def pix
  @pix
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



373
374
375
# File 'lib/stripe/resources/mandate.rb', line 373

def revolut_pay
  @revolut_pay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



375
376
377
# File 'lib/stripe/resources/mandate.rb', line 375

def sepa_debit
  @sepa_debit
end

#typeObject (readonly)

This mandate corresponds with a specific payment method type. The ‘payment_method_details` includes an additional hash with the same name and contains mandate information that’s specific to that payment method.



377
378
379
# File 'lib/stripe/resources/mandate.rb', line 377

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



379
380
381
# File 'lib/stripe/resources/mandate.rb', line 379

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



381
382
383
# File 'lib/stripe/resources/mandate.rb', line 381

def 
  @us_bank_account
end

Class Method Details

.field_remappingsObject



407
408
409
# File 'lib/stripe/resources/mandate.rb', line 407

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/stripe/resources/mandate.rb', line 383

def self.inner_class_types
  @inner_class_types = {
    acss_debit: AcssDebit,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    card: Card,
    cashapp: Cashapp,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    kr_card: KrCard,
    link: Link,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    paypal: Paypal,
    payto: Payto,
    pix: Pix,
    revolut_pay: RevolutPay,
    sepa_debit: SepaDebit,
    upi: Upi,
    us_bank_account: UsBankAccount,
  }
end