Class: Stripe::Mandate::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/mandate.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Card, Cashapp, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Payto, Pix, RevolutPay, SepaDebit, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#type ⇒ Object
readonly
This mandate corresponds with a specific payment method type.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
320 321 322 |
# File 'lib/stripe/resources/mandate.rb', line 320 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
322 323 324 |
# File 'lib/stripe/resources/mandate.rb', line 322 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
324 325 326 |
# File 'lib/stripe/resources/mandate.rb', line 324 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
326 327 328 |
# File 'lib/stripe/resources/mandate.rb', line 326 def bacs_debit @bacs_debit end |
#card ⇒ Object (readonly)
Attribute for field card
328 329 330 |
# File 'lib/stripe/resources/mandate.rb', line 328 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
330 331 332 |
# File 'lib/stripe/resources/mandate.rb', line 330 def cashapp @cashapp end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
332 333 334 |
# File 'lib/stripe/resources/mandate.rb', line 332 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
334 335 336 |
# File 'lib/stripe/resources/mandate.rb', line 334 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
336 337 338 |
# File 'lib/stripe/resources/mandate.rb', line 336 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
338 339 340 |
# File 'lib/stripe/resources/mandate.rb', line 338 def link @link end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
340 341 342 |
# File 'lib/stripe/resources/mandate.rb', line 340 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
342 343 344 |
# File 'lib/stripe/resources/mandate.rb', line 342 def nz_bank_account @nz_bank_account end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
344 345 346 |
# File 'lib/stripe/resources/mandate.rb', line 344 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
346 347 348 |
# File 'lib/stripe/resources/mandate.rb', line 346 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
348 349 350 |
# File 'lib/stripe/resources/mandate.rb', line 348 def pix @pix end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
350 351 352 |
# File 'lib/stripe/resources/mandate.rb', line 350 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
352 353 354 |
# File 'lib/stripe/resources/mandate.rb', line 352 def sepa_debit @sepa_debit end |
#type ⇒ Object (readonly)
This mandate corresponds with a specific payment method type. The ‘payment_method_details` includes an additional hash with the same name and contains mandate information that’s specific to that payment method.
354 355 356 |
# File 'lib/stripe/resources/mandate.rb', line 354 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
356 357 358 |
# File 'lib/stripe/resources/mandate.rb', line 356 def us_bank_account @us_bank_account end |
Class Method Details
.field_remappings ⇒ Object
381 382 383 |
# File 'lib/stripe/resources/mandate.rb', line 381 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/stripe/resources/mandate.rb', line 358 def self.inner_class_types @inner_class_types = { acss_debit: AcssDebit, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, card: Card, cashapp: Cashapp, kakao_pay: KakaoPay, klarna: Klarna, kr_card: KrCard, link: Link, naver_pay: NaverPay, nz_bank_account: NzBankAccount, paypal: Paypal, payto: Payto, pix: Pix, revolut_pay: RevolutPay, sepa_debit: SepaDebit, us_bank_account: UsBankAccount, } end |