Class: Stripe::Mandate::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/mandate.rb
Defined Under Namespace
Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Card, Cashapp, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, Payto, RevolutPay, SepaDebit, UsBankAccount
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#card ⇒ Object
readonly
Attribute for field card.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#type ⇒ Object
readonly
This mandate corresponds with a specific payment method type.
-
#us_bank_account ⇒ Object
readonly
Attribute for field us_bank_account.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
115 116 117 |
# File 'lib/stripe/resources/mandate.rb', line 115 def acss_debit @acss_debit end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
117 118 119 |
# File 'lib/stripe/resources/mandate.rb', line 117 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
119 120 121 |
# File 'lib/stripe/resources/mandate.rb', line 119 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
121 122 123 |
# File 'lib/stripe/resources/mandate.rb', line 121 def bacs_debit @bacs_debit end |
#card ⇒ Object (readonly)
Attribute for field card
123 124 125 |
# File 'lib/stripe/resources/mandate.rb', line 123 def card @card end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
125 126 127 |
# File 'lib/stripe/resources/mandate.rb', line 125 def cashapp @cashapp end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
127 128 129 |
# File 'lib/stripe/resources/mandate.rb', line 127 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
129 130 131 |
# File 'lib/stripe/resources/mandate.rb', line 129 def klarna @klarna end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
131 132 133 |
# File 'lib/stripe/resources/mandate.rb', line 131 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
133 134 135 |
# File 'lib/stripe/resources/mandate.rb', line 133 def link @link end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
135 136 137 |
# File 'lib/stripe/resources/mandate.rb', line 135 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
137 138 139 |
# File 'lib/stripe/resources/mandate.rb', line 137 def nz_bank_account @nz_bank_account end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
139 140 141 |
# File 'lib/stripe/resources/mandate.rb', line 139 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
141 142 143 |
# File 'lib/stripe/resources/mandate.rb', line 141 def payto @payto end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
143 144 145 |
# File 'lib/stripe/resources/mandate.rb', line 143 def revolut_pay @revolut_pay end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
145 146 147 |
# File 'lib/stripe/resources/mandate.rb', line 145 def sepa_debit @sepa_debit end |
#type ⇒ Object (readonly)
This mandate corresponds with a specific payment method type. The ‘payment_method_details` includes an additional hash with the same name and contains mandate information that’s specific to that payment method.
147 148 149 |
# File 'lib/stripe/resources/mandate.rb', line 147 def type @type end |
#us_bank_account ⇒ Object (readonly)
Attribute for field us_bank_account
149 150 151 |
# File 'lib/stripe/resources/mandate.rb', line 149 def us_bank_account @us_bank_account end |