Class: Stripe::Mandate::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/mandate.rb

Defined Under Namespace

Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Card, Cashapp, KakaoPay, Klarna, KrCard, Link, NaverPay, NzBankAccount, Paypal, RevolutPay, SepaDebit, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



93
94
95
# File 'lib/stripe/resources/mandate.rb', line 93

def acss_debit
  @acss_debit
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



95
96
97
# File 'lib/stripe/resources/mandate.rb', line 95

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



97
98
99
# File 'lib/stripe/resources/mandate.rb', line 97

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



99
100
101
# File 'lib/stripe/resources/mandate.rb', line 99

def bacs_debit
  @bacs_debit
end

#cardObject (readonly)

Attribute for field card



101
102
103
# File 'lib/stripe/resources/mandate.rb', line 101

def card
  @card
end

#cashappObject (readonly)

Attribute for field cashapp



103
104
105
# File 'lib/stripe/resources/mandate.rb', line 103

def cashapp
  @cashapp
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



105
106
107
# File 'lib/stripe/resources/mandate.rb', line 105

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



107
108
109
# File 'lib/stripe/resources/mandate.rb', line 107

def klarna
  @klarna
end

#kr_cardObject (readonly)

Attribute for field kr_card



109
110
111
# File 'lib/stripe/resources/mandate.rb', line 109

def kr_card
  @kr_card
end

Attribute for field link



111
112
113
# File 'lib/stripe/resources/mandate.rb', line 111

def link
  @link
end

Attribute for field naver_pay



113
114
115
# File 'lib/stripe/resources/mandate.rb', line 113

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



115
116
117
# File 'lib/stripe/resources/mandate.rb', line 115

def 
  @nz_bank_account
end

#paypalObject (readonly)

Attribute for field paypal



117
118
119
# File 'lib/stripe/resources/mandate.rb', line 117

def paypal
  @paypal
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



119
120
121
# File 'lib/stripe/resources/mandate.rb', line 119

def revolut_pay
  @revolut_pay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



121
122
123
# File 'lib/stripe/resources/mandate.rb', line 121

def sepa_debit
  @sepa_debit
end

#typeObject (readonly)

This mandate corresponds with a specific payment method type. The ‘payment_method_details` includes an additional hash with the same name and contains mandate information that’s specific to that payment method.



123
124
125
# File 'lib/stripe/resources/mandate.rb', line 123

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



125
126
127
# File 'lib/stripe/resources/mandate.rb', line 125

def 
  @us_bank_account
end