Class: Stripe::Mandate::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/mandate.rb

Defined Under Namespace

Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Card, Cashapp, KakaoPay, KrCard, Link, Paypal, Payto, RevolutPay, SepaDebit, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



132
133
134
# File 'lib/stripe/resources/mandate.rb', line 132

def acss_debit
  @acss_debit
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



135
136
137
# File 'lib/stripe/resources/mandate.rb', line 135

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



138
139
140
# File 'lib/stripe/resources/mandate.rb', line 138

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



141
142
143
# File 'lib/stripe/resources/mandate.rb', line 141

def bacs_debit
  @bacs_debit
end

#cardObject (readonly)

Attribute for field card



144
145
146
# File 'lib/stripe/resources/mandate.rb', line 144

def card
  @card
end

#cashappObject (readonly)

Attribute for field cashapp



147
148
149
# File 'lib/stripe/resources/mandate.rb', line 147

def cashapp
  @cashapp
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



150
151
152
# File 'lib/stripe/resources/mandate.rb', line 150

def kakao_pay
  @kakao_pay
end

#kr_cardObject (readonly)

Attribute for field kr_card



153
154
155
# File 'lib/stripe/resources/mandate.rb', line 153

def kr_card
  @kr_card
end

Attribute for field link



156
157
158
# File 'lib/stripe/resources/mandate.rb', line 156

def link
  @link
end

#paypalObject (readonly)

Attribute for field paypal



159
160
161
# File 'lib/stripe/resources/mandate.rb', line 159

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



162
163
164
# File 'lib/stripe/resources/mandate.rb', line 162

def payto
  @payto
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



165
166
167
# File 'lib/stripe/resources/mandate.rb', line 165

def revolut_pay
  @revolut_pay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



168
169
170
# File 'lib/stripe/resources/mandate.rb', line 168

def sepa_debit
  @sepa_debit
end

#typeObject (readonly)

This mandate corresponds with a specific payment method type. The ‘payment_method_details` includes an additional hash with the same name and contains mandate information that’s specific to that payment method.



171
172
173
# File 'lib/stripe/resources/mandate.rb', line 171

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



174
175
176
# File 'lib/stripe/resources/mandate.rb', line 174

def 
  @us_bank_account
end