Class: Stripe::Mandate::PaymentMethodDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/mandate.rb

Defined Under Namespace

Classes: AcssDebit, AmazonPay, AuBecsDebit, BacsDebit, Card, Cashapp, KakaoPay, KrCard, Link, Paypal, Payto, RevolutPay, SepaDebit, UsBankAccount

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#acss_debitObject (readonly)

Attribute for field acss_debit



112
113
114
# File 'lib/stripe/resources/mandate.rb', line 112

def acss_debit
  @acss_debit
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



114
115
116
# File 'lib/stripe/resources/mandate.rb', line 114

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



116
117
118
# File 'lib/stripe/resources/mandate.rb', line 116

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



118
119
120
# File 'lib/stripe/resources/mandate.rb', line 118

def bacs_debit
  @bacs_debit
end

#cardObject (readonly)

Attribute for field card



120
121
122
# File 'lib/stripe/resources/mandate.rb', line 120

def card
  @card
end

#cashappObject (readonly)

Attribute for field cashapp



122
123
124
# File 'lib/stripe/resources/mandate.rb', line 122

def cashapp
  @cashapp
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



124
125
126
# File 'lib/stripe/resources/mandate.rb', line 124

def kakao_pay
  @kakao_pay
end

#kr_cardObject (readonly)

Attribute for field kr_card



126
127
128
# File 'lib/stripe/resources/mandate.rb', line 126

def kr_card
  @kr_card
end

Attribute for field link



128
129
130
# File 'lib/stripe/resources/mandate.rb', line 128

def link
  @link
end

#paypalObject (readonly)

Attribute for field paypal



130
131
132
# File 'lib/stripe/resources/mandate.rb', line 130

def paypal
  @paypal
end

#paytoObject (readonly)

Attribute for field payto



132
133
134
# File 'lib/stripe/resources/mandate.rb', line 132

def payto
  @payto
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



134
135
136
# File 'lib/stripe/resources/mandate.rb', line 134

def revolut_pay
  @revolut_pay
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



136
137
138
# File 'lib/stripe/resources/mandate.rb', line 136

def sepa_debit
  @sepa_debit
end

#typeObject (readonly)

This mandate corresponds with a specific payment method type. The ‘payment_method_details` includes an additional hash with the same name and contains mandate information that’s specific to that payment method.



138
139
140
# File 'lib/stripe/resources/mandate.rb', line 138

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



140
141
142
# File 'lib/stripe/resources/mandate.rb', line 140

def 
  @us_bank_account
end