Class: Stripe::Mandate::PaymentMethodDetails::BacsDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/mandate.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#network_statusObject (readonly)

The status of the mandate on the Bacs network. Can be one of ‘pending`, `revoked`, `refused`, or `accepted`.



61
62
63
# File 'lib/stripe/resources/mandate.rb', line 61

def network_status
  @network_status
end

#referenceObject (readonly)

The unique reference identifying the mandate on the Bacs network.



64
65
66
# File 'lib/stripe/resources/mandate.rb', line 64

def reference
  @reference
end

#revocation_reasonObject (readonly)

When the mandate is revoked on the Bacs network this field displays the reason for the revocation.



67
68
69
# File 'lib/stripe/resources/mandate.rb', line 67

def revocation_reason
  @revocation_reason
end

#urlObject (readonly)

The URL that will contain the mandate that the customer has signed.



70
71
72
# File 'lib/stripe/resources/mandate.rb', line 70

def url
  @url
end