Class: Stripe::Mandate::PaymentMethodDetails::Paypal
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::PaymentMethodDetails::Paypal
- Defined in:
- lib/stripe/resources/mandate.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_agreement_id ⇒ Object
readonly
The PayPal Billing Agreement ID (BAID).
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular PayPal account.
-
#payer_id ⇒ Object
readonly
PayPal account PayerID.
-
#verified_email ⇒ Object
readonly
Owner’s verified email.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_agreement_id ⇒ Object (readonly)
The PayPal Billing Agreement ID (BAID). This is an ID generated by PayPal which represents the mandate between the merchant and the customer.
220 221 222 |
# File 'lib/stripe/resources/mandate.rb', line 220 def billing_agreement_id @billing_agreement_id end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular PayPal account. You can use this attribute to check whether two PayPal accounts are the same.
222 223 224 |
# File 'lib/stripe/resources/mandate.rb', line 222 def fingerprint @fingerprint end |
#payer_id ⇒ Object (readonly)
PayPal account PayerID. This identifier uniquely identifies the PayPal customer.
224 225 226 |
# File 'lib/stripe/resources/mandate.rb', line 224 def payer_id @payer_id end |
#verified_email ⇒ Object (readonly)
Owner’s verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
227 228 229 |
# File 'lib/stripe/resources/mandate.rb', line 227 def verified_email @verified_email end |
Class Method Details
.field_remappings ⇒ Object
233 234 235 |
# File 'lib/stripe/resources/mandate.rb', line 233 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
229 230 231 |
# File 'lib/stripe/resources/mandate.rb', line 229 def self.inner_class_types @inner_class_types = {} end |