Class: Stripe::Mandate::PaymentMethodDetails::Pix
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Mandate::PaymentMethodDetails::Pix
- Defined in:
- lib/stripe/resources/mandate.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_includes_iof ⇒ Object
readonly
Determines if the amount includes the IOF tax.
-
#amount_type ⇒ Object
readonly
Type of amount.
-
#end_date ⇒ Object
readonly
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
-
#payment_schedule ⇒ Object
readonly
Schedule at which the future payments will be charged.
-
#reference ⇒ Object
readonly
Subscription name displayed to buyers in their bank app.
-
#start_date ⇒ Object
readonly
Start date of the mandate, in ‘YYYY-MM-DD`.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_includes_iof ⇒ Object (readonly)
Determines if the amount includes the IOF tax.
110 111 112 |
# File 'lib/stripe/resources/mandate.rb', line 110 def amount_includes_iof @amount_includes_iof end |
#amount_type ⇒ Object (readonly)
Type of amount.
112 113 114 |
# File 'lib/stripe/resources/mandate.rb', line 112 def amount_type @amount_type end |
#end_date ⇒ Object (readonly)
Date when the mandate expires and no further payments will be charged, in ‘YYYY-MM-DD`.
114 115 116 |
# File 'lib/stripe/resources/mandate.rb', line 114 def end_date @end_date end |
#payment_schedule ⇒ Object (readonly)
Schedule at which the future payments will be charged.
116 117 118 |
# File 'lib/stripe/resources/mandate.rb', line 116 def payment_schedule @payment_schedule end |
#reference ⇒ Object (readonly)
Subscription name displayed to buyers in their bank app.
118 119 120 |
# File 'lib/stripe/resources/mandate.rb', line 118 def reference @reference end |
#start_date ⇒ Object (readonly)
Start date of the mandate, in ‘YYYY-MM-DD`.
120 121 122 |
# File 'lib/stripe/resources/mandate.rb', line 120 def start_date @start_date end |