Class: Stripe::Mandate::PaymentMethodDetails::Upi

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/mandate.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount to be charged for future payments.



323
324
325
# File 'lib/stripe/resources/mandate.rb', line 323

def amount
  @amount
end

#amount_typeObject (readonly)

One of fixed or maximum. If fixed, the amount param refers to the exact amount to be charged in future payments. If maximum, the amount charged can be up to the value passed for the amount param.



325
326
327
# File 'lib/stripe/resources/mandate.rb', line 325

def amount_type
  @amount_type
end

#descriptionObject (readonly)

A description of the mandate or subscription that is meant to be displayed to the customer.



327
328
329
# File 'lib/stripe/resources/mandate.rb', line 327

def description
  @description
end

#end_dateObject (readonly)

End date of the mandate or subscription.



329
330
331
# File 'lib/stripe/resources/mandate.rb', line 329

def end_date
  @end_date
end

Class Method Details

.field_remappingsObject



335
336
337
# File 'lib/stripe/resources/mandate.rb', line 335

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



331
332
333
# File 'lib/stripe/resources/mandate.rb', line 331

def self.inner_class_types
  @inner_class_types = {}
end