Class: Stripe::MandateService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::MandateService
- Defined in:
- lib/stripe/services/mandate_service.rb
Defined Under Namespace
Classes: ListParams, RetrieveParams
Instance Method Summary collapse
-
#list(params = {}, opts = {}) ⇒ Object
Retrieves a list of Mandates for a given PaymentMethod.
-
#retrieve(mandate, params = {}, opts = {}) ⇒ Object
Retrieves a Mandate object.
Methods inherited from StripeService
#initialize, #request, #request_stream
Constructor Details
This class inherits a constructor from Stripe::StripeService
Instance Method Details
#list(params = {}, opts = {}) ⇒ Object
Retrieves a list of Mandates for a given PaymentMethod.
51 52 53 |
# File 'lib/stripe/services/mandate_service.rb', line 51 def list(params = {}, opts = {}) request(method: :get, path: "/v1/mandates", params: params, opts: opts, base_address: :api) end |
#retrieve(mandate, params = {}, opts = {}) ⇒ Object
Retrieves a Mandate object.
56 57 58 59 60 61 62 63 64 |
# File 'lib/stripe/services/mandate_service.rb', line 56 def retrieve(mandate, params = {}, opts = {}) request( method: :get, path: format("/v1/mandates/%<mandate>s", { mandate: CGI.escape(mandate) }), params: params, opts: opts, base_address: :api ) end |