Class: Stripe::Margin
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::Margin
- Extended by:
- APIOperations::Create, APIOperations::List
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/margin.rb
Overview
A (partner) margin represents a specific discount distributed in partner reseller programs to business partners who resell products and services and earn a discount (margin) for doing so.
Defined Under Namespace
Classes: CreateParams, ListParams, RetrieveParams, UpdateParams
Constant Summary collapse
- OBJECT_NAME =
"margin"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#active ⇒ Object
readonly
Whether the margin can be applied to invoices, invoice items, or invoice line items.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#name ⇒ Object
readonly
Name of the margin that’s displayed on, for example, invoices.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#percent_off ⇒ Object
readonly
Percent that will be taken off the subtotal before tax (after all other discounts and promotions) of any invoice to which the margin is applied.
-
#updated ⇒ Object
readonly
Time at which the object was last updated.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.create(params = {}, opts = {}) ⇒ Object
Create a margin object to be used with invoices, invoice items, and invoice line items for a customer to represent a partner discount.
-
.list(params = {}, opts = {}) ⇒ Object
Retrieve a list of your margins.
- .object_name ⇒ Object
-
.update(id, params = {}, opts = {}) ⇒ Object
Update the specified margin object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#active ⇒ Object (readonly)
Whether the margin can be applied to invoices, invoice items, or invoice line items. Defaults to ‘true`.
97 98 99 |
# File 'lib/stripe/resources/margin.rb', line 97 def active @active end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
100 101 102 |
# File 'lib/stripe/resources/margin.rb', line 100 def created @created end |
#id ⇒ Object (readonly)
Unique identifier for the object.
103 104 105 |
# File 'lib/stripe/resources/margin.rb', line 103 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
106 107 108 |
# File 'lib/stripe/resources/margin.rb', line 106 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
109 110 111 |
# File 'lib/stripe/resources/margin.rb', line 109 def @metadata end |
#name ⇒ Object (readonly)
Name of the margin that’s displayed on, for example, invoices.
112 113 114 |
# File 'lib/stripe/resources/margin.rb', line 112 def name @name end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
115 116 117 |
# File 'lib/stripe/resources/margin.rb', line 115 def object @object end |
#percent_off ⇒ Object (readonly)
Percent that will be taken off the subtotal before tax (after all other discounts and promotions) of any invoice to which the margin is applied.
118 119 120 |
# File 'lib/stripe/resources/margin.rb', line 118 def percent_off @percent_off end |
#updated ⇒ Object (readonly)
Time at which the object was last updated. Measured in seconds since the Unix epoch.
121 122 123 |
# File 'lib/stripe/resources/margin.rb', line 121 def updated @updated end |
Class Method Details
.create(params = {}, opts = {}) ⇒ Object
Create a margin object to be used with invoices, invoice items, and invoice line items for a customer to represent a partner discount. A margin has a percent_off which is the percent that will be taken off the subtotal after all items and other discounts and promotions) of any invoices for a customer. Calculation of prorations do not include any partner margins applied on the original invoice item.
124 125 126 |
# File 'lib/stripe/resources/margin.rb', line 124 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/billing/margins", params: params, opts: opts) end |
.list(params = {}, opts = {}) ⇒ Object
Retrieve a list of your margins.
129 130 131 |
# File 'lib/stripe/resources/margin.rb', line 129 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/billing/margins", params: params, opts: opts) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/margin.rb', line 13 def self.object_name "margin" end |
.update(id, params = {}, opts = {}) ⇒ Object
Update the specified margin object. Certain fields of the margin object are not editable.
134 135 136 137 138 139 140 141 |
# File 'lib/stripe/resources/margin.rb', line 134 def self.update(id, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/billing/margins/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts ) end |