Class: Stripe::Margin::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/margin.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, name: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



78
79
80
81
82
83
# File 'lib/stripe/resources/margin.rb', line 78

def initialize(active: nil, expand: nil, metadata: nil, name: nil)
  @active = active
  @expand = expand
  @metadata = 
  @name = name
end

Instance Attribute Details

#activeObject

Whether the margin can be applied to invoices, invoice items, or invoice line items or not.



70
71
72
# File 'lib/stripe/resources/margin.rb', line 70

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



72
73
74
# File 'lib/stripe/resources/margin.rb', line 72

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



74
75
76
# File 'lib/stripe/resources/margin.rb', line 74

def 
  @metadata
end

#nameObject

Name of the margin, which is displayed to customers, such as on invoices.



76
77
78
# File 'lib/stripe/resources/margin.rb', line 76

def name
  @name
end