Class: Stripe::MarginService::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/margin_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(active: nil, expand: nil, metadata: nil, name: nil, percent_off: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



47
48
49
50
51
52
53
# File 'lib/stripe/services/margin_service.rb', line 47

def initialize(active: nil, expand: nil, metadata: nil, name: nil, percent_off: nil)
  @active = active
  @expand = expand
  @metadata = 
  @name = name
  @percent_off = percent_off
end

Instance Attribute Details

#activeObject

Whether the margin can be applied to invoices, invoice items, or invoice line items or not. Defaults to ‘true`.



33
34
35
# File 'lib/stripe/services/margin_service.rb', line 33

def active
  @active
end

#expandObject

Specifies which fields in the response should be expanded.



36
37
38
# File 'lib/stripe/services/margin_service.rb', line 36

def expand
  @expand
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



39
40
41
# File 'lib/stripe/services/margin_service.rb', line 39

def 
  @metadata
end

#nameObject

Name of the margin, which is displayed to customers, such as on invoices.



42
43
44
# File 'lib/stripe/services/margin_service.rb', line 42

def name
  @name
end

#percent_offObject

Percent that will be taken off the subtotal before tax (after all other discounts and promotions) of any invoice to which the margin is applied.



45
46
47
# File 'lib/stripe/services/margin_service.rb', line 45

def percent_off
  @percent_off
end