Class: Stripe::Order::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CancelParams
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
2630 2631 2632 |
# File 'lib/stripe/resources/order.rb', line 2630 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2628 2629 2630 |
# File 'lib/stripe/resources/order.rb', line 2628 def @expand end |