Class: Stripe::Order::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 1614 1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/stripe/resources/order.rb', line 1603 def initialize( automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
1575 1576 1577 |
# File 'lib/stripe/resources/order.rb', line 1575 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
1577 1578 1579 |
# File 'lib/stripe/resources/order.rb', line 1577 def billing_details @billing_details end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1579 1580 1581 |
# File 'lib/stripe/resources/order.rb', line 1579 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
1581 1582 1583 |
# File 'lib/stripe/resources/order.rb', line 1581 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1583 1584 1585 |
# File 'lib/stripe/resources/order.rb', line 1583 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
1585 1586 1587 |
# File 'lib/stripe/resources/order.rb', line 1585 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1587 1588 1589 |
# File 'lib/stripe/resources/order.rb', line 1587 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
1589 1590 1591 |
# File 'lib/stripe/resources/order.rb', line 1589 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
1591 1592 1593 |
# File 'lib/stripe/resources/order.rb', line 1591 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1593 1594 1595 |
# File 'lib/stripe/resources/order.rb', line 1593 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
1595 1596 1597 |
# File 'lib/stripe/resources/order.rb', line 1595 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
1597 1598 1599 |
# File 'lib/stripe/resources/order.rb', line 1597 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
1599 1600 1601 |
# File 'lib/stripe/resources/order.rb', line 1599 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
1601 1602 1603 |
# File 'lib/stripe/resources/order.rb', line 1601 def tax_details @tax_details end |