Class: Stripe::Order::CreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ CreateParams

Returns a new instance of CreateParams.



1527
1528
1529
1530
1531
1532
1533
1534
1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
# File 'lib/stripe/resources/order.rb', line 1527

def initialize(
  automatic_tax: nil,
  billing_details: nil,
  currency: nil,
  customer: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  ip_address: nil,
  line_items: nil,
  metadata: nil,
  payment: nil,
  shipping_cost: nil,
  shipping_details: nil,
  tax_details: nil
)
  @automatic_tax = automatic_tax
  @billing_details = billing_details
  @currency = currency
  @customer = customer
  @description = description
  @discounts = discounts
  @expand = expand
  @ip_address = ip_address
  @line_items = line_items
  @metadata = 
  @payment = payment
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @tax_details = tax_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax calculation for this order.



1499
1500
1501
# File 'lib/stripe/resources/order.rb', line 1499

def automatic_tax
  @automatic_tax
end

#billing_detailsObject

Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.



1501
1502
1503
# File 'lib/stripe/resources/order.rb', line 1501

def billing_details
  @billing_details
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



1503
1504
1505
# File 'lib/stripe/resources/order.rb', line 1503

def currency
  @currency
end

#customerObject

The customer associated with this order.



1505
1506
1507
# File 'lib/stripe/resources/order.rb', line 1505

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



1507
1508
1509
# File 'lib/stripe/resources/order.rb', line 1507

def description
  @description
end

#discountsObject

The coupons, promotion codes, and/or discounts to apply to the order.



1509
1510
1511
# File 'lib/stripe/resources/order.rb', line 1509

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



1511
1512
1513
# File 'lib/stripe/resources/order.rb', line 1511

def expand
  @expand
end

#ip_addressObject

The IP address of the purchaser for this order.



1513
1514
1515
# File 'lib/stripe/resources/order.rb', line 1513

def ip_address
  @ip_address
end

#line_itemsObject

A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.



1515
1516
1517
# File 'lib/stripe/resources/order.rb', line 1515

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1517
1518
1519
# File 'lib/stripe/resources/order.rb', line 1517

def 
  @metadata
end

#paymentObject

Payment information associated with the order, including payment settings.



1519
1520
1521
# File 'lib/stripe/resources/order.rb', line 1519

def payment
  @payment
end

#shipping_costObject

Settings for the customer cost of shipping for this order.



1521
1522
1523
# File 'lib/stripe/resources/order.rb', line 1521

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the order.



1523
1524
1525
# File 'lib/stripe/resources/order.rb', line 1523

def shipping_details
  @shipping_details
end

#tax_detailsObject

Additional tax details about the purchaser to be used for this order.



1525
1526
1527
# File 'lib/stripe/resources/order.rb', line 1525

def tax_details
  @tax_details
end