Class: Stripe::Order::CreateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Credit, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#credits ⇒ Object
The credits to apply to the order, only ‘gift_card` currently supported.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ CreateParams
constructor
A new instance of CreateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ CreateParams
Returns a new instance of CreateParams.
1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 1573 1574 1575 1576 1577 1578 1579 1580 1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 |
# File 'lib/stripe/resources/order.rb', line 1558 def initialize( automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @credits = credits @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
1528 1529 1530 |
# File 'lib/stripe/resources/order.rb', line 1528 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
1530 1531 1532 |
# File 'lib/stripe/resources/order.rb', line 1530 def billing_details @billing_details end |
#credits ⇒ Object
The credits to apply to the order, only ‘gift_card` currently supported.
1532 1533 1534 |
# File 'lib/stripe/resources/order.rb', line 1532 def credits @credits end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1534 1535 1536 |
# File 'lib/stripe/resources/order.rb', line 1534 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
1536 1537 1538 |
# File 'lib/stripe/resources/order.rb', line 1536 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1538 1539 1540 |
# File 'lib/stripe/resources/order.rb', line 1538 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
1540 1541 1542 |
# File 'lib/stripe/resources/order.rb', line 1540 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1542 1543 1544 |
# File 'lib/stripe/resources/order.rb', line 1542 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
1544 1545 1546 |
# File 'lib/stripe/resources/order.rb', line 1544 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
1546 1547 1548 |
# File 'lib/stripe/resources/order.rb', line 1546 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1548 1549 1550 |
# File 'lib/stripe/resources/order.rb', line 1548 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
1550 1551 1552 |
# File 'lib/stripe/resources/order.rb', line 1550 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
1552 1553 1554 |
# File 'lib/stripe/resources/order.rb', line 1552 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
1554 1555 1556 |
# File 'lib/stripe/resources/order.rb', line 1554 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
1556 1557 1558 |
# File 'lib/stripe/resources/order.rb', line 1556 def tax_details @tax_details end |