Class: Stripe::Order::CreateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::Discount
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
607 608 609 610 611 |
# File 'lib/stripe/resources/order.rb', line 607 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
601 602 603 |
# File 'lib/stripe/resources/order.rb', line 601 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
603 604 605 |
# File 'lib/stripe/resources/order.rb', line 603 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
605 606 607 |
# File 'lib/stripe/resources/order.rb', line 605 def promotion_code @promotion_code end |