Class: Stripe::Order::CreateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil) ⇒ Discount

Returns a new instance of Discount.



596
597
598
599
# File 'lib/stripe/resources/order.rb', line 596

def initialize(coupon: nil, discount: nil)
  @coupon = coupon
  @discount = discount
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



592
593
594
# File 'lib/stripe/resources/order.rb', line 592

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



594
595
596
# File 'lib/stripe/resources/order.rb', line 594

def discount
  @discount
end