Class: Stripe::Order::CreateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil) ⇒ Discount

Returns a new instance of Discount.



621
622
623
624
# File 'lib/stripe/resources/order.rb', line 621

def initialize(coupon: nil, discount: nil)
  @coupon = coupon
  @discount = discount
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



617
618
619
# File 'lib/stripe/resources/order.rb', line 617

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



619
620
621
# File 'lib/stripe/resources/order.rb', line 619

def discount
  @discount
end