Class: Stripe::Order::CreateParams::LineItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::LineItem::Discount
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil) ⇒ Discount
Returns a new instance of Discount.
734 735 736 737 |
# File 'lib/stripe/resources/order.rb', line 734 def initialize(coupon: nil, discount: nil) @coupon = coupon @discount = discount end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
729 730 731 |
# File 'lib/stripe/resources/order.rb', line 729 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
732 733 734 |
# File 'lib/stripe/resources/order.rb', line 732 def discount @discount end |