Class: Stripe::Order::CreateParams::Payment::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings

Returns a new instance of Settings.



1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
# File 'lib/stripe/resources/order.rb', line 1375

def initialize(
  application_fee_amount: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @application_fee_amount = application_fee_amount
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.



1361
1362
1363
# File 'lib/stripe/resources/order.rb', line 1361

def application_fee_amount
  @application_fee_amount
end

#payment_method_optionsObject

PaymentMethod-specific configuration to provide to the order’s PaymentIntent.



1363
1364
1365
# File 'lib/stripe/resources/order.rb', line 1363

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



1365
1366
1367
# File 'lib/stripe/resources/order.rb', line 1365

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect the customer to after they authenticate their payment.



1367
1368
1369
# File 'lib/stripe/resources/order.rb', line 1367

def return_url
  @return_url
end

#statement_descriptorObject

For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.



1369
1370
1371
# File 'lib/stripe/resources/order.rb', line 1369

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.



1371
1372
1373
# File 'lib/stripe/resources/order.rb', line 1371

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Provides configuration for completing a transfer for the order after it is paid.



1373
1374
1375
# File 'lib/stripe/resources/order.rb', line 1373

def transfer_data
  @transfer_data
end