Class: Stripe::Order::CreateParams::Payment::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::Payment::Settings
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: PaymentMethodOptions, TransferData
Instance Attribute Summary collapse
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#payment_method_options ⇒ Object
PaymentMethod-specific configuration to provide to the order’s PaymentIntent.
-
#payment_method_types ⇒ Object
The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent.
-
#return_url ⇒ Object
The URL to redirect the customer to after they authenticate their payment.
-
#statement_descriptor ⇒ Object
For non-card charges, you can use this value as the complete description that appears on your customers’ statements.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#transfer_data ⇒ Object
Provides configuration for completing a transfer for the order after it is paid.
Instance Method Summary collapse
-
#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings
Returns a new instance of Settings.
1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 |
# File 'lib/stripe/resources/order.rb', line 1511 def initialize( application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil ) @application_fee_amount = application_fee_amount @payment_method_options = @payment_method_types = payment_method_types @return_url = return_url @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data end |
Instance Attribute Details
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
1491 1492 1493 |
# File 'lib/stripe/resources/order.rb', line 1491 def application_fee_amount @application_fee_amount end |
#payment_method_options ⇒ Object
PaymentMethod-specific configuration to provide to the order’s PaymentIntent.
1494 1495 1496 |
# File 'lib/stripe/resources/order.rb', line 1494 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).
1497 1498 1499 |
# File 'lib/stripe/resources/order.rb', line 1497 def payment_method_types @payment_method_types end |
#return_url ⇒ Object
The URL to redirect the customer to after they authenticate their payment.
1500 1501 1502 |
# File 'lib/stripe/resources/order.rb', line 1500 def return_url @return_url end |
#statement_descriptor ⇒ Object
For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.
1503 1504 1505 |
# File 'lib/stripe/resources/order.rb', line 1503 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.
1506 1507 1508 |
# File 'lib/stripe/resources/order.rb', line 1506 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
Provides configuration for completing a transfer for the order after it is paid.
1509 1510 1511 |
# File 'lib/stripe/resources/order.rb', line 1509 def transfer_data @transfer_data end |