Class: Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 |
# File 'lib/stripe/resources/order.rb', line 1144 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
1128 1129 1130 |
# File 'lib/stripe/resources/order.rb', line 1128 def category @category end |
#description ⇒ Object
Description of the line item.
1130 1131 1132 |
# File 'lib/stripe/resources/order.rb', line 1130 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
1132 1133 1134 |
# File 'lib/stripe/resources/order.rb', line 1132 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
1134 1135 1136 |
# File 'lib/stripe/resources/order.rb', line 1134 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
1136 1137 1138 |
# File 'lib/stripe/resources/order.rb', line 1136 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
1138 1139 1140 |
# File 'lib/stripe/resources/order.rb', line 1138 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
1140 1141 1142 |
# File 'lib/stripe/resources/order.rb', line 1140 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
1142 1143 1144 |
# File 'lib/stripe/resources/order.rb', line 1142 def unit_amount @unit_amount end |