Class: Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/stripe/resources/order.rb', line 1068

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



1052
1053
1054
# File 'lib/stripe/resources/order.rb', line 1052

def category
  @category
end

#descriptionObject

Description of the line item.



1054
1055
1056
# File 'lib/stripe/resources/order.rb', line 1054

def description
  @description
end

#nameObject

Descriptive name of the line item.



1056
1057
1058
# File 'lib/stripe/resources/order.rb', line 1056

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



1058
1059
1060
# File 'lib/stripe/resources/order.rb', line 1058

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



1060
1061
1062
# File 'lib/stripe/resources/order.rb', line 1060

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



1062
1063
1064
# File 'lib/stripe/resources/order.rb', line 1062

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



1064
1065
1066
# File 'lib/stripe/resources/order.rb', line 1064

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



1066
1067
1068
# File 'lib/stripe/resources/order.rb', line 1066

def unit_amount
  @unit_amount
end