Class: Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 |
# File 'lib/stripe/resources/order.rb', line 1097 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
1081 1082 1083 |
# File 'lib/stripe/resources/order.rb', line 1081 def category @category end |
#description ⇒ Object
Description of the line item.
1083 1084 1085 |
# File 'lib/stripe/resources/order.rb', line 1083 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
1085 1086 1087 |
# File 'lib/stripe/resources/order.rb', line 1085 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
1087 1088 1089 |
# File 'lib/stripe/resources/order.rb', line 1087 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
1089 1090 1091 |
# File 'lib/stripe/resources/order.rb', line 1089 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
1091 1092 1093 |
# File 'lib/stripe/resources/order.rb', line 1091 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
1093 1094 1095 |
# File 'lib/stripe/resources/order.rb', line 1093 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
1095 1096 1097 |
# File 'lib/stripe/resources/order.rb', line 1095 def unit_amount @unit_amount end |