Class: Stripe::Order::CreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1355
1356
1357
1358
# File 'lib/stripe/resources/order.rb', line 1355

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1351
1352
1353
# File 'lib/stripe/resources/order.rb', line 1351

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1353
1354
1355
# File 'lib/stripe/resources/order.rb', line 1353

def destination
  @destination
end