Class: Stripe::Order::CreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1279
1280
1281
1282
# File 'lib/stripe/resources/order.rb', line 1279

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1275
1276
1277
# File 'lib/stripe/resources/order.rb', line 1275

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1277
1278
1279
# File 'lib/stripe/resources/order.rb', line 1277

def destination
  @destination
end