Class: Stripe::Order::CreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1308
1309
1310
1311
# File 'lib/stripe/resources/order.rb', line 1308

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1304
1305
1306
# File 'lib/stripe/resources/order.rb', line 1304

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1306
1307
1308
# File 'lib/stripe/resources/order.rb', line 1306

def destination
  @destination
end