Class: Stripe::Order::CreateParams::Payment::Settings::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::CreateParams::Payment::Settings::TransferData
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the order is paid.
-
#destination ⇒ Object
ID of the Connected account receiving the transfer.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1297 1298 1299 1300 |
# File 'lib/stripe/resources/order.rb', line 1297 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
1293 1294 1295 |
# File 'lib/stripe/resources/order.rb', line 1293 def amount @amount end |
#destination ⇒ Object
ID of the Connected account receiving the transfer.
1295 1296 1297 |
# File 'lib/stripe/resources/order.rb', line 1295 def destination @destination end |