Class: Stripe::Order::Payment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Settings
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payment_intent ⇒ Object
readonly
ID of the payment intent associated with this order.
-
#settings ⇒ Object
readonly
Settings describing how the order should configure generated PaymentIntents.
-
#status ⇒ Object
readonly
The status of the underlying payment associated with this order, if any.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payment_intent ⇒ Object (readonly)
ID of the payment intent associated with this order. Null when the order is ‘open`.
626 627 628 |
# File 'lib/stripe/resources/order.rb', line 626 def payment_intent @payment_intent end |
#settings ⇒ Object (readonly)
Settings describing how the order should configure generated PaymentIntents.
628 629 630 |
# File 'lib/stripe/resources/order.rb', line 628 def settings @settings end |
#status ⇒ Object (readonly)
The status of the underlying payment associated with this order, if any. Null when the order is ‘open`.
630 631 632 |
# File 'lib/stripe/resources/order.rb', line 630 def status @status end |
Class Method Details
.field_remappings ⇒ Object
636 637 638 |
# File 'lib/stripe/resources/order.rb', line 636 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
632 633 634 |
# File 'lib/stripe/resources/order.rb', line 632 def self.inner_class_types @inner_class_types = { settings: Settings } end |