Class: Stripe::Order::Payment
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Settings
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#payment_intent ⇒ Object
readonly
ID of the payment intent associated with this order.
-
#settings ⇒ Object
readonly
Settings describing how the order should configure generated PaymentIntents.
-
#status ⇒ Object
readonly
The status of the underlying payment associated with this order, if any.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#payment_intent ⇒ Object (readonly)
ID of the payment intent associated with this order. Null when the order is ‘open`.
397 398 399 |
# File 'lib/stripe/resources/order.rb', line 397 def payment_intent @payment_intent end |
#settings ⇒ Object (readonly)
Settings describing how the order should configure generated PaymentIntents.
399 400 401 |
# File 'lib/stripe/resources/order.rb', line 399 def settings @settings end |
#status ⇒ Object (readonly)
The status of the underlying payment associated with this order, if any. Null when the order is ‘open`.
401 402 403 |
# File 'lib/stripe/resources/order.rb', line 401 def status @status end |