Class: Stripe::Order::Payment

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: Settings

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#payment_intentObject (readonly)

ID of the payment intent associated with this order. Null when the order is ‘open`.



463
464
465
# File 'lib/stripe/resources/order.rb', line 463

def payment_intent
  @payment_intent
end

#settingsObject (readonly)

Settings describing how the order should configure generated PaymentIntents.



466
467
468
# File 'lib/stripe/resources/order.rb', line 466

def settings
  @settings
end

#statusObject (readonly)

The status of the underlying payment associated with this order, if any. Null when the order is ‘open`.



469
470
471
# File 'lib/stripe/resources/order.rb', line 469

def status
  @status
end