Class: Stripe::Order::Payment::Settings

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: AutomaticPaymentMethods, PaymentMethodOptions, TransferData

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#application_fee_amountObject (readonly)

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.



597
598
599
# File 'lib/stripe/resources/order.rb', line 597

def application_fee_amount
  @application_fee_amount
end

#automatic_payment_methodsObject (readonly)

Indicates whether order has been opted into using [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods) to manage payment method types.



599
600
601
# File 'lib/stripe/resources/order.rb', line 599

def automatic_payment_methods
  @automatic_payment_methods
end

#payment_method_optionsObject (readonly)

PaymentMethod-specific configuration to provide to the order’s PaymentIntent.



601
602
603
# File 'lib/stripe/resources/order.rb', line 601

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of [payment method types](docs.stripe.com/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



603
604
605
# File 'lib/stripe/resources/order.rb', line 603

def payment_method_types
  @payment_method_types
end

#return_urlObject (readonly)

The URL to redirect the customer to after they authenticate their payment.



605
606
607
# File 'lib/stripe/resources/order.rb', line 605

def return_url
  @return_url
end

#statement_descriptorObject (readonly)

For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.



607
608
609
# File 'lib/stripe/resources/order.rb', line 607

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.



609
610
611
# File 'lib/stripe/resources/order.rb', line 609

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject (readonly)

Provides configuration for completing a transfer for the order after it is paid.



611
612
613
# File 'lib/stripe/resources/order.rb', line 611

def transfer_data
  @transfer_data
end

Class Method Details

.field_remappingsObject



621
622
623
# File 'lib/stripe/resources/order.rb', line 621

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



613
614
615
616
617
618
619
# File 'lib/stripe/resources/order.rb', line 613

def self.inner_class_types
  @inner_class_types = {
    automatic_payment_methods: AutomaticPaymentMethods,
    payment_method_options: PaymentMethodOptions,
    transfer_data: TransferData,
  }
end