Class: Stripe::Order::Payment::Settings

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: AutomaticPaymentMethods, PaymentMethodOptions, TransferData

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#application_fee_amountObject (readonly)

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.



365
366
367
# File 'lib/stripe/resources/order.rb', line 365

def application_fee_amount
  @application_fee_amount
end

#automatic_payment_methodsObject (readonly)

Indicates whether order has been opted into using [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods) to manage payment method types.



367
368
369
# File 'lib/stripe/resources/order.rb', line 367

def automatic_payment_methods
  @automatic_payment_methods
end

#payment_method_optionsObject (readonly)

PaymentMethod-specific configuration to provide to the order’s PaymentIntent.



369
370
371
# File 'lib/stripe/resources/order.rb', line 369

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



371
372
373
# File 'lib/stripe/resources/order.rb', line 371

def payment_method_types
  @payment_method_types
end

#return_urlObject (readonly)

The URL to redirect the customer to after they authenticate their payment.



373
374
375
# File 'lib/stripe/resources/order.rb', line 373

def return_url
  @return_url
end

#statement_descriptorObject (readonly)

For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.



375
376
377
# File 'lib/stripe/resources/order.rb', line 375

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.



377
378
379
# File 'lib/stripe/resources/order.rb', line 377

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject (readonly)

Provides configuration for completing a transfer for the order after it is paid.



379
380
381
# File 'lib/stripe/resources/order.rb', line 379

def transfer_data
  @transfer_data
end