Class: Stripe::Order::Payment::Settings::PaymentMethodOptions::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment::Settings::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/order.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with the payment method.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
161 162 163 |
# File 'lib/stripe/resources/order.rb', line 161 def capture_method @capture_method end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with the payment method.
Providing this parameter will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the order’s Customer, if present, after the order’s PaymentIntent is confirmed and any required actions from the user are complete. If no Customer was provided, the payment method can still be [attached](stripe.com/docs/api/payment_methods/attach) to a Customer after the transaction completes.
When processing card payments, Stripe also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as [SCA](stripe.com/docs/strong-customer-authentication).
If ‘setup_future_usage` is already set and you are performing a request using a publishable key, you may only update the value from `on_session` to `off_session`.
170 171 172 |
# File 'lib/stripe/resources/order.rb', line 170 def setup_future_usage @setup_future_usage end |