Class: Stripe::Order::Payment::Settings::PaymentMethodOptions::Paypal
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment::Settings::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: LineItem
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer's account.
-
#line_items ⇒ Object
readonly
The line items purchased by the customer.
-
#preferred_locale ⇒ Object
readonly
Preferred locale of the PayPal checkout page that the customer is redirected to.
-
#reference ⇒ Object
readonly
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID.
-
#reference_id ⇒ Object
readonly
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent's payment method.
-
#subsellers ⇒ Object
readonly
The Stripe connected account IDs of the sellers on the platform for this transaction (optional).
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer's account.
419 420 421 |
# File 'lib/stripe/resources/order.rb', line 419 def capture_method @capture_method end |
#line_items ⇒ Object (readonly)
The line items purchased by the customer.
421 422 423 |
# File 'lib/stripe/resources/order.rb', line 421 def line_items @line_items end |
#preferred_locale ⇒ Object (readonly)
Preferred locale of the PayPal checkout page that the customer is redirected to.
423 424 425 |
# File 'lib/stripe/resources/order.rb', line 423 def preferred_locale @preferred_locale end |
#reference ⇒ Object (readonly)
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
425 426 427 |
# File 'lib/stripe/resources/order.rb', line 425 def reference @reference end |
#reference_id ⇒ Object (readonly)
A reference of the PayPal transaction visible to customer which is mapped to PayPal's invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
427 428 429 |
# File 'lib/stripe/resources/order.rb', line 427 def reference_id @reference_id end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
435 436 437 |
# File 'lib/stripe/resources/order.rb', line 435 def setup_future_usage @setup_future_usage end |
#subsellers ⇒ Object (readonly)
The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when separate charges and transfers are used.
437 438 439 |
# File 'lib/stripe/resources/order.rb', line 437 def subsellers @subsellers end |
Class Method Details
.field_remappings ⇒ Object
443 444 445 |
# File 'lib/stripe/resources/order.rb', line 443 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
439 440 441 |
# File 'lib/stripe/resources/order.rb', line 439 def self.inner_class_types @inner_class_types = { line_items: LineItem } end |