Class: Stripe::Order::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Tax
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#category ⇒ Object
readonly
Type of the line item.
-
#description ⇒ Object
readonly
Description of the line item.
-
#name ⇒ Object
readonly
Descriptive name of the line item.
-
#quantity ⇒ Object
readonly
Quantity of the line item.
-
#sku ⇒ Object
readonly
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
readonly
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#unit_amount ⇒ Object
readonly
Price for a single unit of the line item in minor units.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#category ⇒ Object (readonly)
Type of the line item.
394 395 396 |
# File 'lib/stripe/resources/order.rb', line 394 def category @category end |
#description ⇒ Object (readonly)
Description of the line item.
396 397 398 |
# File 'lib/stripe/resources/order.rb', line 396 def description @description end |
#name ⇒ Object (readonly)
Descriptive name of the line item.
398 399 400 |
# File 'lib/stripe/resources/order.rb', line 398 def name @name end |
#quantity ⇒ Object (readonly)
Quantity of the line item. Cannot be a negative number.
400 401 402 |
# File 'lib/stripe/resources/order.rb', line 400 def quantity @quantity end |
#sku ⇒ Object (readonly)
Client facing stock keeping unit, article number or similar.
402 403 404 |
# File 'lib/stripe/resources/order.rb', line 402 def sku @sku end |
#sold_by ⇒ Object (readonly)
The Stripe account ID of the connected account that sells the item. This is only needed when using [Separate Charges and Transfers](docs.stripe.com/connect/separate-charges-and-transfers).
404 405 406 |
# File 'lib/stripe/resources/order.rb', line 404 def sold_by @sold_by end |
#tax ⇒ Object (readonly)
Attribute for field tax
406 407 408 |
# File 'lib/stripe/resources/order.rb', line 406 def tax @tax end |
#unit_amount ⇒ Object (readonly)
Price for a single unit of the line item in minor units. Cannot be a negative number.
408 409 410 |
# File 'lib/stripe/resources/order.rb', line 408 def unit_amount @unit_amount end |
Class Method Details
.field_remappings ⇒ Object
414 415 416 |
# File 'lib/stripe/resources/order.rb', line 414 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
410 411 412 |
# File 'lib/stripe/resources/order.rb', line 410 def self.inner_class_types @inner_class_types = { tax: Tax } end |