Class: Stripe::Order::Payment::Settings::TransferData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment::Settings::TransferData
- Defined in:
- lib/stripe/resources/order.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount that will be transferred automatically when the order is paid.
-
#destination ⇒ Object
readonly
ID of the Connected account receiving the transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
584 585 586 |
# File 'lib/stripe/resources/order.rb', line 584 def amount @amount end |
#destination ⇒ Object (readonly)
ID of the Connected account receiving the transfer.
586 587 588 |
# File 'lib/stripe/resources/order.rb', line 586 def destination @destination end |
Class Method Details
.field_remappings ⇒ Object
592 593 594 |
# File 'lib/stripe/resources/order.rb', line 592 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
588 589 590 |
# File 'lib/stripe/resources/order.rb', line 588 def self.inner_class_types @inner_class_types = {} end |