Class: Stripe::Order::Payment::Settings::TransferData
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::Payment::Settings::TransferData
- Defined in:
- lib/stripe/resources/order.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
The amount that will be transferred automatically when the order is paid.
-
#destination ⇒ Object
readonly
ID of the Connected account receiving the transfer.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
433 434 435 |
# File 'lib/stripe/resources/order.rb', line 433 def amount @amount end |
#destination ⇒ Object (readonly)
ID of the Connected account receiving the transfer.
436 437 438 |
# File 'lib/stripe/resources/order.rb', line 436 def destination @destination end |