Class: Stripe::Order::SubmitParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expected_total: nil) ⇒ SubmitParams

Returns a new instance of SubmitParams.



2802
2803
2804
2805
# File 'lib/stripe/resources/order.rb', line 2802

def initialize(expand: nil, expected_total: nil)
  @expand = expand
  @expected_total = expected_total
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2798
2799
2800
# File 'lib/stripe/resources/order.rb', line 2798

def expand
  @expand
end

#expected_totalObject

‘expected_total` should always be set to the order’s ‘amount_total` field. If they don’t match, submitting the order will fail. This helps detect race conditions where something else concurrently modifies the order.



2800
2801
2802
# File 'lib/stripe/resources/order.rb', line 2800

def expected_total
  @expected_total
end