Class: Stripe::Order::SubmitParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::SubmitParams
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expected_total ⇒ Object
‘expected_total` should always be set to the order’s ‘amount_total` field.
Instance Method Summary collapse
-
#initialize(expand: nil, expected_total: nil) ⇒ SubmitParams
constructor
A new instance of SubmitParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, expected_total: nil) ⇒ SubmitParams
Returns a new instance of SubmitParams.
3054 3055 3056 3057 |
# File 'lib/stripe/resources/order.rb', line 3054 def initialize(expand: nil, expected_total: nil) @expand = @expected_total = expected_total end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3049 3050 3051 |
# File 'lib/stripe/resources/order.rb', line 3049 def @expand end |
#expected_total ⇒ Object
‘expected_total` should always be set to the order’s ‘amount_total` field. If they don’t match, submitting the order will fail. This helps detect race conditions where something else concurrently modifies the order.
3052 3053 3054 |
# File 'lib/stripe/resources/order.rb', line 3052 def expected_total @expected_total end |