Class: Stripe::Order::TaxDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::TaxDetails
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: TaxId
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#tax_exempt ⇒ Object
readonly
Describes the purchaser’s tax exemption status.
-
#tax_ids ⇒ Object
readonly
The purchaser’s tax IDs to be used in calculation of tax for this Order.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#tax_exempt ⇒ Object (readonly)
Describes the purchaser’s tax exemption status. One of ‘none`, `exempt`, or `reverse`.
543 544 545 |
# File 'lib/stripe/resources/order.rb', line 543 def tax_exempt @tax_exempt end |
#tax_ids ⇒ Object (readonly)
The purchaser’s tax IDs to be used in calculation of tax for this Order.
546 547 548 |
# File 'lib/stripe/resources/order.rb', line 546 def tax_ids @tax_ids end |