Class: Stripe::Order::TotalDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::TotalDetails
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Breakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_discount ⇒ Object
readonly
This is the sum of all the discounts.
-
#amount_shipping ⇒ Object
readonly
This is the sum of all the shipping amounts.
-
#amount_tax ⇒ Object
readonly
This is the sum of all the tax amounts.
-
#breakdown ⇒ Object
readonly
Attribute for field breakdown.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_discount ⇒ Object (readonly)
This is the sum of all the discounts.
804 805 806 |
# File 'lib/stripe/resources/order.rb', line 804 def amount_discount @amount_discount end |
#amount_shipping ⇒ Object (readonly)
This is the sum of all the shipping amounts.
806 807 808 |
# File 'lib/stripe/resources/order.rb', line 806 def amount_shipping @amount_shipping end |
#amount_tax ⇒ Object (readonly)
This is the sum of all the tax amounts.
808 809 810 |
# File 'lib/stripe/resources/order.rb', line 808 def amount_tax @amount_tax end |
#breakdown ⇒ Object (readonly)
Attribute for field breakdown
810 811 812 |
# File 'lib/stripe/resources/order.rb', line 810 def breakdown @breakdown end |
Class Method Details
.field_remappings ⇒ Object
816 817 818 |
# File 'lib/stripe/resources/order.rb', line 816 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
812 813 814 |
# File 'lib/stripe/resources/order.rb', line 812 def self.inner_class_types @inner_class_types = { breakdown: Breakdown } end |