Class: Stripe::Order::TotalDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: Breakdown

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_creditObject (readonly)

Attribute for field amount_credit



495
496
497
# File 'lib/stripe/resources/order.rb', line 495

def amount_credit
  @amount_credit
end

#amount_discountObject (readonly)

This is the sum of all the discounts.



497
498
499
# File 'lib/stripe/resources/order.rb', line 497

def amount_discount
  @amount_discount
end

#amount_shippingObject (readonly)

This is the sum of all the shipping amounts.



499
500
501
# File 'lib/stripe/resources/order.rb', line 499

def amount_shipping
  @amount_shipping
end

#amount_taxObject (readonly)

This is the sum of all the tax amounts.



501
502
503
# File 'lib/stripe/resources/order.rb', line 501

def amount_tax
  @amount_tax
end

#breakdownObject (readonly)

Attribute for field breakdown



503
504
505
# File 'lib/stripe/resources/order.rb', line 503

def breakdown
  @breakdown
end