Class: Stripe::Order::TotalDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::Order::TotalDetails
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Breakdown
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_credit ⇒ Object
readonly
Attribute for field amount_credit.
-
#amount_discount ⇒ Object
readonly
This is the sum of all the discounts.
-
#amount_shipping ⇒ Object
readonly
This is the sum of all the shipping amounts.
-
#amount_tax ⇒ Object
readonly
This is the sum of all the tax amounts.
-
#breakdown ⇒ Object
readonly
Attribute for field breakdown.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_credit ⇒ Object (readonly)
Attribute for field amount_credit
584 585 586 |
# File 'lib/stripe/resources/order.rb', line 584 def amount_credit @amount_credit end |
#amount_discount ⇒ Object (readonly)
This is the sum of all the discounts.
587 588 589 |
# File 'lib/stripe/resources/order.rb', line 587 def amount_discount @amount_discount end |
#amount_shipping ⇒ Object (readonly)
This is the sum of all the shipping amounts.
590 591 592 |
# File 'lib/stripe/resources/order.rb', line 590 def amount_shipping @amount_shipping end |
#amount_tax ⇒ Object (readonly)
This is the sum of all the tax amounts.
593 594 595 |
# File 'lib/stripe/resources/order.rb', line 593 def amount_tax @amount_tax end |
#breakdown ⇒ Object (readonly)
Attribute for field breakdown
596 597 598 |
# File 'lib/stripe/resources/order.rb', line 596 def breakdown @breakdown end |