Class: Stripe::Order::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 3070 3071 3072 3073 3074 3075 3076 3077 3078 3079 3080 3081 3082 3083 3084 3085 3086 3087 3088 3089 |
# File 'lib/stripe/resources/order.rb', line 3059 def initialize( automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
3031 3032 3033 |
# File 'lib/stripe/resources/order.rb', line 3031 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
3033 3034 3035 |
# File 'lib/stripe/resources/order.rb', line 3033 def billing_details @billing_details end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
3035 3036 3037 |
# File 'lib/stripe/resources/order.rb', line 3035 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
3037 3038 3039 |
# File 'lib/stripe/resources/order.rb', line 3037 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
3039 3040 3041 |
# File 'lib/stripe/resources/order.rb', line 3039 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.
3041 3042 3043 |
# File 'lib/stripe/resources/order.rb', line 3041 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
3043 3044 3045 |
# File 'lib/stripe/resources/order.rb', line 3043 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
3045 3046 3047 |
# File 'lib/stripe/resources/order.rb', line 3045 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
3047 3048 3049 |
# File 'lib/stripe/resources/order.rb', line 3047 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
3049 3050 3051 |
# File 'lib/stripe/resources/order.rb', line 3049 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
3051 3052 3053 |
# File 'lib/stripe/resources/order.rb', line 3051 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
3053 3054 3055 |
# File 'lib/stripe/resources/order.rb', line 3053 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
3055 3056 3057 |
# File 'lib/stripe/resources/order.rb', line 3055 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
3057 3058 3059 |
# File 'lib/stripe/resources/order.rb', line 3057 def tax_details @tax_details end |