Class: Stripe::Order::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2727
2728
2729
2730
2731
2732
2733
2734
2735
2736
2737
2738
2739
2740
2741
2742
2743
2744
2745
2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
# File 'lib/stripe/resources/order.rb', line 2727

def initialize(
  automatic_tax: nil,
  billing_details: nil,
  currency: nil,
  customer: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  ip_address: nil,
  line_items: nil,
  metadata: nil,
  payment: nil,
  shipping_cost: nil,
  shipping_details: nil,
  tax_details: nil
)
  @automatic_tax = automatic_tax
  @billing_details = billing_details
  @currency = currency
  @customer = customer
  @description = description
  @discounts = discounts
  @expand = expand
  @ip_address = ip_address
  @line_items = line_items
  @metadata = 
  @payment = payment
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @tax_details = tax_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax calculation for this order.



2699
2700
2701
# File 'lib/stripe/resources/order.rb', line 2699

def automatic_tax
  @automatic_tax
end

#billing_detailsObject

Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.



2701
2702
2703
# File 'lib/stripe/resources/order.rb', line 2701

def billing_details
  @billing_details
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2703
2704
2705
# File 'lib/stripe/resources/order.rb', line 2703

def currency
  @currency
end

#customerObject

The customer associated with this order.



2705
2706
2707
# File 'lib/stripe/resources/order.rb', line 2705

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2707
2708
2709
# File 'lib/stripe/resources/order.rb', line 2707

def description
  @description
end

#discountsObject

The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.



2709
2710
2711
# File 'lib/stripe/resources/order.rb', line 2709

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



2711
2712
2713
# File 'lib/stripe/resources/order.rb', line 2711

def expand
  @expand
end

#ip_addressObject

The IP address of the purchaser for this order.



2713
2714
2715
# File 'lib/stripe/resources/order.rb', line 2713

def ip_address
  @ip_address
end

#line_itemsObject

A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.



2715
2716
2717
# File 'lib/stripe/resources/order.rb', line 2715

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2717
2718
2719
# File 'lib/stripe/resources/order.rb', line 2717

def 
  @metadata
end

#paymentObject

Payment information associated with the order, including payment settings.



2719
2720
2721
# File 'lib/stripe/resources/order.rb', line 2719

def payment
  @payment
end

#shipping_costObject

Settings for the customer cost of shipping for this order.



2721
2722
2723
# File 'lib/stripe/resources/order.rb', line 2721

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the order.



2723
2724
2725
# File 'lib/stripe/resources/order.rb', line 2723

def shipping_details
  @shipping_details
end

#tax_detailsObject

Additional tax details about the purchaser to be used for this order.



2725
2726
2727
# File 'lib/stripe/resources/order.rb', line 2725

def tax_details
  @tax_details
end