Class: Stripe::Order::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2575 2576 2577 2578 2579 2580 2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 |
# File 'lib/stripe/resources/order.rb', line 2575 def initialize( automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
2547 2548 2549 |
# File 'lib/stripe/resources/order.rb', line 2547 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
2549 2550 2551 |
# File 'lib/stripe/resources/order.rb', line 2549 def billing_details @billing_details end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2551 2552 2553 |
# File 'lib/stripe/resources/order.rb', line 2551 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
2553 2554 2555 |
# File 'lib/stripe/resources/order.rb', line 2553 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2555 2556 2557 |
# File 'lib/stripe/resources/order.rb', line 2555 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.
2557 2558 2559 |
# File 'lib/stripe/resources/order.rb', line 2557 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2559 2560 2561 |
# File 'lib/stripe/resources/order.rb', line 2559 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
2561 2562 2563 |
# File 'lib/stripe/resources/order.rb', line 2561 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
2563 2564 2565 |
# File 'lib/stripe/resources/order.rb', line 2563 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2565 2566 2567 |
# File 'lib/stripe/resources/order.rb', line 2565 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
2567 2568 2569 |
# File 'lib/stripe/resources/order.rb', line 2567 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
2569 2570 2571 |
# File 'lib/stripe/resources/order.rb', line 2569 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
2571 2572 2573 |
# File 'lib/stripe/resources/order.rb', line 2571 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
2573 2574 2575 |
# File 'lib/stripe/resources/order.rb', line 2573 def tax_details @tax_details end |