Class: Stripe::Order::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Credit, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#credits ⇒ Object
The credits to apply to the order, only ‘gift_card` currently supported.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2622 2623 2624 2625 2626 2627 2628 2629 2630 2631 2632 2633 2634 2635 2636 2637 2638 2639 2640 2641 2642 2643 2644 2645 2646 2647 2648 2649 2650 2651 2652 2653 2654 |
# File 'lib/stripe/resources/order.rb', line 2622 def initialize( automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @credits = credits @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
2592 2593 2594 |
# File 'lib/stripe/resources/order.rb', line 2592 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
2594 2595 2596 |
# File 'lib/stripe/resources/order.rb', line 2594 def billing_details @billing_details end |
#credits ⇒ Object
The credits to apply to the order, only ‘gift_card` currently supported. Pass the empty string `“”` to unset this field.
2596 2597 2598 |
# File 'lib/stripe/resources/order.rb', line 2596 def credits @credits end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2598 2599 2600 |
# File 'lib/stripe/resources/order.rb', line 2598 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
2600 2601 2602 |
# File 'lib/stripe/resources/order.rb', line 2600 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2602 2603 2604 |
# File 'lib/stripe/resources/order.rb', line 2602 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.
2604 2605 2606 |
# File 'lib/stripe/resources/order.rb', line 2604 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2606 2607 2608 |
# File 'lib/stripe/resources/order.rb', line 2606 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
2608 2609 2610 |
# File 'lib/stripe/resources/order.rb', line 2608 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
2610 2611 2612 |
# File 'lib/stripe/resources/order.rb', line 2610 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2612 2613 2614 |
# File 'lib/stripe/resources/order.rb', line 2612 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
2614 2615 2616 |
# File 'lib/stripe/resources/order.rb', line 2614 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
2616 2617 2618 |
# File 'lib/stripe/resources/order.rb', line 2616 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
2618 2619 2620 |
# File 'lib/stripe/resources/order.rb', line 2618 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
2620 2621 2622 |
# File 'lib/stripe/resources/order.rb', line 2620 def tax_details @tax_details end |