Class: Stripe::Order::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: AutomaticTax, BillingDetails, Credit, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2973
2974
2975
2976
2977
2978
2979
2980
2981
2982
2983
2984
2985
2986
2987
2988
2989
2990
2991
2992
2993
2994
2995
2996
2997
2998
2999
3000
3001
3002
3003
3004
3005
# File 'lib/stripe/resources/order.rb', line 2973

def initialize(
  automatic_tax: nil,
  billing_details: nil,
  credits: nil,
  currency: nil,
  customer: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  ip_address: nil,
  line_items: nil,
  metadata: nil,
  payment: nil,
  shipping_cost: nil,
  shipping_details: nil,
  tax_details: nil
)
  @automatic_tax = automatic_tax
  @billing_details = billing_details
  @credits = credits
  @currency = currency
  @customer = customer
  @description = description
  @discounts = discounts
  @expand = expand
  @ip_address = ip_address
  @line_items = line_items
  @metadata = 
  @payment = payment
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @tax_details = tax_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax calculation for this order.



2929
2930
2931
# File 'lib/stripe/resources/order.rb', line 2929

def automatic_tax
  @automatic_tax
end

#billing_detailsObject

Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.



2932
2933
2934
# File 'lib/stripe/resources/order.rb', line 2932

def billing_details
  @billing_details
end

#creditsObject

The credits to apply to the order, only ‘gift_card` currently supported. Pass the empty string `“”` to unset this field.



2935
2936
2937
# File 'lib/stripe/resources/order.rb', line 2935

def credits
  @credits
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2938
2939
2940
# File 'lib/stripe/resources/order.rb', line 2938

def currency
  @currency
end

#customerObject

The customer associated with this order.



2941
2942
2943
# File 'lib/stripe/resources/order.rb', line 2941

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2944
2945
2946
# File 'lib/stripe/resources/order.rb', line 2944

def description
  @description
end

#discountsObject

The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.



2947
2948
2949
# File 'lib/stripe/resources/order.rb', line 2947

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



2950
2951
2952
# File 'lib/stripe/resources/order.rb', line 2950

def expand
  @expand
end

#ip_addressObject

The IP address of the purchaser for this order.



2953
2954
2955
# File 'lib/stripe/resources/order.rb', line 2953

def ip_address
  @ip_address
end

#line_itemsObject

A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.



2956
2957
2958
# File 'lib/stripe/resources/order.rb', line 2956

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2959
2960
2961
# File 'lib/stripe/resources/order.rb', line 2959

def 
  @metadata
end

#paymentObject

Payment information associated with the order, including payment settings.



2962
2963
2964
# File 'lib/stripe/resources/order.rb', line 2962

def payment
  @payment
end

#shipping_costObject

Settings for the customer cost of shipping for this order.



2965
2966
2967
# File 'lib/stripe/resources/order.rb', line 2965

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the order.



2968
2969
2970
# File 'lib/stripe/resources/order.rb', line 2968

def shipping_details
  @shipping_details
end

#tax_detailsObject

Additional tax details about the purchaser to be used for this order.



2971
2972
2973
# File 'lib/stripe/resources/order.rb', line 2971

def tax_details
  @tax_details
end