Class: Stripe::Order::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: AutomaticTax, BillingDetails, Credit, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2613
2614
2615
2616
2617
2618
2619
2620
2621
2622
2623
2624
2625
2626
2627
2628
2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
2641
2642
2643
2644
2645
# File 'lib/stripe/resources/order.rb', line 2613

def initialize(
  automatic_tax: nil,
  billing_details: nil,
  credits: nil,
  currency: nil,
  customer: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  ip_address: nil,
  line_items: nil,
  metadata: nil,
  payment: nil,
  shipping_cost: nil,
  shipping_details: nil,
  tax_details: nil
)
  @automatic_tax = automatic_tax
  @billing_details = billing_details
  @credits = credits
  @currency = currency
  @customer = customer
  @description = description
  @discounts = discounts
  @expand = expand
  @ip_address = ip_address
  @line_items = line_items
  @metadata = 
  @payment = payment
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @tax_details = tax_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax calculation for this order.



2583
2584
2585
# File 'lib/stripe/resources/order.rb', line 2583

def automatic_tax
  @automatic_tax
end

#billing_detailsObject

Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.



2585
2586
2587
# File 'lib/stripe/resources/order.rb', line 2585

def billing_details
  @billing_details
end

#creditsObject

The credits to apply to the order, only ‘gift_card` currently supported. Pass the empty string `“”` to unset this field.



2587
2588
2589
# File 'lib/stripe/resources/order.rb', line 2587

def credits
  @credits
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2589
2590
2591
# File 'lib/stripe/resources/order.rb', line 2589

def currency
  @currency
end

#customerObject

The customer associated with this order.



2591
2592
2593
# File 'lib/stripe/resources/order.rb', line 2591

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2593
2594
2595
# File 'lib/stripe/resources/order.rb', line 2593

def description
  @description
end

#discountsObject

The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.



2595
2596
2597
# File 'lib/stripe/resources/order.rb', line 2595

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



2597
2598
2599
# File 'lib/stripe/resources/order.rb', line 2597

def expand
  @expand
end

#ip_addressObject

The IP address of the purchaser for this order.



2599
2600
2601
# File 'lib/stripe/resources/order.rb', line 2599

def ip_address
  @ip_address
end

#line_itemsObject

A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.



2601
2602
2603
# File 'lib/stripe/resources/order.rb', line 2601

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2603
2604
2605
# File 'lib/stripe/resources/order.rb', line 2603

def 
  @metadata
end

#paymentObject

Payment information associated with the order, including payment settings.



2605
2606
2607
# File 'lib/stripe/resources/order.rb', line 2605

def payment
  @payment
end

#shipping_costObject

Settings for the customer cost of shipping for this order.



2607
2608
2609
# File 'lib/stripe/resources/order.rb', line 2607

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the order.



2609
2610
2611
# File 'lib/stripe/resources/order.rb', line 2609

def shipping_details
  @shipping_details
end

#tax_detailsObject

Additional tax details about the purchaser to be used for this order.



2611
2612
2613
# File 'lib/stripe/resources/order.rb', line 2611

def tax_details
  @tax_details
end