Class: Stripe::Order::UpdateParams::AutomaticTax
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::AutomaticTax
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
Instance Method Summary collapse
-
#initialize(enabled: nil) ⇒ AutomaticTax
constructor
A new instance of AutomaticTax.
Methods inherited from RequestParams
Constructor Details
#initialize(enabled: nil) ⇒ AutomaticTax
Returns a new instance of AutomaticTax.
1596 1597 1598 |
# File 'lib/stripe/resources/order.rb', line 1596 def initialize(enabled: nil) @enabled = enabled end |
Instance Attribute Details
#enabled ⇒ Object
Enable automatic tax calculation which will automatically compute tax rates on this order.
1594 1595 1596 |
# File 'lib/stripe/resources/order.rb', line 1594 def enabled @enabled end |