Class: Stripe::Order::UpdateParams::Credit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Credit
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#gift_card ⇒ Object
The gift card to apply to the order.
-
#type ⇒ Object
The type of credit to apply to the order, only ‘gift_card` currently supported.
Instance Method Summary collapse
-
#initialize(gift_card: nil, type: nil) ⇒ Credit
constructor
A new instance of Credit.
Methods inherited from RequestParams
Constructor Details
#initialize(gift_card: nil, type: nil) ⇒ Credit
Returns a new instance of Credit.
1655 1656 1657 1658 |
# File 'lib/stripe/resources/order.rb', line 1655 def initialize(gift_card: nil, type: nil) @gift_card = gift_card @type = type end |
Instance Attribute Details
#gift_card ⇒ Object
The gift card to apply to the order.
1651 1652 1653 |
# File 'lib/stripe/resources/order.rb', line 1651 def gift_card @gift_card end |
#type ⇒ Object
The type of credit to apply to the order, only ‘gift_card` currently supported.
1653 1654 1655 |
# File 'lib/stripe/resources/order.rb', line 1653 def type @type end |