Class: Stripe::Order::UpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Discount
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1702 1703 1704 1705 1706 |
# File 'lib/stripe/resources/order.rb', line 1702 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1696 1697 1698 |
# File 'lib/stripe/resources/order.rb', line 1696 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1698 1699 1700 |
# File 'lib/stripe/resources/order.rb', line 1698 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1700 1701 1702 |
# File 'lib/stripe/resources/order.rb', line 1700 def promotion_code @promotion_code end |