Class: Stripe::Order::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1626
1627
1628
1629
1630
# File 'lib/stripe/resources/order.rb', line 1626

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1620
1621
1622
# File 'lib/stripe/resources/order.rb', line 1620

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1622
1623
1624
# File 'lib/stripe/resources/order.rb', line 1622

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1624
1625
1626
# File 'lib/stripe/resources/order.rb', line 1624

def promotion_code
  @promotion_code
end