Class: Stripe::Order::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1680
1681
1682
1683
1684
# File 'lib/stripe/resources/order.rb', line 1680

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1674
1675
1676
# File 'lib/stripe/resources/order.rb', line 1674

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1676
1677
1678
# File 'lib/stripe/resources/order.rb', line 1676

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1678
1679
1680
# File 'lib/stripe/resources/order.rb', line 1678

def promotion_code
  @promotion_code
end