Class: Stripe::Order::UpdateParams::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Discount
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
-
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount
Returns a new instance of Discount.
1680 1681 1682 1683 1684 |
# File 'lib/stripe/resources/order.rb', line 1680 def initialize(coupon: nil, discount: nil, promotion_code: nil) @coupon = coupon @discount = discount @promotion_code = promotion_code end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1674 1675 1676 |
# File 'lib/stripe/resources/order.rb', line 1674 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1676 1677 1678 |
# File 'lib/stripe/resources/order.rb', line 1676 def discount @discount end |
#promotion_code ⇒ Object
ID of the promotion code to create a new discount for.
1678 1679 1680 |
# File 'lib/stripe/resources/order.rb', line 1678 def promotion_code @promotion_code end |