Class: Stripe::Order::UpdateParams::Discount

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil, promotion_code: nil) ⇒ Discount

Returns a new instance of Discount.



1910
1911
1912
1913
1914
# File 'lib/stripe/resources/order.rb', line 1910

def initialize(coupon: nil, discount: nil, promotion_code: nil)
  @coupon = coupon
  @discount = discount
  @promotion_code = promotion_code
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1902
1903
1904
# File 'lib/stripe/resources/order.rb', line 1902

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1905
1906
1907
# File 'lib/stripe/resources/order.rb', line 1905

def discount
  @discount
end

#promotion_codeObject

ID of the promotion code to create a new discount for.



1908
1909
1910
# File 'lib/stripe/resources/order.rb', line 1908

def promotion_code
  @promotion_code
end