Class: Stripe::Order::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::LineItem
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Discount, PriceData, ProductData
Instance Attribute Summary collapse
-
#description ⇒ Object
The description for the line item.
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#id ⇒ Object
The ID of an existing line item on the order.
-
#price ⇒ Object
The ID of a [Price](docs.stripe.com/api/prices) to add to the Order.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#product ⇒ Object
The ID of a [Product](docs.stripe.com/api/products) to add to the Order.
-
#product_data ⇒ Object
Defines a [Product](docs.stripe.com/api/products) inline and adds it to the Order.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates applied to this line item.
Instance Method Summary collapse
-
#initialize(description: nil, discounts: nil, id: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, discounts: nil, id: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 |
# File 'lib/stripe/resources/order.rb', line 1843 def initialize( description: nil, discounts: nil, id: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil ) @description = description @discounts = discounts @id = id @price = price @price_data = price_data @product = product @product_data = product_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#description ⇒ Object
The description for the line item. Will default to the name of the associated product.
1813 1814 1815 |
# File 'lib/stripe/resources/order.rb', line 1813 def description @description end |
#discounts ⇒ Object
The discounts applied to this line item.
1815 1816 1817 |
# File 'lib/stripe/resources/order.rb', line 1815 def discounts @discounts end |
#id ⇒ Object
The ID of an existing line item on the order.
1817 1818 1819 |
# File 'lib/stripe/resources/order.rb', line 1817 def id @id end |
#price ⇒ Object
The ID of a [Price](docs.stripe.com/api/prices) to add to the Order.
The ‘price` parameter is an alternative to using the `product` parameter. If each of your products are sold at a single price, you can set `Product.default_price` and then pass the `product` parameter when creating a line item. If your products are sold at several possible prices, use the `price` parameter to explicitly specify which one to use.
1821 1822 1823 |
# File 'lib/stripe/resources/order.rb', line 1821 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
The ‘price_data` parameter is an alternative to using the `product` or `price` parameters. If you create a Product upfront and configure a `Product.default_price`, pass the `product` parameter when creating a line item. If you prefer not to define Products upfront, or if you charge variable prices, pass the `price_data` parameter to describe the price for this line item.
Each time you pass ‘price_data` we create a Price for the Product. This Price is hidden in both the Dashboard and API lists and cannot be reused.
1827 1828 1829 |
# File 'lib/stripe/resources/order.rb', line 1827 def price_data @price_data end |
#product ⇒ Object
The ID of a [Product](docs.stripe.com/api/products) to add to the Order.
The Product must have a ‘default_price` specified. Otherwise, specify the price by passing the `price` or `price_data` parameter.
1831 1832 1833 |
# File 'lib/stripe/resources/order.rb', line 1831 def product @product end |
#product_data ⇒ Object
Defines a [Product](docs.stripe.com/api/products) inline and adds it to the Order.
‘product_data` is an alternative to the `product` parameter. If you created a Product upfront, use the `product` parameter to refer to the existing Product. But if you prefer not to create Products upfront, pass the `product_data` parameter to define a Product inline as part of configuring the Order.
‘product_data` automatically creates a Product, just as if you had manually created the Product. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates.
1837 1838 1839 |
# File 'lib/stripe/resources/order.rb', line 1837 def product_data @product_data end |
#quantity ⇒ Object
The quantity of the line item.
1839 1840 1841 |
# File 'lib/stripe/resources/order.rb', line 1839 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates applied to this line item.
1841 1842 1843 |
# File 'lib/stripe/resources/order.rb', line 1841 def tax_rates @tax_rates end |