Class: Stripe::Order::UpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: Discount, PriceData, ProductData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, discounts: nil, id: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
# File 'lib/stripe/resources/order.rb', line 1812

def initialize(
  description: nil,
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  product: nil,
  product_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @description = description
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @product = product
  @product_data = product_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#descriptionObject

The description for the line item. Will default to the name of the associated product.



1782
1783
1784
# File 'lib/stripe/resources/order.rb', line 1782

def description
  @description
end

#discountsObject

The discounts applied to this line item.



1784
1785
1786
# File 'lib/stripe/resources/order.rb', line 1784

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the order.



1786
1787
1788
# File 'lib/stripe/resources/order.rb', line 1786

def id
  @id
end

#priceObject

The ID of a [Price](docs.stripe.com/api/prices) to add to the Order.

The ‘price` parameter is an alternative to using the `product` parameter. If each of your products are sold at a single price, you can set `Product.default_price` and then pass the `product` parameter when creating a line item. If your products are sold at several possible prices, use the `price` parameter to explicitly specify which one to use.



1790
1791
1792
# File 'lib/stripe/resources/order.rb', line 1790

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline.

The ‘price_data` parameter is an alternative to using the `product` or `price` parameters. If you create a Product upfront and configure a `Product.default_price`, pass the `product` parameter when creating a line item. If you prefer not to define Products upfront, or if you charge variable prices, pass the `price_data` parameter to describe the price for this line item.

Each time you pass ‘price_data` we create a Price for the Product. This Price is hidden in both the Dashboard and API lists and cannot be reused.



1796
1797
1798
# File 'lib/stripe/resources/order.rb', line 1796

def price_data
  @price_data
end

#productObject

The ID of a [Product](docs.stripe.com/api/products) to add to the Order.

The Product must have a ‘default_price` specified. Otherwise, specify the price by passing the `price` or `price_data` parameter.



1800
1801
1802
# File 'lib/stripe/resources/order.rb', line 1800

def product
  @product
end

#product_dataObject

Defines a [Product](docs.stripe.com/api/products) inline and adds it to the Order.

‘product_data` is an alternative to the `product` parameter. If you created a Product upfront, use the `product` parameter to refer to the existing Product. But if you prefer not to create Products upfront, pass the `product_data` parameter to define a Product inline as part of configuring the Order.

‘product_data` automatically creates a Product, just as if you had manually created the Product. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates.



1806
1807
1808
# File 'lib/stripe/resources/order.rb', line 1806

def product_data
  @product_data
end

#quantityObject

The quantity of the line item.



1808
1809
1810
# File 'lib/stripe/resources/order.rb', line 1808

def quantity
  @quantity
end

#tax_ratesObject

The tax rates applied to this line item.



1810
1811
1812
# File 'lib/stripe/resources/order.rb', line 1810

def tax_rates
  @tax_rates
end