Class: Stripe::Order::UpdateParams::LineItem

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: Discount, PriceData, ProductData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, discounts: nil, id: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem

Returns a new instance of LineItem.



2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
# File 'lib/stripe/resources/order.rb', line 2075

def initialize(
  description: nil,
  discounts: nil,
  id: nil,
  price: nil,
  price_data: nil,
  product: nil,
  product_data: nil,
  quantity: nil,
  tax_rates: nil
)
  @description = description
  @discounts = discounts
  @id = id
  @price = price
  @price_data = price_data
  @product = product
  @product_data = product_data
  @quantity = quantity
  @tax_rates = tax_rates
end

Instance Attribute Details

#descriptionObject

The description for the line item. Will default to the name of the associated product.



2037
2038
2039
# File 'lib/stripe/resources/order.rb', line 2037

def description
  @description
end

#discountsObject

The discounts applied to this line item.



2040
2041
2042
# File 'lib/stripe/resources/order.rb', line 2040

def discounts
  @discounts
end

#idObject

The ID of an existing line item on the order.



2043
2044
2045
# File 'lib/stripe/resources/order.rb', line 2043

def id
  @id
end

#priceObject

The ID of a [Price](stripe.com/docs/api/prices) to add to the Order.

The ‘price` parameter is an alternative to using the `product` parameter. If each of your products are sold at a single price, you can set `Product.default_price` and then pass the `product` parameter when creating a line item. If your products are sold at several possible prices, use the `price` parameter to explicitly specify which one to use.



2048
2049
2050
# File 'lib/stripe/resources/order.rb', line 2048

def price
  @price
end

#price_dataObject

Data used to generate a new Price object inline.

The ‘price_data` parameter is an alternative to using the `product` or `price` parameters. If you create products upfront and configure a `Product.default_price`, pass the `product` parameter when creating a line item. If you prefer not to define products upfront, or if you charge variable prices, pass the `price_data` parameter to describe the price for this line item.

Each time you pass ‘price_data` we create a Price for the product. This Price is hidden in both the Dashboard and API lists and cannot be reused.



2055
2056
2057
# File 'lib/stripe/resources/order.rb', line 2055

def price_data
  @price_data
end

#productObject

The ID of a [Product](stripe.com/docs/api/products) to add to the Order.

The product must have a ‘default_price` specified. Otherwise, specify the price by passing the `price` or `price_data` parameter.



2060
2061
2062
# File 'lib/stripe/resources/order.rb', line 2060

def product
  @product
end

#product_dataObject

Defines a Product inline and adds it to the Order.

‘product_data` is an alternative to the `product` parameter. If you created a Product upfront, use the `product` parameter to refer to the existing Product. But if you prefer not to create Products upfront, pass the `product_data` parameter to define a Product inline as part of configuring the Order.

‘product_data` automatically creates a Product, just as if you had manually created the Product. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates.



2067
2068
2069
# File 'lib/stripe/resources/order.rb', line 2067

def product_data
  @product_data
end

#quantityObject

The quantity of the line item.



2070
2071
2072
# File 'lib/stripe/resources/order.rb', line 2070

def quantity
  @quantity
end

#tax_ratesObject

The tax rates applied to this line item.



2073
2074
2075
# File 'lib/stripe/resources/order.rb', line 2073

def tax_rates
  @tax_rates
end