Class: Stripe::Order::UpdateParams::LineItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::LineItem::Discount
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil) ⇒ Discount
Returns a new instance of Discount.
2048 2049 2050 2051 |
# File 'lib/stripe/resources/order.rb', line 2048 def initialize(coupon: nil, discount: nil) @coupon = coupon @discount = discount end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
2044 2045 2046 |
# File 'lib/stripe/resources/order.rb', line 2044 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
2046 2047 2048 |
# File 'lib/stripe/resources/order.rb', line 2046 def discount @discount end |