Class: Stripe::Order::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil) ⇒ Discount

Returns a new instance of Discount.



1716
1717
1718
1719
# File 'lib/stripe/resources/order.rb', line 1716

def initialize(coupon: nil, discount: nil)
  @coupon = coupon
  @discount = discount
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1712
1713
1714
# File 'lib/stripe/resources/order.rb', line 1712

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1714
1715
1716
# File 'lib/stripe/resources/order.rb', line 1714

def discount
  @discount
end