Class: Stripe::Order::UpdateParams::LineItem::Discount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::LineItem::Discount
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#coupon ⇒ Object
ID of the coupon to create a new discount for.
-
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
Instance Method Summary collapse
-
#initialize(coupon: nil, discount: nil) ⇒ Discount
constructor
A new instance of Discount.
Methods inherited from RequestParams
Constructor Details
#initialize(coupon: nil, discount: nil) ⇒ Discount
Returns a new instance of Discount.
1716 1717 1718 1719 |
# File 'lib/stripe/resources/order.rb', line 1716 def initialize(coupon: nil, discount: nil) @coupon = coupon @discount = discount end |
Instance Attribute Details
#coupon ⇒ Object
ID of the coupon to create a new discount for.
1712 1713 1714 |
# File 'lib/stripe/resources/order.rb', line 1712 def coupon @coupon end |
#discount ⇒ Object
ID of an existing discount on the object (or one of its ancestors) to reuse.
1714 1715 1716 |
# File 'lib/stripe/resources/order.rb', line 1714 def discount @discount end |