Class: Stripe::Order::UpdateParams::LineItem::Discount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(coupon: nil, discount: nil) ⇒ Discount

Returns a new instance of Discount.



1694
1695
1696
1697
# File 'lib/stripe/resources/order.rb', line 1694

def initialize(coupon: nil, discount: nil)
  @coupon = coupon
  @discount = discount
end

Instance Attribute Details

#couponObject

ID of the coupon to create a new discount for.



1690
1691
1692
# File 'lib/stripe/resources/order.rb', line 1690

def coupon
  @coupon
end

#discountObject

ID of an existing discount on the object (or one of its ancestors) to reuse.



1692
1693
1694
# File 'lib/stripe/resources/order.rb', line 1692

def discount
  @discount
end