Class: Stripe::Order::UpdateParams::LineItem::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData

Returns a new instance of ProductData.



1790
1791
1792
1793
1794
1795
1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
# File 'lib/stripe/resources/order.rb', line 1790

def initialize(
  description: nil,
  id: nil,
  images: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  tax_code: nil,
  url: nil
)
  @description = description
  @id = id
  @images = images
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @tax_code = tax_code
  @url = url
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1770
1771
1772
# File 'lib/stripe/resources/order.rb', line 1770

def description
  @description
end

#idObject

A unique identifier for this product.

‘product_data` automatically creates a Product with this ID. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates. If any of the fields in the existing Product are different from the values in `product_data`, `product_data` updates the existing Product with the new information. So set `product_data` to the same string every time you sell the same product, but don’t re-use the same string for different products.



1774
1775
1776
# File 'lib/stripe/resources/order.rb', line 1774

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1776
1777
1778
# File 'lib/stripe/resources/order.rb', line 1776

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1778
1779
1780
# File 'lib/stripe/resources/order.rb', line 1778

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1780
1781
1782
# File 'lib/stripe/resources/order.rb', line 1780

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



1782
1783
1784
# File 'lib/stripe/resources/order.rb', line 1782

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



1784
1785
1786
# File 'lib/stripe/resources/order.rb', line 1784

def shippable
  @shippable
end

#tax_codeObject



1786
1787
1788
# File 'lib/stripe/resources/order.rb', line 1786

def tax_code
  @tax_code
end

#urlObject

A URL of a publicly-accessible webpage for this product.



1788
1789
1790
# File 'lib/stripe/resources/order.rb', line 1788

def url
  @url
end