Class: Stripe::Order::UpdateParams::LineItem::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData

Returns a new instance of ProductData.



2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
2032
2033
2034
# File 'lib/stripe/resources/order.rb', line 2014

def initialize(
  description: nil,
  id: nil,
  images: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  tax_code: nil,
  url: nil
)
  @description = description
  @id = id
  @images = images
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @tax_code = tax_code
  @url = url
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1986
1987
1988
# File 'lib/stripe/resources/order.rb', line 1986

def description
  @description
end

#idObject

A unique identifier for this product.

‘product_data` automatically creates a Product with this ID. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates. If any of the fields in the existing Product are different from the values in `product_data`, `product_data` updates the existing Product with the new information. So set `product_data` to the same string every time you sell the same product, but don’t re-use the same string for different products.



1991
1992
1993
# File 'lib/stripe/resources/order.rb', line 1991

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1994
1995
1996
# File 'lib/stripe/resources/order.rb', line 1994

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1997
1998
1999
# File 'lib/stripe/resources/order.rb', line 1997

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



2000
2001
2002
# File 'lib/stripe/resources/order.rb', line 2000

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



2003
2004
2005
# File 'lib/stripe/resources/order.rb', line 2003

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



2006
2007
2008
# File 'lib/stripe/resources/order.rb', line 2006

def shippable
  @shippable
end

#tax_codeObject



2009
2010
2011
# File 'lib/stripe/resources/order.rb', line 2009

def tax_code
  @tax_code
end

#urlObject

A URL of a publicly-accessible webpage for this product.



2012
2013
2014
# File 'lib/stripe/resources/order.rb', line 2012

def url
  @url
end