Class: Stripe::Order::UpdateParams::Payment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Payment
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
Instance Method Summary collapse
-
#initialize(settings: nil) ⇒ Payment
constructor
A new instance of Payment.
Methods inherited from RequestParams
Constructor Details
#initialize(settings: nil) ⇒ Payment
Returns a new instance of Payment.
2404 2405 2406 |
# File 'lib/stripe/resources/order.rb', line 2404 def initialize(settings: nil) @settings = settings end |
Instance Attribute Details
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
2402 2403 2404 |
# File 'lib/stripe/resources/order.rb', line 2402 def settings @settings end |