Class: Stripe::Order::UpdateParams::Payment::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Payment::Settings
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: PaymentMethodOptions, TransferData
Instance Attribute Summary collapse
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#payment_method_options ⇒ Object
PaymentMethod-specific configuration to provide to the order’s PaymentIntent.
-
#payment_method_types ⇒ Object
The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent.
-
#return_url ⇒ Object
The URL to redirect the customer to after they authenticate their payment.
-
#statement_descriptor ⇒ Object
For non-card charges, you can use this value as the complete description that appears on your customers’ statements.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#transfer_data ⇒ Object
Provides configuration for completing a transfer for the order after it is paid.
Instance Method Summary collapse
-
#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings
Returns a new instance of Settings.
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 |
# File 'lib/stripe/resources/order.rb', line 2401 def initialize( application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil ) @application_fee_amount = application_fee_amount @payment_method_options = @payment_method_types = payment_method_types @return_url = return_url @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data end |
Instance Attribute Details
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
2387 2388 2389 |
# File 'lib/stripe/resources/order.rb', line 2387 def application_fee_amount @application_fee_amount end |
#payment_method_options ⇒ Object
PaymentMethod-specific configuration to provide to the order’s PaymentIntent.
2389 2390 2391 |
# File 'lib/stripe/resources/order.rb', line 2389 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).
2391 2392 2393 |
# File 'lib/stripe/resources/order.rb', line 2391 def payment_method_types @payment_method_types end |
#return_url ⇒ Object
The URL to redirect the customer to after they authenticate their payment.
2393 2394 2395 |
# File 'lib/stripe/resources/order.rb', line 2393 def return_url @return_url end |
#statement_descriptor ⇒ Object
For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.
2395 2396 2397 |
# File 'lib/stripe/resources/order.rb', line 2395 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.
2397 2398 2399 |
# File 'lib/stripe/resources/order.rb', line 2397 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
Provides configuration for completing a transfer for the order after it is paid.
2399 2400 2401 |
# File 'lib/stripe/resources/order.rb', line 2399 def transfer_data @transfer_data end |