Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
2470
# File 'lib/stripe/resources/order.rb', line 2438

def initialize(
  acss_debit: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  ideal: nil,
  klarna: nil,
  link: nil,
  oxxo: nil,
  p24: nil,
  paypal: nil,
  sepa_debit: nil,
  sofort: nil,
  wechat_pay: nil
)
  @acss_debit = acss_debit
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @ideal = ideal
  @klarna = klarna
  @link = link
  @oxxo = oxxo
  @p24 = p24
  @paypal = paypal
  @sepa_debit = sepa_debit
  @sofort = sofort
  @wechat_pay = wechat_pay
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.



2408
2409
2410
# File 'lib/stripe/resources/order.rb', line 2408

def acss_debit
  @acss_debit
end

#afterpay_clearpayObject

If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.



2410
2411
2412
# File 'lib/stripe/resources/order.rb', line 2410

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.



2412
2413
2414
# File 'lib/stripe/resources/order.rb', line 2412

def alipay
  @alipay
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.



2414
2415
2416
# File 'lib/stripe/resources/order.rb', line 2414

def bancontact
  @bancontact
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.



2416
2417
2418
# File 'lib/stripe/resources/order.rb', line 2416

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.



2418
2419
2420
# File 'lib/stripe/resources/order.rb', line 2418

def customer_balance
  @customer_balance
end

#idealObject

If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.



2420
2421
2422
# File 'lib/stripe/resources/order.rb', line 2420

def ideal
  @ideal
end

#klarnaObject

If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.



2422
2423
2424
# File 'lib/stripe/resources/order.rb', line 2422

def klarna
  @klarna
end

If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.



2424
2425
2426
# File 'lib/stripe/resources/order.rb', line 2424

def link
  @link
end

#oxxoObject

If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.



2426
2427
2428
# File 'lib/stripe/resources/order.rb', line 2426

def oxxo
  @oxxo
end

#p24Object

If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.



2428
2429
2430
# File 'lib/stripe/resources/order.rb', line 2428

def p24
  @p24
end

#paypalObject

If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.



2430
2431
2432
# File 'lib/stripe/resources/order.rb', line 2430

def paypal
  @paypal
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.



2432
2433
2434
# File 'lib/stripe/resources/order.rb', line 2432

def sepa_debit
  @sepa_debit
end

#sofortObject

If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.



2434
2435
2436
# File 'lib/stripe/resources/order.rb', line 2434

def sofort
  @sofort
end

#wechat_payObject

If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.



2436
2437
2438
# File 'lib/stripe/resources/order.rb', line 2436

def wechat_pay
  @wechat_pay
end