Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
-
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
-
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
-
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
-
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
-
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
-
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
-
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
-
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
-
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
-
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
-
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
-
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
-
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
-
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 2345 2346 2347 2348 2349 2350 2351 2352 2353 2354 |
# File 'lib/stripe/resources/order.rb', line 2322 def initialize( acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil ) @acss_debit = acss_debit @afterpay_clearpay = afterpay_clearpay @alipay = alipay @bancontact = bancontact @card = card @customer_balance = customer_balance @ideal = ideal @klarna = klarna @link = link @oxxo = oxxo @p24 = p24 @paypal = paypal @sepa_debit = sepa_debit @sofort = sofort @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
2292 2293 2294 |
# File 'lib/stripe/resources/order.rb', line 2292 def acss_debit @acss_debit end |
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
2294 2295 2296 |
# File 'lib/stripe/resources/order.rb', line 2294 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
2296 2297 2298 |
# File 'lib/stripe/resources/order.rb', line 2296 def alipay @alipay end |
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
2298 2299 2300 |
# File 'lib/stripe/resources/order.rb', line 2298 def bancontact @bancontact end |
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
2300 2301 2302 |
# File 'lib/stripe/resources/order.rb', line 2300 def card @card end |
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
2302 2303 2304 |
# File 'lib/stripe/resources/order.rb', line 2302 def customer_balance @customer_balance end |
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
2304 2305 2306 |
# File 'lib/stripe/resources/order.rb', line 2304 def ideal @ideal end |
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
2306 2307 2308 |
# File 'lib/stripe/resources/order.rb', line 2306 def klarna @klarna end |
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
2308 2309 2310 |
# File 'lib/stripe/resources/order.rb', line 2308 def link @link end |
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
2310 2311 2312 |
# File 'lib/stripe/resources/order.rb', line 2310 def oxxo @oxxo end |
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
2312 2313 2314 |
# File 'lib/stripe/resources/order.rb', line 2312 def p24 @p24 end |
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
2314 2315 2316 |
# File 'lib/stripe/resources/order.rb', line 2314 def paypal @paypal end |
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
2316 2317 2318 |
# File 'lib/stripe/resources/order.rb', line 2316 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
2318 2319 2320 |
# File 'lib/stripe/resources/order.rb', line 2318 def sofort @sofort end |
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
2320 2321 2322 |
# File 'lib/stripe/resources/order.rb', line 2320 def wechat_pay @wechat_pay end |