Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::AfterpayClearpay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::AfterpayClearpay
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#reference ⇒ Object
An internal identifier or reference this payment corresponds to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with the payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, reference: nil, setup_future_usage: nil) ⇒ AfterpayClearpay
constructor
A new instance of AfterpayClearpay.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, reference: nil, setup_future_usage: nil) ⇒ AfterpayClearpay
Returns a new instance of AfterpayClearpay.
2177 2178 2179 2180 2181 |
# File 'lib/stripe/resources/order.rb', line 2177 def initialize(capture_method: nil, reference: nil, setup_future_usage: nil) @capture_method = capture_method @reference = reference @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
2163 2164 2165 |
# File 'lib/stripe/resources/order.rb', line 2163 def capture_method @capture_method end |
#reference ⇒ Object
An internal identifier or reference this payment corresponds to. The identifier is limited to 128 characters and may contain only letters, digits, underscores, backslashes and dashes.
2166 2167 2168 |
# File 'lib/stripe/resources/order.rb', line 2166 def reference @reference end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with the payment method.
Providing this parameter will [attach the payment method](stripe.com/docs/payments/save-during-payment) to the order’s Customer, if present, after the order’s PaymentIntent is confirmed and any required actions from the user are complete. If no Customer was provided, the payment method can still be [attached](stripe.com/docs/api/payment_methods/attach) to a Customer after the transaction completes.
When processing card payments, Stripe also uses ‘setup_future_usage` to dynamically optimize your payment flow and comply with regional legislation and network rules, such as [SCA](stripe.com/docs/strong-customer-authentication).
If ‘setup_future_usage` is already set and you are performing a request using a publishable key, you may only update the value from `on_session` to `off_session`.
2175 2176 2177 |
# File 'lib/stripe/resources/order.rb', line 2175 def setup_future_usage @setup_future_usage end |