Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



2170
2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
# File 'lib/stripe/resources/order.rb', line 2170

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



2154
2155
2156
# File 'lib/stripe/resources/order.rb', line 2154

def category
  @category
end

#descriptionObject

Description of the line item.



2156
2157
2158
# File 'lib/stripe/resources/order.rb', line 2156

def description
  @description
end

#nameObject

Descriptive name of the line item.



2158
2159
2160
# File 'lib/stripe/resources/order.rb', line 2158

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



2160
2161
2162
# File 'lib/stripe/resources/order.rb', line 2160

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



2162
2163
2164
# File 'lib/stripe/resources/order.rb', line 2162

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



2164
2165
2166
# File 'lib/stripe/resources/order.rb', line 2164

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



2166
2167
2168
# File 'lib/stripe/resources/order.rb', line 2166

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



2168
2169
2170
# File 'lib/stripe/resources/order.rb', line 2168

def unit_amount
  @unit_amount
end