Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 2463 2464 2465 |
# File 'lib/stripe/resources/order.rb', line 2447 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2424 2425 2426 |
# File 'lib/stripe/resources/order.rb', line 2424 def category @category end |
#description ⇒ Object
Description of the line item.
2427 2428 2429 |
# File 'lib/stripe/resources/order.rb', line 2427 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2430 2431 2432 |
# File 'lib/stripe/resources/order.rb', line 2430 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2433 2434 2435 |
# File 'lib/stripe/resources/order.rb', line 2433 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2436 2437 2438 |
# File 'lib/stripe/resources/order.rb', line 2436 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2439 2440 2441 |
# File 'lib/stripe/resources/order.rb', line 2439 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2442 2443 2444 |
# File 'lib/stripe/resources/order.rb', line 2442 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2445 2446 2447 |
# File 'lib/stripe/resources/order.rb', line 2445 def unit_amount @unit_amount end |