Class: Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/order.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
2155 2156 2157 2158 2159 2160 2161 2162 2163 2164 2165 2166 2167 2168 2169 2170 2171 2172 2173 |
# File 'lib/stripe/resources/order.rb', line 2155 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
2139 2140 2141 |
# File 'lib/stripe/resources/order.rb', line 2139 def category @category end |
#description ⇒ Object
Description of the line item.
2141 2142 2143 |
# File 'lib/stripe/resources/order.rb', line 2141 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
2143 2144 2145 |
# File 'lib/stripe/resources/order.rb', line 2143 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
2145 2146 2147 |
# File 'lib/stripe/resources/order.rb', line 2145 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
2147 2148 2149 |
# File 'lib/stripe/resources/order.rb', line 2147 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
2149 2150 2151 |
# File 'lib/stripe/resources/order.rb', line 2149 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
2151 2152 2153 |
# File 'lib/stripe/resources/order.rb', line 2151 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
2153 2154 2155 |
# File 'lib/stripe/resources/order.rb', line 2153 def unit_amount @unit_amount end |