Class: Stripe::Order::UpdateParams::Payment::Settings::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::Payment::Settings::TransferData
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the order is paid.
-
#destination ⇒ Object
ID of the Connected account receiving the transfer.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
2811 2812 2813 2814 |
# File 'lib/stripe/resources/order.rb', line 2811 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
2807 2808 2809 |
# File 'lib/stripe/resources/order.rb', line 2807 def amount @amount end |
#destination ⇒ Object
ID of the Connected account receiving the transfer.
2809 2810 2811 |
# File 'lib/stripe/resources/order.rb', line 2809 def destination @destination end |