Class: Stripe::Order::UpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2372
2373
2374
2375
# File 'lib/stripe/resources/order.rb', line 2372

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



2368
2369
2370
# File 'lib/stripe/resources/order.rb', line 2368

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



2370
2371
2372
# File 'lib/stripe/resources/order.rb', line 2370

def destination
  @destination
end