Class: Stripe::Order::UpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2381
2382
2383
2384
# File 'lib/stripe/resources/order.rb', line 2381

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



2377
2378
2379
# File 'lib/stripe/resources/order.rb', line 2377

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



2379
2380
2381
# File 'lib/stripe/resources/order.rb', line 2379

def destination
  @destination
end