Class: Stripe::Order::UpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2363
2364
2365
2366
# File 'lib/stripe/resources/order.rb', line 2363

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



2359
2360
2361
# File 'lib/stripe/resources/order.rb', line 2359

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



2361
2362
2363
# File 'lib/stripe/resources/order.rb', line 2361

def destination
  @destination
end