Class: Stripe::Order::UpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/order.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



2681
2682
2683
2684
# File 'lib/stripe/resources/order.rb', line 2681

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



2676
2677
2678
# File 'lib/stripe/resources/order.rb', line 2676

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



2679
2680
2681
# File 'lib/stripe/resources/order.rb', line 2679

def destination
  @destination
end