Class: Stripe::Order::UpdateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::Order::UpdateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions
- Defined in:
- lib/stripe/resources/order.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
Instance Method Summary collapse
-
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
2453 2454 2455 2456 |
# File 'lib/stripe/resources/order.rb', line 2453 def initialize(amount: nil, tax_behavior: nil) @amount = amount @tax_behavior = tax_behavior end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
2449 2450 2451 |
# File 'lib/stripe/resources/order.rb', line 2449 def amount @amount end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
2451 2452 2453 |
# File 'lib/stripe/resources/order.rb', line 2451 def tax_behavior @tax_behavior end |