Class: Stripe::OrderCreateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/params/order_create_params.rb

Defined Under Namespace

Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, new, #to_h

Constructor Details

#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ OrderCreateParams

Returns a new instance of OrderCreateParams.



2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
# File 'lib/stripe/params/order_create_params.rb', line 2070

def initialize(
  automatic_tax: nil,
  billing_details: nil,
  currency: nil,
  customer: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  ip_address: nil,
  line_items: nil,
  metadata: nil,
  payment: nil,
  shipping_cost: nil,
  shipping_details: nil,
  tax_details: nil
)
  @automatic_tax = automatic_tax
  @billing_details = billing_details
  @currency = currency
  @customer = customer
  @description = description
  @discounts = discounts
  @expand = expand
  @ip_address = ip_address
  @line_items = line_items
  @metadata = 
  @payment = payment
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @tax_details = tax_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax calculation for this order.



2042
2043
2044
# File 'lib/stripe/params/order_create_params.rb', line 2042

def automatic_tax
  @automatic_tax
end

#billing_detailsObject

Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.



2044
2045
2046
# File 'lib/stripe/params/order_create_params.rb', line 2044

def billing_details
  @billing_details
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2046
2047
2048
# File 'lib/stripe/params/order_create_params.rb', line 2046

def currency
  @currency
end

#customerObject

The customer associated with this order.



2048
2049
2050
# File 'lib/stripe/params/order_create_params.rb', line 2048

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2050
2051
2052
# File 'lib/stripe/params/order_create_params.rb', line 2050

def description
  @description
end

#discountsObject

The coupons, promotion codes, and/or discounts to apply to the order.



2052
2053
2054
# File 'lib/stripe/params/order_create_params.rb', line 2052

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



2054
2055
2056
# File 'lib/stripe/params/order_create_params.rb', line 2054

def expand
  @expand
end

#ip_addressObject

The IP address of the purchaser for this order.



2056
2057
2058
# File 'lib/stripe/params/order_create_params.rb', line 2056

def ip_address
  @ip_address
end

#line_itemsObject

A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.



2058
2059
2060
# File 'lib/stripe/params/order_create_params.rb', line 2058

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2060
2061
2062
# File 'lib/stripe/params/order_create_params.rb', line 2060

def 
  @metadata
end

#paymentObject

Payment information associated with the order, including payment settings.



2062
2063
2064
# File 'lib/stripe/params/order_create_params.rb', line 2062

def payment
  @payment
end

#shipping_costObject

Settings for the customer cost of shipping for this order.



2064
2065
2066
# File 'lib/stripe/params/order_create_params.rb', line 2064

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the order.



2066
2067
2068
# File 'lib/stripe/params/order_create_params.rb', line 2066

def shipping_details
  @shipping_details
end

#tax_detailsObject

Additional tax details about the purchaser to be used for this order.



2068
2069
2070
# File 'lib/stripe/params/order_create_params.rb', line 2068

def tax_details
  @tax_details
end

Class Method Details

.field_encodingsObject



2102
2103
2104
2105
2106
2107
2108
2109
2110
2111
2112
# File 'lib/stripe/params/order_create_params.rb', line 2102

def self.field_encodings
  @field_encodings = {
    line_items: {
      kind: :array,
      element: {
        kind: :object,
        fields: { price_data: { kind: :object, fields: { unit_amount_decimal: :decimal_string } } },
      },
    },
  }
end