Class: Stripe::OrderCreateParams::Payment::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Defined Under Namespace

Classes: PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings

Returns a new instance of Settings.



1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
# File 'lib/stripe/params/order_create_params.rb', line 1801

def initialize(
  application_fee_amount: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @application_fee_amount = application_fee_amount
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.



1787
1788
1789
# File 'lib/stripe/params/order_create_params.rb', line 1787

def application_fee_amount
  @application_fee_amount
end

#payment_method_optionsObject

PaymentMethod-specific configuration to provide to the order’s PaymentIntent.



1789
1790
1791
# File 'lib/stripe/params/order_create_params.rb', line 1789

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



1791
1792
1793
# File 'lib/stripe/params/order_create_params.rb', line 1791

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect the customer to after they authenticate their payment.



1793
1794
1795
# File 'lib/stripe/params/order_create_params.rb', line 1793

def return_url
  @return_url
end

#statement_descriptorObject

For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.



1795
1796
1797
# File 'lib/stripe/params/order_create_params.rb', line 1795

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.



1797
1798
1799
# File 'lib/stripe/params/order_create_params.rb', line 1797

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Provides configuration for completing a transfer for the order after it is paid.



1799
1800
1801
# File 'lib/stripe/params/order_create_params.rb', line 1799

def transfer_data
  @transfer_data
end