Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions
- Defined in:
- lib/stripe/params/order_create_params.rb
Defined Under Namespace
Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by
acss_debit, this sub-hash contains details about the ACSS Debit payment method options to pass to the order's PaymentIntent. -
#afterpay_clearpay ⇒ Object
If paying by
afterpay_clearpay, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order's PaymentIntent. -
#alipay ⇒ Object
If paying by
alipay, this sub-hash contains details about the Alipay payment method options to pass to the order's PaymentIntent. -
#bancontact ⇒ Object
If paying by
bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the order's PaymentIntent. -
#card ⇒ Object
If paying by
card, this sub-hash contains details about the Card payment method options to pass to the order's PaymentIntent. -
#customer_balance ⇒ Object
If paying by
customer_balance, this sub-hash contains details about the Customer Balance payment method options to pass to the order's PaymentIntent. -
#ideal ⇒ Object
If paying by
ideal, this sub-hash contains details about the iDEAL payment method options to pass to the order's PaymentIntent. -
#klarna ⇒ Object
If paying by
klarna, this sub-hash contains details about the Klarna payment method options to pass to the order's PaymentIntent. -
#link ⇒ Object
If paying by
link, this sub-hash contains details about the Link payment method options to pass to the order's PaymentIntent. -
#oxxo ⇒ Object
If paying by
oxxo, this sub-hash contains details about the OXXO payment method options to pass to the order's PaymentIntent. -
#p24 ⇒ Object
If paying by
p24, this sub-hash contains details about the P24 payment method options to pass to the order's PaymentIntent. -
#paypal ⇒ Object
If paying by
paypal, this sub-hash contains details about the PayPal payment method options to pass to the order's PaymentIntent. -
#sepa_debit ⇒ Object
If paying by
sepa_debit, this sub-hash contains details about the SEPA Debit payment method options to pass to the order's PaymentIntent. -
#sofort ⇒ Object
If paying by
sofort, this sub-hash contains details about the Sofort payment method options to pass to the order's PaymentIntent. -
#wechat_pay ⇒ Object
If paying by
wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the order's PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 1776 1777 1778 1779 1780 1781 1782 |
# File 'lib/stripe/params/order_create_params.rb', line 1750 def initialize( acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil ) @acss_debit = acss_debit @afterpay_clearpay = afterpay_clearpay @alipay = alipay @bancontact = bancontact @card = card @customer_balance = customer_balance @ideal = ideal @klarna = klarna @link = link @oxxo = oxxo @p24 = p24 @paypal = paypal @sepa_debit = sepa_debit @sofort = sofort @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by acss_debit, this sub-hash contains details about the ACSS Debit payment method options to pass to the order's PaymentIntent.
1720 1721 1722 |
# File 'lib/stripe/params/order_create_params.rb', line 1720 def acss_debit @acss_debit end |
#afterpay_clearpay ⇒ Object
If paying by afterpay_clearpay, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order's PaymentIntent.
1722 1723 1724 |
# File 'lib/stripe/params/order_create_params.rb', line 1722 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If paying by alipay, this sub-hash contains details about the Alipay payment method options to pass to the order's PaymentIntent.
1724 1725 1726 |
# File 'lib/stripe/params/order_create_params.rb', line 1724 def alipay @alipay end |
#bancontact ⇒ Object
If paying by bancontact, this sub-hash contains details about the Bancontact payment method options to pass to the order's PaymentIntent.
1726 1727 1728 |
# File 'lib/stripe/params/order_create_params.rb', line 1726 def bancontact @bancontact end |
#card ⇒ Object
If paying by card, this sub-hash contains details about the Card payment method options to pass to the order's PaymentIntent.
1728 1729 1730 |
# File 'lib/stripe/params/order_create_params.rb', line 1728 def card @card end |
#customer_balance ⇒ Object
If paying by customer_balance, this sub-hash contains details about the Customer Balance payment method options to pass to the order's PaymentIntent.
1730 1731 1732 |
# File 'lib/stripe/params/order_create_params.rb', line 1730 def customer_balance @customer_balance end |
#ideal ⇒ Object
If paying by ideal, this sub-hash contains details about the iDEAL payment method options to pass to the order's PaymentIntent.
1732 1733 1734 |
# File 'lib/stripe/params/order_create_params.rb', line 1732 def ideal @ideal end |
#klarna ⇒ Object
If paying by klarna, this sub-hash contains details about the Klarna payment method options to pass to the order's PaymentIntent.
1734 1735 1736 |
# File 'lib/stripe/params/order_create_params.rb', line 1734 def klarna @klarna end |
#link ⇒ Object
If paying by link, this sub-hash contains details about the Link payment method options to pass to the order's PaymentIntent.
1736 1737 1738 |
# File 'lib/stripe/params/order_create_params.rb', line 1736 def link @link end |
#oxxo ⇒ Object
If paying by oxxo, this sub-hash contains details about the OXXO payment method options to pass to the order's PaymentIntent.
1738 1739 1740 |
# File 'lib/stripe/params/order_create_params.rb', line 1738 def oxxo @oxxo end |
#p24 ⇒ Object
If paying by p24, this sub-hash contains details about the P24 payment method options to pass to the order's PaymentIntent.
1740 1741 1742 |
# File 'lib/stripe/params/order_create_params.rb', line 1740 def p24 @p24 end |
#paypal ⇒ Object
If paying by paypal, this sub-hash contains details about the PayPal payment method options to pass to the order's PaymentIntent.
1742 1743 1744 |
# File 'lib/stripe/params/order_create_params.rb', line 1742 def paypal @paypal end |
#sepa_debit ⇒ Object
If paying by sepa_debit, this sub-hash contains details about the SEPA Debit payment method options to pass to the order's PaymentIntent.
1744 1745 1746 |
# File 'lib/stripe/params/order_create_params.rb', line 1744 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
If paying by sofort, this sub-hash contains details about the Sofort payment method options to pass to the order's PaymentIntent.
1746 1747 1748 |
# File 'lib/stripe/params/order_create_params.rb', line 1746 def sofort @sofort end |
#wechat_pay ⇒ Object
If paying by wechat_pay, this sub-hash contains details about the WeChat Pay payment method options to pass to the order's PaymentIntent.
1748 1749 1750 |
# File 'lib/stripe/params/order_create_params.rb', line 1748 def wechat_pay @wechat_pay end |