Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::EventReservationDetail
- Defined in:
- lib/stripe/params/order_create_params.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
Address of the event.
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#ends_at ⇒ Object
End timestamp of the event.
-
#event_company_name ⇒ Object
Company selling the ticket.
-
#event_name ⇒ Object
Name of the event.
-
#event_type ⇒ Object
Type of the event.
-
#insurances ⇒ Object
List of insurances for this event.
-
#starts_at ⇒ Object
Start timestamp of the event.
-
#venue_name ⇒ Object
Name of the venue where the event takes place.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
constructor
A new instance of EventReservationDetail.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil) ⇒ EventReservationDetail
Returns a new instance of EventReservationDetail.
739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 |
# File 'lib/stripe/params/order_create_params.rb', line 739 def initialize( access_controlled_venue: nil, address: nil, affiliate_name: nil, ends_at: nil, event_company_name: nil, event_name: nil, event_type: nil, insurances: nil, starts_at: nil, venue_name: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate_name = affiliate_name @ends_at = ends_at @event_company_name = event_company_name @event_name = event_name @event_type = event_type @insurances = insurances @starts_at = starts_at @venue_name = venue_name end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
719 720 721 |
# File 'lib/stripe/params/order_create_params.rb', line 719 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
Address of the event.
721 722 723 |
# File 'lib/stripe/params/order_create_params.rb', line 721 def address @address end |
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
723 724 725 |
# File 'lib/stripe/params/order_create_params.rb', line 723 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
End timestamp of the event.
725 726 727 |
# File 'lib/stripe/params/order_create_params.rb', line 725 def ends_at @ends_at end |
#event_company_name ⇒ Object
Company selling the ticket.
727 728 729 |
# File 'lib/stripe/params/order_create_params.rb', line 727 def event_company_name @event_company_name end |
#event_name ⇒ Object
Name of the event.
729 730 731 |
# File 'lib/stripe/params/order_create_params.rb', line 729 def event_name @event_name end |
#event_type ⇒ Object
Type of the event.
731 732 733 |
# File 'lib/stripe/params/order_create_params.rb', line 731 def event_type @event_type end |
#insurances ⇒ Object
List of insurances for this event.
733 734 735 |
# File 'lib/stripe/params/order_create_params.rb', line 733 def insurances @insurances end |
#starts_at ⇒ Object
Start timestamp of the event.
735 736 737 |
# File 'lib/stripe/params/order_create_params.rb', line 735 def starts_at @starts_at end |
#venue_name ⇒ Object
Name of the venue where the event takes place.
737 738 739 |
# File 'lib/stripe/params/order_create_params.rb', line 737 def venue_name @venue_name end |