Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::MarketplaceSeller::MarketplaceSellerAddress
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
constructor
A new instance of MarketplaceSellerAddress.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ MarketplaceSellerAddress
Returns a new instance of MarketplaceSellerAddress.
976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 |
# File 'lib/stripe/params/order_create_params.rb', line 976 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
964 965 966 |
# File 'lib/stripe/params/order_create_params.rb', line 964 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
966 967 968 |
# File 'lib/stripe/params/order_create_params.rb', line 966 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
968 969 970 |
# File 'lib/stripe/params/order_create_params.rb', line 968 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
970 971 972 |
# File 'lib/stripe/params/order_create_params.rb', line 970 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
972 973 974 |
# File 'lib/stripe/params/order_create_params.rb', line 972 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
974 975 976 |
# File 'lib/stripe/params/order_create_params.rb', line 974 def street_address2 @street_address2 end |