Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::Voucher
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
-
#ends_at ⇒ Object
The voucher validity end time.
-
#starts_at ⇒ Object
The voucher validity start time.
-
#voucher_company ⇒ Object
The issuer or provider of this voucher.
-
#voucher_name ⇒ Object
The name or reference to identify the voucher.
-
#voucher_type ⇒ Object
The type of this voucher.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
constructor
A new instance of Voucher.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil) ⇒ Voucher
Returns a new instance of Voucher.
1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 |
# File 'lib/stripe/params/order_create_params.rb', line 1378 def initialize( affiliate_name: nil, ends_at: nil, starts_at: nil, voucher_company: nil, voucher_name: nil, voucher_type: nil ) @affiliate_name = affiliate_name @ends_at = ends_at @starts_at = starts_at @voucher_company = voucher_company @voucher_name = voucher_name @voucher_type = voucher_type end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for this voucher.
1366 1367 1368 |
# File 'lib/stripe/params/order_create_params.rb', line 1366 def affiliate_name @affiliate_name end |
#ends_at ⇒ Object
The voucher validity end time.
1368 1369 1370 |
# File 'lib/stripe/params/order_create_params.rb', line 1368 def ends_at @ends_at end |
#starts_at ⇒ Object
The voucher validity start time.
1370 1371 1372 |
# File 'lib/stripe/params/order_create_params.rb', line 1370 def starts_at @starts_at end |
#voucher_company ⇒ Object
The issuer or provider of this voucher.
1372 1373 1374 |
# File 'lib/stripe/params/order_create_params.rb', line 1372 def voucher_company @voucher_company end |
#voucher_name ⇒ Object
The name or reference to identify the voucher.
1374 1375 1376 |
# File 'lib/stripe/params/order_create_params.rb', line 1374 def voucher_name @voucher_name end |
#voucher_type ⇒ Object
The type of this voucher.
1376 1377 1378 |
# File 'lib/stripe/params/order_create_params.rb', line 1376 def voucher_type @voucher_type end |