Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Link

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, persistent_token: nil, setup_future_usage: nil) ⇒ Link

Returns a new instance of Link.



1503
1504
1505
1506
1507
# File 'lib/stripe/params/order_create_params.rb', line 1503

def initialize(capture_method: nil, persistent_token: nil, setup_future_usage: nil)
  @capture_method = capture_method
  @persistent_token = persistent_token
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#capture_methodObject

Controls when the funds are captured from the customer’s account.

If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.

If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.



1489
1490
1491
# File 'lib/stripe/params/order_create_params.rb', line 1489

def capture_method
  @capture_method
end

#persistent_tokenObject

Deprecated

This is a legacy parameter that no longer has any function.



1491
1492
1493
# File 'lib/stripe/params/order_create_params.rb', line 1491

def persistent_token
  @persistent_token
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



1501
1502
1503
# File 'lib/stripe/params/order_create_params.rb', line 1501

def setup_future_usage
  @setup_future_usage
end