Class: Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/order_create_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 |
# File 'lib/stripe/params/order_create_params.rb', line 633 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
617 618 619 |
# File 'lib/stripe/params/order_create_params.rb', line 617 def category @category end |
#description ⇒ Object
Description of the line item.
619 620 621 |
# File 'lib/stripe/params/order_create_params.rb', line 619 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
621 622 623 |
# File 'lib/stripe/params/order_create_params.rb', line 621 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
623 624 625 |
# File 'lib/stripe/params/order_create_params.rb', line 623 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
625 626 627 |
# File 'lib/stripe/params/order_create_params.rb', line 625 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
627 628 629 |
# File 'lib/stripe/params/order_create_params.rb', line 627 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
629 630 631 |
# File 'lib/stripe/params/order_create_params.rb', line 629 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
631 632 633 |
# File 'lib/stripe/params/order_create_params.rb', line 631 def unit_amount @unit_amount end |