Class: Stripe::OrderCreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1791
1792
1793
1794
# File 'lib/stripe/params/order_create_params.rb', line 1791

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1787
1788
1789
# File 'lib/stripe/params/order_create_params.rb', line 1787

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1789
1790
1791
# File 'lib/stripe/params/order_create_params.rb', line 1789

def destination
  @destination
end