Class: Stripe::OrderCreateParams::Payment::Settings::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::Payment::Settings::TransferData
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the order is paid.
-
#destination ⇒ Object
ID of the Connected account receiving the transfer.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1781 1782 1783 1784 |
# File 'lib/stripe/params/order_create_params.rb', line 1781 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
1777 1778 1779 |
# File 'lib/stripe/params/order_create_params.rb', line 1777 def amount @amount end |
#destination ⇒ Object
ID of the Connected account receiving the transfer.
1779 1780 1781 |
# File 'lib/stripe/params/order_create_params.rb', line 1779 def destination @destination end |