Class: Stripe::OrderCreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



844
845
846
847
# File 'lib/stripe/params/order_create_params.rb', line 844

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



840
841
842
# File 'lib/stripe/params/order_create_params.rb', line 840

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



842
843
844
# File 'lib/stripe/params/order_create_params.rb', line 842

def destination
  @destination
end