Class: Stripe::OrderCreateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderCreateParams::ShippingCost::ShippingRateData::FixedAmount::CurrencyOptions
- Defined in:
- lib/stripe/params/order_create_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
Instance Method Summary collapse
-
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
constructor
A new instance of CurrencyOptions.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, tax_behavior: nil) ⇒ CurrencyOptions
Returns a new instance of CurrencyOptions.
1881 1882 1883 1884 |
# File 'lib/stripe/params/order_create_params.rb', line 1881 def initialize(amount: nil, tax_behavior: nil) @amount = amount @tax_behavior = tax_behavior end |
Instance Attribute Details
#amount ⇒ Object
A non-negative integer in cents representing how much to charge.
1877 1878 1879 |
# File 'lib/stripe/params/order_create_params.rb', line 1877 def amount @amount end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
1879 1880 1881 |
# File 'lib/stripe/params/order_create_params.rb', line 1879 def tax_behavior @tax_behavior end |