Class: Stripe::OrderService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::OrderService
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Returns the value of attribute line_items.
Instance Method Summary collapse
-
#cancel(id, params = {}, opts = {}) ⇒ Object
Cancels the order as well as the payment intent if one is attached.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new open order object.
-
#initialize(requestor) ⇒ OrderService
constructor
A new instance of OrderService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your orders.
-
#reopen(id, params = {}, opts = {}) ⇒ Object
Reopens a submitted order.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing order.
-
#submit(id, params = {}, opts = {}) ⇒ Object
Submitting an Order transitions the status to processing and creates a PaymentIntent object so the order can be paid.
-
#update(id, params = {}, opts = {}) ⇒ Object
Updates the specific order by setting the values of the parameters passed.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ OrderService
Returns a new instance of OrderService.
8 9 10 11 |
# File 'lib/stripe/services/order_service.rb', line 8 def initialize(requestor) super @line_items = Stripe::OrderLineItemService.new(@requestor) end |
Instance Attribute Details
#line_items ⇒ Object (readonly)
Returns the value of attribute line_items.
6 7 8 |
# File 'lib/stripe/services/order_service.rb', line 6 def line_items @line_items end |
Instance Method Details
#cancel(id, params = {}, opts = {}) ⇒ Object
Cancels the order as well as the payment intent if one is attached.
14 15 16 17 18 19 20 21 22 |
# File 'lib/stripe/services/order_service.rb', line 14 def cancel(id, params = {}, opts = {}) request( method: :post, path: format("/v1/orders/%<id>s/cancel", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a new open order object.
25 26 27 |
# File 'lib/stripe/services/order_service.rb', line 25 def create(params = {}, opts = {}) request(method: :post, path: "/v1/orders", params: params, opts: opts, base_address: :api) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your orders. The orders are returned sorted by creation date, with the most recently created orders appearing first.
30 31 32 |
# File 'lib/stripe/services/order_service.rb', line 30 def list(params = {}, opts = {}) request(method: :get, path: "/v1/orders", params: params, opts: opts, base_address: :api) end |
#reopen(id, params = {}, opts = {}) ⇒ Object
Reopens a submitted order.
35 36 37 38 39 40 41 42 43 |
# File 'lib/stripe/services/order_service.rb', line 35 def reopen(id, params = {}, opts = {}) request( method: :post, path: format("/v1/orders/%<id>s/reopen", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing order. Supply the unique order ID from either an order creation request or the order list, and Stripe will return the corresponding order information.
46 47 48 49 50 51 52 53 54 |
# File 'lib/stripe/services/order_service.rb', line 46 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/orders/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#submit(id, params = {}, opts = {}) ⇒ Object
Submitting an Order transitions the status to processing and creates a PaymentIntent object so the order can be paid. If the Order has an amount_total of 0, no PaymentIntent object will be created. Once the order is submitted, its contents cannot be changed, unless the [reopen](docs.stripe.com/api#reopen_order) method is called.
57 58 59 60 61 62 63 64 65 |
# File 'lib/stripe/services/order_service.rb', line 57 def submit(id, params = {}, opts = {}) request( method: :post, path: format("/v1/orders/%<id>s/submit", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Updates the specific order by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
68 69 70 71 72 73 74 75 76 |
# File 'lib/stripe/services/order_service.rb', line 68 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v1/orders/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |