Class: Stripe::OrderService
- Inherits:
-
StripeService
- Object
- StripeService
- Stripe::OrderService
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: CancelParams, CreateParams, ListParams, ReopenParams, RetrieveParams, SubmitParams, UpdateParams
Instance Attribute Summary collapse
-
#line_items ⇒ Object
readonly
Returns the value of attribute line_items.
Instance Method Summary collapse
-
#cancel(id, params = {}, opts = {}) ⇒ Object
Cancels the order as well as the payment intent if one is attached.
-
#create(params = {}, opts = {}) ⇒ Object
Creates a new open order object.
-
#initialize(requestor) ⇒ OrderService
constructor
A new instance of OrderService.
-
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your orders.
-
#reopen(id, params = {}, opts = {}) ⇒ Object
Reopens a submitted order.
-
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing order.
-
#submit(id, params = {}, opts = {}) ⇒ Object
Submitting an Order transitions the status to processing and creates a PaymentIntent object so the order can be paid.
-
#update(id, params = {}, opts = {}) ⇒ Object
Updates the specific order by setting the values of the parameters passed.
Methods inherited from StripeService
Constructor Details
#initialize(requestor) ⇒ OrderService
Returns a new instance of OrderService.
8 9 10 11 |
# File 'lib/stripe/services/order_service.rb', line 8 def initialize(requestor) super @line_items = Stripe::OrderLineItemService.new(@requestor) end |
Instance Attribute Details
#line_items ⇒ Object (readonly)
Returns the value of attribute line_items.
6 7 8 |
# File 'lib/stripe/services/order_service.rb', line 6 def line_items @line_items end |
Instance Method Details
#cancel(id, params = {}, opts = {}) ⇒ Object
Cancels the order as well as the payment intent if one is attached.
2324 2325 2326 2327 2328 2329 2330 2331 2332 |
# File 'lib/stripe/services/order_service.rb', line 2324 def cancel(id, params = {}, opts = {}) request( method: :post, path: format("/v1/orders/%<id>s/cancel", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#create(params = {}, opts = {}) ⇒ Object
Creates a new open order object.
2335 2336 2337 |
# File 'lib/stripe/services/order_service.rb', line 2335 def create(params = {}, opts = {}) request(method: :post, path: "/v1/orders", params: params, opts: opts, base_address: :api) end |
#list(params = {}, opts = {}) ⇒ Object
Returns a list of your orders. The orders are returned sorted by creation date, with the most recently created orders appearing first.
2340 2341 2342 |
# File 'lib/stripe/services/order_service.rb', line 2340 def list(params = {}, opts = {}) request(method: :get, path: "/v1/orders", params: params, opts: opts, base_address: :api) end |
#reopen(id, params = {}, opts = {}) ⇒ Object
Reopens a submitted order.
2345 2346 2347 2348 2349 2350 2351 2352 2353 |
# File 'lib/stripe/services/order_service.rb', line 2345 def reopen(id, params = {}, opts = {}) request( method: :post, path: format("/v1/orders/%<id>s/reopen", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#retrieve(id, params = {}, opts = {}) ⇒ Object
Retrieves the details of an existing order. Supply the unique order ID from either an order creation request or the order list, and Stripe will return the corresponding order information.
2356 2357 2358 2359 2360 2361 2362 2363 2364 |
# File 'lib/stripe/services/order_service.rb', line 2356 def retrieve(id, params = {}, opts = {}) request( method: :get, path: format("/v1/orders/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#submit(id, params = {}, opts = {}) ⇒ Object
Submitting an Order transitions the status to processing and creates a PaymentIntent object so the order can be paid. If the Order has an amount_total of 0, no PaymentIntent object will be created. Once the order is submitted, its contents cannot be changed, unless the [reopen](docs.stripe.com/api#reopen_order) method is called.
2367 2368 2369 2370 2371 2372 2373 2374 2375 |
# File 'lib/stripe/services/order_service.rb', line 2367 def submit(id, params = {}, opts = {}) request( method: :post, path: format("/v1/orders/%<id>s/submit", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |
#update(id, params = {}, opts = {}) ⇒ Object
Updates the specific order by setting the values of the parameters passed. Any parameters not provided will be left unchanged.
2378 2379 2380 2381 2382 2383 2384 2385 2386 |
# File 'lib/stripe/services/order_service.rb', line 2378 def update(id, params = {}, opts = {}) request( method: :post, path: format("/v1/orders/%<id>s", { id: CGI.escape(id) }), params: params, opts: opts, base_address: :api ) end |