Class: Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
-
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
-
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
-
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
-
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
-
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
-
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
-
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
-
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
-
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
-
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
-
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
-
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
-
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
-
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 |
# File 'lib/stripe/services/order_service.rb', line 838 def initialize( acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil ) @acss_debit = acss_debit @afterpay_clearpay = afterpay_clearpay @alipay = alipay @bancontact = bancontact @card = card @customer_balance = customer_balance @ideal = ideal @klarna = klarna @link = link @oxxo = oxxo @p24 = p24 @paypal = paypal @sepa_debit = sepa_debit @sofort = sofort @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
808 809 810 |
# File 'lib/stripe/services/order_service.rb', line 808 def acss_debit @acss_debit end |
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
810 811 812 |
# File 'lib/stripe/services/order_service.rb', line 810 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
812 813 814 |
# File 'lib/stripe/services/order_service.rb', line 812 def alipay @alipay end |
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
814 815 816 |
# File 'lib/stripe/services/order_service.rb', line 814 def bancontact @bancontact end |
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
816 817 818 |
# File 'lib/stripe/services/order_service.rb', line 816 def card @card end |
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
818 819 820 |
# File 'lib/stripe/services/order_service.rb', line 818 def customer_balance @customer_balance end |
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
820 821 822 |
# File 'lib/stripe/services/order_service.rb', line 820 def ideal @ideal end |
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
822 823 824 |
# File 'lib/stripe/services/order_service.rb', line 822 def klarna @klarna end |
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
824 825 826 |
# File 'lib/stripe/services/order_service.rb', line 824 def link @link end |
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
826 827 828 |
# File 'lib/stripe/services/order_service.rb', line 826 def oxxo @oxxo end |
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
828 829 830 |
# File 'lib/stripe/services/order_service.rb', line 828 def p24 @p24 end |
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
830 831 832 |
# File 'lib/stripe/services/order_service.rb', line 830 def paypal @paypal end |
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
832 833 834 |
# File 'lib/stripe/services/order_service.rb', line 832 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
834 835 836 |
# File 'lib/stripe/services/order_service.rb', line 834 def sofort @sofort end |
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
836 837 838 |
# File 'lib/stripe/services/order_service.rb', line 836 def wechat_pay @wechat_pay end |