Class: Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
# File 'lib/stripe/services/order_service.rb', line 857

def initialize(
  acss_debit: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  ideal: nil,
  klarna: nil,
  link: nil,
  oxxo: nil,
  p24: nil,
  paypal: nil,
  sepa_debit: nil,
  sofort: nil,
  wechat_pay: nil
)
  @acss_debit = acss_debit
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @ideal = ideal
  @klarna = klarna
  @link = link
  @oxxo = oxxo
  @p24 = p24
  @paypal = paypal
  @sepa_debit = sepa_debit
  @sofort = sofort
  @wechat_pay = wechat_pay
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.



813
814
815
# File 'lib/stripe/services/order_service.rb', line 813

def acss_debit
  @acss_debit
end

#afterpay_clearpayObject

If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.



816
817
818
# File 'lib/stripe/services/order_service.rb', line 816

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.



819
820
821
# File 'lib/stripe/services/order_service.rb', line 819

def alipay
  @alipay
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.



822
823
824
# File 'lib/stripe/services/order_service.rb', line 822

def bancontact
  @bancontact
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.



825
826
827
# File 'lib/stripe/services/order_service.rb', line 825

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.



828
829
830
# File 'lib/stripe/services/order_service.rb', line 828

def customer_balance
  @customer_balance
end

#idealObject

If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.



831
832
833
# File 'lib/stripe/services/order_service.rb', line 831

def ideal
  @ideal
end

#klarnaObject

If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.



834
835
836
# File 'lib/stripe/services/order_service.rb', line 834

def klarna
  @klarna
end

If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.



837
838
839
# File 'lib/stripe/services/order_service.rb', line 837

def link
  @link
end

#oxxoObject

If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.



840
841
842
# File 'lib/stripe/services/order_service.rb', line 840

def oxxo
  @oxxo
end

#p24Object

If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.



843
844
845
# File 'lib/stripe/services/order_service.rb', line 843

def p24
  @p24
end

#paypalObject

If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.



846
847
848
# File 'lib/stripe/services/order_service.rb', line 846

def paypal
  @paypal
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.



849
850
851
# File 'lib/stripe/services/order_service.rb', line 849

def sepa_debit
  @sepa_debit
end

#sofortObject

If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.



852
853
854
# File 'lib/stripe/services/order_service.rb', line 852

def sofort
  @sofort
end

#wechat_payObject

If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.



855
856
857
# File 'lib/stripe/services/order_service.rb', line 855

def wechat_pay
  @wechat_pay
end