Class: Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::CreateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/stripe/services/order_service.rb', line 604 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
588 589 590 |
# File 'lib/stripe/services/order_service.rb', line 588 def category @category end |
#description ⇒ Object
Description of the line item.
590 591 592 |
# File 'lib/stripe/services/order_service.rb', line 590 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
592 593 594 |
# File 'lib/stripe/services/order_service.rb', line 592 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
594 595 596 |
# File 'lib/stripe/services/order_service.rb', line 594 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
596 597 598 |
# File 'lib/stripe/services/order_service.rb', line 596 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
598 599 600 |
# File 'lib/stripe/services/order_service.rb', line 598 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
600 601 602 |
# File 'lib/stripe/services/order_service.rb', line 600 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
602 603 604 |
# File 'lib/stripe/services/order_service.rb', line 602 def unit_amount @unit_amount end |