Class: Stripe::OrderService::CreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



803
804
805
806
# File 'lib/stripe/services/order_service.rb', line 803

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



799
800
801
# File 'lib/stripe/services/order_service.rb', line 799

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



801
802
803
# File 'lib/stripe/services/order_service.rb', line 801

def destination
  @destination
end