Class: Stripe::OrderService::CreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



815
816
817
818
# File 'lib/stripe/services/order_service.rb', line 815

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



811
812
813
# File 'lib/stripe/services/order_service.rb', line 811

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



813
814
815
# File 'lib/stripe/services/order_service.rb', line 813

def destination
  @destination
end