Class: Stripe::OrderService::CreateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



808
809
810
811
# File 'lib/stripe/services/order_service.rb', line 808

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



804
805
806
# File 'lib/stripe/services/order_service.rb', line 804

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



806
807
808
# File 'lib/stripe/services/order_service.rb', line 806

def destination
  @destination
end