Class: Stripe::OrderService::ReopenParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::ReopenParams
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(expand: nil) ⇒ ReopenParams
constructor
A new instance of ReopenParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil) ⇒ ReopenParams
Returns a new instance of ReopenParams.
2186 2187 2188 |
# File 'lib/stripe/services/order_service.rb', line 2186 def initialize(expand: nil) @expand = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2184 2185 2186 |
# File 'lib/stripe/services/order_service.rb', line 2184 def @expand end |