Class: Stripe::OrderService::SubmitParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(expand: nil, expected_total: nil) ⇒ SubmitParams

Returns a new instance of SubmitParams.



2165
2166
2167
2168
# File 'lib/stripe/services/order_service.rb', line 2165

def initialize(expand: nil, expected_total: nil)
  @expand = expand
  @expected_total = expected_total
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



2161
2162
2163
# File 'lib/stripe/services/order_service.rb', line 2161

def expand
  @expand
end

#expected_totalObject

‘expected_total` should always be set to the order’s ‘amount_total` field. If they don’t match, submitting the order will fail. This helps detect race conditions where something else concurrently modifies the order.



2163
2164
2165
# File 'lib/stripe/services/order_service.rb', line 2163

def expected_total
  @expected_total
end