Class: Stripe::OrderService::SubmitParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::SubmitParams
- Defined in:
- lib/stripe/services/order_service.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#expected_total ⇒ Object
‘expected_total` should always be set to the order’s ‘amount_total` field.
Instance Method Summary collapse
-
#initialize(expand: nil, expected_total: nil) ⇒ SubmitParams
constructor
A new instance of SubmitParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, expected_total: nil) ⇒ SubmitParams
Returns a new instance of SubmitParams.
2197 2198 2199 2200 |
# File 'lib/stripe/services/order_service.rb', line 2197 def initialize(expand: nil, expected_total: nil) @expand = @expected_total = expected_total end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2193 2194 2195 |
# File 'lib/stripe/services/order_service.rb', line 2193 def @expand end |
#expected_total ⇒ Object
‘expected_total` should always be set to the order’s ‘amount_total` field. If they don’t match, submitting the order will fail. This helps detect race conditions where something else concurrently modifies the order.
2195 2196 2197 |
# File 'lib/stripe/services/order_service.rb', line 2195 def expected_total @expected_total end |