Class: Stripe::OrderService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2260 2261 2262 2263 2264 2265 2266 2267 2268 2269 2270 2271 2272 2273 2274 2275 2276 2277 2278 2279 2280 2281 2282 2283 2284 2285 2286 2287 2288 2289 2290 |
# File 'lib/stripe/services/order_service.rb', line 2260 def initialize( automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
2232 2233 2234 |
# File 'lib/stripe/services/order_service.rb', line 2232 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
2234 2235 2236 |
# File 'lib/stripe/services/order_service.rb', line 2234 def billing_details @billing_details end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2236 2237 2238 |
# File 'lib/stripe/services/order_service.rb', line 2236 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
2238 2239 2240 |
# File 'lib/stripe/services/order_service.rb', line 2238 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2240 2241 2242 |
# File 'lib/stripe/services/order_service.rb', line 2240 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.
2242 2243 2244 |
# File 'lib/stripe/services/order_service.rb', line 2242 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2244 2245 2246 |
# File 'lib/stripe/services/order_service.rb', line 2244 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
2246 2247 2248 |
# File 'lib/stripe/services/order_service.rb', line 2246 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
2248 2249 2250 |
# File 'lib/stripe/services/order_service.rb', line 2248 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2250 2251 2252 |
# File 'lib/stripe/services/order_service.rb', line 2250 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
2252 2253 2254 |
# File 'lib/stripe/services/order_service.rb', line 2252 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
2254 2255 2256 |
# File 'lib/stripe/services/order_service.rb', line 2254 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
2256 2257 2258 |
# File 'lib/stripe/services/order_service.rb', line 2256 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
2258 2259 2260 |
# File 'lib/stripe/services/order_service.rb', line 2258 def tax_details @tax_details end |