Class: Stripe::OrderService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
# File 'lib/stripe/services/order_service.rb', line 2108

def initialize(
  automatic_tax: nil,
  billing_details: nil,
  currency: nil,
  customer: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  ip_address: nil,
  line_items: nil,
  metadata: nil,
  payment: nil,
  shipping_cost: nil,
  shipping_details: nil,
  tax_details: nil
)
  @automatic_tax = automatic_tax
  @billing_details = billing_details
  @currency = currency
  @customer = customer
  @description = description
  @discounts = discounts
  @expand = expand
  @ip_address = ip_address
  @line_items = line_items
  @metadata = 
  @payment = payment
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @tax_details = tax_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax calculation for this order.



2080
2081
2082
# File 'lib/stripe/services/order_service.rb', line 2080

def automatic_tax
  @automatic_tax
end

#billing_detailsObject

Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.



2082
2083
2084
# File 'lib/stripe/services/order_service.rb', line 2082

def billing_details
  @billing_details
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2084
2085
2086
# File 'lib/stripe/services/order_service.rb', line 2084

def currency
  @currency
end

#customerObject

The customer associated with this order.



2086
2087
2088
# File 'lib/stripe/services/order_service.rb', line 2086

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2088
2089
2090
# File 'lib/stripe/services/order_service.rb', line 2088

def description
  @description
end

#discountsObject

The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.



2090
2091
2092
# File 'lib/stripe/services/order_service.rb', line 2090

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



2092
2093
2094
# File 'lib/stripe/services/order_service.rb', line 2092

def expand
  @expand
end

#ip_addressObject

The IP address of the purchaser for this order.



2094
2095
2096
# File 'lib/stripe/services/order_service.rb', line 2094

def ip_address
  @ip_address
end

#line_itemsObject

A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.



2096
2097
2098
# File 'lib/stripe/services/order_service.rb', line 2096

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2098
2099
2100
# File 'lib/stripe/services/order_service.rb', line 2098

def 
  @metadata
end

#paymentObject

Payment information associated with the order, including payment settings.



2100
2101
2102
# File 'lib/stripe/services/order_service.rb', line 2100

def payment
  @payment
end

#shipping_costObject

Settings for the customer cost of shipping for this order.



2102
2103
2104
# File 'lib/stripe/services/order_service.rb', line 2102

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the order.



2104
2105
2106
# File 'lib/stripe/services/order_service.rb', line 2104

def shipping_details
  @shipping_details
end

#tax_detailsObject

Additional tax details about the purchaser to be used for this order.



2106
2107
2108
# File 'lib/stripe/services/order_service.rb', line 2106

def tax_details
  @tax_details
end