Class: Stripe::OrderService::UpdateParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: AutomaticTax, BillingDetails, Credit, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams

Returns a new instance of UpdateParams.



2138
2139
2140
2141
2142
2143
2144
2145
2146
2147
2148
2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
2163
2164
2165
2166
2167
2168
2169
2170
# File 'lib/stripe/services/order_service.rb', line 2138

def initialize(
  automatic_tax: nil,
  billing_details: nil,
  credits: nil,
  currency: nil,
  customer: nil,
  description: nil,
  discounts: nil,
  expand: nil,
  ip_address: nil,
  line_items: nil,
  metadata: nil,
  payment: nil,
  shipping_cost: nil,
  shipping_details: nil,
  tax_details: nil
)
  @automatic_tax = automatic_tax
  @billing_details = billing_details
  @credits = credits
  @currency = currency
  @customer = customer
  @description = description
  @discounts = discounts
  @expand = expand
  @ip_address = ip_address
  @line_items = line_items
  @metadata = 
  @payment = payment
  @shipping_cost = shipping_cost
  @shipping_details = shipping_details
  @tax_details = tax_details
end

Instance Attribute Details

#automatic_taxObject

Settings for automatic tax calculation for this order.



2108
2109
2110
# File 'lib/stripe/services/order_service.rb', line 2108

def automatic_tax
  @automatic_tax
end

#billing_detailsObject

Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.



2110
2111
2112
# File 'lib/stripe/services/order_service.rb', line 2110

def billing_details
  @billing_details
end

#creditsObject

The credits to apply to the order, only ‘gift_card` currently supported. Pass the empty string `“”` to unset this field.



2112
2113
2114
# File 'lib/stripe/services/order_service.rb', line 2112

def credits
  @credits
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



2114
2115
2116
# File 'lib/stripe/services/order_service.rb', line 2114

def currency
  @currency
end

#customerObject

The customer associated with this order.



2116
2117
2118
# File 'lib/stripe/services/order_service.rb', line 2116

def customer
  @customer
end

#descriptionObject

An arbitrary string attached to the object. Often useful for displaying to users.



2118
2119
2120
# File 'lib/stripe/services/order_service.rb', line 2118

def description
  @description
end

#discountsObject

The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.



2120
2121
2122
# File 'lib/stripe/services/order_service.rb', line 2120

def discounts
  @discounts
end

#expandObject

Specifies which fields in the response should be expanded.



2122
2123
2124
# File 'lib/stripe/services/order_service.rb', line 2122

def expand
  @expand
end

#ip_addressObject

The IP address of the purchaser for this order.



2124
2125
2126
# File 'lib/stripe/services/order_service.rb', line 2124

def ip_address
  @ip_address
end

#line_itemsObject

A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.



2126
2127
2128
# File 'lib/stripe/services/order_service.rb', line 2126

def line_items
  @line_items
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



2128
2129
2130
# File 'lib/stripe/services/order_service.rb', line 2128

def 
  @metadata
end

#paymentObject

Payment information associated with the order, including payment settings.



2130
2131
2132
# File 'lib/stripe/services/order_service.rb', line 2130

def payment
  @payment
end

#shipping_costObject

Settings for the customer cost of shipping for this order.



2132
2133
2134
# File 'lib/stripe/services/order_service.rb', line 2132

def shipping_cost
  @shipping_cost
end

#shipping_detailsObject

Shipping details for the order.



2134
2135
2136
# File 'lib/stripe/services/order_service.rb', line 2134

def shipping_details
  @shipping_details
end

#tax_detailsObject

Additional tax details about the purchaser to be used for this order.



2136
2137
2138
# File 'lib/stripe/services/order_service.rb', line 2136

def tax_details
  @tax_details
end