Class: Stripe::OrderService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Credit, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#credits ⇒ Object
The credits to apply to the order, only ‘gift_card` currently supported.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2124 2125 2126 2127 2128 2129 2130 2131 2132 2133 2134 2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 |
# File 'lib/stripe/services/order_service.rb', line 2124 def initialize( automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @credits = credits @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
2094 2095 2096 |
# File 'lib/stripe/services/order_service.rb', line 2094 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
2096 2097 2098 |
# File 'lib/stripe/services/order_service.rb', line 2096 def billing_details @billing_details end |
#credits ⇒ Object
The credits to apply to the order, only ‘gift_card` currently supported. Pass the empty string `“”` to unset this field.
2098 2099 2100 |
# File 'lib/stripe/services/order_service.rb', line 2098 def credits @credits end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2100 2101 2102 |
# File 'lib/stripe/services/order_service.rb', line 2100 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
2102 2103 2104 |
# File 'lib/stripe/services/order_service.rb', line 2102 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2104 2105 2106 |
# File 'lib/stripe/services/order_service.rb', line 2104 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.
2106 2107 2108 |
# File 'lib/stripe/services/order_service.rb', line 2106 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2108 2109 2110 |
# File 'lib/stripe/services/order_service.rb', line 2108 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
2110 2111 2112 |
# File 'lib/stripe/services/order_service.rb', line 2110 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
2112 2113 2114 |
# File 'lib/stripe/services/order_service.rb', line 2112 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2114 2115 2116 |
# File 'lib/stripe/services/order_service.rb', line 2114 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
2116 2117 2118 |
# File 'lib/stripe/services/order_service.rb', line 2116 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
2118 2119 2120 |
# File 'lib/stripe/services/order_service.rb', line 2118 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
2120 2121 2122 |
# File 'lib/stripe/services/order_service.rb', line 2120 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
2122 2123 2124 |
# File 'lib/stripe/services/order_service.rb', line 2122 def tax_details @tax_details end |