Class: Stripe::OrderService::UpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Credit, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#credits ⇒ Object
The credits to apply to the order, only ‘gift_card` currently supported.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
constructor
A new instance of UpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ UpdateParams
Returns a new instance of UpdateParams.
2387 2388 2389 2390 2391 2392 2393 2394 2395 2396 2397 2398 2399 2400 2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 |
# File 'lib/stripe/services/order_service.rb', line 2387 def initialize( automatic_tax: nil, billing_details: nil, credits: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @credits = credits @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
2343 2344 2345 |
# File 'lib/stripe/services/order_service.rb', line 2343 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
2346 2347 2348 |
# File 'lib/stripe/services/order_service.rb', line 2346 def billing_details @billing_details end |
#credits ⇒ Object
The credits to apply to the order, only ‘gift_card` currently supported. Pass the empty string `“”` to unset this field.
2349 2350 2351 |
# File 'lib/stripe/services/order_service.rb', line 2349 def credits @credits end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2352 2353 2354 |
# File 'lib/stripe/services/order_service.rb', line 2352 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
2355 2356 2357 |
# File 'lib/stripe/services/order_service.rb', line 2355 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2358 2359 2360 |
# File 'lib/stripe/services/order_service.rb', line 2358 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.
2361 2362 2363 |
# File 'lib/stripe/services/order_service.rb', line 2361 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2364 2365 2366 |
# File 'lib/stripe/services/order_service.rb', line 2364 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
2367 2368 2369 |
# File 'lib/stripe/services/order_service.rb', line 2367 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
2370 2371 2372 |
# File 'lib/stripe/services/order_service.rb', line 2370 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2373 2374 2375 |
# File 'lib/stripe/services/order_service.rb', line 2373 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
2376 2377 2378 |
# File 'lib/stripe/services/order_service.rb', line 2376 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
2379 2380 2381 |
# File 'lib/stripe/services/order_service.rb', line 2379 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
2382 2383 2384 |
# File 'lib/stripe/services/order_service.rb', line 2382 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
2385 2386 2387 |
# File 'lib/stripe/services/order_service.rb', line 2385 def tax_details @tax_details end |