Class: Stripe::OrderService::UpdateParams::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::LineItem
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: Discount, PriceData, ProductData
Instance Attribute Summary collapse
-
#description ⇒ Object
The description for the line item.
-
#discounts ⇒ Object
The discounts applied to this line item.
-
#id ⇒ Object
The ID of an existing line item on the order.
-
#price ⇒ Object
The ID of a [Price](stripe.com/docs/api/prices) to add to the Order.
-
#price_data ⇒ Object
Data used to generate a new Price object inline.
-
#product ⇒ Object
The ID of a [Product](stripe.com/docs/api/products) to add to the Order.
-
#product_data ⇒ Object
Defines a Product inline and adds it to the Order.
-
#quantity ⇒ Object
The quantity of the line item.
-
#tax_rates ⇒ Object
The tax rates applied to this line item.
Instance Method Summary collapse
-
#initialize(description: nil, discounts: nil, id: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(description: nil, discounts: nil, id: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil) ⇒ LineItem
Returns a new instance of LineItem.
1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 |
# File 'lib/stripe/services/order_service.rb', line 1489 def initialize( description: nil, discounts: nil, id: nil, price: nil, price_data: nil, product: nil, product_data: nil, quantity: nil, tax_rates: nil ) @description = description @discounts = discounts @id = id @price = price @price_data = price_data @product = product @product_data = product_data @quantity = quantity @tax_rates = tax_rates end |
Instance Attribute Details
#description ⇒ Object
The description for the line item. Will default to the name of the associated product.
1451 1452 1453 |
# File 'lib/stripe/services/order_service.rb', line 1451 def description @description end |
#discounts ⇒ Object
The discounts applied to this line item.
1454 1455 1456 |
# File 'lib/stripe/services/order_service.rb', line 1454 def discounts @discounts end |
#id ⇒ Object
The ID of an existing line item on the order.
1457 1458 1459 |
# File 'lib/stripe/services/order_service.rb', line 1457 def id @id end |
#price ⇒ Object
The ID of a [Price](stripe.com/docs/api/prices) to add to the Order.
The ‘price` parameter is an alternative to using the `product` parameter. If each of your products are sold at a single price, you can set `Product.default_price` and then pass the `product` parameter when creating a line item. If your products are sold at several possible prices, use the `price` parameter to explicitly specify which one to use.
1462 1463 1464 |
# File 'lib/stripe/services/order_service.rb', line 1462 def price @price end |
#price_data ⇒ Object
Data used to generate a new Price object inline.
The ‘price_data` parameter is an alternative to using the `product` or `price` parameters. If you create products upfront and configure a `Product.default_price`, pass the `product` parameter when creating a line item. If you prefer not to define products upfront, or if you charge variable prices, pass the `price_data` parameter to describe the price for this line item.
Each time you pass ‘price_data` we create a Price for the product. This Price is hidden in both the Dashboard and API lists and cannot be reused.
1469 1470 1471 |
# File 'lib/stripe/services/order_service.rb', line 1469 def price_data @price_data end |
#product ⇒ Object
The ID of a [Product](stripe.com/docs/api/products) to add to the Order.
The product must have a ‘default_price` specified. Otherwise, specify the price by passing the `price` or `price_data` parameter.
1474 1475 1476 |
# File 'lib/stripe/services/order_service.rb', line 1474 def product @product end |
#product_data ⇒ Object
Defines a Product inline and adds it to the Order.
‘product_data` is an alternative to the `product` parameter. If you created a Product upfront, use the `product` parameter to refer to the existing Product. But if you prefer not to create Products upfront, pass the `product_data` parameter to define a Product inline as part of configuring the Order.
‘product_data` automatically creates a Product, just as if you had manually created the Product. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates.
1481 1482 1483 |
# File 'lib/stripe/services/order_service.rb', line 1481 def product_data @product_data end |
#quantity ⇒ Object
The quantity of the line item.
1484 1485 1486 |
# File 'lib/stripe/services/order_service.rb', line 1484 def quantity @quantity end |
#tax_rates ⇒ Object
The tax rates applied to this line item.
1487 1488 1489 |
# File 'lib/stripe/services/order_service.rb', line 1487 def tax_rates @tax_rates end |