Class: Stripe::OrderService::UpdateParams::LineItem::ProductData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: PackageDimensions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(description: nil, id: nil, images: nil, metadata: nil, name: nil, package_dimensions: nil, shippable: nil, tax_code: nil, url: nil) ⇒ ProductData

Returns a new instance of ProductData.



1275
1276
1277
1278
1279
1280
1281
1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
# File 'lib/stripe/services/order_service.rb', line 1275

def initialize(
  description: nil,
  id: nil,
  images: nil,
  metadata: nil,
  name: nil,
  package_dimensions: nil,
  shippable: nil,
  tax_code: nil,
  url: nil
)
  @description = description
  @id = id
  @images = images
  @metadata = 
  @name = name
  @package_dimensions = package_dimensions
  @shippable = shippable
  @tax_code = tax_code
  @url = url
end

Instance Attribute Details

#descriptionObject

The product’s description, meant to be displayable to the customer. Use this field to optionally store a long form explanation of the product being sold for your own rendering purposes.



1255
1256
1257
# File 'lib/stripe/services/order_service.rb', line 1255

def description
  @description
end

#idObject

A unique identifier for this product.

‘product_data` automatically creates a Product with this ID. If a Product with the same ID already exists, then `product_data` re-uses it to avoid duplicates. If any of the fields in the existing Product are different from the values in `product_data`, `product_data` updates the existing Product with the new information. So set `product_data` to the same string every time you sell the same product, but don’t re-use the same string for different products.



1259
1260
1261
# File 'lib/stripe/services/order_service.rb', line 1259

def id
  @id
end

#imagesObject

A list of up to 8 URLs of images for this product, meant to be displayable to the customer.



1261
1262
1263
# File 'lib/stripe/services/order_service.rb', line 1261

def images
  @images
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



1263
1264
1265
# File 'lib/stripe/services/order_service.rb', line 1263

def 
  @metadata
end

#nameObject

The product’s name, meant to be displayable to the customer.



1265
1266
1267
# File 'lib/stripe/services/order_service.rb', line 1265

def name
  @name
end

#package_dimensionsObject

The dimensions of this product for shipping purposes.



1267
1268
1269
# File 'lib/stripe/services/order_service.rb', line 1267

def package_dimensions
  @package_dimensions
end

#shippableObject

Whether this product is shipped (i.e., physical goods).



1269
1270
1271
# File 'lib/stripe/services/order_service.rb', line 1269

def shippable
  @shippable
end

#tax_codeObject



1271
1272
1273
# File 'lib/stripe/services/order_service.rb', line 1271

def tax_code
  @tax_code
end

#urlObject

A URL of a publicly-accessible webpage for this product.



1273
1274
1275
# File 'lib/stripe/services/order_service.rb', line 1273

def url
  @url
end