Class: Stripe::OrderService::UpdateParams::Payment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
Instance Method Summary collapse
-
#initialize(settings: nil) ⇒ Payment
constructor
A new instance of Payment.
Methods inherited from RequestParams
Constructor Details
#initialize(settings: nil) ⇒ Payment
Returns a new instance of Payment.
1929 1930 1931 |
# File 'lib/stripe/services/order_service.rb', line 1929 def initialize(settings: nil) @settings = settings end |
Instance Attribute Details
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
1927 1928 1929 |
# File 'lib/stripe/services/order_service.rb', line 1927 def settings @settings end |