Class: Stripe::OrderService::UpdateParams::Payment::Settings
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment::Settings
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: PaymentMethodOptions, TransferData
Instance Attribute Summary collapse
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#payment_method_options ⇒ Object
PaymentMethod-specific configuration to provide to the order’s PaymentIntent.
-
#payment_method_types ⇒ Object
The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent.
-
#return_url ⇒ Object
The URL to redirect the customer to after they authenticate their payment.
-
#statement_descriptor ⇒ Object
For non-card charges, you can use this value as the complete description that appears on your customers’ statements.
-
#statement_descriptor_suffix ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#transfer_data ⇒ Object
Provides configuration for completing a transfer for the order after it is paid.
Instance Method Summary collapse
-
#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings
constructor
A new instance of Settings.
Methods inherited from RequestParams
Constructor Details
#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings
Returns a new instance of Settings.
1908 1909 1910 1911 1912 1913 1914 1915 1916 1917 1918 1919 1920 1921 1922 1923 1924 |
# File 'lib/stripe/services/order_service.rb', line 1908 def initialize( application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil ) @application_fee_amount = application_fee_amount @payment_method_options = @payment_method_types = payment_method_types @return_url = return_url @statement_descriptor = statement_descriptor @statement_descriptor_suffix = statement_descriptor_suffix @transfer_data = transfer_data end |
Instance Attribute Details
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
1894 1895 1896 |
# File 'lib/stripe/services/order_service.rb', line 1894 def application_fee_amount @application_fee_amount end |
#payment_method_options ⇒ Object
PaymentMethod-specific configuration to provide to the order’s PaymentIntent.
1896 1897 1898 |
# File 'lib/stripe/services/order_service.rb', line 1896 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).
1898 1899 1900 |
# File 'lib/stripe/services/order_service.rb', line 1898 def payment_method_types @payment_method_types end |
#return_url ⇒ Object
The URL to redirect the customer to after they authenticate their payment.
1900 1901 1902 |
# File 'lib/stripe/services/order_service.rb', line 1900 def return_url @return_url end |
#statement_descriptor ⇒ Object
For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.
1902 1903 1904 |
# File 'lib/stripe/services/order_service.rb', line 1902 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.
1904 1905 1906 |
# File 'lib/stripe/services/order_service.rb', line 1904 def statement_descriptor_suffix @statement_descriptor_suffix end |
#transfer_data ⇒ Object
Provides configuration for completing a transfer for the order after it is paid.
1906 1907 1908 |
# File 'lib/stripe/services/order_service.rb', line 1906 def transfer_data @transfer_data end |