Class: Stripe::OrderService::UpdateParams::Payment::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings

Returns a new instance of Settings.



1894
1895
1896
1897
1898
1899
1900
1901
1902
1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/stripe/services/order_service.rb', line 1894

def initialize(
  application_fee_amount: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @application_fee_amount = application_fee_amount
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.



1880
1881
1882
# File 'lib/stripe/services/order_service.rb', line 1880

def application_fee_amount
  @application_fee_amount
end

#payment_method_optionsObject

PaymentMethod-specific configuration to provide to the order’s PaymentIntent.



1882
1883
1884
# File 'lib/stripe/services/order_service.rb', line 1882

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of [payment method types](stripe.com/docs/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



1884
1885
1886
# File 'lib/stripe/services/order_service.rb', line 1884

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect the customer to after they authenticate their payment.



1886
1887
1888
# File 'lib/stripe/services/order_service.rb', line 1886

def return_url
  @return_url
end

#statement_descriptorObject

For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.



1888
1889
1890
# File 'lib/stripe/services/order_service.rb', line 1888

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.



1890
1891
1892
# File 'lib/stripe/services/order_service.rb', line 1890

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Provides configuration for completing a transfer for the order after it is paid.



1892
1893
1894
# File 'lib/stripe/services/order_service.rb', line 1892

def transfer_data
  @transfer_data
end