Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
-
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
-
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
-
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
-
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
-
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
-
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
-
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
-
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
-
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
-
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
-
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
-
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
-
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
-
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 |
# File 'lib/stripe/services/order_service.rb', line 1971 def initialize( acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil ) @acss_debit = acss_debit @afterpay_clearpay = afterpay_clearpay @alipay = alipay @bancontact = bancontact @card = card @customer_balance = customer_balance @ideal = ideal @klarna = klarna @link = link @oxxo = oxxo @p24 = p24 @paypal = paypal @sepa_debit = sepa_debit @sofort = sofort @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
1941 1942 1943 |
# File 'lib/stripe/services/order_service.rb', line 1941 def acss_debit @acss_debit end |
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
1943 1944 1945 |
# File 'lib/stripe/services/order_service.rb', line 1943 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
1945 1946 1947 |
# File 'lib/stripe/services/order_service.rb', line 1945 def alipay @alipay end |
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
1947 1948 1949 |
# File 'lib/stripe/services/order_service.rb', line 1947 def bancontact @bancontact end |
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
1949 1950 1951 |
# File 'lib/stripe/services/order_service.rb', line 1949 def card @card end |
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
1951 1952 1953 |
# File 'lib/stripe/services/order_service.rb', line 1951 def customer_balance @customer_balance end |
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
1953 1954 1955 |
# File 'lib/stripe/services/order_service.rb', line 1953 def ideal @ideal end |
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
1955 1956 1957 |
# File 'lib/stripe/services/order_service.rb', line 1955 def klarna @klarna end |
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
1957 1958 1959 |
# File 'lib/stripe/services/order_service.rb', line 1957 def link @link end |
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
1959 1960 1961 |
# File 'lib/stripe/services/order_service.rb', line 1959 def oxxo @oxxo end |
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
1961 1962 1963 |
# File 'lib/stripe/services/order_service.rb', line 1961 def p24 @p24 end |
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
1963 1964 1965 |
# File 'lib/stripe/services/order_service.rb', line 1963 def paypal @paypal end |
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
1965 1966 1967 |
# File 'lib/stripe/services/order_service.rb', line 1965 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
1967 1968 1969 |
# File 'lib/stripe/services/order_service.rb', line 1967 def sofort @sofort end |
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
1969 1970 1971 |
# File 'lib/stripe/services/order_service.rb', line 1969 def wechat_pay @wechat_pay end |