Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions

Returns a new instance of PaymentMethodOptions.



1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/stripe/services/order_service.rb', line 1847

def initialize(
  acss_debit: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  bancontact: nil,
  card: nil,
  customer_balance: nil,
  ideal: nil,
  klarna: nil,
  link: nil,
  oxxo: nil,
  p24: nil,
  paypal: nil,
  sepa_debit: nil,
  sofort: nil,
  wechat_pay: nil
)
  @acss_debit = acss_debit
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @bancontact = bancontact
  @card = card
  @customer_balance = customer_balance
  @ideal = ideal
  @klarna = klarna
  @link = link
  @oxxo = oxxo
  @p24 = p24
  @paypal = paypal
  @sepa_debit = sepa_debit
  @sofort = sofort
  @wechat_pay = wechat_pay
end

Instance Attribute Details

#acss_debitObject

If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.



1817
1818
1819
# File 'lib/stripe/services/order_service.rb', line 1817

def acss_debit
  @acss_debit
end

#afterpay_clearpayObject

If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.



1819
1820
1821
# File 'lib/stripe/services/order_service.rb', line 1819

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.



1821
1822
1823
# File 'lib/stripe/services/order_service.rb', line 1821

def alipay
  @alipay
end

#bancontactObject

If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.



1823
1824
1825
# File 'lib/stripe/services/order_service.rb', line 1823

def bancontact
  @bancontact
end

#cardObject

If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.



1825
1826
1827
# File 'lib/stripe/services/order_service.rb', line 1825

def card
  @card
end

#customer_balanceObject

If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.



1827
1828
1829
# File 'lib/stripe/services/order_service.rb', line 1827

def customer_balance
  @customer_balance
end

#idealObject

If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.



1829
1830
1831
# File 'lib/stripe/services/order_service.rb', line 1829

def ideal
  @ideal
end

#klarnaObject

If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.



1831
1832
1833
# File 'lib/stripe/services/order_service.rb', line 1831

def klarna
  @klarna
end

If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.



1833
1834
1835
# File 'lib/stripe/services/order_service.rb', line 1833

def link
  @link
end

#oxxoObject

If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.



1835
1836
1837
# File 'lib/stripe/services/order_service.rb', line 1835

def oxxo
  @oxxo
end

#p24Object

If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.



1837
1838
1839
# File 'lib/stripe/services/order_service.rb', line 1837

def p24
  @p24
end

#paypalObject

If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.



1839
1840
1841
# File 'lib/stripe/services/order_service.rb', line 1839

def paypal
  @paypal
end

#sepa_debitObject

If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.



1841
1842
1843
# File 'lib/stripe/services/order_service.rb', line 1841

def sepa_debit
  @sepa_debit
end

#sofortObject

If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.



1843
1844
1845
# File 'lib/stripe/services/order_service.rb', line 1843

def sofort
  @sofort
end

#wechat_payObject

If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.



1845
1846
1847
# File 'lib/stripe/services/order_service.rb', line 1845

def wechat_pay
  @wechat_pay
end