Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
-
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
-
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
-
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
-
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
-
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
-
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
-
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
-
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
-
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
-
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
-
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
-
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
-
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
-
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 |
# File 'lib/stripe/services/order_service.rb', line 1833 def initialize( acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil ) @acss_debit = acss_debit @afterpay_clearpay = afterpay_clearpay @alipay = alipay @bancontact = bancontact @card = card @customer_balance = customer_balance @ideal = ideal @klarna = klarna @link = link @oxxo = oxxo @p24 = p24 @paypal = paypal @sepa_debit = sepa_debit @sofort = sofort @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
1803 1804 1805 |
# File 'lib/stripe/services/order_service.rb', line 1803 def acss_debit @acss_debit end |
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
1805 1806 1807 |
# File 'lib/stripe/services/order_service.rb', line 1805 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
1807 1808 1809 |
# File 'lib/stripe/services/order_service.rb', line 1807 def alipay @alipay end |
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
1809 1810 1811 |
# File 'lib/stripe/services/order_service.rb', line 1809 def bancontact @bancontact end |
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
1811 1812 1813 |
# File 'lib/stripe/services/order_service.rb', line 1811 def card @card end |
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
1813 1814 1815 |
# File 'lib/stripe/services/order_service.rb', line 1813 def customer_balance @customer_balance end |
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
1815 1816 1817 |
# File 'lib/stripe/services/order_service.rb', line 1815 def ideal @ideal end |
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
1817 1818 1819 |
# File 'lib/stripe/services/order_service.rb', line 1817 def klarna @klarna end |
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
1819 1820 1821 |
# File 'lib/stripe/services/order_service.rb', line 1819 def link @link end |
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
1821 1822 1823 |
# File 'lib/stripe/services/order_service.rb', line 1821 def oxxo @oxxo end |
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
1823 1824 1825 |
# File 'lib/stripe/services/order_service.rb', line 1823 def p24 @p24 end |
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
1825 1826 1827 |
# File 'lib/stripe/services/order_service.rb', line 1825 def paypal @paypal end |
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
1827 1828 1829 |
# File 'lib/stripe/services/order_service.rb', line 1827 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
1829 1830 1831 |
# File 'lib/stripe/services/order_service.rb', line 1829 def sofort @sofort end |
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
1831 1832 1833 |
# File 'lib/stripe/services/order_service.rb', line 1831 def wechat_pay @wechat_pay end |