Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: AcssDebit, AfterpayClearpay, Alipay, Bancontact, Card, CustomerBalance, Ideal, Klarna, Link, Oxxo, P24, Paypal, SepaDebit, Sofort, WechatPay
Instance Attribute Summary collapse
-
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
-
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
-
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
-
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
-
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
-
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
-
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
-
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
-
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
-
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
-
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
-
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
-
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
-
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
-
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
Instance Method Summary collapse
-
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
constructor
A new instance of PaymentMethodOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil) ⇒ PaymentMethodOptions
Returns a new instance of PaymentMethodOptions.
2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 2066 2067 2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 2079 2080 2081 2082 2083 2084 2085 |
# File 'lib/stripe/services/order_service.rb', line 2053 def initialize( acss_debit: nil, afterpay_clearpay: nil, alipay: nil, bancontact: nil, card: nil, customer_balance: nil, ideal: nil, klarna: nil, link: nil, oxxo: nil, p24: nil, paypal: nil, sepa_debit: nil, sofort: nil, wechat_pay: nil ) @acss_debit = acss_debit @afterpay_clearpay = afterpay_clearpay @alipay = alipay @bancontact = bancontact @card = card @customer_balance = customer_balance @ideal = ideal @klarna = klarna @link = link @oxxo = oxxo @p24 = p24 @paypal = paypal @sepa_debit = sepa_debit @sofort = sofort @wechat_pay = wechat_pay end |
Instance Attribute Details
#acss_debit ⇒ Object
If paying by ‘acss_debit`, this sub-hash contains details about the ACSS Debit payment method options to pass to the order’s PaymentIntent.
2009 2010 2011 |
# File 'lib/stripe/services/order_service.rb', line 2009 def acss_debit @acss_debit end |
#afterpay_clearpay ⇒ Object
If paying by ‘afterpay_clearpay`, this sub-hash contains details about the AfterpayClearpay payment method options to pass to the order’s PaymentIntent.
2012 2013 2014 |
# File 'lib/stripe/services/order_service.rb', line 2012 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object
If paying by ‘alipay`, this sub-hash contains details about the Alipay payment method options to pass to the order’s PaymentIntent.
2015 2016 2017 |
# File 'lib/stripe/services/order_service.rb', line 2015 def alipay @alipay end |
#bancontact ⇒ Object
If paying by ‘bancontact`, this sub-hash contains details about the Bancontact payment method options to pass to the order’s PaymentIntent.
2018 2019 2020 |
# File 'lib/stripe/services/order_service.rb', line 2018 def bancontact @bancontact end |
#card ⇒ Object
If paying by ‘card`, this sub-hash contains details about the Card payment method options to pass to the order’s PaymentIntent.
2021 2022 2023 |
# File 'lib/stripe/services/order_service.rb', line 2021 def card @card end |
#customer_balance ⇒ Object
If paying by ‘customer_balance`, this sub-hash contains details about the Customer Balance payment method options to pass to the order’s PaymentIntent.
2024 2025 2026 |
# File 'lib/stripe/services/order_service.rb', line 2024 def customer_balance @customer_balance end |
#ideal ⇒ Object
If paying by ‘ideal`, this sub-hash contains details about the iDEAL payment method options to pass to the order’s PaymentIntent.
2027 2028 2029 |
# File 'lib/stripe/services/order_service.rb', line 2027 def ideal @ideal end |
#klarna ⇒ Object
If paying by ‘klarna`, this sub-hash contains details about the Klarna payment method options to pass to the order’s PaymentIntent.
2030 2031 2032 |
# File 'lib/stripe/services/order_service.rb', line 2030 def klarna @klarna end |
#link ⇒ Object
If paying by ‘link`, this sub-hash contains details about the Link payment method options to pass to the order’s PaymentIntent.
2033 2034 2035 |
# File 'lib/stripe/services/order_service.rb', line 2033 def link @link end |
#oxxo ⇒ Object
If paying by ‘oxxo`, this sub-hash contains details about the OXXO payment method options to pass to the order’s PaymentIntent.
2036 2037 2038 |
# File 'lib/stripe/services/order_service.rb', line 2036 def oxxo @oxxo end |
#p24 ⇒ Object
If paying by ‘p24`, this sub-hash contains details about the P24 payment method options to pass to the order’s PaymentIntent.
2039 2040 2041 |
# File 'lib/stripe/services/order_service.rb', line 2039 def p24 @p24 end |
#paypal ⇒ Object
If paying by ‘paypal`, this sub-hash contains details about the PayPal payment method options to pass to the order’s PaymentIntent.
2042 2043 2044 |
# File 'lib/stripe/services/order_service.rb', line 2042 def paypal @paypal end |
#sepa_debit ⇒ Object
If paying by ‘sepa_debit`, this sub-hash contains details about the SEPA Debit payment method options to pass to the order’s PaymentIntent.
2045 2046 2047 |
# File 'lib/stripe/services/order_service.rb', line 2045 def sepa_debit @sepa_debit end |
#sofort ⇒ Object
If paying by ‘sofort`, this sub-hash contains details about the Sofort payment method options to pass to the order’s PaymentIntent.
2048 2049 2050 |
# File 'lib/stripe/services/order_service.rb', line 2048 def sofort @sofort end |
#wechat_pay ⇒ Object
If paying by ‘wechat_pay`, this sub-hash contains details about the WeChat Pay payment method options to pass to the order’s PaymentIntent.
2051 2052 2053 |
# File 'lib/stripe/services/order_service.rb', line 2051 def wechat_pay @wechat_pay end |