Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
1649 1650 1651 1652 1653 1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 |
# File 'lib/stripe/services/order_service.rb', line 1649 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
1633 1634 1635 |
# File 'lib/stripe/services/order_service.rb', line 1633 def category @category end |
#description ⇒ Object
Description of the line item.
1635 1636 1637 |
# File 'lib/stripe/services/order_service.rb', line 1635 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
1637 1638 1639 |
# File 'lib/stripe/services/order_service.rb', line 1637 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
1639 1640 1641 |
# File 'lib/stripe/services/order_service.rb', line 1639 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
1641 1642 1643 |
# File 'lib/stripe/services/order_service.rb', line 1641 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
1643 1644 1645 |
# File 'lib/stripe/services/order_service.rb', line 1643 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
1645 1646 1647 |
# File 'lib/stripe/services/order_service.rb', line 1645 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
1647 1648 1649 |
# File 'lib/stripe/services/order_service.rb', line 1647 def unit_amount @unit_amount end |