Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
1677 1678 1679 1680 1681 1682 1683 1684 1685 1686 1687 1688 1689 1690 1691 1692 1693 1694 1695 |
# File 'lib/stripe/services/order_service.rb', line 1677 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
1661 1662 1663 |
# File 'lib/stripe/services/order_service.rb', line 1661 def category @category end |
#description ⇒ Object
Description of the line item.
1663 1664 1665 |
# File 'lib/stripe/services/order_service.rb', line 1663 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
1665 1666 1667 |
# File 'lib/stripe/services/order_service.rb', line 1665 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
1667 1668 1669 |
# File 'lib/stripe/services/order_service.rb', line 1667 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
1669 1670 1671 |
# File 'lib/stripe/services/order_service.rb', line 1669 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
1671 1672 1673 |
# File 'lib/stripe/services/order_service.rb', line 1671 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
1673 1674 1675 |
# File 'lib/stripe/services/order_service.rb', line 1673 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
1675 1676 1677 |
# File 'lib/stripe/services/order_service.rb', line 1675 def unit_amount @unit_amount end |