Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
# File 'lib/stripe/services/order_service.rb', line 1861

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



1838
1839
1840
# File 'lib/stripe/services/order_service.rb', line 1838

def category
  @category
end

#descriptionObject

Description of the line item.



1841
1842
1843
# File 'lib/stripe/services/order_service.rb', line 1841

def description
  @description
end

#nameObject

Descriptive name of the line item.



1844
1845
1846
# File 'lib/stripe/services/order_service.rb', line 1844

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



1847
1848
1849
# File 'lib/stripe/services/order_service.rb', line 1847

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



1850
1851
1852
# File 'lib/stripe/services/order_service.rb', line 1850

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



1853
1854
1855
# File 'lib/stripe/services/order_service.rb', line 1853

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



1856
1857
1858
# File 'lib/stripe/services/order_service.rb', line 1856

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



1859
1860
1861
# File 'lib/stripe/services/order_service.rb', line 1859

def unit_amount
  @unit_amount
end