Class: Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderService::UpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/services/order_service.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 1684 |
# File 'lib/stripe/services/order_service.rb', line 1666 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
1650 1651 1652 |
# File 'lib/stripe/services/order_service.rb', line 1650 def category @category end |
#description ⇒ Object
Description of the line item.
1652 1653 1654 |
# File 'lib/stripe/services/order_service.rb', line 1652 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
1654 1655 1656 |
# File 'lib/stripe/services/order_service.rb', line 1654 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
1656 1657 1658 |
# File 'lib/stripe/services/order_service.rb', line 1656 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
1658 1659 1660 |
# File 'lib/stripe/services/order_service.rb', line 1658 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
1660 1661 1662 |
# File 'lib/stripe/services/order_service.rb', line 1660 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
1662 1663 1664 |
# File 'lib/stripe/services/order_service.rb', line 1662 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
1664 1665 1666 |
# File 'lib/stripe/services/order_service.rb', line 1664 def unit_amount @unit_amount end |