Class: Stripe::OrderService::UpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1860
1861
1862
1863
# File 'lib/stripe/services/order_service.rb', line 1860

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1856
1857
1858
# File 'lib/stripe/services/order_service.rb', line 1856

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1858
1859
1860
# File 'lib/stripe/services/order_service.rb', line 1858

def destination
  @destination
end