Class: Stripe::OrderService::UpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1888
1889
1890
1891
# File 'lib/stripe/services/order_service.rb', line 1888

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1884
1885
1886
# File 'lib/stripe/services/order_service.rb', line 1884

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1886
1887
1888
# File 'lib/stripe/services/order_service.rb', line 1886

def destination
  @destination
end