Class: Stripe::OrderService::UpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/services/order_service.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



1874
1875
1876
1877
# File 'lib/stripe/services/order_service.rb', line 1874

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



1870
1871
1872
# File 'lib/stripe/services/order_service.rb', line 1870

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



1872
1873
1874
# File 'lib/stripe/services/order_service.rb', line 1872

def destination
  @destination
end