Class: Stripe::OrderUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ OrderUpdateParams
constructor
A new instance of OrderUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ OrderUpdateParams
Returns a new instance of OrderUpdateParams.
2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 2062 2063 |
# File 'lib/stripe/params/order_update_params.rb', line 2033 def initialize( automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
2005 2006 2007 |
# File 'lib/stripe/params/order_update_params.rb', line 2005 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
2007 2008 2009 |
# File 'lib/stripe/params/order_update_params.rb', line 2007 def billing_details @billing_details end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
2009 2010 2011 |
# File 'lib/stripe/params/order_update_params.rb', line 2009 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
2011 2012 2013 |
# File 'lib/stripe/params/order_update_params.rb', line 2011 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
2013 2014 2015 |
# File 'lib/stripe/params/order_update_params.rb', line 2013 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.
2015 2016 2017 |
# File 'lib/stripe/params/order_update_params.rb', line 2015 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
2017 2018 2019 |
# File 'lib/stripe/params/order_update_params.rb', line 2017 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
2019 2020 2021 |
# File 'lib/stripe/params/order_update_params.rb', line 2019 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
2021 2022 2023 |
# File 'lib/stripe/params/order_update_params.rb', line 2021 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
2023 2024 2025 |
# File 'lib/stripe/params/order_update_params.rb', line 2023 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
2025 2026 2027 |
# File 'lib/stripe/params/order_update_params.rb', line 2025 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
2027 2028 2029 |
# File 'lib/stripe/params/order_update_params.rb', line 2027 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
2029 2030 2031 |
# File 'lib/stripe/params/order_update_params.rb', line 2029 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
2031 2032 2033 |
# File 'lib/stripe/params/order_update_params.rb', line 2031 def tax_details @tax_details end |