Class: Stripe::OrderUpdateParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: AutomaticTax, BillingDetails, Discount, LineItem, Payment, ShippingCost, ShippingDetails, TaxDetails
Instance Attribute Summary collapse
-
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
-
#billing_details ⇒ Object
Billing details for the customer.
-
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
The customer associated with this order.
-
#description ⇒ Object
An arbitrary string attached to the object.
-
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#ip_address ⇒ Object
The IP address of the purchaser for this order.
-
#line_items ⇒ Object
A list of line items the customer is ordering.
-
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#payment ⇒ Object
Payment information associated with the order, including payment settings.
-
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
-
#shipping_details ⇒ Object
Shipping details for the order.
-
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
Instance Method Summary collapse
-
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ OrderUpdateParams
constructor
A new instance of OrderUpdateParams.
Methods inherited from RequestParams
Constructor Details
#initialize(automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil) ⇒ OrderUpdateParams
Returns a new instance of OrderUpdateParams.
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 |
# File 'lib/stripe/params/order_update_params.rb', line 1096 def initialize( automatic_tax: nil, billing_details: nil, currency: nil, customer: nil, description: nil, discounts: nil, expand: nil, ip_address: nil, line_items: nil, metadata: nil, payment: nil, shipping_cost: nil, shipping_details: nil, tax_details: nil ) @automatic_tax = automatic_tax @billing_details = billing_details @currency = currency @customer = customer @description = description @discounts = discounts @expand = @ip_address = ip_address @line_items = line_items @metadata = @payment = payment @shipping_cost = shipping_cost @shipping_details = shipping_details @tax_details = tax_details end |
Instance Attribute Details
#automatic_tax ⇒ Object
Settings for automatic tax calculation for this order.
1068 1069 1070 |
# File 'lib/stripe/params/order_update_params.rb', line 1068 def automatic_tax @automatic_tax end |
#billing_details ⇒ Object
Billing details for the customer. If a customer is provided, this will be automatically populated with values from that customer if override values are not provided.
1070 1071 1072 |
# File 'lib/stripe/params/order_update_params.rb', line 1070 def billing_details @billing_details end |
#currency ⇒ Object
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
1072 1073 1074 |
# File 'lib/stripe/params/order_update_params.rb', line 1072 def currency @currency end |
#customer ⇒ Object
The customer associated with this order.
1074 1075 1076 |
# File 'lib/stripe/params/order_update_params.rb', line 1074 def customer @customer end |
#description ⇒ Object
An arbitrary string attached to the object. Often useful for displaying to users.
1076 1077 1078 |
# File 'lib/stripe/params/order_update_params.rb', line 1076 def description @description end |
#discounts ⇒ Object
The coupons, promotion codes, and/or discounts to apply to the order. Pass the empty string ‘“”` to unset this field.
1078 1079 1080 |
# File 'lib/stripe/params/order_update_params.rb', line 1078 def discounts @discounts end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1080 1081 1082 |
# File 'lib/stripe/params/order_update_params.rb', line 1080 def @expand end |
#ip_address ⇒ Object
The IP address of the purchaser for this order.
1082 1083 1084 |
# File 'lib/stripe/params/order_update_params.rb', line 1082 def ip_address @ip_address end |
#line_items ⇒ Object
A list of line items the customer is ordering. Each line item includes information about the product, the quantity, and the resulting cost.
1084 1085 1086 |
# File 'lib/stripe/params/order_update_params.rb', line 1084 def line_items @line_items end |
#metadata ⇒ Object
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1086 1087 1088 |
# File 'lib/stripe/params/order_update_params.rb', line 1086 def @metadata end |
#payment ⇒ Object
Payment information associated with the order, including payment settings.
1088 1089 1090 |
# File 'lib/stripe/params/order_update_params.rb', line 1088 def payment @payment end |
#shipping_cost ⇒ Object
Settings for the customer cost of shipping for this order.
1090 1091 1092 |
# File 'lib/stripe/params/order_update_params.rb', line 1090 def shipping_cost @shipping_cost end |
#shipping_details ⇒ Object
Shipping details for the order.
1092 1093 1094 |
# File 'lib/stripe/params/order_update_params.rb', line 1092 def shipping_details @shipping_details end |
#tax_details ⇒ Object
Additional tax details about the purchaser to be used for this order.
1094 1095 1096 |
# File 'lib/stripe/params/order_update_params.rb', line 1094 def tax_details @tax_details end |