Class: Stripe::OrderUpdateParams::Payment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: Settings
Instance Attribute Summary collapse
-
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
Instance Method Summary collapse
-
#initialize(settings: nil) ⇒ Payment
constructor
A new instance of Payment.
Methods inherited from RequestParams
Constructor Details
#initialize(settings: nil) ⇒ Payment
Returns a new instance of Payment.
889 890 891 |
# File 'lib/stripe/params/order_update_params.rb', line 889 def initialize(settings: nil) @settings = settings end |
Instance Attribute Details
#settings ⇒ Object
Settings describing how the order should configure generated PaymentIntents.
887 888 889 |
# File 'lib/stripe/params/order_update_params.rb', line 887 def settings @settings end |