Class: Stripe::OrderUpdateParams::Payment::Settings

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Defined Under Namespace

Classes: PaymentMethodOptions, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(application_fee_amount: nil, payment_method_options: nil, payment_method_types: nil, return_url: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ Settings

Returns a new instance of Settings.



1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
# File 'lib/stripe/params/order_update_params.rb', line 1846

def initialize(
  application_fee_amount: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  return_url: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @application_fee_amount = application_fee_amount
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @return_url = return_url
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.



1832
1833
1834
# File 'lib/stripe/params/order_update_params.rb', line 1832

def application_fee_amount
  @application_fee_amount
end

#payment_method_optionsObject

PaymentMethod-specific configuration to provide to the order’s PaymentIntent.



1834
1835
1836
# File 'lib/stripe/params/order_update_params.rb', line 1834

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of [payment method types](docs.stripe.com/payments/payment-methods/overview) to provide to the order’s PaymentIntent. Do not include this attribute if you prefer to manage your payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



1836
1837
1838
# File 'lib/stripe/params/order_update_params.rb', line 1836

def payment_method_types
  @payment_method_types
end

#return_urlObject

The URL to redirect the customer to after they authenticate their payment.



1838
1839
1840
# File 'lib/stripe/params/order_update_params.rb', line 1838

def return_url
  @return_url
end

#statement_descriptorObject

For non-card charges, you can use this value as the complete description that appears on your customers’ statements. Must contain at least one letter, maximum 22 characters.



1840
1841
1842
# File 'lib/stripe/params/order_update_params.rb', line 1840

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card payment that customers see on their statements. Concatenated with the prefix (shortened descriptor) or statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters for the concatenated descriptor.



1842
1843
1844
# File 'lib/stripe/params/order_update_params.rb', line 1842

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

Provides configuration for completing a transfer for the order after it is paid.



1844
1845
1846
# File 'lib/stripe/params/order_update_params.rb', line 1844

def transfer_data
  @transfer_data
end