Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: OnDemand, Subscription, SupplementaryPurchaseData
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#on_demand ⇒ Object
On-demand details if setting up or charging an on-demand payment.
-
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
-
#supplementary_purchase_data ⇒ Object
Supplementary Purchase Data for the corresponding Klarna payment.
Instance Method Summary collapse
-
#initialize(capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil, supplementary_purchase_data: nil) ⇒ Klarna
constructor
A new instance of Klarna.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil, supplementary_purchase_data: nil) ⇒ Klarna
Returns a new instance of Klarna.
1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 |
# File 'lib/stripe/params/order_update_params.rb', line 1470 def initialize( capture_method: nil, on_demand: nil, preferred_locale: nil, setup_future_usage: nil, subscriptions: nil, supplementary_purchase_data: nil ) @capture_method = capture_method @on_demand = on_demand @preferred_locale = preferred_locale @setup_future_usage = setup_future_usage @subscriptions = subscriptions @supplementary_purchase_data = supplementary_purchase_data end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
1450 1451 1452 |
# File 'lib/stripe/params/order_update_params.rb', line 1450 def capture_method @capture_method end |
#on_demand ⇒ Object
On-demand details if setting up or charging an on-demand payment.
1452 1453 1454 |
# File 'lib/stripe/params/order_update_params.rb', line 1452 def on_demand @on_demand end |
#preferred_locale ⇒ Object
Preferred language of the Klarna authorization page that the customer is redirected to
1454 1455 1456 |
# File 'lib/stripe/params/order_update_params.rb', line 1454 def preferred_locale @preferred_locale end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
1464 1465 1466 |
# File 'lib/stripe/params/order_update_params.rb', line 1464 def setup_future_usage @setup_future_usage end |
#subscriptions ⇒ Object
Subscription details if setting up or charging a subscription.
1466 1467 1468 |
# File 'lib/stripe/params/order_update_params.rb', line 1466 def subscriptions @subscriptions end |
#supplementary_purchase_data ⇒ Object
Supplementary Purchase Data for the corresponding Klarna payment
1468 1469 1470 |
# File 'lib/stripe/params/order_update_params.rb', line 1468 def supplementary_purchase_data @supplementary_purchase_data end |