Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



482
483
484
485
# File 'lib/stripe/params/order_update_params.rb', line 482

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



478
479
480
# File 'lib/stripe/params/order_update_params.rb', line 478

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



480
481
482
# File 'lib/stripe/params/order_update_params.rb', line 480

def date
  @date
end