Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, new, #to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



472
473
474
475
# File 'lib/stripe/params/order_update_params.rb', line 472

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



468
469
470
# File 'lib/stripe/params/order_update_params.rb', line 468

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



470
471
472
# File 'lib/stripe/params/order_update_params.rb', line 470

def date
  @date
end