Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::BusReservationDetail
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
constructor
A new instance of BusReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ BusReservationDetail
Returns a new instance of BusReservationDetail.
655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/stripe/params/order_update_params.rb', line 655 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
637 638 639 |
# File 'lib/stripe/params/order_update_params.rb', line 637 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
639 640 641 |
# File 'lib/stripe/params/order_update_params.rb', line 639 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
641 642 643 |
# File 'lib/stripe/params/order_update_params.rb', line 641 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
643 644 645 |
# File 'lib/stripe/params/order_update_params.rb', line 643 def currency @currency end |
#departure ⇒ Object
Departure details.
645 646 647 |
# File 'lib/stripe/params/order_update_params.rb', line 645 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
647 648 649 |
# File 'lib/stripe/params/order_update_params.rb', line 647 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
649 650 651 |
# File 'lib/stripe/params/order_update_params.rb', line 649 def passengers @passengers end |
#price ⇒ Object
Price in cents.
651 652 653 |
# File 'lib/stripe/params/order_update_params.rb', line 651 def price @price end |
#ticket_class ⇒ Object
Ticket class.
653 654 655 |
# File 'lib/stripe/params/order_update_params.rb', line 653 def ticket_class @ticket_class end |