Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::RoundTripReservationDetail
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: Arrival, Departure, Insurance, Passenger
Instance Attribute Summary collapse
-
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
-
#arrival ⇒ Object
Arrival details.
-
#carrier_name ⇒ Object
Name of transportation company.
-
#currency ⇒ Object
Currency.
-
#departure ⇒ Object
Departure details.
-
#insurances ⇒ Object
List of insurances for this reservation.
-
#passengers ⇒ Object
List of passengers that this reservation applies to.
-
#price ⇒ Object
Price in cents.
-
#ticket_class ⇒ Object
Ticket class.
Instance Method Summary collapse
-
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ RoundTripReservationDetail
constructor
A new instance of RoundTripReservationDetail.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil) ⇒ RoundTripReservationDetail
Returns a new instance of RoundTripReservationDetail.
1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/stripe/params/order_update_params.rb', line 1191 def initialize( affiliate_name: nil, arrival: nil, carrier_name: nil, currency: nil, departure: nil, insurances: nil, passengers: nil, price: nil, ticket_class: nil ) @affiliate_name = affiliate_name @arrival = arrival @carrier_name = carrier_name @currency = currency @departure = departure @insurances = insurances @passengers = passengers @price = price @ticket_class = ticket_class end |
Instance Attribute Details
#affiliate_name ⇒ Object
Name of associated or partner company for the service.
1173 1174 1175 |
# File 'lib/stripe/params/order_update_params.rb', line 1173 def affiliate_name @affiliate_name end |
#arrival ⇒ Object
Arrival details.
1175 1176 1177 |
# File 'lib/stripe/params/order_update_params.rb', line 1175 def arrival @arrival end |
#carrier_name ⇒ Object
Name of transportation company.
1177 1178 1179 |
# File 'lib/stripe/params/order_update_params.rb', line 1177 def carrier_name @carrier_name end |
#currency ⇒ Object
Currency.
1179 1180 1181 |
# File 'lib/stripe/params/order_update_params.rb', line 1179 def currency @currency end |
#departure ⇒ Object
Departure details.
1181 1182 1183 |
# File 'lib/stripe/params/order_update_params.rb', line 1181 def departure @departure end |
#insurances ⇒ Object
List of insurances for this reservation.
1183 1184 1185 |
# File 'lib/stripe/params/order_update_params.rb', line 1183 def insurances @insurances end |
#passengers ⇒ Object
List of passengers that this reservation applies to.
1185 1186 1187 |
# File 'lib/stripe/params/order_update_params.rb', line 1185 def passengers @passengers end |
#price ⇒ Object
Price in cents.
1187 1188 1189 |
# File 'lib/stripe/params/order_update_params.rb', line 1187 def price @price end |
#ticket_class ⇒ Object
Ticket class.
1189 1190 1191 |
# File 'lib/stripe/params/order_update_params.rb', line 1189 def ticket_class @ticket_class end |