Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Klarna::SupplementaryPurchaseData::TrainReservationDetail::Arrival::Address
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city or town.
-
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
-
#postal_code ⇒ Object
The postal code formatted according to country.
-
#region ⇒ Object
The state, county, province, or region formatted according to country.
-
#street_address ⇒ Object
Line 1 of the street address.
-
#street_address2 ⇒ Object
Line 2 of the street address.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
constructor
A new instance of Address.
Methods inherited from RequestParams
Constructor Details
#initialize(city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil) ⇒ Address
Returns a new instance of Address.
1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 |
# File 'lib/stripe/params/order_update_params.rb', line 1220 def initialize( city: nil, country: nil, postal_code: nil, region: nil, street_address: nil, street_address2: nil ) @city = city @country = country @postal_code = postal_code @region = region @street_address = street_address @street_address2 = street_address2 end |
Instance Attribute Details
#city ⇒ Object
The city or town.
1208 1209 1210 |
# File 'lib/stripe/params/order_update_params.rb', line 1208 def city @city end |
#country ⇒ Object
The country in ISO 3166-1 alpha-2 format.
1210 1211 1212 |
# File 'lib/stripe/params/order_update_params.rb', line 1210 def country @country end |
#postal_code ⇒ Object
The postal code formatted according to country.
1212 1213 1214 |
# File 'lib/stripe/params/order_update_params.rb', line 1212 def postal_code @postal_code end |
#region ⇒ Object
The state, county, province, or region formatted according to country.
1214 1215 1216 |
# File 'lib/stripe/params/order_update_params.rb', line 1214 def region @region end |
#street_address ⇒ Object
Line 1 of the street address.
1216 1217 1218 |
# File 'lib/stripe/params/order_update_params.rb', line 1216 def street_address @street_address end |
#street_address2 ⇒ Object
Line 2 of the street address.
1218 1219 1220 |
# File 'lib/stripe/params/order_update_params.rb', line 1218 def street_address2 @street_address2 end |