Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Paypal

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Defined Under Namespace

Classes: LineItem

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil) ⇒ Paypal

Returns a new instance of Paypal.



1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
# File 'lib/stripe/params/order_update_params.rb', line 1629

def initialize(
  capture_method: nil,
  line_items: nil,
  preferred_locale: nil,
  reference: nil,
  reference_id: nil,
  risk_correlation_id: nil,
  setup_future_usage: nil,
  subsellers: nil
)
  @capture_method = capture_method
  @line_items = line_items
  @preferred_locale = preferred_locale
  @reference = reference
  @reference_id = reference_id
  @risk_correlation_id = risk_correlation_id
  @setup_future_usage = setup_future_usage
  @subsellers = subsellers
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



1605
1606
1607
# File 'lib/stripe/params/order_update_params.rb', line 1605

def capture_method
  @capture_method
end

#line_itemsObject

The line items purchased by the customer.



1607
1608
1609
# File 'lib/stripe/params/order_update_params.rb', line 1607

def line_items
  @line_items
end

#preferred_localeObject

[Preferred locale](docs.stripe.com/payments/paypal/supported-locales) of the PayPal checkout page that the customer is redirected to.



1609
1610
1611
# File 'lib/stripe/params/order_update_params.rb', line 1609

def preferred_locale
  @preferred_locale
end

#referenceObject

A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



1611
1612
1613
# File 'lib/stripe/params/order_update_params.rb', line 1611

def reference
  @reference
end

#reference_idObject

A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.



1613
1614
1615
# File 'lib/stripe/params/order_update_params.rb', line 1613

def reference_id
  @reference_id
end

#risk_correlation_idObject

The risk correlation ID for an on-session payment using a saved PayPal payment method.



1615
1616
1617
# File 'lib/stripe/params/order_update_params.rb', line 1615

def risk_correlation_id
  @risk_correlation_id
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



1625
1626
1627
# File 'lib/stripe/params/order_update_params.rb', line 1625

def setup_future_usage
  @setup_future_usage
end

#subsellersObject

The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.



1627
1628
1629
# File 'lib/stripe/params/order_update_params.rb', line 1627

def subsellers
  @subsellers
end