Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
1615 1616 1617 1618 1619 1620 1621 1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 |
# File 'lib/stripe/params/order_update_params.rb', line 1615 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
1599 1600 1601 |
# File 'lib/stripe/params/order_update_params.rb', line 1599 def category @category end |
#description ⇒ Object
Description of the line item.
1601 1602 1603 |
# File 'lib/stripe/params/order_update_params.rb', line 1601 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
1603 1604 1605 |
# File 'lib/stripe/params/order_update_params.rb', line 1603 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
1605 1606 1607 |
# File 'lib/stripe/params/order_update_params.rb', line 1605 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
1607 1608 1609 |
# File 'lib/stripe/params/order_update_params.rb', line 1607 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
1609 1610 1611 |
# File 'lib/stripe/params/order_update_params.rb', line 1609 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
1611 1612 1613 |
# File 'lib/stripe/params/order_update_params.rb', line 1611 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
1613 1614 1615 |
# File 'lib/stripe/params/order_update_params.rb', line 1613 def unit_amount @unit_amount end |