Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
1584 1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 1598 1599 1600 1601 1602 |
# File 'lib/stripe/params/order_update_params.rb', line 1584 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
1568 1569 1570 |
# File 'lib/stripe/params/order_update_params.rb', line 1568 def category @category end |
#description ⇒ Object
Description of the line item.
1570 1571 1572 |
# File 'lib/stripe/params/order_update_params.rb', line 1570 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
1572 1573 1574 |
# File 'lib/stripe/params/order_update_params.rb', line 1572 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
1574 1575 1576 |
# File 'lib/stripe/params/order_update_params.rb', line 1574 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
1576 1577 1578 |
# File 'lib/stripe/params/order_update_params.rb', line 1576 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
1578 1579 1580 |
# File 'lib/stripe/params/order_update_params.rb', line 1578 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
1580 1581 1582 |
# File 'lib/stripe/params/order_update_params.rb', line 1580 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
1582 1583 1584 |
# File 'lib/stripe/params/order_update_params.rb', line 1582 def unit_amount @unit_amount end |