Class: Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::WechatPay
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::PaymentMethodOptions::WechatPay
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#app_id ⇒ Object
The app ID registered with WeChat Pay.
-
#client ⇒ Object
The client type that the end customer will pay from.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
Instance Method Summary collapse
-
#initialize(app_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay
constructor
A new instance of WechatPay.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(app_id: nil, client: nil, setup_future_usage: nil) ⇒ WechatPay
Returns a new instance of WechatPay.
1717 1718 1719 1720 1721 |
# File 'lib/stripe/params/order_update_params.rb', line 1717 def initialize(app_id: nil, client: nil, setup_future_usage: nil) @app_id = app_id @client = client @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#app_id ⇒ Object
The app ID registered with WeChat Pay. Only required when client is ios, android, or mini_program.
1703 1704 1705 |
# File 'lib/stripe/params/order_update_params.rb', line 1703 def app_id @app_id end |
#client ⇒ Object
The client type that the end customer will pay from
1705 1706 1707 |
# File 'lib/stripe/params/order_update_params.rb', line 1705 def client @client end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent's payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.
If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.
When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.
If you've already set setup_future_usage and you're performing a request using a publishable key, you can only update the value from on_session to off_session.
1715 1716 1717 |
# File 'lib/stripe/params/order_update_params.rb', line 1715 def setup_future_usage @setup_future_usage end |