Class: Stripe::OrderUpdateParams::Payment::Settings::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::Payment::Settings::TransferData
- Defined in:
- lib/stripe/params/order_update_params.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when the order is paid.
-
#destination ⇒ Object
ID of the Connected account receiving the transfer.
Instance Method Summary collapse
-
#initialize(amount: nil, destination: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(amount: nil, destination: nil) ⇒ TransferData
Returns a new instance of TransferData.
1826 1827 1828 1829 |
# File 'lib/stripe/params/order_update_params.rb', line 1826 def initialize(amount: nil, destination: nil) @amount = amount @destination = destination end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.
1822 1823 1824 |
# File 'lib/stripe/params/order_update_params.rb', line 1822 def amount @amount end |
#destination ⇒ Object
ID of the Connected account receiving the transfer.
1824 1825 1826 |
# File 'lib/stripe/params/order_update_params.rb', line 1824 def destination @destination end |