Class: Stripe::OrderUpdateParams::Payment::Settings::TransferData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/order_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, destination: nil) ⇒ TransferData

Returns a new instance of TransferData.



848
849
850
851
# File 'lib/stripe/params/order_update_params.rb', line 848

def initialize(amount: nil, destination: nil)
  @amount = amount
  @destination = destination
end

Instance Attribute Details

#amountObject

The amount that will be transferred automatically when the order is paid. If no amount is set, the full amount is transferred. There cannot be any line items with recurring prices when using this field.



844
845
846
# File 'lib/stripe/params/order_update_params.rb', line 844

def amount
  @amount
end

#destinationObject

ID of the Connected account receiving the transfer.



846
847
848
# File 'lib/stripe/params/order_update_params.rb', line 846

def destination
  @destination
end