Class: Stripe::OrderUpdateParams::ShippingCost::ShippingRateData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::OrderUpdateParams::ShippingCost::ShippingRateData
- Defined in:
- lib/stripe/params/order_update_params.rb
Defined Under Namespace
Classes: DeliveryEstimate, FixedAmount
Instance Attribute Summary collapse
-
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer.
-
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer.
-
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes.
-
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID.
-
#type ⇒ Object
The type of calculation to use on the shipping rate.
Instance Method Summary collapse
-
#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData
constructor
A new instance of ShippingRateData.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil) ⇒ ShippingRateData
Returns a new instance of ShippingRateData.
1918 1919 1920 1921 1922 1923 1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 |
# File 'lib/stripe/params/order_update_params.rb', line 1918 def initialize( delivery_estimate: nil, display_name: nil, fixed_amount: nil, metadata: nil, tax_behavior: nil, tax_code: nil, type: nil ) @delivery_estimate = delivery_estimate @display_name = display_name @fixed_amount = fixed_amount @metadata = @tax_behavior = tax_behavior @tax_code = tax_code @type = type end |
Instance Attribute Details
#delivery_estimate ⇒ Object
The estimated range for how long shipping will take, meant to be displayable to the customer. This will appear on CheckoutSessions.
1904 1905 1906 |
# File 'lib/stripe/params/order_update_params.rb', line 1904 def delivery_estimate @delivery_estimate end |
#display_name ⇒ Object
The name of the shipping rate, meant to be displayable to the customer. This will appear on CheckoutSessions.
1906 1907 1908 |
# File 'lib/stripe/params/order_update_params.rb', line 1906 def display_name @display_name end |
#fixed_amount ⇒ Object
Describes a fixed amount to charge for shipping. Must be present if type is ‘fixed_amount`.
1908 1909 1910 |
# File 'lib/stripe/params/order_update_params.rb', line 1908 def fixed_amount @fixed_amount end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
1910 1911 1912 |
# File 'lib/stripe/params/order_update_params.rb', line 1910 def @metadata end |
#tax_behavior ⇒ Object
Specifies whether the rate is considered inclusive of taxes or exclusive of taxes. One of ‘inclusive`, `exclusive`, or `unspecified`.
1912 1913 1914 |
# File 'lib/stripe/params/order_update_params.rb', line 1912 def tax_behavior @tax_behavior end |
#tax_code ⇒ Object
A [tax code](docs.stripe.com/tax/tax-categories) ID. The Shipping tax code is ‘txcd_92010001`.
1914 1915 1916 |
# File 'lib/stripe/params/order_update_params.rb', line 1914 def tax_code @tax_code end |
#type ⇒ Object
The type of calculation to use on the shipping rate.
1916 1917 1918 |
# File 'lib/stripe/params/order_update_params.rb', line 1916 def type @type end |