Class: Stripe::PaymentAttemptRecord
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentAttemptRecord
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Overview
A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.
Defined Under Namespace
Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, PaymentMethodDetails, ProcessorDetails, ShippingDetails
Constant Summary collapse
- OBJECT_NAME =
"payment_attempt_record"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_authorized ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_canceled ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_failed ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_guaranteed ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_refunded ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_requested ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#application ⇒ Object
readonly
ID of the Connect application that created the PaymentAttemptRecord.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer_details ⇒ Object
readonly
Customer information for this payment.
-
#customer_presence ⇒ Object
readonly
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is
true. -
#metadata ⇒ Object
readonly
Set of key-value pairs that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object's type.
-
#payment_method_details ⇒ Object
readonly
Information about the Payment Method debited for this payment.
-
#payment_record ⇒ Object
readonly
ID of the Payment Record this Payment Attempt Record belongs to.
-
#processor_details ⇒ Object
readonly
Processor information associated with this payment.
-
#reported_by ⇒ Object
readonly
Indicates who reported the payment.
-
#shipping_details ⇒ Object
readonly
Shipping information for this payment.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
List all the Payment Attempt Records attached to the specified Payment Record.
- .object_name ⇒ Object
-
.report_authenticated(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authenticated.
-
.report_authorized(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authorized.
-
.report_canceled(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was canceled.
-
.report_early_fraud_warning(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record received an early fraud warning.
-
.report_failed(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record failed.
-
.report_guaranteed(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was guaranteed.
-
.report_informational(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report informational updates on the specified Payment Attempt Record.
-
.report_refund(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was refunded.
Instance Method Summary collapse
-
#report_authenticated(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authenticated.
-
#report_authorized(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authorized.
-
#report_canceled(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was canceled.
-
#report_early_fraud_warning(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record received an early fraud warning.
-
#report_failed(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record failed.
-
#report_guaranteed(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was guaranteed.
-
#report_informational(params = {}, opts = {}) ⇒ Object
Report informational updates on the specified Payment Attempt Record.
-
#report_refund(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was refunded.
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2338 2339 2340 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2338 def amount @amount end |
#amount_authorized ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2340 2341 2342 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2340 def @amount_authorized end |
#amount_canceled ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2342 2343 2344 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2342 def amount_canceled @amount_canceled end |
#amount_failed ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2344 2345 2346 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2344 def amount_failed @amount_failed end |
#amount_guaranteed ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2346 2347 2348 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2346 def amount_guaranteed @amount_guaranteed end |
#amount_refunded ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2348 2349 2350 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2348 def amount_refunded @amount_refunded end |
#amount_requested ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2350 2351 2352 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2350 def amount_requested @amount_requested end |
#application ⇒ Object (readonly)
ID of the Connect application that created the PaymentAttemptRecord.
2352 2353 2354 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2352 def application @application end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
2354 2355 2356 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2354 def created @created end |
#customer_details ⇒ Object (readonly)
Customer information for this payment.
2356 2357 2358 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2356 def customer_details @customer_details end |
#customer_presence ⇒ Object (readonly)
Indicates whether the customer was present in your checkout flow during this payment.
2358 2359 2360 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2358 def customer_presence @customer_presence end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
2360 2361 2362 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2360 def description @description end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2362 2363 2364 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2362 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.
2364 2365 2366 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2364 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2366 2367 2368 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2366 def @metadata end |
#object ⇒ Object (readonly)
String representing the object's type. Objects of the same type share the same value.
2368 2369 2370 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2368 def object @object end |
#payment_method_details ⇒ Object (readonly)
Information about the Payment Method debited for this payment.
2370 2371 2372 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2370 def payment_method_details @payment_method_details end |
#payment_record ⇒ Object (readonly)
ID of the Payment Record this Payment Attempt Record belongs to.
2372 2373 2374 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2372 def payment_record @payment_record end |
#processor_details ⇒ Object (readonly)
Processor information associated with this payment.
2374 2375 2376 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2374 def processor_details @processor_details end |
#reported_by ⇒ Object (readonly)
Indicates who reported the payment.
2376 2377 2378 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2376 def reported_by @reported_by end |
#shipping_details ⇒ Object (readonly)
Shipping information for this payment.
2378 2379 2380 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2378 def shipping_details @shipping_details end |
Class Method Details
.field_remappings ⇒ Object
2566 2567 2568 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2566 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2550 2551 2552 2553 2554 2555 2556 2557 2558 2559 2560 2561 2562 2563 2564 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2550 def self.inner_class_types @inner_class_types = { amount: Amount, amount_authorized: AmountAuthorized, amount_canceled: AmountCanceled, amount_failed: AmountFailed, amount_guaranteed: AmountGuaranteed, amount_refunded: AmountRefunded, amount_requested: AmountRequested, customer_details: CustomerDetails, payment_method_details: PaymentMethodDetails, processor_details: ProcessorDetails, shipping_details: ShippingDetails, } end |
.list(params = {}, opts = {}) ⇒ Object
List all the Payment Attempt Records attached to the specified Payment Record.
2381 2382 2383 2384 2385 2386 2387 2388 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2381 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_attempt_records", params: params, opts: opts ) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 13 def self.object_name "payment_attempt_record" end |
.report_authenticated(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authenticated.
2401 2402 2403 2404 2405 2406 2407 2408 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2401 def self.report_authenticated(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authenticated", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_authorized(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authorized.
2421 2422 2423 2424 2425 2426 2427 2428 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2421 def self.(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authorized", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_canceled(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was canceled.
2441 2442 2443 2444 2445 2446 2447 2448 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2441 def self.report_canceled(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_canceled", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_early_fraud_warning(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record received an early fraud warning.
2461 2462 2463 2464 2465 2466 2467 2468 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2461 def self.report_early_fraud_warning(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_early_fraud_warning", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_failed(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record failed.
2481 2482 2483 2484 2485 2486 2487 2488 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2481 def self.report_failed(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_failed", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_guaranteed(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was guaranteed.
2501 2502 2503 2504 2505 2506 2507 2508 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2501 def self.report_guaranteed(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_guaranteed", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_informational(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report informational updates on the specified Payment Attempt Record.
2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2521 def self.report_informational(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_informational", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_refund(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was refunded.
2541 2542 2543 2544 2545 2546 2547 2548 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2541 def self.report_refund(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_refund", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
Instance Method Details
#report_authenticated(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authenticated.
2391 2392 2393 2394 2395 2396 2397 2398 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2391 def report_authenticated(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authenticated", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_authorized(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authorized.
2411 2412 2413 2414 2415 2416 2417 2418 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2411 def (params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authorized", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_canceled(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was canceled.
2431 2432 2433 2434 2435 2436 2437 2438 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2431 def report_canceled(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_canceled", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_early_fraud_warning(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record received an early fraud warning.
2451 2452 2453 2454 2455 2456 2457 2458 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2451 def report_early_fraud_warning(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_early_fraud_warning", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_failed(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record failed.
2471 2472 2473 2474 2475 2476 2477 2478 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2471 def report_failed(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_failed", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_guaranteed(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was guaranteed.
2491 2492 2493 2494 2495 2496 2497 2498 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2491 def report_guaranteed(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_guaranteed", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_informational(params = {}, opts = {}) ⇒ Object
Report informational updates on the specified Payment Attempt Record.
2511 2512 2513 2514 2515 2516 2517 2518 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2511 def report_informational(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_informational", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_refund(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was refunded.
2531 2532 2533 2534 2535 2536 2537 2538 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2531 def report_refund(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_refund", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |