Class: Stripe::PaymentAttemptRecord
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentAttemptRecord
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Overview
A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.
Defined Under Namespace
Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, PaymentMethodDetails, ProcessorDetails, ShippingDetails
Constant Summary collapse
- OBJECT_NAME =
"payment_attempt_record"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_authorized ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_canceled ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_failed ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_guaranteed ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_refunded ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_requested ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#application ⇒ Object
readonly
ID of the Connect application that created the PaymentAttemptRecord.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer_details ⇒ Object
readonly
Customer information for this payment.
-
#customer_presence ⇒ Object
readonly
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_details ⇒ Object
readonly
Information about the Payment Method debited for this payment.
-
#payment_record ⇒ Object
readonly
ID of the Payment Record this Payment Attempt Record belongs to.
-
#processor_details ⇒ Object
readonly
Processor information associated with this payment.
-
#reported_by ⇒ Object
readonly
Indicates who reported the payment.
-
#shipping_details ⇒ Object
readonly
Shipping information for this payment.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
List all the Payment Attempt Records attached to the specified Payment Record.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1988 1989 1990 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1988 def amount @amount end |
#amount_authorized ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1990 1991 1992 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1990 def @amount_authorized end |
#amount_canceled ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1992 1993 1994 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1992 def amount_canceled @amount_canceled end |
#amount_failed ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1994 1995 1996 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1994 def amount_failed @amount_failed end |
#amount_guaranteed ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1996 1997 1998 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1996 def amount_guaranteed @amount_guaranteed end |
#amount_refunded ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1998 1999 2000 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1998 def amount_refunded @amount_refunded end |
#amount_requested ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2000 2001 2002 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2000 def amount_requested @amount_requested end |
#application ⇒ Object (readonly)
ID of the Connect application that created the PaymentAttemptRecord.
2002 2003 2004 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2002 def application @application end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
2004 2005 2006 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2004 def created @created end |
#customer_details ⇒ Object (readonly)
Customer information for this payment.
2006 2007 2008 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2006 def customer_details @customer_details end |
#customer_presence ⇒ Object (readonly)
Indicates whether the customer was present in your checkout flow during this payment.
2008 2009 2010 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2008 def customer_presence @customer_presence end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
2010 2011 2012 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2010 def description @description end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2012 2013 2014 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2012 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
2014 2015 2016 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2014 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2016 2017 2018 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2016 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
2018 2019 2020 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2018 def object @object end |
#payment_method_details ⇒ Object (readonly)
Information about the Payment Method debited for this payment.
2020 2021 2022 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2020 def payment_method_details @payment_method_details end |
#payment_record ⇒ Object (readonly)
ID of the Payment Record this Payment Attempt Record belongs to.
2022 2023 2024 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2022 def payment_record @payment_record end |
#processor_details ⇒ Object (readonly)
Processor information associated with this payment.
2024 2025 2026 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2024 def processor_details @processor_details end |
#reported_by ⇒ Object (readonly)
Indicates who reported the payment.
2026 2027 2028 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2026 def reported_by @reported_by end |
#shipping_details ⇒ Object (readonly)
Shipping information for this payment.
2028 2029 2030 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2028 def shipping_details @shipping_details end |
Class Method Details
.field_remappings ⇒ Object
2056 2057 2058 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2056 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 2053 2054 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2040 def self.inner_class_types @inner_class_types = { amount: Amount, amount_authorized: AmountAuthorized, amount_canceled: AmountCanceled, amount_failed: AmountFailed, amount_guaranteed: AmountGuaranteed, amount_refunded: AmountRefunded, amount_requested: AmountRequested, customer_details: CustomerDetails, payment_method_details: PaymentMethodDetails, processor_details: ProcessorDetails, shipping_details: ShippingDetails, } end |
.list(params = {}, opts = {}) ⇒ Object
List all the Payment Attempt Records attached to the specified Payment Record.
2031 2032 2033 2034 2035 2036 2037 2038 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2031 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_attempt_records", params: params, opts: opts ) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 13 def self.object_name "payment_attempt_record" end |