Class: Stripe::PaymentAttemptRecord
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentAttemptRecord
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Overview
A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.
Defined Under Namespace
Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, PaymentMethodDetails, ProcessorDetails, ShippingDetails
Constant Summary collapse
- OBJECT_NAME =
"payment_attempt_record"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_authorized ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_canceled ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_failed ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_guaranteed ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_refunded ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_requested ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#application ⇒ Object
readonly
ID of the Connect application that created the PaymentAttemptRecord.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer_details ⇒ Object
readonly
Customer information for this payment.
-
#customer_presence ⇒ Object
readonly
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
If the object exists in live mode, the value is ‘true`.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_details ⇒ Object
readonly
Information about the Payment Method debited for this payment.
-
#payment_record ⇒ Object
readonly
ID of the Payment Record this Payment Attempt Record belongs to.
-
#processor_details ⇒ Object
readonly
Processor information associated with this payment.
-
#reported_by ⇒ Object
readonly
Indicates who reported the payment.
-
#shipping_details ⇒ Object
readonly
Shipping information for this payment.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
- .field_remappings ⇒ Object
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
List all the Payment Attempt Records attached to the specified Payment Record.
- .object_name ⇒ Object
-
.report_authenticated(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authenticated.
-
.report_authorized(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authorized.
-
.report_canceled(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was canceled.
-
.report_failed(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record failed.
-
.report_guaranteed(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was guaranteed.
-
.report_informational(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report informational updates on the specified Payment Attempt Record.
-
.report_refund(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was refunded.
Instance Method Summary collapse
-
#report_authenticated(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authenticated.
-
#report_authorized(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authorized.
-
#report_canceled(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was canceled.
-
#report_failed(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record failed.
-
#report_guaranteed(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was guaranteed.
-
#report_informational(params = {}, opts = {}) ⇒ Object
Report informational updates on the specified Payment Attempt Record.
-
#report_refund(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was refunded.
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2138 2139 2140 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2138 def amount @amount end |
#amount_authorized ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2140 2141 2142 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2140 def @amount_authorized end |
#amount_canceled ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2142 2143 2144 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2142 def amount_canceled @amount_canceled end |
#amount_failed ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2144 2145 2146 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2144 def amount_failed @amount_failed end |
#amount_guaranteed ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2146 2147 2148 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2146 def amount_guaranteed @amount_guaranteed end |
#amount_refunded ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2148 2149 2150 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2148 def amount_refunded @amount_refunded end |
#amount_requested ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
2150 2151 2152 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2150 def amount_requested @amount_requested end |
#application ⇒ Object (readonly)
ID of the Connect application that created the PaymentAttemptRecord.
2152 2153 2154 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2152 def application @application end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
2154 2155 2156 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2154 def created @created end |
#customer_details ⇒ Object (readonly)
Customer information for this payment.
2156 2157 2158 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2156 def customer_details @customer_details end |
#customer_presence ⇒ Object (readonly)
Indicates whether the customer was present in your checkout flow during this payment.
2158 2159 2160 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2158 def customer_presence @customer_presence end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
2160 2161 2162 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2160 def description @description end |
#id ⇒ Object (readonly)
Unique identifier for the object.
2162 2163 2164 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2162 def id @id end |
#livemode ⇒ Object (readonly)
If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.
2164 2165 2166 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2164 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
2166 2167 2168 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2166 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
2168 2169 2170 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2168 def object @object end |
#payment_method_details ⇒ Object (readonly)
Information about the Payment Method debited for this payment.
2170 2171 2172 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2170 def payment_method_details @payment_method_details end |
#payment_record ⇒ Object (readonly)
ID of the Payment Record this Payment Attempt Record belongs to.
2172 2173 2174 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2172 def payment_record @payment_record end |
#processor_details ⇒ Object (readonly)
Processor information associated with this payment.
2174 2175 2176 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2174 def processor_details @processor_details end |
#reported_by ⇒ Object (readonly)
Indicates who reported the payment.
2176 2177 2178 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2176 def reported_by @reported_by end |
#shipping_details ⇒ Object (readonly)
Shipping information for this payment.
2178 2179 2180 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2178 def shipping_details @shipping_details end |
Class Method Details
.field_remappings ⇒ Object
2346 2347 2348 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2346 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 2344 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2330 def self.inner_class_types @inner_class_types = { amount: Amount, amount_authorized: AmountAuthorized, amount_canceled: AmountCanceled, amount_failed: AmountFailed, amount_guaranteed: AmountGuaranteed, amount_refunded: AmountRefunded, amount_requested: AmountRequested, customer_details: CustomerDetails, payment_method_details: PaymentMethodDetails, processor_details: ProcessorDetails, shipping_details: ShippingDetails, } end |
.list(params = {}, opts = {}) ⇒ Object
List all the Payment Attempt Records attached to the specified Payment Record.
2181 2182 2183 2184 2185 2186 2187 2188 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2181 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_attempt_records", params: params, opts: opts ) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 13 def self.object_name "payment_attempt_record" end |
.report_authenticated(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authenticated.
2201 2202 2203 2204 2205 2206 2207 2208 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2201 def self.report_authenticated(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authenticated", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_authorized(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authorized.
2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2221 def self.(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authorized", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_canceled(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was canceled.
2241 2242 2243 2244 2245 2246 2247 2248 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2241 def self.report_canceled(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_canceled", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_failed(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record failed.
2261 2262 2263 2264 2265 2266 2267 2268 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2261 def self.report_failed(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_failed", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_guaranteed(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was guaranteed.
2281 2282 2283 2284 2285 2286 2287 2288 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2281 def self.report_guaranteed(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_guaranteed", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_informational(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report informational updates on the specified Payment Attempt Record.
2301 2302 2303 2304 2305 2306 2307 2308 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2301 def self.report_informational(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_informational", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
.report_refund(payment_attempt_record, params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was refunded.
2321 2322 2323 2324 2325 2326 2327 2328 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2321 def self.report_refund(payment_attempt_record, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_refund", { payment_attempt_record: CGI.escape(payment_attempt_record) }), params: params, opts: opts ) end |
Instance Method Details
#report_authenticated(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authenticated.
2191 2192 2193 2194 2195 2196 2197 2198 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2191 def report_authenticated(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authenticated", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_authorized(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was authorized.
2211 2212 2213 2214 2215 2216 2217 2218 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2211 def (params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authorized", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_canceled(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was canceled.
2231 2232 2233 2234 2235 2236 2237 2238 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2231 def report_canceled(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_canceled", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_failed(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record failed.
2251 2252 2253 2254 2255 2256 2257 2258 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2251 def report_failed(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_failed", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_guaranteed(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was guaranteed.
2271 2272 2273 2274 2275 2276 2277 2278 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2271 def report_guaranteed(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_guaranteed", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_informational(params = {}, opts = {}) ⇒ Object
Report informational updates on the specified Payment Attempt Record.
2291 2292 2293 2294 2295 2296 2297 2298 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2291 def report_informational(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_informational", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#report_refund(params = {}, opts = {}) ⇒ Object
Report that the specified Payment Attempt Record was refunded.
2311 2312 2313 2314 2315 2316 2317 2318 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2311 def report_refund(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_refund", { payment_attempt_record: CGI.escape(self["id"]) }), params: params, opts: opts ) end |