Class: Stripe::PaymentAttemptRecord

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Overview

A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.

Defined Under Namespace

Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Constant Summary collapse

OBJECT_NAME =
"payment_attempt_record"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2119
2120
2121
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2119

def amount
  @amount
end

#amount_authorizedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2121
2122
2123
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2121

def amount_authorized
  @amount_authorized
end

#amount_canceledObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2123
2124
2125
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2123

def amount_canceled
  @amount_canceled
end

#amount_failedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2125
2126
2127
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2125

def amount_failed
  @amount_failed
end

#amount_guaranteedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2127
2128
2129
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2127

def amount_guaranteed
  @amount_guaranteed
end

#amount_refundedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2129
2130
2131
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2129

def amount_refunded
  @amount_refunded
end

#amount_requestedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2131
2132
2133
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2131

def amount_requested
  @amount_requested
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentAttemptRecord.



2133
2134
2135
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2133

def application
  @application
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2135
2136
2137
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2135

def created
  @created
end

#customer_detailsObject (readonly)

Customer information for this payment.



2137
2138
2139
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2137

def customer_details
  @customer_details
end

#customer_presenceObject (readonly)

Indicates whether the customer was present in your checkout flow during this payment.



2139
2140
2141
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2139

def customer_presence
  @customer_presence
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



2141
2142
2143
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2141

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



2143
2144
2145
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2143

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2145
2146
2147
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2145

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2147
2148
2149
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2147

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2149
2150
2151
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2149

def object
  @object
end

#payment_method_detailsObject (readonly)

Information about the Payment Method debited for this payment.



2151
2152
2153
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2151

def payment_method_details
  @payment_method_details
end

#payment_recordObject (readonly)

ID of the Payment Record this Payment Attempt Record belongs to.



2153
2154
2155
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2153

def payment_record
  @payment_record
end

#processor_detailsObject (readonly)

Processor information associated with this payment.



2155
2156
2157
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2155

def processor_details
  @processor_details
end

#reported_byObject (readonly)

Indicates who reported the payment.



2157
2158
2159
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2157

def reported_by
  @reported_by
end

#shipping_detailsObject (readonly)

Shipping information for this payment.



2159
2160
2161
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2159

def shipping_details
  @shipping_details
end

Class Method Details

.field_remappingsObject



2187
2188
2189
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2187

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2171
2172
2173
2174
2175
2176
2177
2178
2179
2180
2181
2182
2183
2184
2185
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2171

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    amount_authorized: AmountAuthorized,
    amount_canceled: AmountCanceled,
    amount_failed: AmountFailed,
    amount_guaranteed: AmountGuaranteed,
    amount_refunded: AmountRefunded,
    amount_requested: AmountRequested,
    customer_details: CustomerDetails,
    payment_method_details: PaymentMethodDetails,
    processor_details: ProcessorDetails,
    shipping_details: ShippingDetails,
  }
end

.list(params = {}, opts = {}) ⇒ Object

List all the Payment Attempt Records attached to the specified Payment Record.



2162
2163
2164
2165
2166
2167
2168
2169
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2162

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_attempt_records",
    params: params,
    opts: opts
  )
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/payment_attempt_record.rb', line 13

def self.object_name
  "payment_attempt_record"
end