Class: Stripe::PaymentAttemptRecord

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Overview

A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.

Defined Under Namespace

Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Constant Summary collapse

OBJECT_NAME =
"payment_attempt_record"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2030
2031
2032
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2030

def amount
  @amount
end

#amount_authorizedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2032
2033
2034
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2032

def amount_authorized
  @amount_authorized
end

#amount_canceledObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2034
2035
2036
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2034

def amount_canceled
  @amount_canceled
end

#amount_failedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2036
2037
2038
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2036

def amount_failed
  @amount_failed
end

#amount_guaranteedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2038
2039
2040
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2038

def amount_guaranteed
  @amount_guaranteed
end

#amount_refundedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2040
2041
2042
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2040

def amount_refunded
  @amount_refunded
end

#amount_requestedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



2042
2043
2044
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2042

def amount_requested
  @amount_requested
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentAttemptRecord.



2044
2045
2046
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2044

def application
  @application
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



2046
2047
2048
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2046

def created
  @created
end

#customer_detailsObject (readonly)

Customer information for this payment.



2048
2049
2050
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2048

def customer_details
  @customer_details
end

#customer_presenceObject (readonly)

Indicates whether the customer was present in your checkout flow during this payment.



2050
2051
2052
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2050

def customer_presence
  @customer_presence
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



2052
2053
2054
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2052

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



2054
2055
2056
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2054

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



2056
2057
2058
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2056

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



2058
2059
2060
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2058

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



2060
2061
2062
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2060

def object
  @object
end

#payment_method_detailsObject (readonly)

Information about the Payment Method debited for this payment.



2062
2063
2064
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2062

def payment_method_details
  @payment_method_details
end

#payment_recordObject (readonly)

ID of the Payment Record this Payment Attempt Record belongs to.



2064
2065
2066
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2064

def payment_record
  @payment_record
end

#processor_detailsObject (readonly)

Processor information associated with this payment.



2066
2067
2068
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2066

def processor_details
  @processor_details
end

#reported_byObject (readonly)

Indicates who reported the payment.



2068
2069
2070
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2068

def reported_by
  @reported_by
end

#shipping_detailsObject (readonly)

Shipping information for this payment.



2070
2071
2072
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2070

def shipping_details
  @shipping_details
end

Class Method Details

.field_remappingsObject



2098
2099
2100
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2098

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2082

def self.inner_class_types
  @inner_class_types = {
    amount: Amount,
    amount_authorized: AmountAuthorized,
    amount_canceled: AmountCanceled,
    amount_failed: AmountFailed,
    amount_guaranteed: AmountGuaranteed,
    amount_refunded: AmountRefunded,
    amount_requested: AmountRequested,
    customer_details: CustomerDetails,
    payment_method_details: PaymentMethodDetails,
    processor_details: ProcessorDetails,
    shipping_details: ShippingDetails,
  }
end

.list(params = {}, opts = {}) ⇒ Object

List all the Payment Attempt Records attached to the specified Payment Record.



2073
2074
2075
2076
2077
2078
2079
2080
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2073

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_attempt_records",
    params: params,
    opts: opts
  )
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/payment_attempt_record.rb', line 13

def self.object_name
  "payment_attempt_record"
end