Class: Stripe::PaymentAttemptRecord

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Overview

A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.

Defined Under Namespace

Classes: Amount, AmountAuthorized, AmountCanceled, AmountFailed, AmountGuaranteed, AmountRefunded, AmountRequested, CustomerDetails, ListParams, PaymentMethodDetails, ProcessorDetails, ShippingDetails

Constant Summary collapse

OBJECT_NAME =
"payment_attempt_record"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1125
1126
1127
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1125

def amount
  @amount
end

#amount_authorizedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1127
1128
1129
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1127

def amount_authorized
  @amount_authorized
end

#amount_canceledObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1129
1130
1131
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1129

def amount_canceled
  @amount_canceled
end

#amount_failedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1131
1132
1133
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1131

def amount_failed
  @amount_failed
end

#amount_guaranteedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1133
1134
1135
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1133

def amount_guaranteed
  @amount_guaranteed
end

#amount_refundedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1135
1136
1137
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1135

def amount_refunded
  @amount_refunded
end

#amount_requestedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1137
1138
1139
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1137

def amount_requested
  @amount_requested
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentAttemptRecord.



1139
1140
1141
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1139

def application
  @application
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1141
1142
1143
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1141

def created
  @created
end

#customer_detailsObject (readonly)

Customer information for this payment.



1143
1144
1145
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1143

def customer_details
  @customer_details
end

#customer_presenceObject (readonly)

Indicates whether the customer was present in your checkout flow during this payment.



1145
1146
1147
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1145

def customer_presence
  @customer_presence
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



1147
1148
1149
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1147

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



1149
1150
1151
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1149

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1151
1152
1153
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1151

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1153
1154
1155
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1153

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1155
1156
1157
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1155

def object
  @object
end

#payment_method_detailsObject (readonly)

Information about the Payment Method debited for this payment.



1157
1158
1159
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1157

def payment_method_details
  @payment_method_details
end

#payment_recordObject (readonly)

ID of the Payment Record this Payment Attempt Record belongs to.



1159
1160
1161
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1159

def payment_record
  @payment_record
end

#processor_detailsObject (readonly)

Processor information associated with this payment.



1161
1162
1163
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1161

def processor_details
  @processor_details
end

#reported_byObject (readonly)

Indicates who reported the payment.



1163
1164
1165
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1163

def reported_by
  @reported_by
end

#shipping_detailsObject (readonly)

Shipping information for this payment.



1165
1166
1167
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1165

def shipping_details
  @shipping_details
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

List all the Payment Attempt Records attached to the specified Payment Record.



1168
1169
1170
1171
1172
1173
1174
1175
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1168

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_attempt_records",
    params: params,
    opts: opts
  )
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/payment_attempt_record.rb', line 13

def self.object_name
  "payment_attempt_record"
end