Class: Stripe::PaymentAttemptRecord
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentAttemptRecord
- Extended by:
- APIOperations::List
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Overview
A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.
Defined Under Namespace
Classes: AmountCanceled, AmountFailed, AmountGuaranteed, AmountRequested, CustomerDetails, ListParams, PaymentMethodDetails, ShippingDetails
Constant Summary collapse
- OBJECT_NAME =
"payment_attempt_record"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount_canceled ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_failed ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_guaranteed ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#amount_requested ⇒ Object
readonly
A representation of an amount of money, consisting of an amount and a currency.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#customer_details ⇒ Object
readonly
Customer information for this payment.
-
#customer_presence ⇒ Object
readonly
Indicates whether the customer was present in your checkout flow during this payment.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#payment_method_details ⇒ Object
readonly
Information about the Payment Method debited for this payment.
-
#payment_record ⇒ Object
readonly
ID of the Payment Record this Payment Attempt Record belongs to.
-
#payment_reference ⇒ Object
readonly
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
-
#reported_by ⇒ Object
readonly
Indicates who reported the payment.
-
#shipping_details ⇒ Object
readonly
Shipping information for this payment.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.list(params = {}, opts = {}) ⇒ Object
List all the Payment Attempt Records attached to the specified Payment Record.
- .object_name ⇒ Object
Methods included from APIOperations::List
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount_canceled ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1057 1058 1059 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1057 def amount_canceled @amount_canceled end |
#amount_failed ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1059 1060 1061 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1059 def amount_failed @amount_failed end |
#amount_guaranteed ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1061 1062 1063 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1061 def amount_guaranteed @amount_guaranteed end |
#amount_requested ⇒ Object (readonly)
A representation of an amount of money, consisting of an amount and a currency.
1063 1064 1065 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1063 def amount_requested @amount_requested end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
1065 1066 1067 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1065 def created @created end |
#customer_details ⇒ Object (readonly)
Customer information for this payment.
1067 1068 1069 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1067 def customer_details @customer_details end |
#customer_presence ⇒ Object (readonly)
Indicates whether the customer was present in your checkout flow during this payment.
1069 1070 1071 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1069 def customer_presence @customer_presence end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
1071 1072 1073 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1071 def description @description end |
#id ⇒ Object (readonly)
Unique identifier for the object.
1073 1074 1075 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1073 def id @id end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
1075 1076 1077 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1075 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
1077 1078 1079 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1077 def @metadata end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
1079 1080 1081 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1079 def object @object end |
#payment_method_details ⇒ Object (readonly)
Information about the Payment Method debited for this payment.
1081 1082 1083 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1081 def payment_method_details @payment_method_details end |
#payment_record ⇒ Object (readonly)
ID of the Payment Record this Payment Attempt Record belongs to.
1083 1084 1085 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1083 def payment_record @payment_record end |
#payment_reference ⇒ Object (readonly)
An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.
1085 1086 1087 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1085 def payment_reference @payment_reference end |
#reported_by ⇒ Object (readonly)
Indicates who reported the payment.
1087 1088 1089 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1087 def reported_by @reported_by end |
#shipping_details ⇒ Object (readonly)
Shipping information for this payment.
1089 1090 1091 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1089 def shipping_details @shipping_details end |
Class Method Details
.list(params = {}, opts = {}) ⇒ Object
List all the Payment Attempt Records attached to the specified Payment Record.
1092 1093 1094 1095 1096 1097 1098 1099 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1092 def self.list(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_attempt_records", params: params, opts: opts ) end |
.object_name ⇒ Object
13 14 15 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 13 def self.object_name "payment_attempt_record" end |