Class: Stripe::PaymentAttemptRecord

Inherits:
APIResource show all
Extended by:
APIOperations::List
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Overview

A Payment Attempt Record represents an individual attempt at making a payment, on or off Stripe. Each payment attempt tries to collect a fixed amount of money from a fixed customer and payment method. Payment Attempt Records are attached to Payment Records. Only one attempt per Payment Record can have guaranteed funds.

Defined Under Namespace

Classes: AmountCanceled, AmountFailed, AmountGuaranteed, AmountRequested, CustomerDetails, ListParams, PaymentMethodDetails, ShippingDetails

Constant Summary collapse

OBJECT_NAME =
"payment_attempt_record"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods included from APIOperations::List

list

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_canceledObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1034
1035
1036
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1034

def amount_canceled
  @amount_canceled
end

#amount_failedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1036
1037
1038
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1036

def amount_failed
  @amount_failed
end

#amount_guaranteedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1038
1039
1040
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1038

def amount_guaranteed
  @amount_guaranteed
end

#amount_requestedObject (readonly)

A representation of an amount of money, consisting of an amount and a currency.



1040
1041
1042
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1040

def amount_requested
  @amount_requested
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



1042
1043
1044
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1042

def created
  @created
end

#customer_detailsObject (readonly)

Customer information for this payment.



1044
1045
1046
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1044

def customer_details
  @customer_details
end

#customer_presenceObject (readonly)

Indicates whether the customer was present in your checkout flow during this payment.



1046
1047
1048
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1046

def customer_presence
  @customer_presence
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



1048
1049
1050
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1048

def description
  @description
end

#idObject (readonly)

Unique identifier for the object.



1050
1051
1052
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1050

def id
  @id
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



1052
1053
1054
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1052

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.



1054
1055
1056
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1054

def 
  @metadata
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



1056
1057
1058
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1056

def object
  @object
end

#payment_method_detailsObject (readonly)

Information about the Payment Method debited for this payment.



1058
1059
1060
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1058

def payment_method_details
  @payment_method_details
end

#payment_recordObject (readonly)

ID of the Payment Record this Payment Attempt Record belongs to.



1060
1061
1062
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1060

def payment_record
  @payment_record
end

#payment_referenceObject (readonly)

An opaque string for manual reconciliation of this payment, for example a check number or a payment processor ID.



1062
1063
1064
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1062

def payment_reference
  @payment_reference
end

#reported_byObject (readonly)

Indicates who reported the payment.



1064
1065
1066
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1064

def reported_by
  @reported_by
end

#shipping_detailsObject (readonly)

Shipping information for this payment.



1066
1067
1068
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1066

def shipping_details
  @shipping_details
end

Class Method Details

.list(params = {}, opts = {}) ⇒ Object

List all the Payment Attempt Records attached to the specified Payment Record.



1069
1070
1071
1072
1073
1074
1075
1076
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1069

def self.list(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_attempt_records",
    params: params,
    opts: opts
  )
end

.object_nameObject



13
14
15
# File 'lib/stripe/resources/payment_attempt_record.rb', line 13

def self.object_name
  "payment_attempt_record"
end