Class: Stripe::PaymentAttemptRecord::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecord::ListParams
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_record ⇒ Object
The ID of the Payment Record.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, payment_record: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, payment_record: nil) ⇒ ListParams
Returns a new instance of ListParams.
1977 1978 1979 1980 1981 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1977 def initialize(expand: nil, limit: nil, payment_record: nil) @expand = @limit = limit @payment_record = payment_record end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1971 1972 1973 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1971 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1973 1974 1975 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1973 def limit @limit end |
#payment_record ⇒ Object
The ID of the Payment Record.
1975 1976 1977 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1975 def payment_record @payment_record end |