Class: Stripe::PaymentAttemptRecord::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecord::ListParams
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#limit ⇒ Object
A limit on the number of objects to be returned.
-
#payment_record ⇒ Object
The ID of the Payment Record.
Instance Method Summary collapse
-
#initialize(expand: nil, limit: nil, payment_record: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, limit: nil, payment_record: nil) ⇒ ListParams
Returns a new instance of ListParams.
1118 1119 1120 1121 1122 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1118 def initialize(expand: nil, limit: nil, payment_record: nil) @expand = @limit = limit @payment_record = payment_record end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1112 1113 1114 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1112 def @expand end |
#limit ⇒ Object
A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
1114 1115 1116 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1114 def limit @limit end |
#payment_record ⇒ Object
The ID of the Payment Record.
1116 1117 1118 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1116 def payment_record @payment_record end |