Class: Stripe::PaymentAttemptRecord::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecord::ListParams
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_record ⇒ Object
The ID of the Payment Record.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_record: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_record: nil) ⇒ ListParams
Returns a new instance of ListParams.
1036 1037 1038 1039 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1036 def initialize(expand: nil, payment_record: nil) @expand = @payment_record = payment_record end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1032 1033 1034 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1032 def @expand end |
#payment_record ⇒ Object
The ID of the Payment Record.
1034 1035 1036 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1034 def payment_record @payment_record end |