Class: Stripe::PaymentAttemptRecord::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecord::ListParams
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_record ⇒ Object
The ID of the Payment Record.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_record: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_record: nil) ⇒ ListParams
Returns a new instance of ListParams.
1028 1029 1030 1031 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1028 def initialize(expand: nil, payment_record: nil) @expand = @payment_record = payment_record end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
1024 1025 1026 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1024 def @expand end |
#payment_record ⇒ Object
The ID of the Payment Record.
1026 1027 1028 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1026 def payment_record @payment_record end |