Class: Stripe::PaymentAttemptRecord::ListParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecord::ListParams
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#payment_record ⇒ Object
The ID of the Payment Record.
Instance Method Summary collapse
-
#initialize(expand: nil, payment_record: nil) ⇒ ListParams
constructor
A new instance of ListParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, payment_record: nil) ⇒ ListParams
Returns a new instance of ListParams.
154 155 156 157 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 154 def initialize(expand: nil, payment_record: nil) @expand = @payment_record = payment_record end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
149 150 151 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 149 def @expand end |
#payment_record ⇒ Object
The ID of the Payment Record.
152 153 154 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 152 def payment_record @payment_record end |