Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, GiftCard, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



1888
1889
1890
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1888

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



1890
1891
1892
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1890

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



1892
1893
1894
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1892

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1894
1895
1896
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1894

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1896
1897
1898
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1896

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1898
1899
1900
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1898

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1900
1901
1902
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1900

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1902
1903
1904
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1902

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1904
1905
1906
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1904

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1906
1907
1908
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1906

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1908
1909
1910
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1908

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1910
1911
1912
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1910

def billie
  @billie
end

#billing_detailsObject (readonly)

The billing details associated with the method of payment.



1912
1913
1914
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1912

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



1914
1915
1916
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1914

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1916
1917
1918
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1916

def boleto
  @boleto
end

#cardObject (readonly)

Details of the card used for this payment attempt.



1918
1919
1920
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1918

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1920
1921
1922
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1920

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1922
1923
1924
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1922

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1924
1925
1926
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1924

def crypto
  @crypto
end

#customObject (readonly)

Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.



1928
1929
1930
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1928

def custom
  @custom
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1930
1931
1932
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1930

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1932
1933
1934
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1932

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1934
1935
1936
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1934

def fpx
  @fpx
end

#gift_cardObject (readonly)

Attribute for field gift_card



1936
1937
1938
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1936

def gift_card
  @gift_card
end

#giropayObject (readonly)

Attribute for field giropay



1938
1939
1940
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1938

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1940
1941
1942
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1940

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1942
1943
1944
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1942

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1944
1945
1946
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1944

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1946
1947
1948
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1946

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1948
1949
1950
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1948

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1950
1951
1952
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1950

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1952
1953
1954
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1952

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1954
1955
1956
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1954

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1956
1957
1958
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1956

def kr_card
  @kr_card
end

Attribute for field link



1958
1959
1960
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1958

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1960
1961
1962
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1960

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1962
1963
1964
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1962

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1964
1965
1966
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1964

def multibanco
  @multibanco
end

Attribute for field naver_pay



1966
1967
1968
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1966

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1968
1969
1970
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1968

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1970
1971
1972
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1970

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1972
1973
1974
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1972

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1974
1975
1976
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1974

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1976
1977
1978
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1976

def payco
  @payco
end

#payment_methodObject (readonly)

ID of the Stripe PaymentMethod used to make this payment.



1978
1979
1980
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1978

def payment_method
  @payment_method
end

#paynowObject (readonly)

Attribute for field paynow



1980
1981
1982
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1980

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1982
1983
1984
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1982

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



1984
1985
1986
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1984

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



1986
1987
1988
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1986

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1988
1989
1990
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1988

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1990
1991
1992
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1990

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1992
1993
1994
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1992

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1994
1995
1996
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1994

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1996
1997
1998
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1996

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1998
1999
2000
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1998

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



2000
2001
2002
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2000

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



2002
2003
2004
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2002

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



2004
2005
2006
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2004

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



2006
2007
2008
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2006

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



2008
2009
2010
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2008

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



2010
2011
2012
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2010

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



2012
2013
2014
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2012

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



2014
2015
2016
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2014

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



2016
2017
2018
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2016

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



2020
2021
2022
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2020

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



2022
2023
2024
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2022

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



2024
2025
2026
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2024

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



2026
2027
2028
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2026

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



2028
2029
2030
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2028

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



2030
2031
2032
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2030

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2105
2106
2107
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2105

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
2063
2064
2065
2066
2067
2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
2079
2080
2081
2082
2083
2084
2085
2086
2087
2088
2089
2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2032

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    custom: Custom,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    gift_card: GiftCard,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end