Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Sunbit, Swish, Twint, Upi, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



1844
1845
1846
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1844

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



1846
1847
1848
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1846

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



1848
1849
1850
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1848

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1850
1851
1852
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1850

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1852
1853
1854
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1852

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1854
1855
1856
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1854

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1856
1857
1858
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1856

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1858
1859
1860
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1858

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1860
1861
1862
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1860

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1862
1863
1864
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1862

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1864
1865
1866
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1864

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1866
1867
1868
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1866

def billie
  @billie
end

#billing_detailsObject (readonly)

The billing details associated with the method of payment.



1868
1869
1870
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1868

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



1870
1871
1872
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1870

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1872
1873
1874
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1872

def boleto
  @boleto
end

#cardObject (readonly)

Details of the card used for this payment attempt.



1874
1875
1876
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1874

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1876
1877
1878
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1876

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1878
1879
1880
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1878

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1880
1881
1882
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1880

def crypto
  @crypto
end

#customObject (readonly)

Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.



1884
1885
1886
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1884

def custom
  @custom
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1886
1887
1888
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1886

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1888
1889
1890
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1888

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1890
1891
1892
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1890

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1892
1893
1894
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1892

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1894
1895
1896
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1894

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1896
1897
1898
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1896

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1898
1899
1900
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1898

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1900
1901
1902
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1900

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1902
1903
1904
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1902

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1904
1905
1906
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1904

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1906
1907
1908
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1906

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1908
1909
1910
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1908

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1910
1911
1912
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1910

def kr_card
  @kr_card
end

Attribute for field link



1912
1913
1914
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1912

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1914
1915
1916
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1914

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1916
1917
1918
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1916

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1918
1919
1920
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1918

def multibanco
  @multibanco
end

Attribute for field naver_pay



1920
1921
1922
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1920

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1922
1923
1924
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1922

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1924
1925
1926
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1924

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1926
1927
1928
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1926

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1928
1929
1930
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1928

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1930
1931
1932
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1930

def payco
  @payco
end

#payment_methodObject (readonly)

ID of the Stripe PaymentMethod used to make this payment.



1932
1933
1934
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1932

def payment_method
  @payment_method
end

#paynowObject (readonly)

Attribute for field paynow



1934
1935
1936
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1934

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1936
1937
1938
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1936

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



1938
1939
1940
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1938

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



1940
1941
1942
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1940

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1942
1943
1944
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1942

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1944
1945
1946
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1944

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1946
1947
1948
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1946

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1948
1949
1950
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1948

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1950
1951
1952
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1950

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1952
1953
1954
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1952

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1954
1955
1956
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1954

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



1956
1957
1958
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1956

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1958
1959
1960
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1958

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1960
1961
1962
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1960

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1962
1963
1964
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1962

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



1964
1965
1966
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1964

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



1966
1967
1968
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1966

def stripe_balance
  @stripe_balance
end

#sunbitObject (readonly)

Attribute for field sunbit



1968
1969
1970
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1968

def sunbit
  @sunbit
end

#swishObject (readonly)

Attribute for field swish



1970
1971
1972
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1970

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1972
1973
1974
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1972

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



1976
1977
1978
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1976

def type
  @type
end

#upiObject (readonly)

Attribute for field upi



1978
1979
1980
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1978

def upi
  @upi
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1980
1981
1982
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1980

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



1982
1983
1984
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1982

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1984
1985
1986
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1984

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1986
1987
1988
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1986

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2061
2062
2063
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2061

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
2019
2020
2021
2022
2023
2024
2025
2026
2027
2028
2029
2030
2031
2032
2033
2034
2035
2036
2037
2038
2039
2040
2041
2042
2043
2044
2045
2046
2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
2058
2059
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1988

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    custom: Custom,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    sunbit: Sunbit,
    swish: Swish,
    twint: Twint,
    upi: Upi,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end