Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Paypay, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#ach_credit_transferObject (readonly)

Attribute for field ach_credit_transfer



1809
1810
1811
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1809

def ach_credit_transfer
  @ach_credit_transfer
end

#ach_debitObject (readonly)

Attribute for field ach_debit



1811
1812
1813
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1811

def ach_debit
  @ach_debit
end

#acss_debitObject (readonly)

Attribute for field acss_debit



1813
1814
1815
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1813

def acss_debit
  @acss_debit
end

#affirmObject (readonly)

Attribute for field affirm



1815
1816
1817
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1815

def affirm
  @affirm
end

#afterpay_clearpayObject (readonly)

Attribute for field afterpay_clearpay



1817
1818
1819
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1817

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject (readonly)

Attribute for field alipay



1819
1820
1821
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1819

def alipay
  @alipay
end

#almaObject (readonly)

Attribute for field alma



1821
1822
1823
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1821

def alma
  @alma
end

#amazon_payObject (readonly)

Attribute for field amazon_pay



1823
1824
1825
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1823

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject (readonly)

Attribute for field au_becs_debit



1825
1826
1827
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1825

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject (readonly)

Attribute for field bacs_debit



1827
1828
1829
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1827

def bacs_debit
  @bacs_debit
end

#bancontactObject (readonly)

Attribute for field bancontact



1829
1830
1831
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1829

def bancontact
  @bancontact
end

#billieObject (readonly)

Attribute for field billie



1831
1832
1833
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1831

def billie
  @billie
end

#billing_detailsObject (readonly)

The billing details associated with the method of payment.



1833
1834
1835
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1833

def billing_details
  @billing_details
end

#blikObject (readonly)

Attribute for field blik



1835
1836
1837
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1835

def blik
  @blik
end

#boletoObject (readonly)

Attribute for field boleto



1837
1838
1839
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1837

def boleto
  @boleto
end

#cardObject (readonly)

Details of the card used for this payment attempt.



1839
1840
1841
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1839

def card
  @card
end

#card_presentObject (readonly)

Attribute for field card_present



1841
1842
1843
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1841

def card_present
  @card_present
end

#cashappObject (readonly)

Attribute for field cashapp



1843
1844
1845
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1843

def cashapp
  @cashapp
end

#cryptoObject (readonly)

Attribute for field crypto



1845
1846
1847
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1845

def crypto
  @crypto
end

#customObject (readonly)

Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.



1849
1850
1851
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1849

def custom
  @custom
end

#customer_balanceObject (readonly)

Attribute for field customer_balance



1851
1852
1853
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1851

def customer_balance
  @customer_balance
end

#epsObject (readonly)

Attribute for field eps



1853
1854
1855
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1853

def eps
  @eps
end

#fpxObject (readonly)

Attribute for field fpx



1855
1856
1857
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1855

def fpx
  @fpx
end

#giropayObject (readonly)

Attribute for field giropay



1857
1858
1859
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1857

def giropay
  @giropay
end

#gopayObject (readonly)

Attribute for field gopay



1859
1860
1861
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1859

def gopay
  @gopay
end

#grabpayObject (readonly)

Attribute for field grabpay



1861
1862
1863
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1861

def grabpay
  @grabpay
end

#id_bank_transferObject (readonly)

Attribute for field id_bank_transfer



1863
1864
1865
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1863

def id_bank_transfer
  @id_bank_transfer
end

#idealObject (readonly)

Attribute for field ideal



1865
1866
1867
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1865

def ideal
  @ideal
end

#interac_presentObject (readonly)

Attribute for field interac_present



1867
1868
1869
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1867

def interac_present
  @interac_present
end

#kakao_payObject (readonly)

Attribute for field kakao_pay



1869
1870
1871
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1869

def kakao_pay
  @kakao_pay
end

#klarnaObject (readonly)

Attribute for field klarna



1871
1872
1873
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1871

def klarna
  @klarna
end

#konbiniObject (readonly)

Attribute for field konbini



1873
1874
1875
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1873

def konbini
  @konbini
end

#kr_cardObject (readonly)

Attribute for field kr_card



1875
1876
1877
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1875

def kr_card
  @kr_card
end

Attribute for field link



1877
1878
1879
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1877

def link
  @link
end

#mb_wayObject (readonly)

Attribute for field mb_way



1879
1880
1881
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1879

def mb_way
  @mb_way
end

#mobilepayObject (readonly)

Attribute for field mobilepay



1881
1882
1883
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1881

def mobilepay
  @mobilepay
end

#multibancoObject (readonly)

Attribute for field multibanco



1883
1884
1885
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1883

def multibanco
  @multibanco
end

Attribute for field naver_pay



1885
1886
1887
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1885

def naver_pay
  @naver_pay
end

#nz_bank_accountObject (readonly)

Attribute for field nz_bank_account



1887
1888
1889
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1887

def 
  @nz_bank_account
end

#oxxoObject (readonly)

Attribute for field oxxo



1889
1890
1891
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1889

def oxxo
  @oxxo
end

#p24Object (readonly)

Attribute for field p24



1891
1892
1893
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1891

def p24
  @p24
end

#pay_by_bankObject (readonly)

Attribute for field pay_by_bank



1893
1894
1895
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1893

def pay_by_bank
  @pay_by_bank
end

#paycoObject (readonly)

Attribute for field payco



1895
1896
1897
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1895

def payco
  @payco
end

#payment_methodObject (readonly)

ID of the Stripe PaymentMethod used to make this payment.



1897
1898
1899
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1897

def payment_method
  @payment_method
end

#paynowObject (readonly)

Attribute for field paynow



1899
1900
1901
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1899

def paynow
  @paynow
end

#paypalObject (readonly)

Attribute for field paypal



1901
1902
1903
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1901

def paypal
  @paypal
end

#paypayObject (readonly)

Attribute for field paypay



1903
1904
1905
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1903

def paypay
  @paypay
end

#paytoObject (readonly)

Attribute for field payto



1905
1906
1907
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1905

def payto
  @payto
end

#pixObject (readonly)

Attribute for field pix



1907
1908
1909
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1907

def pix
  @pix
end

#promptpayObject (readonly)

Attribute for field promptpay



1909
1910
1911
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1909

def promptpay
  @promptpay
end

#qrisObject (readonly)

Attribute for field qris



1911
1912
1913
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1911

def qris
  @qris
end

#rechnungObject (readonly)

Attribute for field rechnung



1913
1914
1915
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1913

def rechnung
  @rechnung
end

#revolut_payObject (readonly)

Attribute for field revolut_pay



1915
1916
1917
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1915

def revolut_pay
  @revolut_pay
end

#samsung_payObject (readonly)

Attribute for field samsung_pay



1917
1918
1919
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1917

def samsung_pay
  @samsung_pay
end

#satispayObject (readonly)

Attribute for field satispay



1919
1920
1921
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1919

def satispay
  @satispay
end

#sepa_credit_transferObject (readonly)

Attribute for field sepa_credit_transfer



1921
1922
1923
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1921

def sepa_credit_transfer
  @sepa_credit_transfer
end

#sepa_debitObject (readonly)

Attribute for field sepa_debit



1923
1924
1925
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1923

def sepa_debit
  @sepa_debit
end

#shopeepayObject (readonly)

Attribute for field shopeepay



1925
1926
1927
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1925

def shopeepay
  @shopeepay
end

#sofortObject (readonly)

Attribute for field sofort



1927
1928
1929
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1927

def sofort
  @sofort
end

#stripe_accountObject (readonly)

Attribute for field stripe_account



1929
1930
1931
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1929

def 
  @stripe_account
end

#stripe_balanceObject (readonly)

Attribute for field stripe_balance



1931
1932
1933
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1931

def stripe_balance
  @stripe_balance
end

#swishObject (readonly)

Attribute for field swish



1933
1934
1935
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1933

def swish
  @swish
end

#twintObject (readonly)

Attribute for field twint



1935
1936
1937
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1935

def twint
  @twint
end

#typeObject (readonly)

The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](docs.stripe.com/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.



1939
1940
1941
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1939

def type
  @type
end

#us_bank_accountObject (readonly)

Attribute for field us_bank_account



1941
1942
1943
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1941

def 
  @us_bank_account
end

#wechatObject (readonly)

Attribute for field wechat



1943
1944
1945
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1943

def wechat
  @wechat
end

#wechat_payObject (readonly)

Attribute for field wechat_pay



1945
1946
1947
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1945

def wechat_pay
  @wechat_pay
end

#zipObject (readonly)

Attribute for field zip



1947
1948
1949
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1947

def zip
  @zip
end

Class Method Details

.field_remappingsObject



2020
2021
2022
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2020

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
1967
1968
1969
1970
1971
1972
1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
1996
1997
1998
1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1949

def self.inner_class_types
  @inner_class_types = {
    ach_credit_transfer: AchCreditTransfer,
    ach_debit: AchDebit,
    acss_debit: AcssDebit,
    affirm: Affirm,
    afterpay_clearpay: AfterpayClearpay,
    alipay: Alipay,
    alma: Alma,
    amazon_pay: AmazonPay,
    au_becs_debit: AuBecsDebit,
    bacs_debit: BacsDebit,
    bancontact: Bancontact,
    billie: Billie,
    billing_details: BillingDetails,
    blik: Blik,
    boleto: Boleto,
    card: Card,
    card_present: CardPresent,
    cashapp: Cashapp,
    crypto: Crypto,
    custom: Custom,
    customer_balance: CustomerBalance,
    eps: Eps,
    fpx: Fpx,
    giropay: Giropay,
    gopay: Gopay,
    grabpay: Grabpay,
    id_bank_transfer: IdBankTransfer,
    ideal: Ideal,
    interac_present: InteracPresent,
    kakao_pay: KakaoPay,
    klarna: Klarna,
    konbini: Konbini,
    kr_card: KrCard,
    link: Link,
    mb_way: MbWay,
    mobilepay: Mobilepay,
    multibanco: Multibanco,
    naver_pay: NaverPay,
    nz_bank_account: NzBankAccount,
    oxxo: Oxxo,
    p24: P24,
    pay_by_bank: PayByBank,
    payco: Payco,
    paynow: Paynow,
    paypal: Paypal,
    paypay: Paypay,
    payto: Payto,
    pix: Pix,
    promptpay: Promptpay,
    qris: Qris,
    rechnung: Rechnung,
    revolut_pay: RevolutPay,
    samsung_pay: SamsungPay,
    satispay: Satispay,
    sepa_credit_transfer: SepaCreditTransfer,
    sepa_debit: SepaDebit,
    shopeepay: Shopeepay,
    sofort: Sofort,
    stripe_account: StripeAccount,
    stripe_balance: StripeBalance,
    swish: Swish,
    twint: Twint,
    us_bank_account: UsBankAccount,
    wechat: Wechat,
    wechat_pay: WechatPay,
    zip: Zip,
  }
end