Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Defined Under Namespace
Classes: AchCreditTransfer, AchDebit, AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Card, CardPresent, Cashapp, Crypto, Custom, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, Rechnung, RevolutPay, SamsungPay, Satispay, SepaCreditTransfer, SepaDebit, Shopeepay, Sofort, StripeAccount, StripeBalance, Swish, Twint, UsBankAccount, Wechat, WechatPay, Zip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#ach_credit_transfer ⇒ Object
readonly
Attribute for field ach_credit_transfer.
-
#ach_debit ⇒ Object
readonly
Attribute for field ach_debit.
-
#acss_debit ⇒ Object
readonly
Attribute for field acss_debit.
-
#affirm ⇒ Object
readonly
Attribute for field affirm.
-
#afterpay_clearpay ⇒ Object
readonly
Attribute for field afterpay_clearpay.
-
#alipay ⇒ Object
readonly
Attribute for field alipay.
-
#alma ⇒ Object
readonly
Attribute for field alma.
-
#amazon_pay ⇒ Object
readonly
Attribute for field amazon_pay.
-
#au_becs_debit ⇒ Object
readonly
Attribute for field au_becs_debit.
-
#bacs_debit ⇒ Object
readonly
Attribute for field bacs_debit.
-
#bancontact ⇒ Object
readonly
Attribute for field bancontact.
-
#billie ⇒ Object
readonly
Attribute for field billie.
-
#billing_details ⇒ Object
readonly
The billing details associated with the method of payment.
-
#blik ⇒ Object
readonly
Attribute for field blik.
-
#boleto ⇒ Object
readonly
Attribute for field boleto.
-
#card ⇒ Object
readonly
Details of the card used for this payment attempt.
-
#card_present ⇒ Object
readonly
Attribute for field card_present.
-
#cashapp ⇒ Object
readonly
Attribute for field cashapp.
-
#crypto ⇒ Object
readonly
Attribute for field crypto.
-
#custom ⇒ Object
readonly
Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API.
-
#customer_balance ⇒ Object
readonly
Attribute for field customer_balance.
-
#eps ⇒ Object
readonly
Attribute for field eps.
-
#fpx ⇒ Object
readonly
Attribute for field fpx.
-
#giropay ⇒ Object
readonly
Attribute for field giropay.
-
#gopay ⇒ Object
readonly
Attribute for field gopay.
-
#grabpay ⇒ Object
readonly
Attribute for field grabpay.
-
#id_bank_transfer ⇒ Object
readonly
Attribute for field id_bank_transfer.
-
#ideal ⇒ Object
readonly
Attribute for field ideal.
-
#interac_present ⇒ Object
readonly
Attribute for field interac_present.
-
#kakao_pay ⇒ Object
readonly
Attribute for field kakao_pay.
-
#klarna ⇒ Object
readonly
Attribute for field klarna.
-
#konbini ⇒ Object
readonly
Attribute for field konbini.
-
#kr_card ⇒ Object
readonly
Attribute for field kr_card.
-
#link ⇒ Object
readonly
Attribute for field link.
-
#mb_way ⇒ Object
readonly
Attribute for field mb_way.
-
#mobilepay ⇒ Object
readonly
Attribute for field mobilepay.
-
#multibanco ⇒ Object
readonly
Attribute for field multibanco.
-
#naver_pay ⇒ Object
readonly
Attribute for field naver_pay.
-
#nz_bank_account ⇒ Object
readonly
Attribute for field nz_bank_account.
-
#oxxo ⇒ Object
readonly
Attribute for field oxxo.
-
#p24 ⇒ Object
readonly
Attribute for field p24.
-
#pay_by_bank ⇒ Object
readonly
Attribute for field pay_by_bank.
-
#payco ⇒ Object
readonly
Attribute for field payco.
-
#payment_method ⇒ Object
readonly
ID of the Stripe PaymentMethod used to make this payment.
-
#paynow ⇒ Object
readonly
Attribute for field paynow.
-
#paypal ⇒ Object
readonly
Attribute for field paypal.
-
#payto ⇒ Object
readonly
Attribute for field payto.
-
#pix ⇒ Object
readonly
Attribute for field pix.
-
#promptpay ⇒ Object
readonly
Attribute for field promptpay.
-
#qris ⇒ Object
readonly
Attribute for field qris.
-
#rechnung ⇒ Object
readonly
Attribute for field rechnung.
-
#revolut_pay ⇒ Object
readonly
Attribute for field revolut_pay.
-
#samsung_pay ⇒ Object
readonly
Attribute for field samsung_pay.
-
#satispay ⇒ Object
readonly
Attribute for field satispay.
-
#sepa_credit_transfer ⇒ Object
readonly
Attribute for field sepa_credit_transfer.
-
#sepa_debit ⇒ Object
readonly
Attribute for field sepa_debit.
-
#shopeepay ⇒ Object
readonly
Attribute for field shopeepay.
-
#sofort ⇒ Object
readonly
Attribute for field sofort.
-
#stripe_account ⇒ Object
readonly
Attribute for field stripe_account.
-
#stripe_balance ⇒ Object
readonly
Attribute for field stripe_balance.
-
#swish ⇒ Object
readonly
Attribute for field swish.
-
#twint ⇒ Object
readonly
Attribute for field twint.
-
#type ⇒ Object
readonly
The type of transaction-specific details of the payment method used in the payment.
-
#us_bank_account ⇒ Object
readonly
Details of the US Bank Account used for this payment attempt.
-
#wechat ⇒ Object
readonly
Attribute for field wechat.
-
#wechat_pay ⇒ Object
readonly
Attribute for field wechat_pay.
-
#zip ⇒ Object
readonly
Attribute for field zip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#ach_credit_transfer ⇒ Object (readonly)
Attribute for field ach_credit_transfer
1688 1689 1690 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1688 def ach_credit_transfer @ach_credit_transfer end |
#ach_debit ⇒ Object (readonly)
Attribute for field ach_debit
1690 1691 1692 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1690 def ach_debit @ach_debit end |
#acss_debit ⇒ Object (readonly)
Attribute for field acss_debit
1692 1693 1694 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1692 def acss_debit @acss_debit end |
#affirm ⇒ Object (readonly)
Attribute for field affirm
1694 1695 1696 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1694 def affirm @affirm end |
#afterpay_clearpay ⇒ Object (readonly)
Attribute for field afterpay_clearpay
1696 1697 1698 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1696 def afterpay_clearpay @afterpay_clearpay end |
#alipay ⇒ Object (readonly)
Attribute for field alipay
1698 1699 1700 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1698 def alipay @alipay end |
#alma ⇒ Object (readonly)
Attribute for field alma
1700 1701 1702 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1700 def alma @alma end |
#amazon_pay ⇒ Object (readonly)
Attribute for field amazon_pay
1702 1703 1704 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1702 def amazon_pay @amazon_pay end |
#au_becs_debit ⇒ Object (readonly)
Attribute for field au_becs_debit
1704 1705 1706 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1704 def au_becs_debit @au_becs_debit end |
#bacs_debit ⇒ Object (readonly)
Attribute for field bacs_debit
1706 1707 1708 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1706 def bacs_debit @bacs_debit end |
#bancontact ⇒ Object (readonly)
Attribute for field bancontact
1708 1709 1710 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1708 def bancontact @bancontact end |
#billie ⇒ Object (readonly)
Attribute for field billie
1710 1711 1712 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1710 def billie @billie end |
#billing_details ⇒ Object (readonly)
The billing details associated with the method of payment.
1712 1713 1714 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1712 def billing_details @billing_details end |
#blik ⇒ Object (readonly)
Attribute for field blik
1714 1715 1716 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1714 def blik @blik end |
#boleto ⇒ Object (readonly)
Attribute for field boleto
1716 1717 1718 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1716 def boleto @boleto end |
#card ⇒ Object (readonly)
Details of the card used for this payment attempt.
1718 1719 1720 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1718 def card @card end |
#card_present ⇒ Object (readonly)
Attribute for field card_present
1720 1721 1722 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1720 def card_present @card_present end |
#cashapp ⇒ Object (readonly)
Attribute for field cashapp
1722 1723 1724 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1722 def cashapp @cashapp end |
#crypto ⇒ Object (readonly)
Attribute for field crypto
1724 1725 1726 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1724 def crypto @crypto end |
#custom ⇒ Object (readonly)
Custom Payment Methods represent Payment Method types not modeled directly in the Stripe API. This resource consists of details about the custom payment method used for this payment attempt.
1728 1729 1730 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1728 def custom @custom end |
#customer_balance ⇒ Object (readonly)
Attribute for field customer_balance
1730 1731 1732 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1730 def customer_balance @customer_balance end |
#eps ⇒ Object (readonly)
Attribute for field eps
1732 1733 1734 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1732 def eps @eps end |
#fpx ⇒ Object (readonly)
Attribute for field fpx
1734 1735 1736 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1734 def fpx @fpx end |
#giropay ⇒ Object (readonly)
Attribute for field giropay
1736 1737 1738 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1736 def giropay @giropay end |
#gopay ⇒ Object (readonly)
Attribute for field gopay
1738 1739 1740 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1738 def gopay @gopay end |
#grabpay ⇒ Object (readonly)
Attribute for field grabpay
1740 1741 1742 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1740 def grabpay @grabpay end |
#id_bank_transfer ⇒ Object (readonly)
Attribute for field id_bank_transfer
1742 1743 1744 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1742 def id_bank_transfer @id_bank_transfer end |
#ideal ⇒ Object (readonly)
Attribute for field ideal
1744 1745 1746 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1744 def ideal @ideal end |
#interac_present ⇒ Object (readonly)
Attribute for field interac_present
1746 1747 1748 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1746 def interac_present @interac_present end |
#kakao_pay ⇒ Object (readonly)
Attribute for field kakao_pay
1748 1749 1750 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1748 def kakao_pay @kakao_pay end |
#klarna ⇒ Object (readonly)
Attribute for field klarna
1750 1751 1752 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1750 def klarna @klarna end |
#konbini ⇒ Object (readonly)
Attribute for field konbini
1752 1753 1754 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1752 def konbini @konbini end |
#kr_card ⇒ Object (readonly)
Attribute for field kr_card
1754 1755 1756 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1754 def kr_card @kr_card end |
#link ⇒ Object (readonly)
Attribute for field link
1756 1757 1758 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1756 def link @link end |
#mb_way ⇒ Object (readonly)
Attribute for field mb_way
1758 1759 1760 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1758 def mb_way @mb_way end |
#mobilepay ⇒ Object (readonly)
Attribute for field mobilepay
1760 1761 1762 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1760 def mobilepay @mobilepay end |
#multibanco ⇒ Object (readonly)
Attribute for field multibanco
1762 1763 1764 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1762 def multibanco @multibanco end |
#naver_pay ⇒ Object (readonly)
Attribute for field naver_pay
1764 1765 1766 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1764 def naver_pay @naver_pay end |
#nz_bank_account ⇒ Object (readonly)
Attribute for field nz_bank_account
1766 1767 1768 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1766 def nz_bank_account @nz_bank_account end |
#oxxo ⇒ Object (readonly)
Attribute for field oxxo
1768 1769 1770 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1768 def oxxo @oxxo end |
#p24 ⇒ Object (readonly)
Attribute for field p24
1770 1771 1772 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1770 def p24 @p24 end |
#pay_by_bank ⇒ Object (readonly)
Attribute for field pay_by_bank
1772 1773 1774 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1772 def pay_by_bank @pay_by_bank end |
#payco ⇒ Object (readonly)
Attribute for field payco
1774 1775 1776 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1774 def payco @payco end |
#payment_method ⇒ Object (readonly)
ID of the Stripe PaymentMethod used to make this payment.
1776 1777 1778 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1776 def payment_method @payment_method end |
#paynow ⇒ Object (readonly)
Attribute for field paynow
1778 1779 1780 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1778 def paynow @paynow end |
#paypal ⇒ Object (readonly)
Attribute for field paypal
1780 1781 1782 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1780 def paypal @paypal end |
#payto ⇒ Object (readonly)
Attribute for field payto
1782 1783 1784 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1782 def payto @payto end |
#pix ⇒ Object (readonly)
Attribute for field pix
1784 1785 1786 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1784 def pix @pix end |
#promptpay ⇒ Object (readonly)
Attribute for field promptpay
1786 1787 1788 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1786 def promptpay @promptpay end |
#qris ⇒ Object (readonly)
Attribute for field qris
1788 1789 1790 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1788 def qris @qris end |
#rechnung ⇒ Object (readonly)
Attribute for field rechnung
1790 1791 1792 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1790 def rechnung @rechnung end |
#revolut_pay ⇒ Object (readonly)
Attribute for field revolut_pay
1792 1793 1794 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1792 def revolut_pay @revolut_pay end |
#samsung_pay ⇒ Object (readonly)
Attribute for field samsung_pay
1794 1795 1796 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1794 def samsung_pay @samsung_pay end |
#satispay ⇒ Object (readonly)
Attribute for field satispay
1796 1797 1798 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1796 def satispay @satispay end |
#sepa_credit_transfer ⇒ Object (readonly)
Attribute for field sepa_credit_transfer
1798 1799 1800 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1798 def sepa_credit_transfer @sepa_credit_transfer end |
#sepa_debit ⇒ Object (readonly)
Attribute for field sepa_debit
1800 1801 1802 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1800 def sepa_debit @sepa_debit end |
#shopeepay ⇒ Object (readonly)
Attribute for field shopeepay
1802 1803 1804 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1802 def shopeepay @shopeepay end |
#sofort ⇒ Object (readonly)
Attribute for field sofort
1804 1805 1806 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1804 def sofort @sofort end |
#stripe_account ⇒ Object (readonly)
Attribute for field stripe_account
1806 1807 1808 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1806 def stripe_account @stripe_account end |
#stripe_balance ⇒ Object (readonly)
Attribute for field stripe_balance
1808 1809 1810 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1808 def stripe_balance @stripe_balance end |
#swish ⇒ Object (readonly)
Attribute for field swish
1810 1811 1812 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1810 def swish @swish end |
#twint ⇒ Object (readonly)
Attribute for field twint
1812 1813 1814 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1812 def twint @twint end |
#type ⇒ Object (readonly)
The type of transaction-specific details of the payment method used in the payment. See [PaymentMethod.type](stripe.com/docs/api/payment_methods/object#payment_method_object-type) for the full list of possible types. An additional hash is included on ‘payment_method_details` with a name matching this value. It contains information specific to the payment method.
1816 1817 1818 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1816 def type @type end |
#us_bank_account ⇒ Object (readonly)
Details of the US Bank Account used for this payment attempt.
1818 1819 1820 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1818 def us_bank_account @us_bank_account end |
#wechat ⇒ Object (readonly)
Attribute for field wechat
1820 1821 1822 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1820 def wechat @wechat end |
#wechat_pay ⇒ Object (readonly)
Attribute for field wechat_pay
1822 1823 1824 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1822 def wechat_pay @wechat_pay end |
#zip ⇒ Object (readonly)
Attribute for field zip
1824 1825 1826 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1824 def zip @zip end |
Class Method Details
.field_remappings ⇒ Object
1896 1897 1898 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1896 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 1847 1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 1858 1859 1860 1861 1862 1863 1864 1865 1866 1867 1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 1893 1894 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1826 def self.inner_class_types @inner_class_types = { ach_credit_transfer: AchCreditTransfer, ach_debit: AchDebit, acss_debit: AcssDebit, affirm: Affirm, afterpay_clearpay: AfterpayClearpay, alipay: Alipay, alma: Alma, amazon_pay: AmazonPay, au_becs_debit: AuBecsDebit, bacs_debit: BacsDebit, bancontact: Bancontact, billie: Billie, billing_details: BillingDetails, blik: Blik, boleto: Boleto, card: Card, card_present: CardPresent, cashapp: Cashapp, crypto: Crypto, custom: Custom, customer_balance: CustomerBalance, eps: Eps, fpx: Fpx, giropay: Giropay, gopay: Gopay, grabpay: Grabpay, id_bank_transfer: IdBankTransfer, ideal: Ideal, interac_present: InteracPresent, kakao_pay: KakaoPay, klarna: Klarna, konbini: Konbini, kr_card: KrCard, link: Link, mb_way: MbWay, mobilepay: Mobilepay, multibanco: Multibanco, naver_pay: NaverPay, nz_bank_account: NzBankAccount, oxxo: Oxxo, p24: P24, pay_by_bank: PayByBank, payco: Payco, paynow: Paynow, paypal: Paypal, payto: Payto, pix: Pix, promptpay: Promptpay, qris: Qris, rechnung: Rechnung, revolut_pay: RevolutPay, samsung_pay: SamsungPay, satispay: Satispay, sepa_credit_transfer: SepaCreditTransfer, sepa_debit: SepaDebit, shopeepay: Shopeepay, sofort: Sofort, stripe_account: StripeAccount, stripe_balance: StripeBalance, swish: Swish, twint: Twint, us_bank_account: UsBankAccount, wechat: Wechat, wechat_pay: WechatPay, zip: Zip, } end |