Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: BillingDetails, Custom

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#billing_detailsObject (readonly)

The billing details associated with the method of payment.



89
90
91
# File 'lib/stripe/resources/payment_attempt_record.rb', line 89

def billing_details
  @billing_details
end

#customObject (readonly)

Information about the custom (user-defined) payment method used to make this payment.



91
92
93
# File 'lib/stripe/resources/payment_attempt_record.rb', line 91

def custom
  @custom
end

#payment_methodObject (readonly)

ID of the Stripe PaymentMethod used to make this payment.



93
94
95
# File 'lib/stripe/resources/payment_attempt_record.rb', line 93

def payment_method
  @payment_method
end

#typeObject (readonly)

The type of Payment Method used for this payment attempt.



95
96
97
# File 'lib/stripe/resources/payment_attempt_record.rb', line 95

def type
  @type
end