Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Defined Under Namespace
Classes: BillingDetails, Custom
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#billing_details ⇒ Object
readonly
The billing details associated with the method of payment.
-
#custom ⇒ Object
readonly
Information about the custom (user-defined) payment method used to make this payment.
-
#payment_method ⇒ Object
readonly
ID of the Stripe PaymentMethod used to make this payment.
-
#type ⇒ Object
readonly
The type of Payment Method used for this payment attempt.
Attributes inherited from StripeObject
Method Summary
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#billing_details ⇒ Object (readonly)
The billing details associated with the method of payment.
89 90 91 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 89 def billing_details @billing_details end |
#custom ⇒ Object (readonly)
Information about the custom (user-defined) payment method used to make this payment.
91 92 93 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 91 def custom @custom end |
#payment_method ⇒ Object (readonly)
ID of the Stripe PaymentMethod used to make this payment.
93 94 95 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 93 def payment_method @payment_method end |
#type ⇒ Object (readonly)
The type of Payment Method used for this payment attempt.
95 96 97 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 95 def type @type end |