Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Bancontact
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::Bancontact
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#generated_sepa_debit ⇒ Object
readonly
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#generated_sepa_debit_mandate ⇒ Object
readonly
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
-
#iban_last4 ⇒ Object
readonly
Last four characters of the IBAN.
-
#preferred_language ⇒ Object
readonly
Preferred language of the Bancontact authorization page that the customer is redirected to.
-
#verified_name ⇒ Object
readonly
Owner’s verified full name.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
382 383 384 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 382 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
384 385 386 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 384 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
386 387 388 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 386 def bic @bic end |
#generated_sepa_debit ⇒ Object (readonly)
The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.
388 389 390 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 388 def generated_sepa_debit @generated_sepa_debit end |
#generated_sepa_debit_mandate ⇒ Object (readonly)
The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.
390 391 392 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 390 def generated_sepa_debit_mandate @generated_sepa_debit_mandate end |
#iban_last4 ⇒ Object (readonly)
Last four characters of the IBAN.
392 393 394 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 392 def iban_last4 @iban_last4 end |
#preferred_language ⇒ Object (readonly)
Preferred language of the Bancontact authorization page that the customer is redirected to. Can be one of ‘en`, `de`, `fr`, or `nl`
394 395 396 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 394 def preferred_language @preferred_language end |
#verified_name ⇒ Object (readonly)
Owner’s verified full name. Values are verified or provided by Bancontact directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
396 397 398 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 396 def verified_name @verified_name end |
Class Method Details
.field_remappings ⇒ Object
402 403 404 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 402 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
398 399 400 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 398 def self.inner_class_types @inner_class_types = {} end |