Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Bancontact

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



172
173
174
# File 'lib/stripe/resources/payment_attempt_record.rb', line 172

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



174
175
176
# File 'lib/stripe/resources/payment_attempt_record.rb', line 174

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



176
177
178
# File 'lib/stripe/resources/payment_attempt_record.rb', line 176

def bic
  @bic
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



178
179
180
# File 'lib/stripe/resources/payment_attempt_record.rb', line 178

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



180
181
182
# File 'lib/stripe/resources/payment_attempt_record.rb', line 180

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



182
183
184
# File 'lib/stripe/resources/payment_attempt_record.rb', line 182

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the Bancontact authorization page that the customer is redirected to. Can be one of ‘en`, `de`, `fr`, or `nl`



185
186
187
# File 'lib/stripe/resources/payment_attempt_record.rb', line 185

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by Bancontact directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



188
189
190
# File 'lib/stripe/resources/payment_attempt_record.rb', line 188

def verified_name
  @verified_name
end