Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Card
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::Card
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Defined Under Namespace
Classes: Checks, Installments, NetworkToken, ThreeDSecure, Wallet
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#authorization_code ⇒ Object
readonly
The authorization code of the payment.
-
#brand ⇒ Object
readonly
Card brand.
-
#capture_before ⇒ Object
readonly
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
-
#checks ⇒ Object
readonly
Check results by Card networks on Card address and CVC at time of payment.
-
#country ⇒ Object
readonly
Two-letter ISO code representing the country of the card.
-
#description ⇒ Object
readonly
A high-level description of the type of cards issued in this range.
-
#exp_month ⇒ Object
readonly
Two-digit number representing the card’s expiration month.
-
#exp_year ⇒ Object
readonly
Four-digit number representing the card’s expiration year.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular card number.
-
#funding ⇒ Object
readonly
Card funding type.
-
#iin ⇒ Object
readonly
Issuer identification number of the card.
-
#installments ⇒ Object
readonly
Installment details for this payment.
-
#issuer ⇒ Object
readonly
The name of the card’s issuing bank.
-
#last4 ⇒ Object
readonly
The last four digits of the card.
-
#moto ⇒ Object
readonly
True if this payment was marked as MOTO and out of scope for SCA.
-
#network ⇒ Object
readonly
Identifies which network this charge was processed on.
-
#network_advice_code ⇒ Object
readonly
Advice code from the card network for the failed payment.
-
#network_decline_code ⇒ Object
readonly
Decline code from the card network for the failed payment.
-
#network_token ⇒ Object
readonly
If this card has network token credentials, this contains the details of the network token credentials.
-
#network_transaction_id ⇒ Object
readonly
This is used by the financial networks to identify a transaction.
-
#stored_credential_usage ⇒ Object
readonly
The transaction type that was passed for an off-session, Merchant-Initiated transaction, one of ‘recurring` or `unscheduled`.
-
#three_d_secure ⇒ Object
readonly
Populated if this transaction used 3D Secure authentication.
-
#wallet ⇒ Object
readonly
If this Card is part of a card wallet, this contains the details of the card wallet.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#authorization_code ⇒ Object (readonly)
The authorization code of the payment.
615 616 617 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 615 def @authorization_code end |
#brand ⇒ Object (readonly)
Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.
617 618 619 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 617 def brand @brand end |
#capture_before ⇒ Object (readonly)
When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.
619 620 621 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 619 def capture_before @capture_before end |
#checks ⇒ Object (readonly)
Check results by Card networks on Card address and CVC at time of payment.
621 622 623 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 621 def checks @checks end |
#country ⇒ Object (readonly)
Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
623 624 625 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 623 def country @country end |
#description ⇒ Object (readonly)
A high-level description of the type of cards issued in this range.
625 626 627 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 625 def description @description end |
#exp_month ⇒ Object (readonly)
Two-digit number representing the card’s expiration month.
627 628 629 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 627 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
Four-digit number representing the card’s expiration year.
629 630 631 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 629 def exp_year @exp_year end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.
*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*
633 634 635 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 633 def fingerprint @fingerprint end |
#funding ⇒ Object (readonly)
Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.
635 636 637 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 635 def funding @funding end |
#iin ⇒ Object (readonly)
Issuer identification number of the card.
637 638 639 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 637 def iin @iin end |
#installments ⇒ Object (readonly)
Installment details for this payment.
639 640 641 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 639 def installments @installments end |
#issuer ⇒ Object (readonly)
The name of the card’s issuing bank.
641 642 643 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 641 def issuer @issuer end |
#last4 ⇒ Object (readonly)
The last four digits of the card.
643 644 645 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 643 def last4 @last4 end |
#moto ⇒ Object (readonly)
True if this payment was marked as MOTO and out of scope for SCA.
645 646 647 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 645 def moto @moto end |
#network ⇒ Object (readonly)
Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.
647 648 649 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 647 def network @network end |
#network_advice_code ⇒ Object (readonly)
Advice code from the card network for the failed payment.
649 650 651 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 649 def network_advice_code @network_advice_code end |
#network_decline_code ⇒ Object (readonly)
Decline code from the card network for the failed payment.
651 652 653 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 651 def network_decline_code @network_decline_code end |
#network_token ⇒ Object (readonly)
If this card has network token credentials, this contains the details of the network token credentials.
653 654 655 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 653 def network_token @network_token end |
#network_transaction_id ⇒ Object (readonly)
This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.
655 656 657 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 655 def network_transaction_id @network_transaction_id end |
#stored_credential_usage ⇒ Object (readonly)
The transaction type that was passed for an off-session, Merchant-Initiated transaction, one of ‘recurring` or `unscheduled`.
657 658 659 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 657 def stored_credential_usage @stored_credential_usage end |
#three_d_secure ⇒ Object (readonly)
Populated if this transaction used 3D Secure authentication.
659 660 661 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 659 def three_d_secure @three_d_secure end |
#wallet ⇒ Object (readonly)
If this Card is part of a card wallet, this contains the details of the card wallet.
661 662 663 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 661 def wallet @wallet end |
Class Method Details
.field_remappings ⇒ Object
673 674 675 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 673 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
663 664 665 666 667 668 669 670 671 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 663 def self.inner_class_types @inner_class_types = { checks: Checks, installments: Installments, network_token: NetworkToken, three_d_secure: ThreeDSecure, wallet: Wallet, } end |