Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Card

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: Checks, NetworkToken, ThreeDSecure

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#brandObject (readonly)

Card brand. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `jcb`, `link`, `mastercard`, `unionpay`, `visa` or `unknown`.



533
534
535
# File 'lib/stripe/resources/payment_attempt_record.rb', line 533

def brand
  @brand
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp at which the charge will be automatically refunded if uncaptured.



535
536
537
# File 'lib/stripe/resources/payment_attempt_record.rb', line 535

def capture_before
  @capture_before
end

#checksObject (readonly)

Check results by Card networks on Card address and CVC at time of payment.



537
538
539
# File 'lib/stripe/resources/payment_attempt_record.rb', line 537

def checks
  @checks
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.



539
540
541
# File 'lib/stripe/resources/payment_attempt_record.rb', line 539

def country
  @country
end

#exp_monthObject (readonly)

Two-digit number representing the card’s expiration month.



541
542
543
# File 'lib/stripe/resources/payment_attempt_record.rb', line 541

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card’s expiration year.



543
544
545
# File 'lib/stripe/resources/payment_attempt_record.rb', line 543

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

*As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card—one for India and one for the rest of the world.*



547
548
549
# File 'lib/stripe/resources/payment_attempt_record.rb', line 547

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be ‘credit`, `debit`, `prepaid`, or `unknown`.



549
550
551
# File 'lib/stripe/resources/payment_attempt_record.rb', line 549

def funding
  @funding
end

#last4Object (readonly)

The last four digits of the card.



551
552
553
# File 'lib/stripe/resources/payment_attempt_record.rb', line 551

def last4
  @last4
end

#motoObject (readonly)

True if this payment was marked as MOTO and out of scope for SCA.



553
554
555
# File 'lib/stripe/resources/payment_attempt_record.rb', line 553

def moto
  @moto
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be ‘amex`, `cartes_bancaires`, `diners`, `discover`, `eftpos_au`, `interac`, `jcb`, `link`, `mastercard`, `unionpay`, `visa`, or `unknown`.



555
556
557
# File 'lib/stripe/resources/payment_attempt_record.rb', line 555

def network
  @network
end

#network_tokenObject (readonly)

If this card has network token credentials, this contains the details of the network token credentials.



557
558
559
# File 'lib/stripe/resources/payment_attempt_record.rb', line 557

def network_token
  @network_token
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



559
560
561
# File 'lib/stripe/resources/payment_attempt_record.rb', line 559

def network_transaction_id
  @network_transaction_id
end

#three_d_secureObject (readonly)

Populated if this transaction used 3D Secure authentication.



561
562
563
# File 'lib/stripe/resources/payment_attempt_record.rb', line 561

def three_d_secure
  @three_d_secure
end

Class Method Details

.field_remappingsObject



571
572
573
# File 'lib/stripe/resources/payment_attempt_record.rb', line 571

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



563
564
565
566
567
568
569
# File 'lib/stripe/resources/payment_attempt_record.rb', line 563

def self.inner_class_types
  @inner_class_types = {
    checks: Checks,
    network_token: NetworkToken,
    three_d_secure: ThreeDSecure,
  }
end