Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Card::ThreeDSecure

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#authentication_flowObject (readonly)

For authenticated transactions: Indicates how the issuing bank authenticated the customer.



549
550
551
# File 'lib/stripe/resources/payment_attempt_record.rb', line 549

def authentication_flow
  @authentication_flow
end

#cryptogramObject (readonly)

The 3D Secure cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV).



551
552
553
# File 'lib/stripe/resources/payment_attempt_record.rb', line 551

def cryptogram
  @cryptogram
end

#electronic_commerce_indicatorObject (readonly)

The Electronic Commerce Indicator (ECI). A protocol-level field indicating what degree of authentication was performed.



553
554
555
# File 'lib/stripe/resources/payment_attempt_record.rb', line 553

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#exemption_indicatorObject (readonly)

The exemption requested via 3DS and accepted by the issuer at authentication time.



555
556
557
# File 'lib/stripe/resources/payment_attempt_record.rb', line 555

def exemption_indicator
  @exemption_indicator
end

#exemption_indicator_appliedObject (readonly)

Whether Stripe requested the value of ‘exemption_indicator` in the transaction. This will depend on the outcome of Stripe’s internal risk assessment.



557
558
559
# File 'lib/stripe/resources/payment_attempt_record.rb', line 557

def exemption_indicator_applied
  @exemption_indicator_applied
end

#resultObject (readonly)

Indicates the outcome of 3D Secure authentication.



559
560
561
# File 'lib/stripe/resources/payment_attempt_record.rb', line 559

def result
  @result
end

#result_reasonObject (readonly)

Additional information about why 3D Secure succeeded or failed, based on the ‘result`.



561
562
563
# File 'lib/stripe/resources/payment_attempt_record.rb', line 561

def result_reason
  @result_reason
end

#versionObject (readonly)

The version of 3D Secure that was used.



563
564
565
# File 'lib/stripe/resources/payment_attempt_record.rb', line 563

def version
  @version
end

Class Method Details

.field_remappingsObject



569
570
571
# File 'lib/stripe/resources/payment_attempt_record.rb', line 569

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



565
566
567
# File 'lib/stripe/resources/payment_attempt_record.rb', line 565

def self.inner_class_types
  @inner_class_types = {}
end