Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::CardPresent

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: Multicapture, Offline, Reauthorization, Receipt, Wallet

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amount_authorizedObject (readonly)

The authorized amount



775
776
777
# File 'lib/stripe/resources/payment_attempt_record.rb', line 775

def amount_authorized
  @amount_authorized
end

#brandObject (readonly)

Card brand. Can be amex, cartes_bancaires, diners, discover, eftpos_au, jcb, link, mastercard, unionpay, visa or unknown.



777
778
779
# File 'lib/stripe/resources/payment_attempt_record.rb', line 777

def brand
  @brand
end

#brand_productObject (readonly)

The product code that identifies the specific program or product associated with a card.



779
780
781
# File 'lib/stripe/resources/payment_attempt_record.rb', line 779

def brand_product
  @brand_product
end

#capture_beforeObject (readonly)

When using manual capture, a future timestamp after which the charge will be automatically refunded if uncaptured.



781
782
783
# File 'lib/stripe/resources/payment_attempt_record.rb', line 781

def capture_before
  @capture_before
end

#cardholder_nameObject (readonly)

The cardholder name as read from the card, in ISO 7813 format. May include alphanumeric characters, special characters and first/last name separator (/). In some cases, the cardholder name may not be available depending on how the issuer has configured the card. Cardholder name is typically not available on swipe or contactless payments, such as those made with Apple Pay and Google Pay.



783
784
785
# File 'lib/stripe/resources/payment_attempt_record.rb', line 783

def cardholder_name
  @cardholder_name
end

#countryObject (readonly)

Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you've collected.



785
786
787
# File 'lib/stripe/resources/payment_attempt_record.rb', line 785

def country
  @country
end

#descriptionObject (readonly)

A high-level description of the type of cards issued in this range. (For internal use only and not typically available in standard API requests.)



787
788
789
# File 'lib/stripe/resources/payment_attempt_record.rb', line 787

def description
  @description
end

#emv_auth_dataObject (readonly)

Authorization response cryptogram.



789
790
791
# File 'lib/stripe/resources/payment_attempt_record.rb', line 789

def emv_auth_data
  @emv_auth_data
end

#exp_monthObject (readonly)

Two-digit number representing the card's expiration month.



791
792
793
# File 'lib/stripe/resources/payment_attempt_record.rb', line 791

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

Four-digit number representing the card's expiration year.



793
794
795
# File 'lib/stripe/resources/payment_attempt_record.rb', line 793

def exp_year
  @exp_year
end

#fingerprintObject (readonly)

Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example. For payment methods that tokenize card information (Apple Pay, Google Pay), the tokenized number might be provided instead of the underlying card number.

As of May 1, 2021, card fingerprint in India for Connect changed to allow two fingerprints for the same card---one for India and one for the rest of the world.



797
798
799
# File 'lib/stripe/resources/payment_attempt_record.rb', line 797

def fingerprint
  @fingerprint
end

#fundingObject (readonly)

Card funding type. Can be credit, debit, prepaid, or unknown.



799
800
801
# File 'lib/stripe/resources/payment_attempt_record.rb', line 799

def funding
  @funding
end

#generated_cardObject (readonly)

ID of a card PaymentMethod generated from the card_present PaymentMethod that may be attached to a Customer for future transactions. Only present if it was possible to generate a card PaymentMethod.



801
802
803
# File 'lib/stripe/resources/payment_attempt_record.rb', line 801

def generated_card
  @generated_card
end

#iinObject (readonly)

Issuer identification number of the card. (For internal use only and not typically available in standard API requests.)



803
804
805
# File 'lib/stripe/resources/payment_attempt_record.rb', line 803

def iin
  @iin
end

#incremental_authorization_supportedObject (readonly)

Whether this PaymentIntent is eligible for incremental authorizations. Request support using request_incremental_authorization_support.



805
806
807
# File 'lib/stripe/resources/payment_attempt_record.rb', line 805

def incremental_authorization_supported
  @incremental_authorization_supported
end

#issuerObject (readonly)

The name of the card's issuing bank. (For internal use only and not typically available in standard API requests.)



807
808
809
# File 'lib/stripe/resources/payment_attempt_record.rb', line 807

def issuer
  @issuer
end

#last4Object (readonly)

The last four digits of the card.



809
810
811
# File 'lib/stripe/resources/payment_attempt_record.rb', line 809

def last4
  @last4
end

#locationObject (readonly)

ID of the location that this transaction's reader is assigned to.



811
812
813
# File 'lib/stripe/resources/payment_attempt_record.rb', line 811

def location
  @location
end

#multicaptureObject (readonly)

Attribute for field multicapture



813
814
815
# File 'lib/stripe/resources/payment_attempt_record.rb', line 813

def multicapture
  @multicapture
end

#networkObject (readonly)

Identifies which network this charge was processed on. Can be amex, cartes_bancaires, diners, discover, eftpos_au, interac, jcb, link, mastercard, unionpay, visa, or unknown.



815
816
817
# File 'lib/stripe/resources/payment_attempt_record.rb', line 815

def network
  @network
end

#network_transaction_idObject (readonly)

This is used by the financial networks to identify a transaction. Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data. This value will be present if it is returned by the financial network in the authorization response, and null otherwise.



817
818
819
# File 'lib/stripe/resources/payment_attempt_record.rb', line 817

def network_transaction_id
  @network_transaction_id
end

#offlineObject (readonly)

Details about payments collected offline.



819
820
821
# File 'lib/stripe/resources/payment_attempt_record.rb', line 819

def offline
  @offline
end

#overcapture_supportedObject (readonly)

Defines whether the authorized amount can be over-captured or not



821
822
823
# File 'lib/stripe/resources/payment_attempt_record.rb', line 821

def overcapture_supported
  @overcapture_supported
end

#preferred_localesObject (readonly)

The languages that the issuing bank recommends using for localizing any customer-facing text, as read from the card. Referenced from EMV tag 5F2D, data encoded on the card's chip.



823
824
825
# File 'lib/stripe/resources/payment_attempt_record.rb', line 823

def preferred_locales
  @preferred_locales
end

#read_methodObject (readonly)

How card details were read in this transaction.



825
826
827
# File 'lib/stripe/resources/payment_attempt_record.rb', line 825

def read_method
  @read_method
end

#readerObject (readonly)

ID of the reader this transaction was made on.



827
828
829
# File 'lib/stripe/resources/payment_attempt_record.rb', line 827

def reader
  @reader
end

#reauthorizationObject (readonly)

Whether the PaymentIntent can be reauthorized or not.



829
830
831
# File 'lib/stripe/resources/payment_attempt_record.rb', line 829

def reauthorization
  @reauthorization
end

#reauthorize_beforeObject (readonly)

The time at which the associated PaymentIntent will transition to a terminal state if it is not reauthorized.



831
832
833
# File 'lib/stripe/resources/payment_attempt_record.rb', line 831

def reauthorize_before
  @reauthorize_before
end

#receiptObject (readonly)

A collection of fields required to be displayed on receipts. Only required for EMV transactions.



833
834
835
# File 'lib/stripe/resources/payment_attempt_record.rb', line 833

def receipt
  @receipt
end

#retrieval_reference_numberObject (readonly)

The retrieval reference number assigned to this transaction.



835
836
837
# File 'lib/stripe/resources/payment_attempt_record.rb', line 835

def retrieval_reference_number
  @retrieval_reference_number
end

#walletObject (readonly)

Attribute for field wallet



837
838
839
# File 'lib/stripe/resources/payment_attempt_record.rb', line 837

def wallet
  @wallet
end

Class Method Details

.field_remappingsObject



849
850
851
# File 'lib/stripe/resources/payment_attempt_record.rb', line 849

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



839
840
841
842
843
844
845
846
847
# File 'lib/stripe/resources/payment_attempt_record.rb', line 839

def self.inner_class_types
  @inner_class_types = {
    multicapture: Multicapture,
    offline: Offline,
    reauthorization: Reauthorization,
    receipt: Receipt,
    wallet: Wallet,
  }
end