Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Crypto

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#buyer_addressObject (readonly)

The wallet address of the customer.



385
386
387
# File 'lib/stripe/resources/payment_attempt_record.rb', line 385

def buyer_address
  @buyer_address
end

#networkObject (readonly)

The blockchain network that the transaction was sent on.



387
388
389
# File 'lib/stripe/resources/payment_attempt_record.rb', line 387

def network
  @network
end

#token_currencyObject (readonly)

The token currency that the transaction was sent with.



389
390
391
# File 'lib/stripe/resources/payment_attempt_record.rb', line 389

def token_currency
  @token_currency
end

#transaction_hashObject (readonly)

The blockchain transaction hash of the crypto payment.



391
392
393
# File 'lib/stripe/resources/payment_attempt_record.rb', line 391

def transaction_hash
  @transaction_hash
end