Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::GiftCard

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: Balance

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#balanceObject (readonly)

The balance of the gift card after the transaction.



945
946
947
# File 'lib/stripe/resources/payment_attempt_record.rb', line 945

def balance
  @balance
end

#brandObject (readonly)

The brand of the gift card.



947
948
949
# File 'lib/stripe/resources/payment_attempt_record.rb', line 947

def brand
  @brand
end

#exp_monthObject (readonly)

The expiration month of the gift card.



949
950
951
# File 'lib/stripe/resources/payment_attempt_record.rb', line 949

def exp_month
  @exp_month
end

#exp_yearObject (readonly)

The expiration year of the gift card.



951
952
953
# File 'lib/stripe/resources/payment_attempt_record.rb', line 951

def exp_year
  @exp_year
end

#first6Object (readonly)

The first six digits of the gift card number.



953
954
955
# File 'lib/stripe/resources/payment_attempt_record.rb', line 953

def first6
  @first6
end

#last4Object (readonly)

The last four digits of the gift card number.



955
956
957
# File 'lib/stripe/resources/payment_attempt_record.rb', line 955

def last4
  @last4
end

#transaction_idObject (readonly)

The transaction ID from the gift card processor.



957
958
959
# File 'lib/stripe/resources/payment_attempt_record.rb', line 957

def transaction_id
  @transaction_id
end

Class Method Details

.field_remappingsObject



963
964
965
# File 'lib/stripe/resources/payment_attempt_record.rb', line 963

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



959
960
961
# File 'lib/stripe/resources/payment_attempt_record.rb', line 959

def self.inner_class_types
  @inner_class_types = { balance: Balance }
end