Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::GiftCard
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::GiftCard
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Defined Under Namespace
Classes: Balance
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#balance ⇒ Object
readonly
Attribute for field balance.
-
#brand ⇒ Object
readonly
The brand of the gift card.
-
#exp_month ⇒ Object
readonly
The expiration month of the gift card.
-
#exp_year ⇒ Object
readonly
The expiration year of the gift card.
-
#first6 ⇒ Object
readonly
The first six digits of the gift card number.
-
#transaction_id ⇒ Object
readonly
The transaction ID from the gift card processor.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#balance ⇒ Object (readonly)
Attribute for field balance
934 935 936 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 934 def balance @balance end |
#brand ⇒ Object (readonly)
The brand of the gift card.
936 937 938 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 936 def brand @brand end |
#exp_month ⇒ Object (readonly)
The expiration month of the gift card.
938 939 940 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 938 def exp_month @exp_month end |
#exp_year ⇒ Object (readonly)
The expiration year of the gift card.
940 941 942 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 940 def exp_year @exp_year end |
#first6 ⇒ Object (readonly)
The first six digits of the gift card number.
942 943 944 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 942 def first6 @first6 end |
#transaction_id ⇒ Object (readonly)
The transaction ID from the gift card processor.
944 945 946 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 944 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
950 951 952 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 950 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
946 947 948 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 946 def self.inner_class_types @inner_class_types = { balance: Balance } end |