Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Giropay
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::Giropay
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#bank_code ⇒ Object
readonly
Bank code of bank associated with the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#bic ⇒ Object
readonly
Bank Identifier Code of the bank associated with the bank account.
-
#verified_name ⇒ Object
readonly
Owner's verified full name.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#bank_code ⇒ Object (readonly)
Bank code of bank associated with the bank account.
998 999 1000 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 998 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1000 1001 1002 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1000 def bank_name @bank_name end |
#bic ⇒ Object (readonly)
Bank Identifier Code of the bank associated with the bank account.
1002 1003 1004 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1002 def bic @bic end |
#verified_name ⇒ Object (readonly)
Owner's verified full name. Values are verified or provided by Giropay directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Giropay rarely provides this information so the attribute is usually empty.
1004 1005 1006 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1004 def verified_name @verified_name end |
Class Method Details
.field_remappings ⇒ Object
1010 1011 1012 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1010 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1006 1007 1008 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1006 def self.inner_class_types @inner_class_types = {} end |