Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Giropay

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



909
910
911
# File 'lib/stripe/resources/payment_attempt_record.rb', line 909

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



911
912
913
# File 'lib/stripe/resources/payment_attempt_record.rb', line 911

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



913
914
915
# File 'lib/stripe/resources/payment_attempt_record.rb', line 913

def bic
  @bic
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by Giropay directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Giropay rarely provides this information so the attribute is usually empty.



915
916
917
# File 'lib/stripe/resources/payment_attempt_record.rb', line 915

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



921
922
923
# File 'lib/stripe/resources/payment_attempt_record.rb', line 921

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



917
918
919
# File 'lib/stripe/resources/payment_attempt_record.rb', line 917

def self.inner_class_types
  @inner_class_types = {}
end