Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Giropay

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



912
913
914
# File 'lib/stripe/resources/payment_attempt_record.rb', line 912

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



914
915
916
# File 'lib/stripe/resources/payment_attempt_record.rb', line 914

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



916
917
918
# File 'lib/stripe/resources/payment_attempt_record.rb', line 916

def bic
  @bic
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by Giropay directly (if supported) at the time of authorization or settlement. They cannot be set or mutated. Giropay rarely provides this information so the attribute is usually empty.



918
919
920
# File 'lib/stripe/resources/payment_attempt_record.rb', line 918

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



924
925
926
# File 'lib/stripe/resources/payment_attempt_record.rb', line 924

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



920
921
922
# File 'lib/stripe/resources/payment_attempt_record.rb', line 920

def self.inner_class_types
  @inner_class_types = {}
end