Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::IdBankTransfer

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_numberObject (readonly)

Account number of the bank account to transfer funds to.



938
939
940
# File 'lib/stripe/resources/payment_attempt_record.rb', line 938

def 
  @account_number
end

#bankObject (readonly)

Bank where the account is located.



940
941
942
# File 'lib/stripe/resources/payment_attempt_record.rb', line 940

def bank
  @bank
end

#bank_codeObject (readonly)

Local bank code of the bank.



942
943
944
# File 'lib/stripe/resources/payment_attempt_record.rb', line 942

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



944
945
946
# File 'lib/stripe/resources/payment_attempt_record.rb', line 944

def bank_name
  @bank_name
end

#display_nameObject (readonly)

Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.



946
947
948
# File 'lib/stripe/resources/payment_attempt_record.rb', line 946

def display_name
  @display_name
end

Class Method Details

.field_remappingsObject



952
953
954
# File 'lib/stripe/resources/payment_attempt_record.rb', line 952

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



948
949
950
# File 'lib/stripe/resources/payment_attempt_record.rb', line 948

def self.inner_class_types
  @inner_class_types = {}
end