Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::IdBankTransfer
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::IdBankTransfer
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_number ⇒ Object
readonly
Account number of the bank account to transfer funds to.
-
#bank ⇒ Object
readonly
Bank where the account is located.
-
#bank_code ⇒ Object
readonly
Local bank code of the bank.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#display_name ⇒ Object
readonly
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_number ⇒ Object (readonly)
Account number of the bank account to transfer funds to.
836 837 838 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 836 def account_number @account_number end |
#bank ⇒ Object (readonly)
Bank where the account is located.
838 839 840 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 838 def bank @bank end |
#bank_code ⇒ Object (readonly)
Local bank code of the bank.
840 841 842 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 840 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
842 843 844 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 842 def bank_name @bank_name end |
#display_name ⇒ Object (readonly)
Merchant name and billing details name, for the customer to check for the correct merchant when performing the bank transfer.
844 845 846 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 844 def display_name @display_name end |
Class Method Details
.field_remappings ⇒ Object
850 851 852 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 850 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
846 847 848 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 846 def self.inner_class_types @inner_class_types = {} end |