Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer’s bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1258 1259 1260 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1258 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
1260 1261 1262 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1260 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1262 1263 1264 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1262 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
1264 1265 1266 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1264 def branch_code @branch_code end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.
1266 1267 1268 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1266 def expected_debit_date @expected_debit_date end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1268 1269 1270 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1268 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1270 1271 1272 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1270 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1276 1277 1278 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1276 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1272 1273 1274 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1272 def self.inner_class_types @inner_class_types = {} end |