Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer’s bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1278 1279 1280 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1278 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
1280 1281 1282 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1280 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1282 1283 1284 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1282 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
1284 1285 1286 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1284 def branch_code @branch_code end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.
1286 1287 1288 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1286 def expected_debit_date @expected_debit_date end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1288 1289 1290 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1288 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1290 1291 1292 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1290 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1296 1297 1298 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1296 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1292 1293 1294 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1292 def self.inner_class_types @inner_class_types = {} end |