Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::NzBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
readonly
The name on the bank account.
-
#bank_code ⇒ Object
readonly
The numeric code for the bank account’s bank.
-
#bank_name ⇒ Object
readonly
The name of the bank.
-
#branch_code ⇒ Object
readonly
The numeric code for the bank account’s bank branch.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer’s bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#suffix ⇒ Object
readonly
The suffix of the bank account number.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_name ⇒ Object (readonly)
The name on the bank account. Only present if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
1212 1213 1214 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1212 def account_holder_name @account_holder_name end |
#bank_code ⇒ Object (readonly)
The numeric code for the bank account’s bank.
1214 1215 1216 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1214 def bank_code @bank_code end |
#bank_name ⇒ Object (readonly)
The name of the bank.
1216 1217 1218 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1216 def bank_name @bank_name end |
#branch_code ⇒ Object (readonly)
The numeric code for the bank account’s bank branch.
1218 1219 1220 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1218 def branch_code @branch_code end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.
1220 1221 1222 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1220 def expected_debit_date @expected_debit_date end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1222 1223 1224 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1222 def last4 @last4 end |
#suffix ⇒ Object (readonly)
The suffix of the bank account number.
1224 1225 1226 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1224 def suffix @suffix end |
Class Method Details
.field_remappings ⇒ Object
1230 1231 1232 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1230 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1226 1227 1228 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1226 def self.inner_class_types @inner_class_types = {} end |