Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer's country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1514
1515
1516
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1514

def country
  @country
end

#payer_emailObject (readonly)

Owner's email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1517
1518
1519
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1517

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



1519
1520
1521
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1519

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner's full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1522
1523
1524
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1522

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



1524
1525
1526
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1524

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1528
1529
1530
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1528

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



1530
1531
1532
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1530

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1534
1535
1536
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1534

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner's verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1537
1538
1539
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1537

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner's verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1540
1541
1542
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1540

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1550
1551
1552
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1550

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1542
1543
1544
1545
1546
1547
1548
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1542

def self.inner_class_types
  @inner_class_types = {
    seller_protection: SellerProtection,
    shipping: Shipping,
    verified_address: VerifiedAddress,
  }
end