Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer’s country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1474
1475
1476
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1474

def country
  @country
end

#payer_emailObject (readonly)

Owner’s email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1477
1478
1479
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1477

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



1479
1480
1481
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1479

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner’s full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1482
1483
1484
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1482

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



1484
1485
1486
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1484

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1488
1489
1490
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1488

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



1490
1491
1492
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1490

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1494
1495
1496
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1494

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner’s verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1497
1498
1499
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1497

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1500
1501
1502
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1500

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1510
1511
1512
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1510

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1502
1503
1504
1505
1506
1507
1508
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1502

def self.inner_class_types
  @inner_class_types = {
    seller_protection: SellerProtection,
    shipping: Shipping,
    verified_address: VerifiedAddress,
  }
end