Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer’s country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1430
1431
1432
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1430

def country
  @country
end

#payer_emailObject (readonly)

Owner’s email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1433
1434
1435
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1433

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



1435
1436
1437
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1435

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner’s full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1438
1439
1440
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1438

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



1440
1441
1442
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1440

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1444
1445
1446
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1444

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



1446
1447
1448
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1446

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1450
1451
1452
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1450

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner’s verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1453
1454
1455
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1453

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1456
1457
1458
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1456

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1466
1467
1468
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1466

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1458
1459
1460
1461
1462
1463
1464
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1458

def self.inner_class_types
  @inner_class_types = {
    seller_protection: SellerProtection,
    shipping: Shipping,
    verified_address: VerifiedAddress,
  }
end