Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Paypal
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::Paypal
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Defined Under Namespace
Classes: SellerProtection
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#country ⇒ Object
readonly
Two-letter ISO code representing the buyer’s country.
-
#payer_email ⇒ Object
readonly
Owner’s email.
-
#payer_id ⇒ Object
readonly
PayPal account PayerID.
-
#payer_name ⇒ Object
readonly
Owner’s full name.
-
#seller_protection ⇒ Object
readonly
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
-
#transaction_id ⇒ Object
readonly
A unique ID generated by PayPal for this transaction.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#country ⇒ Object (readonly)
Two-letter ISO code representing the buyer’s country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1325 1326 1327 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1325 def country @country end |
#payer_email ⇒ Object (readonly)
Owner’s email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1328 1329 1330 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1328 def payer_email @payer_email end |
#payer_id ⇒ Object (readonly)
PayPal account PayerID. This identifier uniquely identifies the PayPal customer.
1330 1331 1332 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1330 def payer_id @payer_id end |
#payer_name ⇒ Object (readonly)
Owner’s full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.
1333 1334 1335 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1333 def payer_name @payer_name end |
#seller_protection ⇒ Object (readonly)
The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.
1335 1336 1337 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1335 def seller_protection @seller_protection end |
#transaction_id ⇒ Object (readonly)
A unique ID generated by PayPal for this transaction.
1337 1338 1339 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1337 def transaction_id @transaction_id end |
Class Method Details
.field_remappings ⇒ Object
1343 1344 1345 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1343 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1339 1340 1341 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1339 def self.inner_class_types @inner_class_types = { seller_protection: SellerProtection } end |