Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Paypal

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: SellerProtection, Shipping, VerifiedAddress

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#countryObject (readonly)

Two-letter ISO code representing the buyer’s country. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1350
1351
1352
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1350

def country
  @country
end

#payer_emailObject (readonly)

Owner’s email. Values are provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1353
1354
1355
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1353

def payer_email
  @payer_email
end

#payer_idObject (readonly)

PayPal account PayerID. This identifier uniquely identifies the PayPal customer.



1355
1356
1357
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1355

def payer_id
  @payer_id
end

#payer_nameObject (readonly)

Owner’s full name. Values provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1358
1359
1360
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1358

def payer_name
  @payer_name
end

#seller_protectionObject (readonly)

The level of protection offered as defined by PayPal Seller Protection for Merchants, for this transaction.



1360
1361
1362
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1360

def seller_protection
  @seller_protection
end

#shippingObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1364
1365
1366
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1364

def shipping
  @shipping
end

#transaction_idObject (readonly)

A unique ID generated by PayPal for this transaction.



1366
1367
1368
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1366

def transaction_id
  @transaction_id
end

#verified_addressObject (readonly)

The shipping address for the customer, as supplied by the merchant at the point of payment execution. This shipping address will not be updated if the merchant updates the shipping address on the PaymentIntent after the PaymentIntent was successfully confirmed.



1370
1371
1372
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1370

def verified_address
  @verified_address
end

#verified_emailObject (readonly)

Owner’s verified email. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1373
1374
1375
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1373

def verified_email
  @verified_email
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by PayPal directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1376
1377
1378
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1376

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1386
1387
1388
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1386

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1378
1379
1380
1381
1382
1383
1384
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1378

def self.inner_class_types
  @inner_class_types = {
    seller_protection: SellerProtection,
    shipping: Shipping,
    verified_address: VerifiedAddress,
  }
end