Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1569
1570
1571
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1569

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



1571
1572
1573
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1571

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1573
1574
1575
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1573

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1575
1576
1577
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1575

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



1577
1578
1579
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1577

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](stripe.com/docs/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](stripe.com/docs/api/mandates/retrieve).



1579
1580
1581
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1579

def mandate
  @mandate
end

Class Method Details

.field_remappingsObject



1585
1586
1587
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1585

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1581
1582
1583
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1581

def self.inner_class_types
  @inner_class_types = {}
end