Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::SepaDebit

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



789
790
791
# File 'lib/stripe/resources/payment_attempt_record.rb', line 789

def bank_code
  @bank_code
end

#branch_codeObject (readonly)

Branch code of bank associated with the bank account.



791
792
793
# File 'lib/stripe/resources/payment_attempt_record.rb', line 791

def branch_code
  @branch_code
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



793
794
795
# File 'lib/stripe/resources/payment_attempt_record.rb', line 793

def country
  @country
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



795
796
797
# File 'lib/stripe/resources/payment_attempt_record.rb', line 795

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four characters of the IBAN.



797
798
799
# File 'lib/stripe/resources/payment_attempt_record.rb', line 797

def last4
  @last4
end

#mandateObject (readonly)

Find the ID of the mandate used for this payment under the [payment_method_details.sepa_debit.mandate](stripe.com/docs/api/charges/object#charge_object-payment_method_details-sepa_debit-mandate) property on the Charge. Use this mandate ID to [retrieve the Mandate](stripe.com/docs/api/mandates/retrieve).



799
800
801
# File 'lib/stripe/resources/payment_attempt_record.rb', line 799

def mandate
  @mandate
end