Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1755
1756
1757
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1755

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1757
1758
1759
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1757

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1759
1760
1761
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1759

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1761
1762
1763
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1761

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1763
1764
1765
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1763

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1765
1766
1767
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1765

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1767
1768
1769
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1767

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1769
1770
1771
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1769

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1771
1772
1773
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1771

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1777
1778
1779
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1777

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1773
1774
1775
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1773

def self.inner_class_types
  @inner_class_types = {}
end