Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1694
1695
1696
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1694

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1696
1697
1698
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1696

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1698
1699
1700
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1698

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1700
1701
1702
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1700

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1702
1703
1704
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1702

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1704
1705
1706
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1704

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1706
1707
1708
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1706

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1708
1709
1710
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1708

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1710
1711
1712
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1710

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1716
1717
1718
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1716

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1712
1713
1714
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1712

def self.inner_class_types
  @inner_class_types = {}
end