Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::Sofort

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#bank_codeObject (readonly)

Bank code of bank associated with the bank account.



1520
1521
1522
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1520

def bank_code
  @bank_code
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1522
1523
1524
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1522

def bank_name
  @bank_name
end

#bicObject (readonly)

Bank Identifier Code of the bank associated with the bank account.



1524
1525
1526
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1524

def bic
  @bic
end

#countryObject (readonly)

Two-letter ISO code representing the country the bank account is located in.



1526
1527
1528
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1526

def country
  @country
end

#generated_sepa_debitObject (readonly)

The ID of the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1528
1529
1530
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1528

def generated_sepa_debit
  @generated_sepa_debit
end

#generated_sepa_debit_mandateObject (readonly)

The mandate for the SEPA Direct Debit PaymentMethod which was generated by this Charge.



1530
1531
1532
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1530

def generated_sepa_debit_mandate
  @generated_sepa_debit_mandate
end

#iban_last4Object (readonly)

Last four characters of the IBAN.



1532
1533
1534
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1532

def iban_last4
  @iban_last4
end

#preferred_languageObject (readonly)

Preferred language of the SOFORT authorization page that the customer is redirected to. Can be one of ‘de`, `en`, `es`, `fr`, `it`, `nl`, or `pl`



1535
1536
1537
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1535

def preferred_language
  @preferred_language
end

#verified_nameObject (readonly)

Owner’s verified full name. Values are verified or provided by SOFORT directly (if supported) at the time of authorization or settlement. They cannot be set or mutated.



1538
1539
1540
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1538

def verified_name
  @verified_name
end

Class Method Details

.field_remappingsObject



1544
1545
1546
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1544

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1540
1541
1542
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1540

def self.inner_class_types
  @inner_class_types = {}
end