Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

The type of entity that holds the account. This can be either ‘individual’ or ‘company’.



1822
1823
1824
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1822

def 
  @account_holder_type
end

#account_typeObject (readonly)

The type of the bank account. This can be either ‘checking’ or ‘savings’.



1824
1825
1826
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1824

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1826
1827
1828
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1826

def bank_name
  @bank_name
end

#expected_debit_dateObject (readonly)

Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.



1828
1829
1830
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1828

def expected_debit_date
  @expected_debit_date
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1830
1831
1832
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1830

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1832
1833
1834
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1832

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



1834
1835
1836
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1834

def mandate
  @mandate
end

#payment_referenceObject (readonly)

The ACH payment reference for this transaction.



1836
1837
1838
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1836

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

The routing number for the bank account.



1838
1839
1840
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1838

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



1844
1845
1846
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1844

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1840
1841
1842
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1840

def self.inner_class_types
  @inner_class_types = {}
end