Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
The type of entity that holds the account.
-
#account_type ⇒ Object
readonly
The type of the bank account.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#expected_debit_date ⇒ Object
readonly
Estimated date to debit the customer’s bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#payment_reference ⇒ Object
readonly
The ACH payment reference for this transaction.
-
#routing_number ⇒ Object
readonly
The routing number for the bank account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
The type of entity that holds the account. This can be either ‘individual’ or ‘company’.
1743 1744 1745 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1743 def account_holder_type @account_holder_type end |
#account_type ⇒ Object (readonly)
The type of the bank account. This can be either ‘checking’ or ‘savings’.
1745 1746 1747 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1745 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1747 1748 1749 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1747 def bank_name @bank_name end |
#expected_debit_date ⇒ Object (readonly)
Estimated date to debit the customer’s bank account. A date string in YYYY-MM-DD format.
1749 1750 1751 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1749 def expected_debit_date @expected_debit_date end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
1751 1752 1753 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1751 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1753 1754 1755 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1753 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
1755 1756 1757 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1755 def mandate @mandate end |
#payment_reference ⇒ Object (readonly)
The ACH payment reference for this transaction.
1757 1758 1759 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1757 def payment_reference @payment_reference end |
#routing_number ⇒ Object (readonly)
The routing number for the bank account.
1759 1760 1761 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1759 def routing_number @routing_number end |
Class Method Details
.field_remappings ⇒ Object
1765 1766 1767 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1765 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1761 1762 1763 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1761 def self.inner_class_types @inner_class_types = {} end |