Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::UsBankAccount
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::PaymentMethodDetails::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
readonly
Attribute for field account_holder_type.
-
#account_type ⇒ Object
readonly
Attribute for field account_type.
-
#bank_name ⇒ Object
readonly
Name of the bank associated with the bank account.
-
#fingerprint ⇒ Object
readonly
Uniquely identifies this particular bank account.
-
#last4 ⇒ Object
readonly
Last four digits of the bank account number.
-
#mandate ⇒ Object
readonly
ID of the mandate used to make this payment.
-
#payment_reference ⇒ Object
readonly
Reference number to locate ACH payments with customer’s bank.
-
#routing_number ⇒ Object
readonly
Routing number of the bank account.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#account_holder_type ⇒ Object (readonly)
Attribute for field account_holder_type
1685 1686 1687 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1685 def account_holder_type @account_holder_type end |
#account_type ⇒ Object (readonly)
Attribute for field account_type
1687 1688 1689 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1687 def account_type @account_type end |
#bank_name ⇒ Object (readonly)
Name of the bank associated with the bank account.
1689 1690 1691 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1689 def bank_name @bank_name end |
#fingerprint ⇒ Object (readonly)
Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
1691 1692 1693 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1691 def fingerprint @fingerprint end |
#last4 ⇒ Object (readonly)
Last four digits of the bank account number.
1693 1694 1695 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1693 def last4 @last4 end |
#mandate ⇒ Object (readonly)
ID of the mandate used to make this payment.
1695 1696 1697 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1695 def mandate @mandate end |
#payment_reference ⇒ Object (readonly)
Reference number to locate ACH payments with customer’s bank.
1697 1698 1699 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1697 def payment_reference @payment_reference end |
#routing_number ⇒ Object (readonly)
Routing number of the bank account.
1699 1700 1701 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1699 def routing_number @routing_number end |
Class Method Details
.field_remappings ⇒ Object
1705 1706 1707 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1705 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1701 1702 1703 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1701 def self.inner_class_types @inner_class_types = {} end |