Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Method Summary

Methods inherited from StripeObject

#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Attribute for field account_holder_type



903
904
905
# File 'lib/stripe/resources/payment_attempt_record.rb', line 903

def 
  @account_holder_type
end

#account_typeObject (readonly)

Attribute for field account_type



905
906
907
# File 'lib/stripe/resources/payment_attempt_record.rb', line 905

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



907
908
909
# File 'lib/stripe/resources/payment_attempt_record.rb', line 907

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



909
910
911
# File 'lib/stripe/resources/payment_attempt_record.rb', line 909

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



911
912
913
# File 'lib/stripe/resources/payment_attempt_record.rb', line 911

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



913
914
915
# File 'lib/stripe/resources/payment_attempt_record.rb', line 913

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



915
916
917
# File 'lib/stripe/resources/payment_attempt_record.rb', line 915

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



917
918
919
# File 'lib/stripe/resources/payment_attempt_record.rb', line 917

def routing_number
  @routing_number
end