Class: Stripe::PaymentAttemptRecord::PaymentMethodDetails::UsBankAccount

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#account_holder_typeObject (readonly)

Attribute for field account_holder_type



1624
1625
1626
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1624

def 
  @account_holder_type
end

#account_typeObject (readonly)

Attribute for field account_type



1626
1627
1628
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1626

def 
  @account_type
end

#bank_nameObject (readonly)

Name of the bank associated with the bank account.



1628
1629
1630
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1628

def bank_name
  @bank_name
end

#fingerprintObject (readonly)

Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.



1630
1631
1632
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1630

def fingerprint
  @fingerprint
end

#last4Object (readonly)

Last four digits of the bank account number.



1632
1633
1634
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1632

def last4
  @last4
end

#mandateObject (readonly)

ID of the mandate used to make this payment.



1634
1635
1636
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1634

def mandate
  @mandate
end

#payment_referenceObject (readonly)

Reference number to locate ACH payments with customer’s bank.



1636
1637
1638
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1636

def payment_reference
  @payment_reference
end

#routing_numberObject (readonly)

Routing number of the bank account.



1638
1639
1640
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1638

def routing_number
  @routing_number
end

Class Method Details

.field_remappingsObject



1644
1645
1646
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1644

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1640
1641
1642
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1640

def self.inner_class_types
  @inner_class_types = {}
end