Class: Stripe::PaymentAttemptRecord::ProcessorDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::ProcessorDetails
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Defined Under Namespace
Classes: Custom
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom ⇒ Object
readonly
Custom processors represent payment processors not modeled directly in the Stripe API.
-
#type ⇒ Object
readonly
The processor used for this payment attempt.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom ⇒ Object (readonly)
Custom processors represent payment processors not modeled directly in the Stripe API. This resource consists of details about the custom processor used for this payment attempt.
1936 1937 1938 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1936 def custom @custom end |
#type ⇒ Object (readonly)
The processor used for this payment attempt.
1938 1939 1940 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1938 def type @type end |
Class Method Details
.field_remappings ⇒ Object
1944 1945 1946 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1944 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
1940 1941 1942 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1940 def self.inner_class_types @inner_class_types = { custom: Custom } end |