Class: Stripe::PaymentAttemptRecord::ProcessorDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentAttemptRecord::ProcessorDetails
- Defined in:
- lib/stripe/resources/payment_attempt_record.rb
Defined Under Namespace
Classes: Custom
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#custom ⇒ Object
readonly
Custom processors represent payment processors not modeled directly in the Stripe API.
-
#type ⇒ Object
readonly
The processor used for this payment attempt.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#custom ⇒ Object (readonly)
Custom processors represent payment processors not modeled directly in the Stripe API. This resource consists of details about the custom processor used for this payment attempt.
2067 2068 2069 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2067 def custom @custom end |
#type ⇒ Object (readonly)
The processor used for this payment attempt.
2069 2070 2071 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2069 def type @type end |
Class Method Details
.field_remappings ⇒ Object
2075 2076 2077 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2075 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
2071 2072 2073 |
# File 'lib/stripe/resources/payment_attempt_record.rb', line 2071 def self.inner_class_types @inner_class_types = { custom: Custom } end |