Class: Stripe::PaymentAttemptRecord::ProcessorDetails

Inherits:
StripeObject
  • Object
show all
Defined in:
lib/stripe/resources/payment_attempt_record.rb

Defined Under Namespace

Classes: Custom

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#customObject (readonly)

Custom processors represent payment processors not modeled directly in the Stripe API. This resource consists of details about the custom processor used for this payment attempt.



1865
1866
1867
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1865

def custom
  @custom
end

#typeObject (readonly)

The processor used for this payment attempt.



1867
1868
1869
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1867

def type
  @type
end

Class Method Details

.field_remappingsObject



1873
1874
1875
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1873

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



1869
1870
1871
# File 'lib/stripe/resources/payment_attempt_record.rb', line 1869

def self.inner_class_types
  @inner_class_types = { custom: Custom }
end