Class: Stripe::PaymentAttemptRecordReportFailedParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/params/payment_attempt_record_report_failed_params.rb

Defined Under Namespace

Classes: ProcessorDetails

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h

Constructor Details

#initialize(expand: nil, failed_at: nil, failure_code: nil, metadata: nil, payment_evaluations: nil, processor_details: nil) ⇒ PaymentAttemptRecordReportFailedParams

Returns a new instance of PaymentAttemptRecordReportFailedParams.



38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 38

def initialize(
  expand: nil,
  failed_at: nil,
  failure_code: nil,
  metadata: nil,
  payment_evaluations: nil,
  processor_details: nil
)
  @expand = expand
  @failed_at = failed_at
  @failure_code = failure_code
  @metadata = 
  @payment_evaluations = payment_evaluations
  @processor_details = processor_details
end

Instance Attribute Details

#expandObject

Specifies which fields in the response should be expanded.



26
27
28
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 26

def expand
  @expand
end

#failed_atObject

When the reported payment failed. Measured in seconds since the Unix epoch.



28
29
30
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 28

def failed_at
  @failed_at
end

#failure_codeObject

The failure code for this payment attempt. Must be one of ‘payment_method_customer_decline` or `payment_method_provider_unknown_outcome`.



30
31
32
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 30

def failure_code
  @failure_code
end

#metadataObject

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



32
33
34
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 32

def 
  @metadata
end

#payment_evaluationsObject

Payment evaluations associated with this reported payment.



34
35
36
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 34

def payment_evaluations
  @payment_evaluations
end

#processor_detailsObject

Processor information for this payment.



36
37
38
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 36

def processor_details
  @processor_details
end