Class: Stripe::PaymentAttemptRecordReportFailedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecordReportFailedParams
- Defined in:
- lib/stripe/params/payment_attempt_record_report_failed_params.rb
Defined Under Namespace
Classes: ProcessorDetails
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed_at ⇒ Object
When the reported payment failed.
-
#failure_code ⇒ Object
The failure code for this payment attempt.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#processor_details ⇒ Object
Processor information for this payment.
Instance Method Summary collapse
-
#initialize(expand: nil, failed_at: nil, failure_code: nil, metadata: nil, processor_details: nil) ⇒ PaymentAttemptRecordReportFailedParams
constructor
A new instance of PaymentAttemptRecordReportFailedParams.
Methods inherited from RequestParams
attr_accessor, coerce_params, coerce_value, field_encodings, new, #to_h
Constructor Details
#initialize(expand: nil, failed_at: nil, failure_code: nil, metadata: nil, processor_details: nil) ⇒ PaymentAttemptRecordReportFailedParams
Returns a new instance of PaymentAttemptRecordReportFailedParams.
36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 36 def initialize( expand: nil, failed_at: nil, failure_code: nil, metadata: nil, processor_details: nil ) @expand = @failed_at = failed_at @failure_code = failure_code @metadata = @processor_details = processor_details end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
26 27 28 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 26 def @expand end |
#failed_at ⇒ Object
When the reported payment failed. Measured in seconds since the Unix epoch.
28 29 30 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 28 def failed_at @failed_at end |
#failure_code ⇒ Object
The failure code for this payment attempt. Must be one of ‘payment_method_customer_decline` or `payment_method_provider_unknown_outcome`.
30 31 32 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 30 def failure_code @failure_code end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
32 33 34 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 32 def @metadata end |
#processor_details ⇒ Object
Processor information for this payment.
34 35 36 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 34 def processor_details @processor_details end |