Class: Stripe::PaymentAttemptRecordReportFailedParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentAttemptRecordReportFailedParams
- Defined in:
- lib/stripe/params/payment_attempt_record_report_failed_params.rb
Instance Attribute Summary collapse
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#failed_at ⇒ Object
When the reported payment failed.
-
#failure_code ⇒ Object
The failure code for this payment attempt.
-
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
Instance Method Summary collapse
-
#initialize(expand: nil, failed_at: nil, failure_code: nil, metadata: nil) ⇒ PaymentAttemptRecordReportFailedParams
constructor
A new instance of PaymentAttemptRecordReportFailedParams.
Methods inherited from RequestParams
Constructor Details
#initialize(expand: nil, failed_at: nil, failure_code: nil, metadata: nil) ⇒ PaymentAttemptRecordReportFailedParams
Returns a new instance of PaymentAttemptRecordReportFailedParams.
15 16 17 18 19 20 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 15 def initialize(expand: nil, failed_at: nil, failure_code: nil, metadata: nil) @expand = @failed_at = failed_at @failure_code = failure_code @metadata = end |
Instance Attribute Details
#expand ⇒ Object
Specifies which fields in the response should be expanded.
7 8 9 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 7 def @expand end |
#failed_at ⇒ Object
When the reported payment failed. Measured in seconds since the Unix epoch.
9 10 11 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 9 def failed_at @failed_at end |
#failure_code ⇒ Object
The failure code for this payment attempt. Must be one of ‘payment_method_customer_decline` or `payment_method_provider_unknown_outcome`.
11 12 13 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 11 def failure_code @failure_code end |
#metadata ⇒ Object
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.
13 14 15 |
# File 'lib/stripe/params/payment_attempt_record_report_failed_params.rb', line 13 def @metadata end |