Class: Stripe::PaymentAttemptRecordService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/payment_attempt_record_service.rb

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#list(params = {}, opts = {}) ⇒ Object

List all the Payment Attempt Records attached to the specified Payment Record.



7
8
9
10
11
12
13
14
15
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 7

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/payment_attempt_records",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#report_authenticated(payment_attempt_record, params = {}, opts = {}) ⇒ Object

Report that the specified Payment Attempt Record was authenticated.



18
19
20
21
22
23
24
25
26
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 18

def report_authenticated(payment_attempt_record, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authenticated", { payment_attempt_record: CGI.escape(payment_attempt_record) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#report_authorized(payment_attempt_record, params = {}, opts = {}) ⇒ Object

Report that the specified Payment Attempt Record was authorized.



29
30
31
32
33
34
35
36
37
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 29

def report_authorized(payment_attempt_record, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_authorized", { payment_attempt_record: CGI.escape(payment_attempt_record) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#report_canceled(payment_attempt_record, params = {}, opts = {}) ⇒ Object

Report that the specified Payment Attempt Record was canceled.



40
41
42
43
44
45
46
47
48
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 40

def report_canceled(payment_attempt_record, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_canceled", { payment_attempt_record: CGI.escape(payment_attempt_record) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#report_failed(payment_attempt_record, params = {}, opts = {}) ⇒ Object

Report that the specified Payment Attempt Record failed.



51
52
53
54
55
56
57
58
59
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 51

def report_failed(payment_attempt_record, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_failed", { payment_attempt_record: CGI.escape(payment_attempt_record) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#report_guaranteed(payment_attempt_record, params = {}, opts = {}) ⇒ Object

Report that the specified Payment Attempt Record was guaranteed.



62
63
64
65
66
67
68
69
70
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 62

def report_guaranteed(payment_attempt_record, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_guaranteed", { payment_attempt_record: CGI.escape(payment_attempt_record) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#report_informational(payment_attempt_record, params = {}, opts = {}) ⇒ Object

Report informational updates on the specified Payment Attempt Record.



73
74
75
76
77
78
79
80
81
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 73

def report_informational(payment_attempt_record, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_informational", { payment_attempt_record: CGI.escape(payment_attempt_record) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#report_refund(payment_attempt_record, params = {}, opts = {}) ⇒ Object

Report that the specified Payment Attempt Record was refunded.



84
85
86
87
88
89
90
91
92
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 84

def report_refund(payment_attempt_record, params = {}, opts = {})
  request(
    method: :post,
    path: format("/v1/payment_attempt_records/%<payment_attempt_record>s/report_refund", { payment_attempt_record: CGI.escape(payment_attempt_record) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieves a Payment Attempt Record with the given ID



95
96
97
98
99
100
101
102
103
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 95

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/payment_attempt_records/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end