Class: Stripe::PaymentAttemptRecordService

Inherits:
StripeService show all
Defined in:
lib/stripe/services/payment_attempt_record_service.rb

Defined Under Namespace

Classes: ListParams, RetrieveParams

Instance Method Summary collapse

Methods inherited from StripeService

#initialize, #request, #request_stream

Constructor Details

This class inherits a constructor from Stripe::StripeService

Instance Method Details

#list(params = {}, opts = {}) ⇒ Object

List all the Payment Attempt Records attached to the specified Payment Record.



31
32
33
34
35
36
37
38
39
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 31

def list(params = {}, opts = {})
  request(
    method: :get,
    path: "/v1/payment_attempt_records",
    params: params,
    opts: opts,
    base_address: :api
  )
end

#retrieve(id, params = {}, opts = {}) ⇒ Object

Retrieves a Payment Attempt Record with the given ID



42
43
44
45
46
47
48
49
50
# File 'lib/stripe/services/payment_attempt_record_service.rb', line 42

def retrieve(id, params = {}, opts = {})
  request(
    method: :get,
    path: format("/v1/payment_attempt_records/%<id>s", { id: CGI.escape(id) }),
    params: params,
    opts: opts,
    base_address: :api
  )
end