Class: Stripe::PaymentIntent

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_intent.rb

Overview

A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.

A PaymentIntent transitions through multiple statuses throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.

Related guide: Payment Intents API

Defined Under Namespace

Classes: AmountDetails, AsyncWorkflows, AutomaticPaymentMethods, Hooks, LastPaymentError, ManagedPayments, NextAction, PaymentDetails, PaymentMethodConfigurationDetails, PaymentMethodOptions, PresentmentDetails, Processing, Redaction, Shipping, TransferData

Constant Summary collapse

OBJECT_NAME =
"payment_intent"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allowed_payment_method_typesObject (readonly)

The list of payment method types allowed for use with this payment. Stripe automatically returns compatible payment methods from this list in the payment_method_types field of the response, based on the other PaymentIntent parameters, such as currency, amount, and customer.



4536
4537
4538
# File 'lib/stripe/resources/payment_intent.rb', line 4536

def allowed_payment_method_types
  @allowed_payment_method_types
end

#amountObject (readonly)

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or equivalent in charge currency. The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



4538
4539
4540
# File 'lib/stripe/resources/payment_intent.rb', line 4538

def amount
  @amount
end

#amount_capturableObject (readonly)

Amount that can be captured from this PaymentIntent.



4540
4541
4542
# File 'lib/stripe/resources/payment_intent.rb', line 4540

def amount_capturable
  @amount_capturable
end

#amount_detailsObject (readonly)

Attribute for field amount_details



4542
4543
4544
# File 'lib/stripe/resources/payment_intent.rb', line 4542

def amount_details
  @amount_details
end

#amount_receivedObject (readonly)

Amount that this PaymentIntent collects.



4544
4545
4546
# File 'lib/stripe/resources/payment_intent.rb', line 4544

def amount_received
  @amount_received
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentIntent.



4546
4547
4548
# File 'lib/stripe/resources/payment_intent.rb', line 4546

def application
  @application
end

#application_fee_amountObject (readonly)

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner's Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents use case for connected accounts.



4548
4549
4550
# File 'lib/stripe/resources/payment_intent.rb', line 4548

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject (readonly)

Attribute for field async_workflows



4550
4551
4552
# File 'lib/stripe/resources/payment_intent.rb', line 4550

def async_workflows
  @async_workflows
end

#automatic_payment_methodsObject (readonly)

Settings to configure compatible payment methods from the Stripe Dashboard



4552
4553
4554
# File 'lib/stripe/resources/payment_intent.rb', line 4552

def automatic_payment_methods
  @automatic_payment_methods
end

#canceled_atObject (readonly)

Populated when status is canceled, this is the time at which the PaymentIntent was canceled. Measured in seconds since the Unix epoch.



4554
4555
4556
# File 'lib/stripe/resources/payment_intent.rb', line 4554

def canceled_at
  @canceled_at
end

#cancellation_reasonObject (readonly)

Reason for cancellation of this PaymentIntent, either user-provided (duplicate, fraudulent, requested_by_customer, or abandoned) or generated by Stripe internally (failed_invoice, void_invoice, automatic, or expired).



4556
4557
4558
# File 'lib/stripe/resources/payment_intent.rb', line 4556

def cancellation_reason
  @cancellation_reason
end

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer's account.



4558
4559
4560
# File 'lib/stripe/resources/payment_intent.rb', line 4558

def capture_method
  @capture_method
end

#client_secretObject (readonly)

The client secret of this PaymentIntent. Used for client-side retrieval using a publishable key.

The client secret can be used to complete a payment from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.

Refer to our docs to accept a payment and learn about how client_secret should be handled.



4564
4565
4566
# File 'lib/stripe/resources/payment_intent.rb', line 4564

def client_secret
  @client_secret
end

#confirmation_methodObject (readonly)

Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.



4566
4567
4568
# File 'lib/stripe/resources/payment_intent.rb', line 4566

def confirmation_method
  @confirmation_method
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



4568
4569
4570
# File 'lib/stripe/resources/payment_intent.rb', line 4568

def created
  @created
end

#currencyObject (readonly)

Three-letter ISO currency code, in lowercase. Must be a supported currency.



4570
4571
4572
# File 'lib/stripe/resources/payment_intent.rb', line 4570

def currency
  @currency
end

#customerObject (readonly)

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Customer instead.



4576
4577
4578
# File 'lib/stripe/resources/payment_intent.rb', line 4576

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.

Payment methods attached to other Accounts cannot be used with this PaymentIntent.

If setup_future_usage is set and this PaymentIntent's payment method is not card_present, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is card_present and isn't a digital wallet, then a generated_card payment method representing the card is created and attached to the Account instead.



4582
4583
4584
# File 'lib/stripe/resources/payment_intent.rb', line 4582

def 
  @customer_account
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



4584
4585
4586
# File 'lib/stripe/resources/payment_intent.rb', line 4584

def description
  @description
end

#excluded_payment_method_typesObject (readonly)

The list of payment method types to exclude from use with this payment.



4586
4587
4588
# File 'lib/stripe/resources/payment_intent.rb', line 4586

def excluded_payment_method_types
  @excluded_payment_method_types
end

#fx_quoteObject (readonly)

The FX Quote used for the PaymentIntent.



4588
4589
4590
# File 'lib/stripe/resources/payment_intent.rb', line 4588

def fx_quote
  @fx_quote
end

#hooksObject (readonly)

Attribute for field hooks



4590
4591
4592
# File 'lib/stripe/resources/payment_intent.rb', line 4590

def hooks
  @hooks
end

#idObject (readonly)

Unique identifier for the object.



4592
4593
4594
# File 'lib/stripe/resources/payment_intent.rb', line 4592

def id
  @id
end

#last_payment_errorObject (readonly)

The payment error encountered in the previous PaymentIntent confirmation. It will be cleared if the PaymentIntent is later updated for any reason.



4594
4595
4596
# File 'lib/stripe/resources/payment_intent.rb', line 4594

def last_payment_error
  @last_payment_error
end

#latest_chargeObject (readonly)

ID of the latest Charge object created by this PaymentIntent. This property is null until PaymentIntent confirmation is attempted.



4596
4597
4598
# File 'lib/stripe/resources/payment_intent.rb', line 4596

def latest_charge
  @latest_charge
end

#livemodeObject (readonly)

If the object exists in live mode, the value is true. If the object exists in test mode, the value is false.



4598
4599
4600
# File 'lib/stripe/resources/payment_intent.rb', line 4598

def livemode
  @livemode
end

#managed_paymentsObject (readonly)

Settings for Managed Payments.



4600
4601
4602
# File 'lib/stripe/resources/payment_intent.rb', line 4600

def managed_payments
  @managed_payments
end

#metadataObject (readonly)

Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about storing information in metadata.



4602
4603
4604
# File 'lib/stripe/resources/payment_intent.rb', line 4602

def 
  @metadata
end

#next_actionObject (readonly)

If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.



4604
4605
4606
# File 'lib/stripe/resources/payment_intent.rb', line 4604

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object's type. Objects of the same type share the same value.



4606
4607
4608
# File 'lib/stripe/resources/payment_intent.rb', line 4606

def object
  @object
end

#on_behalf_ofObject (readonly)

You can specify the settlement merchant as the connected account using the on_behalf_of attribute on the charge. See the PaymentIntents use case for connected accounts for details.



4609
4610
4611
# File 'lib/stripe/resources/payment_intent.rb', line 4609

def on_behalf_of
  @on_behalf_of
end

#payment_detailsObject (readonly)

Attribute for field payment_details



4611
4612
4613
# File 'lib/stripe/resources/payment_intent.rb', line 4611

def payment_details
  @payment_details
end

#payment_methodObject (readonly)

ID of the payment method used in this PaymentIntent.



4613
4614
4615
# File 'lib/stripe/resources/payment_intent.rb', line 4613

def payment_method
  @payment_method
end

#payment_method_configuration_detailsObject (readonly)

Information about the payment method configuration used for this PaymentIntent.



4615
4616
4617
# File 'lib/stripe/resources/payment_intent.rb', line 4615

def payment_method_configuration_details
  @payment_method_configuration_details
end

#payment_method_optionsObject (readonly)

Payment-method-specific configuration for this PaymentIntent.



4617
4618
4619
# File 'lib/stripe/resources/payment_intent.rb', line 4617

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types (e.g. card) that this PaymentIntent is allowed to use. A comprehensive list of valid payment method types can be found here.



4619
4620
4621
# File 'lib/stripe/resources/payment_intent.rb', line 4619

def payment_method_types
  @payment_method_types
end

#presentment_detailsObject (readonly)

Attribute for field presentment_details



4621
4622
4623
# File 'lib/stripe/resources/payment_intent.rb', line 4621

def presentment_details
  @presentment_details
end

#processingObject (readonly)

If present, this property tells you about the processing state of the payment.



4623
4624
4625
# File 'lib/stripe/resources/payment_intent.rb', line 4623

def processing
  @processing
end

#receipt_emailObject (readonly)

Email address that the receipt for the resulting payment will be sent to. If receipt_email is specified for a payment in live mode, a receipt will be sent regardless of your email settings.



4625
4626
4627
# File 'lib/stripe/resources/payment_intent.rb', line 4625

def receipt_email
  @receipt_email
end

#redactionObject (readonly)

Redaction status of this PaymentIntent. If the PaymentIntent isn't redacted, this field is null.



4627
4628
4629
# File 'lib/stripe/resources/payment_intent.rb', line 4627

def redaction
  @redaction
end

#reviewObject (readonly)

ID of the review associated with this PaymentIntent, if any.



4629
4630
4631
# File 'lib/stripe/resources/payment_intent.rb', line 4629

def review
  @review
end

#secret_key_confirmationObject (readonly)

Indicates whether confirmation for this PaymentIntent using a secret key is required or optional.



4631
4632
4633
# File 'lib/stripe/resources/payment_intent.rb', line 4631

def secret_key_confirmation
  @secret_key_confirmation
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent's payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to attach the payment method to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don't provide a Customer, you can still attach the payment method to a Customer after the transaction completes.

If the payment method is card_present and isn't a digital wallet, Stripe creates and attaches a generated_card payment method representing the card to the Customer instead.

When processing card payments, Stripe uses setup_future_usage to help you comply with regional legislation and network rules, such as SCA.



4639
4640
4641
# File 'lib/stripe/resources/payment_intent.rb', line 4639

def setup_future_usage
  @setup_future_usage
end

#shippingObject (readonly)

Shipping information for this PaymentIntent.



4641
4642
4643
# File 'lib/stripe/resources/payment_intent.rb', line 4641

def shipping
  @shipping
end

#sourceObject (readonly)

This is a legacy field that will be removed in the future. It is the ID of the Source object that is associated with this PaymentIntent, if one was supplied.



4643
4644
4645
# File 'lib/stripe/resources/payment_intent.rb', line 4643

def source
  @source
end

#statement_descriptorObject (readonly)

Text that appears on the customer's statement as the statement descriptor for a non-card charge. This value overrides the account's default statement descriptor. For information about requirements, including the 22-character limit, see the Statement Descriptor docs.

Setting this value for a card charge returns an error. For card charges, set the statement_descriptor_suffix instead.



4647
4648
4649
# File 'lib/stripe/resources/payment_intent.rb', line 4647

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

Provides information about a card charge. Concatenated to the account's statement descriptor prefix to form the complete statement descriptor that appears on the customer's statement.



4649
4650
4651
# File 'lib/stripe/resources/payment_intent.rb', line 4649

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#statusObject (readonly)

Status of this PaymentIntent, one of requires_payment_method, requires_confirmation, requires_action, processing, requires_capture, canceled, or succeeded. Read more about each PaymentIntent status.



4651
4652
4653
# File 'lib/stripe/resources/payment_intent.rb', line 4651

def status
  @status
end

#transfer_dataObject (readonly)

The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for connected accounts.



4653
4654
4655
# File 'lib/stripe/resources/payment_intent.rb', line 4653

def transfer_data
  @transfer_data
end

#transfer_groupObject (readonly)

A string that identifies the resulting payment as part of a group. Learn more about the use case for connected accounts.



4655
4656
4657
# File 'lib/stripe/resources/payment_intent.rb', line 4655

def transfer_group
  @transfer_group
end

Class Method Details

.apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object

Manually reconcile the remaining amount for a customer_balance PaymentIntent.



4668
4669
4670
4671
4672
4673
4674
4675
# File 'lib/stripe/resources/payment_intent.rb', line 4668

def self.apply_customer_balance(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.cancel(intent, params = {}, opts = {}) ⇒ Object

You can cancel a PaymentIntent object when it's in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, in rare cases, processing.

After it's canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.

You can directly cancel the PaymentIntent for a Checkout Session only when the PaymentIntent has a status of requires_capture. Otherwise, you must expire the Checkout Session.



4696
4697
4698
4699
4700
4701
4702
4703
# File 'lib/stripe/resources/payment_intent.rb', line 4696

def self.cancel(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.capture(intent, params = {}, opts = {}) ⇒ Object

Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.

Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.

Learn more about separate authorization and capture.



4724
4725
4726
4727
4728
4729
4730
4731
# File 'lib/stripe/resources/payment_intent.rb', line 4724

def self.capture(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.confirm(intent, params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.

If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).

If the confirmation_method is automatic, payment may be attempted using our client SDKs and the PaymentIntent's client_secret. After next_actions are handled by the client, no additional confirmation is required to complete the payment.

If the confirmation_method is manual, all payment attempts must be initiated using a secret key.

If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.

There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.



4802
4803
4804
4805
4806
4807
4808
4809
# File 'lib/stripe/resources/payment_intent.rb', line 4802

def self.confirm(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a PaymentIntent object.

After the PaymentIntent is created, attach a payment method and confirm to continue the payment. Learn more about the available payment flows with the Payment Intents API.

When you use confirm=true during creation, it's equivalent to creating and confirming the PaymentIntent in the same call. You can use any parameters available in the confirm API when you supply confirm=true.



4821
4822
4823
# File 'lib/stripe/resources/payment_intent.rb', line 4821

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/payment_intents", params: params, opts: opts)
end

.decrement_authorization(intent, params = {}, opts = {}) ⇒ Object

Perform a decremental authorization on an eligible PaymentIntent. To be eligible, the PaymentIntent's status must be requires_capture and decremental_authorization.status must be available.

Decremental authorizations decrease the authorized amount on your customer's card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.

After decrement, the PaymentIntent object returns with the updated amount. The PaymentIntent will now be capturable up to the new authorized amount.

Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it's fully captured, a PaymentIntent can no longer be decremented.



4866
4867
4868
4869
4870
4871
4872
4873
# File 'lib/stripe/resources/payment_intent.rb', line 4866

def self.decrement_authorization(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



5039
5040
5041
# File 'lib/stripe/resources/payment_intent.rb', line 5039

def self.field_remappings
  @field_remappings = {}
end

.increment_authorization(intent, params = {}, opts = {}) ⇒ Object

Perform an incremental authorization on an eligible PaymentIntent. To be eligible, the PaymentIntent's status must be requires_capture and incremental_authorization_supported must be true.

Incremental authorizations attempt to increase the authorized amount on your customer's card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.

If the incremental authorization succeeds, the PaymentIntent object returns with the updated amount. If the incremental authorization fails, a card_declined error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.

Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it's captured, a PaymentIntent can no longer be incremented.

Learn more about incremental authorizations with in-person payments and online payments.



4936
4937
4938
4939
4940
4941
4942
4943
# File 'lib/stripe/resources/payment_intent.rb', line 4936

def self.increment_authorization(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.inner_class_typesObject



5019
5020
5021
5022
5023
5024
5025
5026
5027
5028
5029
5030
5031
5032
5033
5034
5035
5036
5037
# File 'lib/stripe/resources/payment_intent.rb', line 5019

def self.inner_class_types
  @inner_class_types = {
    amount_details: AmountDetails,
    async_workflows: AsyncWorkflows,
    automatic_payment_methods: AutomaticPaymentMethods,
    hooks: Hooks,
    last_payment_error: LastPaymentError,
    managed_payments: ManagedPayments,
    next_action: NextAction,
    payment_details: PaymentDetails,
    payment_method_configuration_details: PaymentMethodConfigurationDetails,
    payment_method_options: PaymentMethodOptions,
    presentment_details: PresentmentDetails,
    processing: Processing,
    redaction: Redaction,
    shipping: Shipping,
    transfer_data: TransferData,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of PaymentIntents.



4946
4947
4948
# File 'lib/stripe/resources/payment_intent.rb', line 4946

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/payment_intents", params: params, opts: opts)
end

.object_nameObject



24
25
26
# File 'lib/stripe/resources/payment_intent.rb', line 24

def self.object_name
  "payment_intent"
end

.search(params = {}, opts = {}) ⇒ Object



4950
4951
4952
4953
4954
4955
4956
4957
# File 'lib/stripe/resources/payment_intent.rb', line 4950

def self.search(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_intents/search",
    params: params,
    opts: opts
  )
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



4959
4960
4961
# File 'lib/stripe/resources/payment_intent.rb', line 4959

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.trigger_action(intent, params = {}, opts = {}) ⇒ Object

Trigger an external action on a PaymentIntent.



4974
4975
4976
4977
4978
4979
4980
4981
# File 'lib/stripe/resources/payment_intent.rb', line 4974

def self.trigger_action(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.update(intent, params = {}, opts = {}) ⇒ Object

Updates properties on a PaymentIntent object without confirming.

Depending on which properties you update, you might need to confirm the PaymentIntent again. For example, updating the payment_method always requires you to confirm the PaymentIntent again. If you prefer to update and confirm at the same time, we recommend updating properties through the confirm API instead.



4990
4991
4992
4993
4994
4995
4996
4997
# File 'lib/stripe/resources/payment_intent.rb', line 4990

def self.update(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a PaymentIntent object.



5010
5011
5012
5013
5014
5015
5016
5017
# File 'lib/stripe/resources/payment_intent.rb', line 5010

def self.verify_microdeposits(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#apply_customer_balance(params = {}, opts = {}) ⇒ Object

Manually reconcile the remaining amount for a customer_balance PaymentIntent.



4658
4659
4660
4661
4662
4663
4664
4665
# File 'lib/stripe/resources/payment_intent.rb', line 4658

def apply_customer_balance(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#cancel(params = {}, opts = {}) ⇒ Object

You can cancel a PaymentIntent object when it's in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, in rare cases, processing.

After it's canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.

You can directly cancel the PaymentIntent for a Checkout Session only when the PaymentIntent has a status of requires_capture. Otherwise, you must expire the Checkout Session.



4682
4683
4684
4685
4686
4687
4688
4689
# File 'lib/stripe/resources/payment_intent.rb', line 4682

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#capture(params = {}, opts = {}) ⇒ Object

Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.

Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.

Learn more about separate authorization and capture.



4710
4711
4712
4713
4714
4715
4716
4717
# File 'lib/stripe/resources/payment_intent.rb', line 4710

def capture(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#confirm(params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.

If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).

If the confirmation_method is automatic, payment may be attempted using our client SDKs and the PaymentIntent's client_secret. After next_actions are handled by the client, no additional confirmation is required to complete the payment.

If the confirmation_method is manual, all payment attempts must be initiated using a secret key.

If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.

There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.



4763
4764
4765
4766
4767
4768
4769
4770
# File 'lib/stripe/resources/payment_intent.rb', line 4763

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#decrement_authorization(params = {}, opts = {}) ⇒ Object

Perform a decremental authorization on an eligible PaymentIntent. To be eligible, the PaymentIntent's status must be requires_capture and decremental_authorization.status must be available.

Decremental authorizations decrease the authorized amount on your customer's card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.

After decrement, the PaymentIntent object returns with the updated amount. The PaymentIntent will now be capturable up to the new authorized amount.

Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it's fully captured, a PaymentIntent can no longer be decremented.



4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/stripe/resources/payment_intent.rb', line 4841

def decrement_authorization(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#increment_authorization(params = {}, opts = {}) ⇒ Object

Perform an incremental authorization on an eligible PaymentIntent. To be eligible, the PaymentIntent's status must be requires_capture and incremental_authorization_supported must be true.

Incremental authorizations attempt to increase the authorized amount on your customer's card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.

If the incremental authorization succeeds, the PaymentIntent object returns with the updated amount. If the incremental authorization fails, a card_declined error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.

Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it's captured, a PaymentIntent can no longer be incremented.

Learn more about incremental authorizations with in-person payments and online payments.



4901
4902
4903
4904
4905
4906
4907
4908
# File 'lib/stripe/resources/payment_intent.rb', line 4901

def increment_authorization(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#trigger_action(params = {}, opts = {}) ⇒ Object

Trigger an external action on a PaymentIntent.



4964
4965
4966
4967
4968
4969
4970
4971
# File 'lib/stripe/resources/payment_intent.rb', line 4964

def trigger_action(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#verify_microdeposits(params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a PaymentIntent object.



5000
5001
5002
5003
5004
5005
5006
5007
# File 'lib/stripe/resources/payment_intent.rb', line 5000

def verify_microdeposits(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end