Class: Stripe::PaymentIntent

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_intent.rb

Overview

A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.

A PaymentIntent transitions through [multiple statuses](docs.stripe.com/payments/paymentintents/lifecycle) throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.

Related guide: [Payment Intents API](docs.stripe.com/payments/payment-intents)

Defined Under Namespace

Classes: AmountDetails, AutomaticPaymentMethods, Hooks, LastPaymentError, ManagedPayments, NextAction, PaymentDetails, PaymentMethodConfigurationDetails, PaymentMethodOptions, PresentmentDetails, Processing, Shipping, TransferData

Constant Summary collapse

OBJECT_NAME =
"payment_intent"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#amountObject (readonly)

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



2999
3000
3001
# File 'lib/stripe/resources/payment_intent.rb', line 2999

def amount
  @amount
end

#amount_capturableObject (readonly)

Amount that can be captured from this PaymentIntent.



3001
3002
3003
# File 'lib/stripe/resources/payment_intent.rb', line 3001

def amount_capturable
  @amount_capturable
end

#amount_detailsObject (readonly)

Attribute for field amount_details



3003
3004
3005
# File 'lib/stripe/resources/payment_intent.rb', line 3003

def amount_details
  @amount_details
end

#amount_receivedObject (readonly)

Amount that this PaymentIntent collects.



3005
3006
3007
# File 'lib/stripe/resources/payment_intent.rb', line 3005

def amount_received
  @amount_received
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentIntent.



3007
3008
3009
# File 'lib/stripe/resources/payment_intent.rb', line 3007

def application
  @application
end

#application_fee_amountObject (readonly)

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



3009
3010
3011
# File 'lib/stripe/resources/payment_intent.rb', line 3009

def application_fee_amount
  @application_fee_amount
end

#automatic_payment_methodsObject (readonly)

Settings to configure compatible payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods)



3011
3012
3013
# File 'lib/stripe/resources/payment_intent.rb', line 3011

def automatic_payment_methods
  @automatic_payment_methods
end

#canceled_atObject (readonly)

Populated when ‘status` is `canceled`, this is the time at which the PaymentIntent was canceled. Measured in seconds since the Unix epoch.



3013
3014
3015
# File 'lib/stripe/resources/payment_intent.rb', line 3013

def canceled_at
  @canceled_at
end

#cancellation_reasonObject (readonly)

Reason for cancellation of this PaymentIntent, either user-provided (‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`) or generated by Stripe internally (`failed_invoice`, `void_invoice`, `automatic`, or `expired`).



3015
3016
3017
# File 'lib/stripe/resources/payment_intent.rb', line 3015

def cancellation_reason
  @cancellation_reason
end

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer’s account.



3017
3018
3019
# File 'lib/stripe/resources/payment_intent.rb', line 3017

def capture_method
  @capture_method
end

#client_secretObject (readonly)

The client secret of this PaymentIntent. Used for client-side retrieval using a publishable key.

The client secret can be used to complete a payment from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.

Refer to our docs to [accept a payment](docs.stripe.com/payments/accept-a-payment?ui=elements) and learn about how ‘client_secret` should be handled.



3023
3024
3025
# File 'lib/stripe/resources/payment_intent.rb', line 3023

def client_secret
  @client_secret
end

#confirmation_methodObject (readonly)

Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.



3025
3026
3027
# File 'lib/stripe/resources/payment_intent.rb', line 3025

def confirmation_method
  @confirmation_method
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



3027
3028
3029
# File 'lib/stripe/resources/payment_intent.rb', line 3027

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



3029
3030
3031
# File 'lib/stripe/resources/payment_intent.rb', line 3029

def currency
  @currency
end

#customerObject (readonly)

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.



3035
3036
3037
# File 'lib/stripe/resources/payment_intent.rb', line 3035

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.

Payment methods attached to other Accounts cannot be used with this PaymentIntent.

If [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.



3041
3042
3043
# File 'lib/stripe/resources/payment_intent.rb', line 3041

def 
  @customer_account
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



3043
3044
3045
# File 'lib/stripe/resources/payment_intent.rb', line 3043

def description
  @description
end

#excluded_payment_method_typesObject (readonly)

The list of payment method types to exclude from use with this payment.



3045
3046
3047
# File 'lib/stripe/resources/payment_intent.rb', line 3045

def excluded_payment_method_types
  @excluded_payment_method_types
end

#hooksObject (readonly)

Attribute for field hooks



3047
3048
3049
# File 'lib/stripe/resources/payment_intent.rb', line 3047

def hooks
  @hooks
end

#idObject (readonly)

Unique identifier for the object.



3049
3050
3051
# File 'lib/stripe/resources/payment_intent.rb', line 3049

def id
  @id
end

#last_payment_errorObject (readonly)

The payment error encountered in the previous PaymentIntent confirmation. It will be cleared if the PaymentIntent is later updated for any reason.



3051
3052
3053
# File 'lib/stripe/resources/payment_intent.rb', line 3051

def last_payment_error
  @last_payment_error
end

#latest_chargeObject (readonly)

ID of the latest [Charge object](docs.stripe.com/api/charges) created by this PaymentIntent. This property is ‘null` until PaymentIntent confirmation is attempted.



3053
3054
3055
# File 'lib/stripe/resources/payment_intent.rb', line 3053

def latest_charge
  @latest_charge
end

#livemodeObject (readonly)

If the object exists in live mode, the value is ‘true`. If the object exists in test mode, the value is `false`.



3055
3056
3057
# File 'lib/stripe/resources/payment_intent.rb', line 3055

def livemode
  @livemode
end

#managed_paymentsObject (readonly)

Settings for Managed Payments.



3057
3058
3059
# File 'lib/stripe/resources/payment_intent.rb', line 3057

def managed_payments
  @managed_payments
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents/creating-payment-intents#storing-information-in-metadata).



3059
3060
3061
# File 'lib/stripe/resources/payment_intent.rb', line 3059

def 
  @metadata
end

#next_actionObject (readonly)

If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.



3061
3062
3063
# File 'lib/stripe/resources/payment_intent.rb', line 3061

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



3063
3064
3065
# File 'lib/stripe/resources/payment_intent.rb', line 3063

def object
  @object
end

#on_behalf_ofObject (readonly)

You can specify the settlement merchant as the connected account using the ‘on_behalf_of` attribute on the charge. See the PaymentIntents [use case for connected accounts](/payments/connected-accounts) for details.



3066
3067
3068
# File 'lib/stripe/resources/payment_intent.rb', line 3066

def on_behalf_of
  @on_behalf_of
end

#payment_detailsObject (readonly)

Attribute for field payment_details



3068
3069
3070
# File 'lib/stripe/resources/payment_intent.rb', line 3068

def payment_details
  @payment_details
end

#payment_methodObject (readonly)

ID of the payment method used in this PaymentIntent.



3070
3071
3072
# File 'lib/stripe/resources/payment_intent.rb', line 3070

def payment_method
  @payment_method
end

#payment_method_configuration_detailsObject (readonly)

Information about the [payment method configuration](docs.stripe.com/api/payment_method_configurations) used for this PaymentIntent.



3072
3073
3074
# File 'lib/stripe/resources/payment_intent.rb', line 3072

def payment_method_configuration_details
  @payment_method_configuration_details
end

#payment_method_optionsObject (readonly)

Payment-method-specific configuration for this PaymentIntent.



3074
3075
3076
# File 'lib/stripe/resources/payment_intent.rb', line 3074

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types (e.g. card) that this PaymentIntent is allowed to use. A comprehensive list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



3076
3077
3078
# File 'lib/stripe/resources/payment_intent.rb', line 3076

def payment_method_types
  @payment_method_types
end

#presentment_detailsObject (readonly)

Attribute for field presentment_details



3078
3079
3080
# File 'lib/stripe/resources/payment_intent.rb', line 3078

def presentment_details
  @presentment_details
end

#processingObject (readonly)

If present, this property tells you about the processing state of the payment.



3080
3081
3082
# File 'lib/stripe/resources/payment_intent.rb', line 3080

def processing
  @processing
end

#receipt_emailObject (readonly)

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



3082
3083
3084
# File 'lib/stripe/resources/payment_intent.rb', line 3082

def receipt_email
  @receipt_email
end

#reviewObject (readonly)

ID of the review associated with this PaymentIntent, if any.



3084
3085
3086
# File 'lib/stripe/resources/payment_intent.rb', line 3084

def review
  @review
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



3092
3093
3094
# File 'lib/stripe/resources/payment_intent.rb', line 3092

def setup_future_usage
  @setup_future_usage
end

#shippingObject (readonly)

Shipping information for this PaymentIntent.



3094
3095
3096
# File 'lib/stripe/resources/payment_intent.rb', line 3094

def shipping
  @shipping
end

#sourceObject (readonly)

This is a legacy field that will be removed in the future. It is the ID of the Source object that is associated with this PaymentIntent, if one was supplied.



3096
3097
3098
# File 'lib/stripe/resources/payment_intent.rb', line 3096

def source
  @source
end

#statement_descriptorObject (readonly)

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



3100
3101
3102
# File 'lib/stripe/resources/payment_intent.rb', line 3100

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



3102
3103
3104
# File 'lib/stripe/resources/payment_intent.rb', line 3102

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#statusObject (readonly)

Status of this PaymentIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `requires_capture`, `canceled`, or `succeeded`. Read more about each PaymentIntent [status](docs.stripe.com/payments/intents#intent-statuses).



3104
3105
3106
# File 'lib/stripe/resources/payment_intent.rb', line 3104

def status
  @status
end

#transfer_dataObject (readonly)

The data that automatically creates a Transfer after the payment finalizes. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



3106
3107
3108
# File 'lib/stripe/resources/payment_intent.rb', line 3106

def transfer_data
  @transfer_data
end

#transfer_groupObject (readonly)

A string that identifies the resulting payment as part of a group. Learn more about the [use case for connected accounts](docs.stripe.com/connect/separate-charges-and-transfers).



3108
3109
3110
# File 'lib/stripe/resources/payment_intent.rb', line 3108

def transfer_group
  @transfer_group
end

Class Method Details

.apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object

Manually reconcile the remaining amount for a customer_balance PaymentIntent.



3121
3122
3123
3124
3125
3126
3127
3128
# File 'lib/stripe/resources/payment_intent.rb', line 3121

def self.apply_customer_balance(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.cancel(intent, params = {}, opts = {}) ⇒ Object

You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.

After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.

You can directly cancel the PaymentIntent for a Checkout Session only when the PaymentIntent has a status of requires_capture. Otherwise, you must [expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire).



3149
3150
3151
3152
3153
3154
3155
3156
# File 'lib/stripe/resources/payment_intent.rb', line 3149

def self.cancel(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.capture(intent, params = {}, opts = {}) ⇒ Object

Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.

Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.

Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).



3177
3178
3179
3180
3181
3182
3183
3184
# File 'lib/stripe/resources/payment_intent.rb', line 3177

def self.capture(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.confirm(intent, params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.

If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).

If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment.

If the confirmation_method is manual, all payment attempts must be initiated using a secret key.

If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.

There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.



3255
3256
3257
3258
3259
3260
3261
3262
# File 'lib/stripe/resources/payment_intent.rb', line 3255

def self.confirm(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a PaymentIntent object.

After the PaymentIntent is created, attach a payment method and [confirm](docs.stripe.com/docs/api/payment_intents/confirm) to continue the payment. Learn more about <a href=“/docs/payments/payment-intents”>the available payment flows with the Payment Intents API.

When you use confirm=true during creation, it’s equivalent to creating and confirming the PaymentIntent in the same call. You can use any parameters available in the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) when you supply confirm=true.



3274
3275
3276
# File 'lib/stripe/resources/payment_intent.rb', line 3274

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/payment_intents", params: params, opts: opts)
end

.field_remappingsObject



3420
3421
3422
# File 'lib/stripe/resources/payment_intent.rb', line 3420

def self.field_remappings
  @field_remappings = {}
end

.increment_authorization(intent, params = {}, opts = {}) ⇒ Object

Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.

Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.

If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.

Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.

Learn more about incremental authorizations with [in-person payments](docs.stripe.com/docs/terminal/features/incremental-authorizations) and [online payments](docs.stripe.com/docs/payments/incremental-authorization?platform=web&ui=elements).



3339
3340
3341
3342
3343
3344
3345
3346
# File 'lib/stripe/resources/payment_intent.rb', line 3339

def self.increment_authorization(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.inner_class_typesObject



3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
3412
3413
3414
3415
3416
3417
3418
# File 'lib/stripe/resources/payment_intent.rb', line 3402

def self.inner_class_types
  @inner_class_types = {
    amount_details: AmountDetails,
    automatic_payment_methods: AutomaticPaymentMethods,
    hooks: Hooks,
    last_payment_error: LastPaymentError,
    managed_payments: ManagedPayments,
    next_action: NextAction,
    payment_details: PaymentDetails,
    payment_method_configuration_details: PaymentMethodConfigurationDetails,
    payment_method_options: PaymentMethodOptions,
    presentment_details: PresentmentDetails,
    processing: Processing,
    shipping: Shipping,
    transfer_data: TransferData,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of PaymentIntents.



3349
3350
3351
# File 'lib/stripe/resources/payment_intent.rb', line 3349

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/payment_intents", params: params, opts: opts)
end

.object_nameObject



24
25
26
# File 'lib/stripe/resources/payment_intent.rb', line 24

def self.object_name
  "payment_intent"
end

.search(params = {}, opts = {}) ⇒ Object



3353
3354
3355
3356
3357
3358
3359
3360
# File 'lib/stripe/resources/payment_intent.rb', line 3353

def self.search(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_intents/search",
    params: params,
    opts: opts
  )
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



3362
3363
3364
# File 'lib/stripe/resources/payment_intent.rb', line 3362

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.update(intent, params = {}, opts = {}) ⇒ Object

Updates properties on a PaymentIntent object without confirming.

Depending on which properties you update, you might need to confirm the PaymentIntent again. For example, updating the payment_method always requires you to confirm the PaymentIntent again. If you prefer to update and confirm at the same time, we recommend updating properties through the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) instead.



3373
3374
3375
3376
3377
3378
3379
3380
# File 'lib/stripe/resources/payment_intent.rb', line 3373

def self.update(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a PaymentIntent object.



3393
3394
3395
3396
3397
3398
3399
3400
# File 'lib/stripe/resources/payment_intent.rb', line 3393

def self.verify_microdeposits(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#apply_customer_balance(params = {}, opts = {}) ⇒ Object

Manually reconcile the remaining amount for a customer_balance PaymentIntent.



3111
3112
3113
3114
3115
3116
3117
3118
# File 'lib/stripe/resources/payment_intent.rb', line 3111

def apply_customer_balance(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#cancel(params = {}, opts = {}) ⇒ Object

You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.

After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.

You can directly cancel the PaymentIntent for a Checkout Session only when the PaymentIntent has a status of requires_capture. Otherwise, you must [expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire).



3135
3136
3137
3138
3139
3140
3141
3142
# File 'lib/stripe/resources/payment_intent.rb', line 3135

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#capture(params = {}, opts = {}) ⇒ Object

Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.

Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.

Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).



3163
3164
3165
3166
3167
3168
3169
3170
# File 'lib/stripe/resources/payment_intent.rb', line 3163

def capture(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#confirm(params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.

If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).

If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment.

If the confirmation_method is manual, all payment attempts must be initiated using a secret key.

If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.

There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.



3216
3217
3218
3219
3220
3221
3222
3223
# File 'lib/stripe/resources/payment_intent.rb', line 3216

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#increment_authorization(params = {}, opts = {}) ⇒ Object

Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.

Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.

If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.

Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.

Learn more about incremental authorizations with [in-person payments](docs.stripe.com/docs/terminal/features/incremental-authorizations) and [online payments](docs.stripe.com/docs/payments/incremental-authorization?platform=web&ui=elements).



3304
3305
3306
3307
3308
3309
3310
3311
# File 'lib/stripe/resources/payment_intent.rb', line 3304

def increment_authorization(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#verify_microdeposits(params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a PaymentIntent object.



3383
3384
3385
3386
3387
3388
3389
3390
# File 'lib/stripe/resources/payment_intent.rb', line 3383

def verify_microdeposits(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end