Class: Stripe::PaymentIntent

Inherits:
APIResource show all
Extended by:
APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
Includes:
APIOperations::Save
Defined in:
lib/stripe/resources/payment_intent.rb

Overview

A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.

A PaymentIntent transitions through [multiple statuses](docs.stripe.com/payments/paymentintents/lifecycle) throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.

Related guide: [Payment Intents API](docs.stripe.com/payments/payment-intents)

Defined Under Namespace

Classes: AllocatedFunds, AmountDetails, AsyncWorkflows, AutomaticPaymentMethods, Hooks, LastPaymentError, NextAction, PaymentDetails, PaymentMethodConfigurationDetails, PaymentMethodOptions, PaymentsOrchestration, PresentmentDetails, Processing, Shipping, TransferData

Constant Summary collapse

OBJECT_NAME =
"payment_intent"

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from APIResource

#save_with_parent

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Instance Method Summary collapse

Methods included from APIOperations::Create

create

Methods included from APIOperations::List

list

Methods included from APIOperations::NestedResource

nested_resource_class_methods

Methods included from APIOperations::Search

_search

Methods included from APIOperations::Save

included, #save

Methods inherited from APIResource

class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource

Methods included from APIOperations::Request

included

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#allocated_fundsObject (readonly)

Allocated Funds configuration for this PaymentIntent.



4351
4352
4353
# File 'lib/stripe/resources/payment_intent.rb', line 4351

def allocated_funds
  @allocated_funds
end

#amountObject (readonly)

Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).



4353
4354
4355
# File 'lib/stripe/resources/payment_intent.rb', line 4353

def amount
  @amount
end

#amount_capturableObject (readonly)

Amount that can be captured from this PaymentIntent.



4355
4356
4357
# File 'lib/stripe/resources/payment_intent.rb', line 4355

def amount_capturable
  @amount_capturable
end

#amount_detailsObject (readonly)

Attribute for field amount_details



4357
4358
4359
# File 'lib/stripe/resources/payment_intent.rb', line 4357

def amount_details
  @amount_details
end

#amount_receivedObject (readonly)

Amount that this PaymentIntent collects.



4359
4360
4361
# File 'lib/stripe/resources/payment_intent.rb', line 4359

def amount_received
  @amount_received
end

#applicationObject (readonly)

ID of the Connect application that created the PaymentIntent.



4361
4362
4363
# File 'lib/stripe/resources/payment_intent.rb', line 4361

def application
  @application
end

#application_fee_amountObject (readonly)

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



4363
4364
4365
# File 'lib/stripe/resources/payment_intent.rb', line 4363

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject (readonly)

Attribute for field async_workflows



4365
4366
4367
# File 'lib/stripe/resources/payment_intent.rb', line 4365

def async_workflows
  @async_workflows
end

#automatic_payment_methodsObject (readonly)

Settings to configure compatible payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods)



4367
4368
4369
# File 'lib/stripe/resources/payment_intent.rb', line 4367

def automatic_payment_methods
  @automatic_payment_methods
end

#canceled_atObject (readonly)

Populated when ‘status` is `canceled`, this is the time at which the PaymentIntent was canceled. Measured in seconds since the Unix epoch.



4369
4370
4371
# File 'lib/stripe/resources/payment_intent.rb', line 4369

def canceled_at
  @canceled_at
end

#cancellation_reasonObject (readonly)

Reason for cancellation of this PaymentIntent, either user-provided (‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`) or generated by Stripe internally (`failed_invoice`, `void_invoice`, `automatic`, or `expired`).



4371
4372
4373
# File 'lib/stripe/resources/payment_intent.rb', line 4371

def cancellation_reason
  @cancellation_reason
end

#capture_methodObject (readonly)

Controls when the funds will be captured from the customer’s account.



4373
4374
4375
# File 'lib/stripe/resources/payment_intent.rb', line 4373

def capture_method
  @capture_method
end

#client_secretObject (readonly)

The client secret of this PaymentIntent. Used for client-side retrieval using a publishable key.

The client secret can be used to complete a payment from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.

Refer to our docs to [accept a payment](docs.stripe.com/payments/accept-a-payment?ui=elements) and learn about how ‘client_secret` should be handled.



4379
4380
4381
# File 'lib/stripe/resources/payment_intent.rb', line 4379

def client_secret
  @client_secret
end

#confirmation_methodObject (readonly)

Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.



4381
4382
4383
# File 'lib/stripe/resources/payment_intent.rb', line 4381

def confirmation_method
  @confirmation_method
end

#createdObject (readonly)

Time at which the object was created. Measured in seconds since the Unix epoch.



4383
4384
4385
# File 'lib/stripe/resources/payment_intent.rb', line 4383

def created
  @created
end

#currencyObject (readonly)

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



4385
4386
4387
# File 'lib/stripe/resources/payment_intent.rb', line 4385

def currency
  @currency
end

#customerObject (readonly)

ID of the Customer this PaymentIntent belongs to, if one exists.

Payment methods attached to other Customers cannot be used with this PaymentIntent.

If [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.



4391
4392
4393
# File 'lib/stripe/resources/payment_intent.rb', line 4391

def customer
  @customer
end

#customer_accountObject (readonly)

ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.

Payment methods attached to other Accounts cannot be used with this PaymentIntent.

If [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.



4397
4398
4399
# File 'lib/stripe/resources/payment_intent.rb', line 4397

def 
  @customer_account
end

#descriptionObject (readonly)

An arbitrary string attached to the object. Often useful for displaying to users.



4399
4400
4401
# File 'lib/stripe/resources/payment_intent.rb', line 4399

def description
  @description
end

#excluded_payment_method_typesObject (readonly)

The list of payment method types to exclude from use with this payment.



4401
4402
4403
# File 'lib/stripe/resources/payment_intent.rb', line 4401

def excluded_payment_method_types
  @excluded_payment_method_types
end

#fx_quoteObject (readonly)

The FX Quote used for the PaymentIntent.



4403
4404
4405
# File 'lib/stripe/resources/payment_intent.rb', line 4403

def fx_quote
  @fx_quote
end

#hooksObject (readonly)

Attribute for field hooks



4405
4406
4407
# File 'lib/stripe/resources/payment_intent.rb', line 4405

def hooks
  @hooks
end

#idObject (readonly)

Unique identifier for the object.



4407
4408
4409
# File 'lib/stripe/resources/payment_intent.rb', line 4407

def id
  @id
end

#last_payment_errorObject (readonly)

The payment error encountered in the previous PaymentIntent confirmation. It will be cleared if the PaymentIntent is later updated for any reason.



4409
4410
4411
# File 'lib/stripe/resources/payment_intent.rb', line 4409

def last_payment_error
  @last_payment_error
end

#latest_chargeObject (readonly)

ID of the latest [Charge object](docs.stripe.com/api/charges) created by this PaymentIntent. This property is ‘null` until PaymentIntent confirmation is attempted.



4411
4412
4413
# File 'lib/stripe/resources/payment_intent.rb', line 4411

def latest_charge
  @latest_charge
end

#livemodeObject (readonly)

Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.



4413
4414
4415
# File 'lib/stripe/resources/payment_intent.rb', line 4413

def livemode
  @livemode
end

#metadataObject (readonly)

Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents/creating-payment-intents#storing-information-in-metadata).



4415
4416
4417
# File 'lib/stripe/resources/payment_intent.rb', line 4415

def 
  @metadata
end

#next_actionObject (readonly)

If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.



4417
4418
4419
# File 'lib/stripe/resources/payment_intent.rb', line 4417

def next_action
  @next_action
end

#objectObject (readonly)

String representing the object’s type. Objects of the same type share the same value.



4419
4420
4421
# File 'lib/stripe/resources/payment_intent.rb', line 4419

def object
  @object
end

#on_behalf_ofObject (readonly)

You can specify the settlement merchant as the connected account using the ‘on_behalf_of` attribute on the charge. See the PaymentIntents [use case for connected accounts](/payments/connected-accounts) for details.



4422
4423
4424
# File 'lib/stripe/resources/payment_intent.rb', line 4422

def on_behalf_of
  @on_behalf_of
end

#payment_detailsObject (readonly)

Attribute for field payment_details



4424
4425
4426
# File 'lib/stripe/resources/payment_intent.rb', line 4424

def payment_details
  @payment_details
end

#payment_methodObject (readonly)

ID of the payment method used in this PaymentIntent.



4426
4427
4428
# File 'lib/stripe/resources/payment_intent.rb', line 4426

def payment_method
  @payment_method
end

#payment_method_configuration_detailsObject (readonly)

Information about the [payment method configuration](docs.stripe.com/api/payment_method_configurations) used for this PaymentIntent.



4428
4429
4430
# File 'lib/stripe/resources/payment_intent.rb', line 4428

def payment_method_configuration_details
  @payment_method_configuration_details
end

#payment_method_optionsObject (readonly)

Payment-method-specific configuration for this PaymentIntent.



4430
4431
4432
# File 'lib/stripe/resources/payment_intent.rb', line 4430

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject (readonly)

The list of payment method types (e.g. card) that this PaymentIntent is allowed to use. A comprehensive list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



4432
4433
4434
# File 'lib/stripe/resources/payment_intent.rb', line 4432

def payment_method_types
  @payment_method_types
end

#payments_orchestrationObject (readonly)

When you enable this parameter, this PaymentIntent will route your payment to processors that you configure in the dashboard.



4434
4435
4436
# File 'lib/stripe/resources/payment_intent.rb', line 4434

def payments_orchestration
  @payments_orchestration
end

#presentment_detailsObject (readonly)

Attribute for field presentment_details



4436
4437
4438
# File 'lib/stripe/resources/payment_intent.rb', line 4436

def presentment_details
  @presentment_details
end

#processingObject (readonly)

If present, this property tells you about the processing state of the payment.



4438
4439
4440
# File 'lib/stripe/resources/payment_intent.rb', line 4438

def processing
  @processing
end

#receipt_emailObject (readonly)

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



4440
4441
4442
# File 'lib/stripe/resources/payment_intent.rb', line 4440

def receipt_email
  @receipt_email
end

#reviewObject (readonly)

ID of the review associated with this PaymentIntent, if any.



4442
4443
4444
# File 'lib/stripe/resources/payment_intent.rb', line 4442

def review
  @review
end

#secret_key_confirmationObject (readonly)

Indicates whether confirmation for this PaymentIntent using a secret key is ‘required` or `optional`.



4444
4445
4446
# File 'lib/stripe/resources/payment_intent.rb', line 4444

def secret_key_confirmation
  @secret_key_confirmation
end

#setup_future_usageObject (readonly)

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).



4452
4453
4454
# File 'lib/stripe/resources/payment_intent.rb', line 4452

def setup_future_usage
  @setup_future_usage
end

#shared_payment_granted_tokenObject (readonly)

ID of the shared payment token granted to be used in this PaymentIntent



4454
4455
4456
# File 'lib/stripe/resources/payment_intent.rb', line 4454

def shared_payment_granted_token
  @shared_payment_granted_token
end

#shippingObject (readonly)

Shipping information for this PaymentIntent.



4456
4457
4458
# File 'lib/stripe/resources/payment_intent.rb', line 4456

def shipping
  @shipping
end

#sourceObject (readonly)

This is a legacy field that will be removed in the future. It is the ID of the Source object that is associated with this PaymentIntent, if one was supplied.



4458
4459
4460
# File 'lib/stripe/resources/payment_intent.rb', line 4458

def source
  @source
end

#statement_descriptorObject (readonly)

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



4462
4463
4464
# File 'lib/stripe/resources/payment_intent.rb', line 4462

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject (readonly)

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



4464
4465
4466
# File 'lib/stripe/resources/payment_intent.rb', line 4464

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#statusObject (readonly)

Status of this PaymentIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `requires_capture`, `canceled`, or `succeeded`. Read more about each PaymentIntent [status](docs.stripe.com/payments/intents#intent-statuses).



4466
4467
4468
# File 'lib/stripe/resources/payment_intent.rb', line 4466

def status
  @status
end

#transfer_dataObject (readonly)

The data that automatically creates a Transfer after the payment finalizes. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).



4468
4469
4470
# File 'lib/stripe/resources/payment_intent.rb', line 4468

def transfer_data
  @transfer_data
end

#transfer_groupObject (readonly)

A string that identifies the resulting payment as part of a group. Learn more about the [use case for connected accounts](docs.stripe.com/connect/separate-charges-and-transfers).



4470
4471
4472
# File 'lib/stripe/resources/payment_intent.rb', line 4470

def transfer_group
  @transfer_group
end

Class Method Details

.apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object

Manually reconcile the remaining amount for a customer_balance PaymentIntent.



4483
4484
4485
4486
4487
4488
4489
4490
# File 'lib/stripe/resources/payment_intent.rb', line 4483

def self.apply_customer_balance(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.cancel(intent, params = {}, opts = {}) ⇒ Object

You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.

After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.

You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.



4511
4512
4513
4514
4515
4516
4517
4518
# File 'lib/stripe/resources/payment_intent.rb', line 4511

def self.cancel(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.capture(intent, params = {}, opts = {}) ⇒ Object

Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.

Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.

Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).



4539
4540
4541
4542
4543
4544
4545
4546
# File 'lib/stripe/resources/payment_intent.rb', line 4539

def self.capture(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.confirm(intent, params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.

If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).

If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment.

If the confirmation_method is manual, all payment attempts must be initiated using a secret key.

If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.

There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.



4617
4618
4619
4620
4621
4622
4623
4624
# File 'lib/stripe/resources/payment_intent.rb', line 4617

def self.confirm(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.create(params = {}, opts = {}) ⇒ Object

Creates a PaymentIntent object.

After the PaymentIntent is created, attach a payment method and [confirm](docs.stripe.com/docs/api/payment_intents/confirm) to continue the payment. Learn more about <a href=“/docs/payments/payment-intents”>the available payment flows with the Payment Intents API.

When you use confirm=true during creation, it’s equivalent to creating and confirming the PaymentIntent in the same call. You can use any parameters available in the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) when you supply confirm=true.



4636
4637
4638
# File 'lib/stripe/resources/payment_intent.rb', line 4636

def self.create(params = {}, opts = {})
  request_stripe_object(method: :post, path: "/v1/payment_intents", params: params, opts: opts)
end

.decrement_authorization(intent, params = {}, opts = {}) ⇒ Object

Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [decremental_authorization.status](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card-decremental_authorization) must be available.

Decremental authorizations decrease the authorized amount on your customer’s card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.

After decrement, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). The PaymentIntent will now be capturable up to the new authorized amount.

Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it’s fully captured, a PaymentIntent can no longer be decremented.



4681
4682
4683
4684
4685
4686
4687
4688
# File 'lib/stripe/resources/payment_intent.rb', line 4681

def self.decrement_authorization(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.field_remappingsObject



4850
4851
4852
# File 'lib/stripe/resources/payment_intent.rb', line 4850

def self.field_remappings
  @field_remappings = {}
end

.increment_authorization(intent, params = {}, opts = {}) ⇒ Object

Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.

Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.

If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.

Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.

Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).



4747
4748
4749
4750
4751
4752
4753
4754
# File 'lib/stripe/resources/payment_intent.rb', line 4747

def self.increment_authorization(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.inner_class_typesObject



4830
4831
4832
4833
4834
4835
4836
4837
4838
4839
4840
4841
4842
4843
4844
4845
4846
4847
4848
# File 'lib/stripe/resources/payment_intent.rb', line 4830

def self.inner_class_types
  @inner_class_types = {
    allocated_funds: AllocatedFunds,
    amount_details: AmountDetails,
    async_workflows: AsyncWorkflows,
    automatic_payment_methods: AutomaticPaymentMethods,
    hooks: Hooks,
    last_payment_error: LastPaymentError,
    next_action: NextAction,
    payment_details: PaymentDetails,
    payment_method_configuration_details: PaymentMethodConfigurationDetails,
    payment_method_options: PaymentMethodOptions,
    payments_orchestration: PaymentsOrchestration,
    presentment_details: PresentmentDetails,
    processing: Processing,
    shipping: Shipping,
    transfer_data: TransferData,
  }
end

.list(params = {}, opts = {}) ⇒ Object

Returns a list of PaymentIntents.



4757
4758
4759
# File 'lib/stripe/resources/payment_intent.rb', line 4757

def self.list(params = {}, opts = {})
  request_stripe_object(method: :get, path: "/v1/payment_intents", params: params, opts: opts)
end

.object_nameObject



24
25
26
# File 'lib/stripe/resources/payment_intent.rb', line 24

def self.object_name
  "payment_intent"
end

.search(params = {}, opts = {}) ⇒ Object



4761
4762
4763
4764
4765
4766
4767
4768
# File 'lib/stripe/resources/payment_intent.rb', line 4761

def self.search(params = {}, opts = {})
  request_stripe_object(
    method: :get,
    path: "/v1/payment_intents/search",
    params: params,
    opts: opts
  )
end

.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object



4770
4771
4772
# File 'lib/stripe/resources/payment_intent.rb', line 4770

def self.search_auto_paging_each(params = {}, opts = {}, &blk)
  search(params, opts).auto_paging_each(&blk)
end

.trigger_action(intent, params = {}, opts = {}) ⇒ Object

Trigger an external action on a PaymentIntent.



4785
4786
4787
4788
4789
4790
4791
4792
# File 'lib/stripe/resources/payment_intent.rb', line 4785

def self.trigger_action(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.update(intent, params = {}, opts = {}) ⇒ Object

Updates properties on a PaymentIntent object without confirming.

Depending on which properties you update, you might need to confirm the PaymentIntent again. For example, updating the payment_method always requires you to confirm the PaymentIntent again. If you prefer to update and confirm at the same time, we recommend updating properties through the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) instead.



4801
4802
4803
4804
4805
4806
4807
4808
# File 'lib/stripe/resources/payment_intent.rb', line 4801

def self.update(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a PaymentIntent object.



4821
4822
4823
4824
4825
4826
4827
4828
# File 'lib/stripe/resources/payment_intent.rb', line 4821

def self.verify_microdeposits(intent, params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }),
    params: params,
    opts: opts
  )
end

Instance Method Details

#apply_customer_balance(params = {}, opts = {}) ⇒ Object

Manually reconcile the remaining amount for a customer_balance PaymentIntent.



4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/stripe/resources/payment_intent.rb', line 4473

def apply_customer_balance(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#cancel(params = {}, opts = {}) ⇒ Object

You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.

After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.

You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.



4497
4498
4499
4500
4501
4502
4503
4504
# File 'lib/stripe/resources/payment_intent.rb', line 4497

def cancel(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#capture(params = {}, opts = {}) ⇒ Object

Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.

Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.

Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).



4525
4526
4527
4528
4529
4530
4531
4532
# File 'lib/stripe/resources/payment_intent.rb', line 4525

def capture(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#confirm(params = {}, opts = {}) ⇒ Object

Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.

If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).

If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment.

If the confirmation_method is manual, all payment attempts must be initiated using a secret key.

If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.

There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.



4578
4579
4580
4581
4582
4583
4584
4585
# File 'lib/stripe/resources/payment_intent.rb', line 4578

def confirm(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#decrement_authorization(params = {}, opts = {}) ⇒ Object

Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [decremental_authorization.status](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card-decremental_authorization) must be available.

Decremental authorizations decrease the authorized amount on your customer’s card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.

After decrement, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). The PaymentIntent will now be capturable up to the new authorized amount.

Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it’s fully captured, a PaymentIntent can no longer be decremented.



4656
4657
4658
4659
4660
4661
4662
4663
# File 'lib/stripe/resources/payment_intent.rb', line 4656

def decrement_authorization(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#increment_authorization(params = {}, opts = {}) ⇒ Object

Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.

Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.

If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.

Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.

Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).



4714
4715
4716
4717
4718
4719
4720
4721
# File 'lib/stripe/resources/payment_intent.rb', line 4714

def increment_authorization(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#trigger_action(params = {}, opts = {}) ⇒ Object

Trigger an external action on a PaymentIntent.



4775
4776
4777
4778
4779
4780
4781
4782
# File 'lib/stripe/resources/payment_intent.rb', line 4775

def trigger_action(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end

#verify_microdeposits(params = {}, opts = {}) ⇒ Object

Verifies microdeposits on a PaymentIntent object.



4811
4812
4813
4814
4815
4816
4817
4818
# File 'lib/stripe/resources/payment_intent.rb', line 4811

def verify_microdeposits(params = {}, opts = {})
  request_stripe_object(
    method: :post,
    path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }),
    params: params,
    opts: opts
  )
end