Class: Stripe::PaymentIntent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentIntent
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_intent.rb
Overview
A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.
A PaymentIntent transitions through [multiple statuses](docs.stripe.com/payments/paymentintents/lifecycle) throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.
Related guide: [Payment Intents API](docs.stripe.com/payments/payment-intents)
Defined Under Namespace
Classes: AmountDetails, AsyncWorkflows, AutomaticPaymentMethods, Hooks, LastPaymentError, NextAction, PaymentDetails, PaymentMethodConfigurationDetails, PaymentMethodOptions, PresentmentDetails, Processing, Shipping, TransferData
Constant Summary collapse
- OBJECT_NAME =
"payment_intent"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount intended to be collected by this PaymentIntent.
-
#amount_capturable ⇒ Object
readonly
Amount that can be captured from this PaymentIntent.
-
#amount_details ⇒ Object
readonly
Attribute for field amount_details.
-
#amount_received ⇒ Object
readonly
Amount that this PaymentIntent collects.
-
#application ⇒ Object
readonly
ID of the Connect application that created the PaymentIntent.
-
#application_fee_amount ⇒ Object
readonly
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#async_workflows ⇒ Object
readonly
Attribute for field async_workflows.
-
#automatic_payment_methods ⇒ Object
readonly
Settings to configure compatible payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).
-
#canceled_at ⇒ Object
readonly
Populated when ‘status` is `canceled`, this is the time at which the PaymentIntent was canceled.
-
#cancellation_reason ⇒ Object
readonly
Reason for cancellation of this PaymentIntent, either user-provided (‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`) or generated by Stripe internally (`failed_invoice`, `void_invoice`, `automatic`, or `expired`).
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#client_secret ⇒ Object
readonly
The client secret of this PaymentIntent.
-
#confirmation_method ⇒ Object
readonly
Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
ID of the Customer this PaymentIntent belongs to, if one exists.
-
#customer_account ⇒ Object
readonly
ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#excluded_payment_method_types ⇒ Object
readonly
The list of payment method types to exclude from use with this payment.
-
#fx_quote ⇒ Object
readonly
The FX Quote used for the PaymentIntent.
-
#hooks ⇒ Object
readonly
Attribute for field hooks.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_payment_error ⇒ Object
readonly
The payment error encountered in the previous PaymentIntent confirmation.
-
#latest_charge ⇒ Object
readonly
ID of the latest [Charge object](docs.stripe.com/api/charges) created by this PaymentIntent.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object.
-
#next_action ⇒ Object
readonly
If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
You can specify the settlement merchant as the connected account using the ‘on_behalf_of` attribute on the charge.
-
#payment_details ⇒ Object
readonly
Attribute for field payment_details.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this PaymentIntent.
-
#payment_method_configuration_details ⇒ Object
readonly
Information about the [payment method configuration](docs.stripe.com/api/payment_method_configurations) used for this PaymentIntent.
-
#payment_method_options ⇒ Object
readonly
Payment-method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
readonly
The list of payment method types (e.g. card) that this PaymentIntent is allowed to use.
-
#presentment_details ⇒ Object
readonly
Attribute for field presentment_details.
-
#processing ⇒ Object
readonly
If present, this property tells you about the processing state of the payment.
-
#receipt_email ⇒ Object
readonly
Email address that the receipt for the resulting payment will be sent to.
-
#review ⇒ Object
readonly
ID of the review associated with this PaymentIntent, if any.
-
#secret_key_confirmation ⇒ Object
readonly
Indicates whether confirmation for this PaymentIntent using a secret key is ‘required` or `optional`.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
readonly
Shipping information for this PaymentIntent.
-
#source ⇒ Object
readonly
This is a legacy field that will be removed in the future.
-
#statement_descriptor ⇒ Object
readonly
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
Status of this PaymentIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `requires_capture`, `canceled`, or `succeeded`.
-
#transfer_data ⇒ Object
readonly
The data that automatically creates a Transfer after the payment finalizes.
-
#transfer_group ⇒ Object
readonly
A string that identifies the resulting payment as part of a group.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
-
.cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
-
.capture(intent, params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
-
.confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a PaymentIntent object.
-
.decrement_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
- .field_remappings ⇒ Object
-
.increment_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
- .inner_class_types ⇒ Object
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentIntents.
- .object_name ⇒ Object
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.trigger_action(intent, params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
-
.update(intent, params = {}, opts = {}) ⇒ Object
Updates properties on a PaymentIntent object without confirming.
-
.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
Instance Method Summary collapse
-
#apply_customer_balance(params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
-
#cancel(params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
-
#capture(params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method.
-
#decrement_authorization(params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
#increment_authorization(params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
#trigger_action(params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
-
#verify_microdeposits(params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](docs.stripe.com/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
4297 4298 4299 |
# File 'lib/stripe/resources/payment_intent.rb', line 4297 def amount @amount end |
#amount_capturable ⇒ Object (readonly)
Amount that can be captured from this PaymentIntent.
4299 4300 4301 |
# File 'lib/stripe/resources/payment_intent.rb', line 4299 def amount_capturable @amount_capturable end |
#amount_details ⇒ Object (readonly)
Attribute for field amount_details
4301 4302 4303 |
# File 'lib/stripe/resources/payment_intent.rb', line 4301 def amount_details @amount_details end |
#amount_received ⇒ Object (readonly)
Amount that this PaymentIntent collects.
4303 4304 4305 |
# File 'lib/stripe/resources/payment_intent.rb', line 4303 def amount_received @amount_received end |
#application ⇒ Object (readonly)
ID of the Connect application that created the PaymentIntent.
4305 4306 4307 |
# File 'lib/stripe/resources/payment_intent.rb', line 4305 def application @application end |
#application_fee_amount ⇒ Object (readonly)
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
4307 4308 4309 |
# File 'lib/stripe/resources/payment_intent.rb', line 4307 def application_fee_amount @application_fee_amount end |
#async_workflows ⇒ Object (readonly)
Attribute for field async_workflows
4309 4310 4311 |
# File 'lib/stripe/resources/payment_intent.rb', line 4309 def async_workflows @async_workflows end |
#automatic_payment_methods ⇒ Object (readonly)
Settings to configure compatible payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods)
4311 4312 4313 |
# File 'lib/stripe/resources/payment_intent.rb', line 4311 def automatic_payment_methods @automatic_payment_methods end |
#canceled_at ⇒ Object (readonly)
Populated when ‘status` is `canceled`, this is the time at which the PaymentIntent was canceled. Measured in seconds since the Unix epoch.
4313 4314 4315 |
# File 'lib/stripe/resources/payment_intent.rb', line 4313 def canceled_at @canceled_at end |
#cancellation_reason ⇒ Object (readonly)
Reason for cancellation of this PaymentIntent, either user-provided (‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`) or generated by Stripe internally (`failed_invoice`, `void_invoice`, `automatic`, or `expired`).
4315 4316 4317 |
# File 'lib/stripe/resources/payment_intent.rb', line 4315 def cancellation_reason @cancellation_reason end |
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
4317 4318 4319 |
# File 'lib/stripe/resources/payment_intent.rb', line 4317 def capture_method @capture_method end |
#client_secret ⇒ Object (readonly)
The client secret of this PaymentIntent. Used for client-side retrieval using a publishable key.
The client secret can be used to complete a payment from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.
Refer to our docs to [accept a payment](docs.stripe.com/payments/accept-a-payment?ui=elements) and learn about how ‘client_secret` should be handled.
4323 4324 4325 |
# File 'lib/stripe/resources/payment_intent.rb', line 4323 def client_secret @client_secret end |
#confirmation_method ⇒ Object (readonly)
Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.
4325 4326 4327 |
# File 'lib/stripe/resources/payment_intent.rb', line 4325 def confirmation_method @confirmation_method end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
4327 4328 4329 |
# File 'lib/stripe/resources/payment_intent.rb', line 4327 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
4329 4330 4331 |
# File 'lib/stripe/resources/payment_intent.rb', line 4329 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the Customer this PaymentIntent belongs to, if one exists.
Payment methods attached to other Customers cannot be used with this PaymentIntent.
If [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.
4335 4336 4337 |
# File 'lib/stripe/resources/payment_intent.rb', line 4335 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the Account representing the customer that this PaymentIntent belongs to, if one exists.
Payment methods attached to other Accounts cannot be used with this PaymentIntent.
If [setup_future_usage](api.stripe.com#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.
4341 4342 4343 |
# File 'lib/stripe/resources/payment_intent.rb', line 4341 def customer_account @customer_account end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
4343 4344 4345 |
# File 'lib/stripe/resources/payment_intent.rb', line 4343 def description @description end |
#excluded_payment_method_types ⇒ Object (readonly)
The list of payment method types to exclude from use with this payment.
4345 4346 4347 |
# File 'lib/stripe/resources/payment_intent.rb', line 4345 def excluded_payment_method_types @excluded_payment_method_types end |
#fx_quote ⇒ Object (readonly)
The FX Quote used for the PaymentIntent.
4347 4348 4349 |
# File 'lib/stripe/resources/payment_intent.rb', line 4347 def fx_quote @fx_quote end |
#hooks ⇒ Object (readonly)
Attribute for field hooks
4349 4350 4351 |
# File 'lib/stripe/resources/payment_intent.rb', line 4349 def hooks @hooks end |
#id ⇒ Object (readonly)
Unique identifier for the object.
4351 4352 4353 |
# File 'lib/stripe/resources/payment_intent.rb', line 4351 def id @id end |
#last_payment_error ⇒ Object (readonly)
The payment error encountered in the previous PaymentIntent confirmation. It will be cleared if the PaymentIntent is later updated for any reason.
4353 4354 4355 |
# File 'lib/stripe/resources/payment_intent.rb', line 4353 def last_payment_error @last_payment_error end |
#latest_charge ⇒ Object (readonly)
ID of the latest [Charge object](docs.stripe.com/api/charges) created by this PaymentIntent. This property is ‘null` until PaymentIntent confirmation is attempted.
4355 4356 4357 |
# File 'lib/stripe/resources/payment_intent.rb', line 4355 def latest_charge @latest_charge end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
4357 4358 4359 |
# File 'lib/stripe/resources/payment_intent.rb', line 4357 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](docs.stripe.com/payments/payment-intents/creating-payment-intents#storing-information-in-metadata).
4359 4360 4361 |
# File 'lib/stripe/resources/payment_intent.rb', line 4359 def @metadata end |
#next_action ⇒ Object (readonly)
If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.
4361 4362 4363 |
# File 'lib/stripe/resources/payment_intent.rb', line 4361 def next_action @next_action end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
4363 4364 4365 |
# File 'lib/stripe/resources/payment_intent.rb', line 4363 def object @object end |
#on_behalf_of ⇒ Object (readonly)
You can specify the settlement merchant as the connected account using the ‘on_behalf_of` attribute on the charge. See the PaymentIntents [use case for connected accounts](/payments/connected-accounts) for details.
4366 4367 4368 |
# File 'lib/stripe/resources/payment_intent.rb', line 4366 def on_behalf_of @on_behalf_of end |
#payment_details ⇒ Object (readonly)
Attribute for field payment_details
4368 4369 4370 |
# File 'lib/stripe/resources/payment_intent.rb', line 4368 def payment_details @payment_details end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this PaymentIntent.
4370 4371 4372 |
# File 'lib/stripe/resources/payment_intent.rb', line 4370 def payment_method @payment_method end |
#payment_method_configuration_details ⇒ Object (readonly)
Information about the [payment method configuration](docs.stripe.com/api/payment_method_configurations) used for this PaymentIntent.
4372 4373 4374 |
# File 'lib/stripe/resources/payment_intent.rb', line 4372 def payment_method_configuration_details @payment_method_configuration_details end |
#payment_method_options ⇒ Object (readonly)
Payment-method-specific configuration for this PaymentIntent.
4374 4375 4376 |
# File 'lib/stripe/resources/payment_intent.rb', line 4374 def @payment_method_options end |
#payment_method_types ⇒ Object (readonly)
The list of payment method types (e.g. card) that this PaymentIntent is allowed to use. A comprehensive list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
4376 4377 4378 |
# File 'lib/stripe/resources/payment_intent.rb', line 4376 def payment_method_types @payment_method_types end |
#presentment_details ⇒ Object (readonly)
Attribute for field presentment_details
4378 4379 4380 |
# File 'lib/stripe/resources/payment_intent.rb', line 4378 def presentment_details @presentment_details end |
#processing ⇒ Object (readonly)
If present, this property tells you about the processing state of the payment.
4380 4381 4382 |
# File 'lib/stripe/resources/payment_intent.rb', line 4380 def processing @processing end |
#receipt_email ⇒ Object (readonly)
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
4382 4383 4384 |
# File 'lib/stripe/resources/payment_intent.rb', line 4382 def receipt_email @receipt_email end |
#review ⇒ Object (readonly)
ID of the review associated with this PaymentIntent, if any.
4384 4385 4386 |
# File 'lib/stripe/resources/payment_intent.rb', line 4384 def review @review end |
#secret_key_confirmation ⇒ Object (readonly)
Indicates whether confirmation for this PaymentIntent using a secret key is ‘required` or `optional`.
4386 4387 4388 |
# File 'lib/stripe/resources/payment_intent.rb', line 4386 def secret_key_confirmation @secret_key_confirmation end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
4394 4395 4396 |
# File 'lib/stripe/resources/payment_intent.rb', line 4394 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object (readonly)
Shipping information for this PaymentIntent.
4396 4397 4398 |
# File 'lib/stripe/resources/payment_intent.rb', line 4396 def shipping @shipping end |
#source ⇒ Object (readonly)
This is a legacy field that will be removed in the future. It is the ID of the Source object that is associated with this PaymentIntent, if one was supplied.
4398 4399 4400 |
# File 'lib/stripe/resources/payment_intent.rb', line 4398 def source @source end |
#statement_descriptor ⇒ Object (readonly)
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
4402 4403 4404 |
# File 'lib/stripe/resources/payment_intent.rb', line 4402 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
4404 4405 4406 |
# File 'lib/stripe/resources/payment_intent.rb', line 4404 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
Status of this PaymentIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `requires_capture`, `canceled`, or `succeeded`. Read more about each PaymentIntent [status](docs.stripe.com/payments/intents#intent-statuses).
4406 4407 4408 |
# File 'lib/stripe/resources/payment_intent.rb', line 4406 def status @status end |
#transfer_data ⇒ Object (readonly)
The data that automatically creates a Transfer after the payment finalizes. Learn more about the [use case for connected accounts](docs.stripe.com/payments/connected-accounts).
4408 4409 4410 |
# File 'lib/stripe/resources/payment_intent.rb', line 4408 def transfer_data @transfer_data end |
#transfer_group ⇒ Object (readonly)
A string that identifies the resulting payment as part of a group. Learn more about the [use case for connected accounts](docs.stripe.com/connect/separate-charges-and-transfers).
4410 4411 4412 |
# File 'lib/stripe/resources/payment_intent.rb', line 4410 def transfer_group @transfer_group end |
Class Method Details
.apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
4423 4424 4425 4426 4427 4428 4429 4430 |
# File 'lib/stripe/resources/payment_intent.rb', line 4423 def self.apply_customer_balance(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.
You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/stripe/resources/payment_intent.rb', line 4451 def self.cancel(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.capture(intent, params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.
Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).
4479 4480 4481 4482 4483 4484 4485 4486 |
# File 'lib/stripe/resources/payment_intent.rb', line 4479 def self.capture(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.
If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).
If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment.
If the confirmation_method is manual, all payment attempts must be initiated using a secret key.
If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.
There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.
4557 4558 4559 4560 4561 4562 4563 4564 |
# File 'lib/stripe/resources/payment_intent.rb', line 4557 def self.confirm(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a PaymentIntent object.
After the PaymentIntent is created, attach a payment method and [confirm](docs.stripe.com/docs/api/payment_intents/confirm) to continue the payment. Learn more about <a href=“/docs/payments/payment-intents”>the available payment flows with the Payment Intents API.
When you use confirm=true during creation, it’s equivalent to creating and confirming the PaymentIntent in the same call. You can use any parameters available in the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) when you supply confirm=true.
4576 4577 4578 |
# File 'lib/stripe/resources/payment_intent.rb', line 4576 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/payment_intents", params: params, opts: opts) end |
.decrement_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [decremental_authorization.status](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card-decremental_authorization) must be available.
Decremental authorizations decrease the authorized amount on your customer’s card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.
After decrement, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). The PaymentIntent will now be capturable up to the new authorized amount.
Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it’s fully captured, a PaymentIntent can no longer be decremented.
4621 4622 4623 4624 4625 4626 4627 4628 |
# File 'lib/stripe/resources/payment_intent.rb', line 4621 def self.(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.field_remappings ⇒ Object
4788 4789 4790 |
# File 'lib/stripe/resources/payment_intent.rb', line 4788 def self.field_remappings @field_remappings = {} end |
.increment_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.
Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.
If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.
Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.
Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).
4687 4688 4689 4690 4691 4692 4693 4694 |
# File 'lib/stripe/resources/payment_intent.rb', line 4687 def self.(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.inner_class_types ⇒ Object
4770 4771 4772 4773 4774 4775 4776 4777 4778 4779 4780 4781 4782 4783 4784 4785 4786 |
# File 'lib/stripe/resources/payment_intent.rb', line 4770 def self.inner_class_types @inner_class_types = { amount_details: AmountDetails, async_workflows: AsyncWorkflows, automatic_payment_methods: AutomaticPaymentMethods, hooks: Hooks, last_payment_error: LastPaymentError, next_action: NextAction, payment_details: PaymentDetails, payment_method_configuration_details: PaymentMethodConfigurationDetails, payment_method_options: PaymentMethodOptions, presentment_details: PresentmentDetails, processing: Processing, shipping: Shipping, transfer_data: TransferData, } end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentIntents.
4697 4698 4699 |
# File 'lib/stripe/resources/payment_intent.rb', line 4697 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/payment_intents", params: params, opts: opts) end |
.object_name ⇒ Object
24 25 26 |
# File 'lib/stripe/resources/payment_intent.rb', line 24 def self.object_name "payment_intent" end |
.search(params = {}, opts = {}) ⇒ Object
4701 4702 4703 4704 4705 4706 4707 4708 |
# File 'lib/stripe/resources/payment_intent.rb', line 4701 def self.search(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_intents/search", params: params, opts: opts ) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
4710 4711 4712 |
# File 'lib/stripe/resources/payment_intent.rb', line 4710 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.trigger_action(intent, params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
4725 4726 4727 4728 4729 4730 4731 4732 |
# File 'lib/stripe/resources/payment_intent.rb', line 4725 def self.trigger_action(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.update(intent, params = {}, opts = {}) ⇒ Object
Updates properties on a PaymentIntent object without confirming.
Depending on which properties you update, you might need to confirm the PaymentIntent again. For example, updating the payment_method always requires you to confirm the PaymentIntent again. If you prefer to update and confirm at the same time, we recommend updating properties through the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) instead.
4741 4742 4743 4744 4745 4746 4747 4748 |
# File 'lib/stripe/resources/payment_intent.rb', line 4741 def self.update(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
4761 4762 4763 4764 4765 4766 4767 4768 |
# File 'lib/stripe/resources/payment_intent.rb', line 4761 def self.verify_microdeposits(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
Instance Method Details
#apply_customer_balance(params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
4413 4414 4415 4416 4417 4418 4419 4420 |
# File 'lib/stripe/resources/payment_intent.rb', line 4413 def apply_customer_balance(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#cancel(params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.
You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
4437 4438 4439 4440 4441 4442 4443 4444 |
# File 'lib/stripe/resources/payment_intent.rb', line 4437 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#capture(params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.
Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).
4465 4466 4467 4468 4469 4470 4471 4472 |
# File 'lib/stripe/resources/payment_intent.rb', line 4465 def capture(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#confirm(params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment.
If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual).
If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment.
If the confirmation_method is manual, all payment attempts must be initiated using a secret key.
If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt.
There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.
4518 4519 4520 4521 4522 4523 4524 4525 |
# File 'lib/stripe/resources/payment_intent.rb', line 4518 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#decrement_authorization(params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [decremental_authorization.status](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card-decremental_authorization) must be available.
Decremental authorizations decrease the authorized amount on your customer’s card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.
After decrement, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). The PaymentIntent will now be capturable up to the new authorized amount.
Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it’s fully captured, a PaymentIntent can no longer be decremented.
4596 4597 4598 4599 4600 4601 4602 4603 |
# File 'lib/stripe/resources/payment_intent.rb', line 4596 def (params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#increment_authorization(params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.
Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.
If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.
Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.
Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).
4654 4655 4656 4657 4658 4659 4660 4661 |
# File 'lib/stripe/resources/payment_intent.rb', line 4654 def (params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#trigger_action(params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
4715 4716 4717 4718 4719 4720 4721 4722 |
# File 'lib/stripe/resources/payment_intent.rb', line 4715 def trigger_action(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#verify_microdeposits(params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
4751 4752 4753 4754 4755 4756 4757 4758 |
# File 'lib/stripe/resources/payment_intent.rb', line 4751 def verify_microdeposits(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |