Class: Stripe::PaymentIntent
- Inherits:
-
APIResource
- Object
- StripeObject
- APIResource
- Stripe::PaymentIntent
- Extended by:
- APIOperations::Create, APIOperations::List, APIOperations::NestedResource, APIOperations::Search
- Includes:
- APIOperations::Save
- Defined in:
- lib/stripe/resources/payment_intent.rb
Overview
A PaymentIntent guides you through the process of collecting a payment from your customer. We recommend that you create exactly one PaymentIntent for each order or customer session in your system. You can reference the PaymentIntent later to see the history of payment attempts for a particular session.
A PaymentIntent transitions through [multiple statuses](stripe.com/docs/payments/intents#intent-statuses) throughout its lifetime as it interfaces with Stripe.js to perform authentication flows and ultimately creates at most one successful charge.
Related guide: [Payment Intents API](stripe.com/docs/payments/payment-intents)
Defined Under Namespace
Classes: AmountDetails, ApplyCustomerBalanceParams, AutomaticPaymentMethods, CancelParams, CaptureParams, ConfirmParams, CreateParams, DecrementAuthorizationParams, Hooks, IncrementAuthorizationParams, LastPaymentError, ListParams, NextAction, PaymentDetails, PaymentMethodConfigurationDetails, PaymentMethodOptions, PresentmentDetails, Processing, SearchParams, Shipping, TransferData, TriggerActionParams, UpdateParams, VerifyMicrodepositsParams
Constant Summary collapse
- OBJECT_NAME =
"payment_intent"
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Amount intended to be collected by this PaymentIntent.
-
#amount_capturable ⇒ Object
readonly
Amount that can be captured from this PaymentIntent.
-
#amount_details ⇒ Object
readonly
Attribute for field amount_details.
-
#amount_received ⇒ Object
readonly
Amount that this PaymentIntent collects.
-
#application ⇒ Object
readonly
ID of the Connect application that created the PaymentIntent.
-
#application_fee_amount ⇒ Object
readonly
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#automatic_payment_methods ⇒ Object
readonly
Settings to configure compatible payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).
-
#canceled_at ⇒ Object
readonly
Populated when ‘status` is `canceled`, this is the time at which the PaymentIntent was canceled.
-
#cancellation_reason ⇒ Object
readonly
Reason for cancellation of this PaymentIntent, either user-provided (‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`) or generated by Stripe internally (`failed_invoice`, `void_invoice`, `automatic`, or `expired`).
-
#capture_method ⇒ Object
readonly
Controls when the funds will be captured from the customer’s account.
-
#client_secret ⇒ Object
readonly
The client secret of this PaymentIntent.
-
#confirmation_method ⇒ Object
readonly
Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.
-
#created ⇒ Object
readonly
Time at which the object was created.
-
#currency ⇒ Object
readonly
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase.
-
#customer ⇒ Object
readonly
ID of the Customer this PaymentIntent belongs to, if one exists.
-
#customer_account ⇒ Object
readonly
ID of the Account this PaymentIntent belongs to, if one exists.
-
#description ⇒ Object
readonly
An arbitrary string attached to the object.
-
#fx_quote ⇒ Object
readonly
The FX Quote used for the PaymentIntent.
-
#hooks ⇒ Object
readonly
Attribute for field hooks.
-
#id ⇒ Object
readonly
Unique identifier for the object.
-
#last_payment_error ⇒ Object
readonly
The payment error encountered in the previous PaymentIntent confirmation.
-
#latest_charge ⇒ Object
readonly
ID of the latest [Charge object](stripe.com/docs/api/charges) created by this PaymentIntent.
-
#livemode ⇒ Object
readonly
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
-
#metadata ⇒ Object
readonly
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object.
-
#next_action ⇒ Object
readonly
If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.
-
#object ⇒ Object
readonly
String representing the object’s type.
-
#on_behalf_of ⇒ Object
readonly
The account (if any) for which the funds of the PaymentIntent are intended.
-
#payment_details ⇒ Object
readonly
Attribute for field payment_details.
-
#payment_method ⇒ Object
readonly
ID of the payment method used in this PaymentIntent.
-
#payment_method_configuration_details ⇒ Object
readonly
Information about the [payment method configuration](stripe.com/docs/api/payment_method_configurations) used for this PaymentIntent.
-
#payment_method_options ⇒ Object
readonly
Payment-method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
readonly
The list of payment method types (e.g. card) that this PaymentIntent is allowed to use.
-
#presentment_details ⇒ Object
readonly
Attribute for field presentment_details.
-
#processing ⇒ Object
readonly
If present, this property tells you about the processing state of the payment.
-
#receipt_email ⇒ Object
readonly
Email address that the receipt for the resulting payment will be sent to.
-
#review ⇒ Object
readonly
ID of the review associated with this PaymentIntent, if any.
-
#secret_key_confirmation ⇒ Object
readonly
Indicates whether confirmation for this PaymentIntent using a secret key is ‘required` or `optional`.
-
#setup_future_usage ⇒ Object
readonly
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
readonly
Shipping information for this PaymentIntent.
-
#source ⇒ Object
readonly
This is a legacy field that will be removed in the future.
-
#statement_descriptor ⇒ Object
readonly
Text that appears on the customer’s statement as the statement descriptor for a non-card charge.
-
#statement_descriptor_suffix ⇒ Object
readonly
Provides information about a card charge.
-
#status ⇒ Object
readonly
Status of this PaymentIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `requires_capture`, `canceled`, or `succeeded`.
-
#transfer_data ⇒ Object
readonly
The data that automatically creates a Transfer after the payment finalizes.
-
#transfer_group ⇒ Object
readonly
A string that identifies the resulting payment as part of a group.
Attributes inherited from APIResource
Attributes inherited from StripeObject
Class Method Summary collapse
-
.apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
-
.cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
-
.capture(intent, params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
-
.confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method.
-
.create(params = {}, opts = {}) ⇒ Object
Creates a PaymentIntent object.
-
.decrement_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
.increment_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
.list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentIntents.
- .object_name ⇒ Object
- .search(params = {}, opts = {}) ⇒ Object
- .search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
-
.trigger_action(intent, params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
-
.update(intent, params = {}, opts = {}) ⇒ Object
Updates properties on a PaymentIntent object without confirming.
-
.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
Instance Method Summary collapse
-
#apply_customer_balance(params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
-
#cancel(params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
-
#capture(params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
-
#confirm(params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method.
-
#decrement_authorization(params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
#increment_authorization(params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object).
-
#trigger_action(params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
-
#verify_microdeposits(params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
Methods included from APIOperations::Create
Methods included from APIOperations::List
Methods included from APIOperations::NestedResource
Methods included from APIOperations::Search
Methods included from APIOperations::Save
Methods inherited from APIResource
class_name, custom_method, #refresh, #request_stripe_object, resource_url, #resource_url, retrieve, save_nested_resource
Methods included from APIOperations::Request
Methods inherited from StripeObject
#==, #[], #[]=, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Amount intended to be collected by this PaymentIntent. A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (e.g., 100 cents to charge $1.00 or 100 to charge ¥100, a zero-decimal currency). The minimum amount is $0.50 US or [equivalent in charge currency](stripe.com/docs/currencies#minimum-and-maximum-charge-amounts). The amount value supports up to eight digits (e.g., a value of 99999999 for a USD charge of $999,999.99).
13411 13412 13413 |
# File 'lib/stripe/resources/payment_intent.rb', line 13411 def amount @amount end |
#amount_capturable ⇒ Object (readonly)
Amount that can be captured from this PaymentIntent.
13413 13414 13415 |
# File 'lib/stripe/resources/payment_intent.rb', line 13413 def amount_capturable @amount_capturable end |
#amount_details ⇒ Object (readonly)
Attribute for field amount_details
13415 13416 13417 |
# File 'lib/stripe/resources/payment_intent.rb', line 13415 def amount_details @amount_details end |
#amount_received ⇒ Object (readonly)
Amount that this PaymentIntent collects.
13417 13418 13419 |
# File 'lib/stripe/resources/payment_intent.rb', line 13417 def amount_received @amount_received end |
#application ⇒ Object (readonly)
ID of the Connect application that created the PaymentIntent.
13419 13420 13421 |
# File 'lib/stripe/resources/payment_intent.rb', line 13419 def application @application end |
#application_fee_amount ⇒ Object (readonly)
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
13421 13422 13423 |
# File 'lib/stripe/resources/payment_intent.rb', line 13421 def application_fee_amount @application_fee_amount end |
#automatic_payment_methods ⇒ Object (readonly)
Settings to configure compatible payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods)
13423 13424 13425 |
# File 'lib/stripe/resources/payment_intent.rb', line 13423 def automatic_payment_methods @automatic_payment_methods end |
#canceled_at ⇒ Object (readonly)
Populated when ‘status` is `canceled`, this is the time at which the PaymentIntent was canceled. Measured in seconds since the Unix epoch.
13425 13426 13427 |
# File 'lib/stripe/resources/payment_intent.rb', line 13425 def canceled_at @canceled_at end |
#cancellation_reason ⇒ Object (readonly)
Reason for cancellation of this PaymentIntent, either user-provided (‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`) or generated by Stripe internally (`failed_invoice`, `void_invoice`, `automatic`, or `expired`).
13427 13428 13429 |
# File 'lib/stripe/resources/payment_intent.rb', line 13427 def cancellation_reason @cancellation_reason end |
#capture_method ⇒ Object (readonly)
Controls when the funds will be captured from the customer’s account.
13429 13430 13431 |
# File 'lib/stripe/resources/payment_intent.rb', line 13429 def capture_method @capture_method end |
#client_secret ⇒ Object (readonly)
The client secret of this PaymentIntent. Used for client-side retrieval using a publishable key.
The client secret can be used to complete a payment from your frontend. It should not be stored, logged, or exposed to anyone other than the customer. Make sure that you have TLS enabled on any page that includes the client secret.
Refer to our docs to [accept a payment](stripe.com/docs/payments/accept-a-payment?ui=elements) and learn about how ‘client_secret` should be handled.
13435 13436 13437 |
# File 'lib/stripe/resources/payment_intent.rb', line 13435 def client_secret @client_secret end |
#confirmation_method ⇒ Object (readonly)
Describes whether we can confirm this PaymentIntent automatically, or if it requires customer action to confirm the payment.
13437 13438 13439 |
# File 'lib/stripe/resources/payment_intent.rb', line 13437 def confirmation_method @confirmation_method end |
#created ⇒ Object (readonly)
Time at which the object was created. Measured in seconds since the Unix epoch.
13439 13440 13441 |
# File 'lib/stripe/resources/payment_intent.rb', line 13439 def created @created end |
#currency ⇒ Object (readonly)
Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).
13441 13442 13443 |
# File 'lib/stripe/resources/payment_intent.rb', line 13441 def currency @currency end |
#customer ⇒ Object (readonly)
ID of the Customer this PaymentIntent belongs to, if one exists.
Payment methods attached to other Customers cannot be used with this PaymentIntent.
If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Customer after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Customer instead.
13447 13448 13449 |
# File 'lib/stripe/resources/payment_intent.rb', line 13447 def customer @customer end |
#customer_account ⇒ Object (readonly)
ID of the Account this PaymentIntent belongs to, if one exists.
Payment methods attached to other Accounts cannot be used with this PaymentIntent.
If [setup_future_usage](stripe.com/docs/api#payment_intent_object-setup_future_usage) is set and this PaymentIntent’s payment method is not ‘card_present`, then the payment method attaches to the Account after the PaymentIntent has been confirmed and any required actions from the user are complete. If the payment method is `card_present` and isn’t a digital wallet, then a [generated_card](docs.stripe.com/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card is created and attached to the Account instead.
13453 13454 13455 |
# File 'lib/stripe/resources/payment_intent.rb', line 13453 def customer_account @customer_account end |
#description ⇒ Object (readonly)
An arbitrary string attached to the object. Often useful for displaying to users.
13455 13456 13457 |
# File 'lib/stripe/resources/payment_intent.rb', line 13455 def description @description end |
#fx_quote ⇒ Object (readonly)
The FX Quote used for the PaymentIntent.
13457 13458 13459 |
# File 'lib/stripe/resources/payment_intent.rb', line 13457 def fx_quote @fx_quote end |
#hooks ⇒ Object (readonly)
Attribute for field hooks
13459 13460 13461 |
# File 'lib/stripe/resources/payment_intent.rb', line 13459 def hooks @hooks end |
#id ⇒ Object (readonly)
Unique identifier for the object.
13461 13462 13463 |
# File 'lib/stripe/resources/payment_intent.rb', line 13461 def id @id end |
#last_payment_error ⇒ Object (readonly)
The payment error encountered in the previous PaymentIntent confirmation. It will be cleared if the PaymentIntent is later updated for any reason.
13463 13464 13465 |
# File 'lib/stripe/resources/payment_intent.rb', line 13463 def last_payment_error @last_payment_error end |
#latest_charge ⇒ Object (readonly)
ID of the latest [Charge object](stripe.com/docs/api/charges) created by this PaymentIntent. This property is ‘null` until PaymentIntent confirmation is attempted.
13465 13466 13467 |
# File 'lib/stripe/resources/payment_intent.rb', line 13465 def latest_charge @latest_charge end |
#livemode ⇒ Object (readonly)
Has the value ‘true` if the object exists in live mode or the value `false` if the object exists in test mode.
13467 13468 13469 |
# File 'lib/stripe/resources/payment_intent.rb', line 13467 def livemode @livemode end |
#metadata ⇒ Object (readonly)
Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Learn more about [storing information in metadata](stripe.com/docs/payments/payment-intents/creating-payment-intents#storing-information-in-metadata).
13469 13470 13471 |
# File 'lib/stripe/resources/payment_intent.rb', line 13469 def @metadata end |
#next_action ⇒ Object (readonly)
If present, this property tells you what actions you need to take in order for your customer to fulfill a payment using the provided source.
13471 13472 13473 |
# File 'lib/stripe/resources/payment_intent.rb', line 13471 def next_action @next_action end |
#object ⇒ Object (readonly)
String representing the object’s type. Objects of the same type share the same value.
13473 13474 13475 |
# File 'lib/stripe/resources/payment_intent.rb', line 13473 def object @object end |
#on_behalf_of ⇒ Object (readonly)
The account (if any) for which the funds of the PaymentIntent are intended. See the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts) for details.
13475 13476 13477 |
# File 'lib/stripe/resources/payment_intent.rb', line 13475 def on_behalf_of @on_behalf_of end |
#payment_details ⇒ Object (readonly)
Attribute for field payment_details
13477 13478 13479 |
# File 'lib/stripe/resources/payment_intent.rb', line 13477 def payment_details @payment_details end |
#payment_method ⇒ Object (readonly)
ID of the payment method used in this PaymentIntent.
13479 13480 13481 |
# File 'lib/stripe/resources/payment_intent.rb', line 13479 def payment_method @payment_method end |
#payment_method_configuration_details ⇒ Object (readonly)
Information about the [payment method configuration](stripe.com/docs/api/payment_method_configurations) used for this PaymentIntent.
13481 13482 13483 |
# File 'lib/stripe/resources/payment_intent.rb', line 13481 def payment_method_configuration_details @payment_method_configuration_details end |
#payment_method_options ⇒ Object (readonly)
Payment-method-specific configuration for this PaymentIntent.
13483 13484 13485 |
# File 'lib/stripe/resources/payment_intent.rb', line 13483 def @payment_method_options end |
#payment_method_types ⇒ Object (readonly)
The list of payment method types (e.g. card) that this PaymentIntent is allowed to use. A comprehensive list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
13485 13486 13487 |
# File 'lib/stripe/resources/payment_intent.rb', line 13485 def payment_method_types @payment_method_types end |
#presentment_details ⇒ Object (readonly)
Attribute for field presentment_details
13487 13488 13489 |
# File 'lib/stripe/resources/payment_intent.rb', line 13487 def presentment_details @presentment_details end |
#processing ⇒ Object (readonly)
If present, this property tells you about the processing state of the payment.
13489 13490 13491 |
# File 'lib/stripe/resources/payment_intent.rb', line 13489 def processing @processing end |
#receipt_email ⇒ Object (readonly)
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
13491 13492 13493 |
# File 'lib/stripe/resources/payment_intent.rb', line 13491 def receipt_email @receipt_email end |
#review ⇒ Object (readonly)
ID of the review associated with this PaymentIntent, if any.
13493 13494 13495 |
# File 'lib/stripe/resources/payment_intent.rb', line 13493 def review @review end |
#secret_key_confirmation ⇒ Object (readonly)
Indicates whether confirmation for this PaymentIntent using a secret key is ‘required` or `optional`.
13495 13496 13497 |
# File 'lib/stripe/resources/payment_intent.rb', line 13495 def secret_key_confirmation @secret_key_confirmation end |
#setup_future_usage ⇒ Object (readonly)
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
13503 13504 13505 |
# File 'lib/stripe/resources/payment_intent.rb', line 13503 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object (readonly)
Shipping information for this PaymentIntent.
13505 13506 13507 |
# File 'lib/stripe/resources/payment_intent.rb', line 13505 def shipping @shipping end |
#source ⇒ Object (readonly)
This is a legacy field that will be removed in the future. It is the ID of the Source object that is associated with this PaymentIntent, if one was supplied.
13507 13508 13509 |
# File 'lib/stripe/resources/payment_intent.rb', line 13507 def source @source end |
#statement_descriptor ⇒ Object (readonly)
Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).
Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.
13511 13512 13513 |
# File 'lib/stripe/resources/payment_intent.rb', line 13511 def statement_descriptor @statement_descriptor end |
#statement_descriptor_suffix ⇒ Object (readonly)
Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.
13513 13514 13515 |
# File 'lib/stripe/resources/payment_intent.rb', line 13513 def statement_descriptor_suffix @statement_descriptor_suffix end |
#status ⇒ Object (readonly)
Status of this PaymentIntent, one of ‘requires_payment_method`, `requires_confirmation`, `requires_action`, `processing`, `requires_capture`, `canceled`, or `succeeded`. Read more about each PaymentIntent [status](stripe.com/docs/payments/intents#intent-statuses).
13515 13516 13517 |
# File 'lib/stripe/resources/payment_intent.rb', line 13515 def status @status end |
#transfer_data ⇒ Object (readonly)
The data that automatically creates a Transfer after the payment finalizes. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
13517 13518 13519 |
# File 'lib/stripe/resources/payment_intent.rb', line 13517 def transfer_data @transfer_data end |
#transfer_group ⇒ Object (readonly)
A string that identifies the resulting payment as part of a group. Learn more about the [use case for connected accounts](stripe.com/docs/connect/separate-charges-and-transfers).
13519 13520 13521 |
# File 'lib/stripe/resources/payment_intent.rb', line 13519 def transfer_group @transfer_group end |
Class Method Details
.apply_customer_balance(intent, params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
13532 13533 13534 13535 13536 13537 13538 13539 |
# File 'lib/stripe/resources/payment_intent.rb', line 13532 def self.apply_customer_balance(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.cancel(intent, params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.
You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
13560 13561 13562 13563 13564 13565 13566 13567 |
# File 'lib/stripe/resources/payment_intent.rb', line 13560 def self.cancel(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.capture(intent, params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.
Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).
13588 13589 13590 13591 13592 13593 13594 13595 |
# File 'lib/stripe/resources/payment_intent.rb', line 13588 def self.capture(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.confirm(intent, params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment. If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual). If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment. If the confirmation_method is manual, all payment attempts must be initiated using a secret key. If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt. There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.
13656 13657 13658 13659 13660 13661 13662 13663 |
# File 'lib/stripe/resources/payment_intent.rb', line 13656 def self.confirm(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.create(params = {}, opts = {}) ⇒ Object
Creates a PaymentIntent object.
After the PaymentIntent is created, attach a payment method and [confirm](docs.stripe.com/docs/api/payment_intents/confirm) to continue the payment. Learn more about <a href=“/docs/payments/payment-intents”>the available payment flows with the Payment Intents API.
When you use confirm=true during creation, it’s equivalent to creating and confirming the PaymentIntent in the same call. You can use any parameters available in the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) when you supply confirm=true.
13675 13676 13677 |
# File 'lib/stripe/resources/payment_intent.rb', line 13675 def self.create(params = {}, opts = {}) request_stripe_object(method: :post, path: "/v1/payment_intents", params: params, opts: opts) end |
.decrement_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [decremental_authorization.status](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card-decremental_authorization) must be available.
Decremental authorizations decrease the authorized amount on your customer’s card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.
After decrement, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). The PaymentIntent will now be capturable up to the new authorized amount.
Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it’s fully captured, a PaymentIntent can no longer be decremented.
13720 13721 13722 13723 13724 13725 13726 13727 |
# File 'lib/stripe/resources/payment_intent.rb', line 13720 def self.(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.increment_authorization(intent, params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.
Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.
If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.
Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.
Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).
13786 13787 13788 13789 13790 13791 13792 13793 |
# File 'lib/stripe/resources/payment_intent.rb', line 13786 def self.(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.list(params = {}, opts = {}) ⇒ Object
Returns a list of PaymentIntents.
13796 13797 13798 |
# File 'lib/stripe/resources/payment_intent.rb', line 13796 def self.list(params = {}, opts = {}) request_stripe_object(method: :get, path: "/v1/payment_intents", params: params, opts: opts) end |
.object_name ⇒ Object
24 25 26 |
# File 'lib/stripe/resources/payment_intent.rb', line 24 def self.object_name "payment_intent" end |
.search(params = {}, opts = {}) ⇒ Object
13800 13801 13802 13803 13804 13805 13806 13807 |
# File 'lib/stripe/resources/payment_intent.rb', line 13800 def self.search(params = {}, opts = {}) request_stripe_object( method: :get, path: "/v1/payment_intents/search", params: params, opts: opts ) end |
.search_auto_paging_each(params = {}, opts = {}, &blk) ⇒ Object
13809 13810 13811 |
# File 'lib/stripe/resources/payment_intent.rb', line 13809 def self.search_auto_paging_each(params = {}, opts = {}, &blk) search(params, opts).auto_paging_each(&blk) end |
.trigger_action(intent, params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
13824 13825 13826 13827 13828 13829 13830 13831 |
# File 'lib/stripe/resources/payment_intent.rb', line 13824 def self.trigger_action(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.update(intent, params = {}, opts = {}) ⇒ Object
Updates properties on a PaymentIntent object without confirming.
Depending on which properties you update, you might need to confirm the PaymentIntent again. For example, updating the payment_method always requires you to confirm the PaymentIntent again. If you prefer to update and confirm at the same time, we recommend updating properties through the [confirm API](docs.stripe.com/docs/api/payment_intents/confirm) instead.
13840 13841 13842 13843 13844 13845 13846 13847 |
# File 'lib/stripe/resources/payment_intent.rb', line 13840 def self.update(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
.verify_microdeposits(intent, params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
13860 13861 13862 13863 13864 13865 13866 13867 |
# File 'lib/stripe/resources/payment_intent.rb', line 13860 def self.verify_microdeposits(intent, params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(intent) }), params: params, opts: opts ) end |
Instance Method Details
#apply_customer_balance(params = {}, opts = {}) ⇒ Object
Manually reconcile the remaining amount for a customer_balance PaymentIntent.
13522 13523 13524 13525 13526 13527 13528 13529 |
# File 'lib/stripe/resources/payment_intent.rb', line 13522 def apply_customer_balance(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/apply_customer_balance", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#cancel(params = {}, opts = {}) ⇒ Object
You can cancel a PaymentIntent object when it’s in one of these statuses: requires_payment_method, requires_capture, requires_confirmation, requires_action or, [in rare cases](docs.stripe.com/docs/payments/intents), processing.
After it’s canceled, no additional charges are made by the PaymentIntent and any operations on the PaymentIntent fail with an error. For PaymentIntents with a status of requires_capture, the remaining amount_capturable is automatically refunded.
You can’t cancel the PaymentIntent for a Checkout Session. [Expire the Checkout Session](docs.stripe.com/docs/api/checkout/sessions/expire) instead.
13546 13547 13548 13549 13550 13551 13552 13553 |
# File 'lib/stripe/resources/payment_intent.rb', line 13546 def cancel(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/cancel", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#capture(params = {}, opts = {}) ⇒ Object
Capture the funds of an existing uncaptured PaymentIntent when its status is requires_capture.
Uncaptured PaymentIntents are cancelled a set number of days (7 by default) after their creation.
Learn more about [separate authorization and capture](docs.stripe.com/docs/payments/capture-later).
13574 13575 13576 13577 13578 13579 13580 13581 |
# File 'lib/stripe/resources/payment_intent.rb', line 13574 def capture(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/capture", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#confirm(params = {}, opts = {}) ⇒ Object
Confirm that your customer intends to pay with current or provided payment method. Upon confirmation, the PaymentIntent will attempt to initiate a payment. If the selected payment method requires additional authentication steps, the PaymentIntent will transition to the requires_action status and suggest additional actions via next_action. If payment fails, the PaymentIntent transitions to the requires_payment_method status or the canceled status if the confirmation limit is reached. If payment succeeds, the PaymentIntent will transition to the succeeded status (or requires_capture, if capture_method is set to manual). If the confirmation_method is automatic, payment may be attempted using our [client SDKs](docs.stripe.com/docs/stripe-js/reference#stripe-handle-card-payment) and the PaymentIntent’s [client_secret](docs.stripe.com/api#payment_intent_object-client_secret). After next_actions are handled by the client, no additional confirmation is required to complete the payment. If the confirmation_method is manual, all payment attempts must be initiated using a secret key. If any actions are required for the payment, the PaymentIntent will return to the requires_confirmation state after those actions are completed. Your server needs to then explicitly re-confirm the PaymentIntent to initiate the next payment attempt. There is a variable upper limit on how many times a PaymentIntent can be confirmed. After this limit is reached, any further calls to this endpoint will transition the PaymentIntent to the canceled state.
13622 13623 13624 13625 13626 13627 13628 13629 |
# File 'lib/stripe/resources/payment_intent.rb', line 13622 def confirm(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/confirm", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#decrement_authorization(params = {}, opts = {}) ⇒ Object
Perform a decremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [decremental_authorization.status](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card-decremental_authorization) must be available.
Decremental authorizations decrease the authorized amount on your customer’s card to the new, lower amount provided. A single PaymentIntent can call this endpoint multiple times to further decrease the authorized amount.
After decrement, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). The PaymentIntent will now be capturable up to the new authorized amount.
Each PaymentIntent can have a maximum of 10 decremental or incremental authorization attempts, including declines. After it’s fully captured, a PaymentIntent can no longer be decremented.
13695 13696 13697 13698 13699 13700 13701 13702 |
# File 'lib/stripe/resources/payment_intent.rb', line 13695 def (params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/decrement_authorization", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#increment_authorization(params = {}, opts = {}) ⇒ Object
Perform an incremental authorization on an eligible [PaymentIntent](docs.stripe.com/docs/api/payment_intents/object). To be eligible, the PaymentIntent’s status must be requires_capture and [incremental_authorization_supported](docs.stripe.com/docs/api/charges/object#charge_object-payment_method_details-card_present-incremental_authorization_supported) must be true.
Incremental authorizations attempt to increase the authorized amount on your customer’s card to the new, higher amount provided. Similar to the initial authorization, incremental authorizations can be declined. A single PaymentIntent can call this endpoint multiple times to further increase the authorized amount.
If the incremental authorization succeeds, the PaymentIntent object returns with the updated [amount](docs.stripe.com/docs/api/payment_intents/object#payment_intent_object-amount). If the incremental authorization fails, a [card_declined](docs.stripe.com/docs/error-codes#card-declined) error returns, and no other fields on the PaymentIntent or Charge update. The PaymentIntent object remains capturable for the previously authorized amount.
Each PaymentIntent can have a maximum of 10 incremental authorization attempts, including declines. After it’s captured, a PaymentIntent can no longer be incremented.
Learn more about [incremental authorizations](docs.stripe.com/docs/terminal/features/incremental-authorizations).
13753 13754 13755 13756 13757 13758 13759 13760 |
# File 'lib/stripe/resources/payment_intent.rb', line 13753 def (params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/increment_authorization", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#trigger_action(params = {}, opts = {}) ⇒ Object
Trigger an external action on a PaymentIntent.
13814 13815 13816 13817 13818 13819 13820 13821 |
# File 'lib/stripe/resources/payment_intent.rb', line 13814 def trigger_action(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/test/payment_intents/%<intent>s/trigger_action", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |
#verify_microdeposits(params = {}, opts = {}) ⇒ Object
Verifies microdeposits on a PaymentIntent object.
13850 13851 13852 13853 13854 13855 13856 13857 |
# File 'lib/stripe/resources/payment_intent.rb', line 13850 def verify_microdeposits(params = {}, opts = {}) request_stripe_object( method: :post, path: format("/v1/payment_intents/%<intent>s/verify_microdeposits", { intent: CGI.escape(self["id"]) }), params: params, opts: opts ) end |