Class: Stripe::PaymentIntent::AmountDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::AmountDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Error, Shipping, Surcharge, Tax, Tip
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
readonly
The total discount applied on the transaction represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal).
-
#error ⇒ Object
readonly
Attribute for field error.
-
#line_items ⇒ Object
readonly
A list of line items, each containing information about a product in the PaymentIntent.
-
#shipping ⇒ Object
readonly
Attribute for field shipping.
-
#surcharge ⇒ Object
readonly
Attribute for field surcharge.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#tip ⇒ Object
readonly
Attribute for field tip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discount_amount ⇒ Object (readonly)
The total discount applied on the transaction represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). An integer greater than 0.
This field is mutually exclusive with the ‘amount_details[#][discount_amount]` field.
112 113 114 |
# File 'lib/stripe/resources/payment_intent.rb', line 112 def discount_amount @discount_amount end |
#error ⇒ Object (readonly)
Attribute for field error
114 115 116 |
# File 'lib/stripe/resources/payment_intent.rb', line 114 def error @error end |
#line_items ⇒ Object (readonly)
A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 200 line items.
116 117 118 |
# File 'lib/stripe/resources/payment_intent.rb', line 116 def line_items @line_items end |
#shipping ⇒ Object (readonly)
Attribute for field shipping
118 119 120 |
# File 'lib/stripe/resources/payment_intent.rb', line 118 def shipping @shipping end |
#surcharge ⇒ Object (readonly)
Attribute for field surcharge
120 121 122 |
# File 'lib/stripe/resources/payment_intent.rb', line 120 def surcharge @surcharge end |
#tax ⇒ Object (readonly)
Attribute for field tax
122 123 124 |
# File 'lib/stripe/resources/payment_intent.rb', line 122 def tax @tax end |
#tip ⇒ Object (readonly)
Attribute for field tip
124 125 126 |
# File 'lib/stripe/resources/payment_intent.rb', line 124 def tip @tip end |
Class Method Details
.field_remappings ⇒ Object
136 137 138 |
# File 'lib/stripe/resources/payment_intent.rb', line 136 def self.field_remappings @field_remappings = {} end |