Class: Stripe::PaymentIntent::AmountDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Error, Shipping, Surcharge, Tax, Tip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discount_amountObject (readonly)

The total discount applied on the transaction represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). An integer greater than 0.

This field is mutually exclusive with the ‘amount_details[#][discount_amount]` field.



125
126
127
# File 'lib/stripe/resources/payment_intent.rb', line 125

def discount_amount
  @discount_amount
end

#errorObject (readonly)

Attribute for field error



127
128
129
# File 'lib/stripe/resources/payment_intent.rb', line 127

def error
  @error
end

#line_itemsObject (readonly)

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 200 line items.



129
130
131
# File 'lib/stripe/resources/payment_intent.rb', line 129

def line_items
  @line_items
end

#shippingObject (readonly)

Attribute for field shipping



131
132
133
# File 'lib/stripe/resources/payment_intent.rb', line 131

def shipping
  @shipping
end

#surchargeObject (readonly)

Attribute for field surcharge



133
134
135
# File 'lib/stripe/resources/payment_intent.rb', line 133

def surcharge
  @surcharge
end

#taxObject (readonly)

Attribute for field tax



135
136
137
# File 'lib/stripe/resources/payment_intent.rb', line 135

def tax
  @tax
end

#tipObject (readonly)

Attribute for field tip



137
138
139
# File 'lib/stripe/resources/payment_intent.rb', line 137

def tip
  @tip
end

Class Method Details

.field_remappingsObject



149
150
151
# File 'lib/stripe/resources/payment_intent.rb', line 149

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



139
140
141
142
143
144
145
146
147
# File 'lib/stripe/resources/payment_intent.rb', line 139

def self.inner_class_types
  @inner_class_types = {
    error: Error,
    shipping: Shipping,
    surcharge: Surcharge,
    tax: Tax,
    tip: Tip,
  }
end