Class: Stripe::PaymentIntent::AmountDetails

Inherits:
StripeObject show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Error, Shipping, Tax, Tip

Constant Summary

Constants inherited from StripeObject

StripeObject::RESERVED_FIELD_NAMES

Instance Attribute Summary collapse

Attributes inherited from StripeObject

#last_response

Class Method Summary collapse

Methods inherited from StripeObject

#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values

Constructor Details

This class inherits a constructor from Stripe::StripeObject

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject

Instance Attribute Details

#discount_amountObject (readonly)

The total discount applied on the transaction represented in the [smallest currency unit](docs.stripe.com/currencies#zero-decimal). An integer greater than 0.

This field is mutually exclusive with the ‘amount_details[#][discount_amount]` field.



106
107
108
# File 'lib/stripe/resources/payment_intent.rb', line 106

def discount_amount
  @discount_amount
end

#errorObject (readonly)

Attribute for field error



108
109
110
# File 'lib/stripe/resources/payment_intent.rb', line 108

def error
  @error
end

#line_itemsObject (readonly)

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 200 line items.



110
111
112
# File 'lib/stripe/resources/payment_intent.rb', line 110

def line_items
  @line_items
end

#shippingObject (readonly)

Attribute for field shipping



112
113
114
# File 'lib/stripe/resources/payment_intent.rb', line 112

def shipping
  @shipping
end

#taxObject (readonly)

Attribute for field tax



114
115
116
# File 'lib/stripe/resources/payment_intent.rb', line 114

def tax
  @tax
end

#tipObject (readonly)

Attribute for field tip



116
117
118
# File 'lib/stripe/resources/payment_intent.rb', line 116

def tip
  @tip
end

Class Method Details

.field_remappingsObject



122
123
124
# File 'lib/stripe/resources/payment_intent.rb', line 122

def self.field_remappings
  @field_remappings = {}
end

.inner_class_typesObject



118
119
120
# File 'lib/stripe/resources/payment_intent.rb', line 118

def self.inner_class_types
  @inner_class_types = { error: Error, shipping: Shipping, tax: Tax, tip: Tip }
end