Class: Stripe::PaymentIntent::AmountDetails
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::AmountDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
readonly
The amount an item was discounted for.
-
#line_items ⇒ Object
readonly
A list of line items, each containing information about a product in the PaymentIntent.
-
#shipping ⇒ Object
readonly
Attribute for field shipping.
-
#tax ⇒ Object
readonly
Attribute for field tax.
-
#tip ⇒ Object
readonly
Attribute for field tip.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#discount_amount ⇒ Object (readonly)
The amount an item was discounted for.
74 75 76 |
# File 'lib/stripe/resources/payment_intent.rb', line 74 def discount_amount @discount_amount end |
#line_items ⇒ Object (readonly)
A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.
76 77 78 |
# File 'lib/stripe/resources/payment_intent.rb', line 76 def line_items @line_items end |
#shipping ⇒ Object (readonly)
Attribute for field shipping
78 79 80 |
# File 'lib/stripe/resources/payment_intent.rb', line 78 def shipping @shipping end |
#tax ⇒ Object (readonly)
Attribute for field tax
80 81 82 |
# File 'lib/stripe/resources/payment_intent.rb', line 80 def tax @tax end |
#tip ⇒ Object (readonly)
Attribute for field tip
82 83 84 |
# File 'lib/stripe/resources/payment_intent.rb', line 82 def tip @tip end |
Class Method Details
.field_remappings ⇒ Object
88 89 90 |
# File 'lib/stripe/resources/payment_intent.rb', line 88 def self.field_remappings @field_remappings = {} end |