Class: Stripe::PaymentIntent::AmountDetails::Surcharge
- Inherits:
-
StripeObject
- Object
- StripeObject
- Stripe::PaymentIntent::AmountDetails::Surcharge
- Defined in:
- lib/stripe/resources/payment_intent.rb
Constant Summary
Constants inherited from StripeObject
StripeObject::RESERVED_FIELD_NAMES
Instance Attribute Summary collapse
-
#amount ⇒ Object
readonly
Portion of the amount that corresponds to a surcharge.
-
#enforce_validation ⇒ Object
readonly
Indicate whether to enforce validations on the surcharge amount.
-
#maximum_amount ⇒ Object
readonly
The maximum amount allowed for the surcharge.
-
#status ⇒ Object
readonly
The status of the surcharge.
Attributes inherited from StripeObject
Class Method Summary collapse
Methods inherited from StripeObject
#==, #[], #[]=, #_get_inner_class_type, additive_object_param, additive_object_param?, #as_json, construct_from, #deleted?, #dirty!, #each, #eql?, field_encodings, #hash, #initialize, #inspect, #keys, #marshal_dump, #marshal_load, protected_fields, #serialize_params, #to_hash, #to_json, #to_s, #update_attributes, #values
Constructor Details
This class inherits a constructor from Stripe::StripeObject
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Stripe::StripeObject
Instance Attribute Details
#amount ⇒ Object (readonly)
Portion of the amount that corresponds to a surcharge.
65 66 67 |
# File 'lib/stripe/resources/payment_intent.rb', line 65 def amount @amount end |
#enforce_validation ⇒ Object (readonly)
Indicate whether to enforce validations on the surcharge amount.
67 68 69 |
# File 'lib/stripe/resources/payment_intent.rb', line 67 def enforce_validation @enforce_validation end |
#maximum_amount ⇒ Object (readonly)
The maximum amount allowed for the surcharge.
69 70 71 |
# File 'lib/stripe/resources/payment_intent.rb', line 69 def maximum_amount @maximum_amount end |
#status ⇒ Object (readonly)
The status of the surcharge.
71 72 73 |
# File 'lib/stripe/resources/payment_intent.rb', line 71 def status @status end |
Class Method Details
.field_remappings ⇒ Object
77 78 79 |
# File 'lib/stripe/resources/payment_intent.rb', line 77 def self.field_remappings @field_remappings = {} end |
.inner_class_types ⇒ Object
73 74 75 |
# File 'lib/stripe/resources/payment_intent.rb', line 73 def self.inner_class_types @inner_class_types = {} end |