Class: Stripe::PaymentIntent::ApplyCustomerBalanceParams

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, currency: nil, expand: nil) ⇒ ApplyCustomerBalanceParams

Returns a new instance of ApplyCustomerBalanceParams.



6176
6177
6178
6179
6180
# File 'lib/stripe/resources/payment_intent.rb', line 6176

def initialize(amount: nil, currency: nil, expand: nil)
  @amount = amount
  @currency = currency
  @expand = expand
end

Instance Attribute Details

#amountObject

Amount that you intend to apply to this PaymentIntent from the customer’s cash balance. If the PaymentIntent was created by an Invoice, the full amount of the PaymentIntent is applied regardless of this parameter.

A positive integer representing how much to charge in the [smallest currency unit](stripe.com/docs/currencies#zero-decimal) (for example, 100 cents to charge 1 USD or 100 to charge 100 JPY, a zero-decimal currency). The maximum amount is the amount of the PaymentIntent.

When you omit the amount, it defaults to the remaining amount requested on the PaymentIntent.



6170
6171
6172
# File 'lib/stripe/resources/payment_intent.rb', line 6170

def amount
  @amount
end

#currencyObject

Three-letter [ISO currency code](www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](stripe.com/docs/currencies).



6172
6173
6174
# File 'lib/stripe/resources/payment_intent.rb', line 6172

def currency
  @currency
end

#expandObject

Specifies which fields in the response should be expanded.



6174
6175
6176
# File 'lib/stripe/resources/payment_intent.rb', line 6174

def expand
  @expand
end