Class: Stripe::PaymentIntent::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CancelParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#cancellation_reason ⇒ Object
Reason for canceling this PaymentIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(cancellation_reason: nil, expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_reason: nil, expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
8945 8946 8947 8948 |
# File 'lib/stripe/resources/payment_intent.rb', line 8945 def initialize(cancellation_reason: nil, expand: nil) @cancellation_reason = cancellation_reason @expand = end |
Instance Attribute Details
#cancellation_reason ⇒ Object
Reason for canceling this PaymentIntent. Possible values are: ‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`
8941 8942 8943 |
# File 'lib/stripe/resources/payment_intent.rb', line 8941 def cancellation_reason @cancellation_reason end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8943 8944 8945 |
# File 'lib/stripe/resources/payment_intent.rb', line 8943 def @expand end |