Class: Stripe::PaymentIntent::CancelParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CancelParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#cancellation_reason ⇒ Object
Reason for canceling this PaymentIntent.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
Instance Method Summary collapse
-
#initialize(cancellation_reason: nil, expand: nil) ⇒ CancelParams
constructor
A new instance of CancelParams.
Methods inherited from RequestParams
Constructor Details
#initialize(cancellation_reason: nil, expand: nil) ⇒ CancelParams
Returns a new instance of CancelParams.
6212 6213 6214 6215 |
# File 'lib/stripe/resources/payment_intent.rb', line 6212 def initialize(cancellation_reason: nil, expand: nil) @cancellation_reason = cancellation_reason @expand = end |
Instance Attribute Details
#cancellation_reason ⇒ Object
Reason for canceling this PaymentIntent. Possible values are: ‘duplicate`, `fraudulent`, `requested_by_customer`, or `abandoned`
6208 6209 6210 |
# File 'lib/stripe/resources/payment_intent.rb', line 6208 def cancellation_reason @cancellation_reason end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
6210 6211 6212 |
# File 'lib/stripe/resources/payment_intent.rb', line 6210 def @expand end |