Class: Stripe::PaymentIntent::CaptureParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Hooks, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_to_capture: nil, application_fee_amount: nil, expand: nil, final_capture: nil, hooks: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ CaptureParams

Returns a new instance of CaptureParams.



9996
9997
9998
9999
10000
10001
10002
10003
10004
10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
# File 'lib/stripe/resources/payment_intent.rb', line 9996

def initialize(
  amount_to_capture: nil,
  application_fee_amount: nil,
  expand: nil,
  final_capture: nil,
  hooks: nil,
  metadata: nil,
  payment_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_to_capture = amount_to_capture
  @application_fee_amount = application_fee_amount
  @expand = expand
  @final_capture = final_capture
  @hooks = hooks
  @metadata = 
  @payment_details = payment_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_to_captureObject

The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Defaults to the full ‘amount_capturable` if it’s not provided.



9973
9974
9975
# File 'lib/stripe/resources/payment_intent.rb', line 9973

def amount_to_capture
  @amount_to_capture
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



9975
9976
9977
# File 'lib/stripe/resources/payment_intent.rb', line 9975

def application_fee_amount
  @application_fee_amount
end

#expandObject

Specifies which fields in the response should be expanded.



9977
9978
9979
# File 'lib/stripe/resources/payment_intent.rb', line 9977

def expand
  @expand
end

#final_captureObject

Defaults to ‘true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they’re captured in future requests. You can only use this setting when [multicapture](stripe.com/docs/payments/multicapture) is available for PaymentIntents.



9979
9980
9981
# File 'lib/stripe/resources/payment_intent.rb', line 9979

def final_capture
  @final_capture
end

#hooksObject

Automations to be run during the PaymentIntent lifecycle



9981
9982
9983
# File 'lib/stripe/resources/payment_intent.rb', line 9981

def hooks
  @hooks
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



9983
9984
9985
# File 'lib/stripe/resources/payment_intent.rb', line 9983

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



9985
9986
9987
# File 'lib/stripe/resources/payment_intent.rb', line 9985

def payment_details
  @payment_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



9989
9990
9991
# File 'lib/stripe/resources/payment_intent.rb', line 9989

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



9991
9992
9993
# File 'lib/stripe/resources/payment_intent.rb', line 9991

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



9994
9995
9996
# File 'lib/stripe/resources/payment_intent.rb', line 9994

def transfer_data
  @transfer_data
end