Class: Stripe::PaymentIntent::CaptureParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AsyncWorkflows, PaymentDetails, TransferData

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount_to_capture: nil, application_fee_amount: nil, async_workflows: nil, expand: nil, final_capture: nil, metadata: nil, payment_details: nil, statement_descriptor: nil, statement_descriptor_suffix: nil, transfer_data: nil) ⇒ CaptureParams

Returns a new instance of CaptureParams.



9261
9262
9263
9264
9265
9266
9267
9268
9269
9270
9271
9272
9273
9274
9275
9276
9277
9278
9279
9280
9281
9282
9283
# File 'lib/stripe/resources/payment_intent.rb', line 9261

def initialize(
  amount_to_capture: nil,
  application_fee_amount: nil,
  async_workflows: nil,
  expand: nil,
  final_capture: nil,
  metadata: nil,
  payment_details: nil,
  statement_descriptor: nil,
  statement_descriptor_suffix: nil,
  transfer_data: nil
)
  @amount_to_capture = amount_to_capture
  @application_fee_amount = application_fee_amount
  @async_workflows = async_workflows
  @expand = expand
  @final_capture = final_capture
  @metadata = 
  @payment_details = payment_details
  @statement_descriptor = statement_descriptor
  @statement_descriptor_suffix = statement_descriptor_suffix
  @transfer_data = transfer_data
end

Instance Attribute Details

#amount_to_captureObject

The amount to capture from the PaymentIntent, which must be less than or equal to the original amount. Any additional amount is automatically refunded. Defaults to the full ‘amount_capturable` if it’s not provided.



9238
9239
9240
# File 'lib/stripe/resources/payment_intent.rb', line 9238

def amount_to_capture
  @amount_to_capture
end

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total payment amount. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



9240
9241
9242
# File 'lib/stripe/resources/payment_intent.rb', line 9240

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject

Automations to be run during the PaymentIntent lifecycle



9242
9243
9244
# File 'lib/stripe/resources/payment_intent.rb', line 9242

def async_workflows
  @async_workflows
end

#expandObject

Specifies which fields in the response should be expanded.



9244
9245
9246
# File 'lib/stripe/resources/payment_intent.rb', line 9244

def expand
  @expand
end

#final_captureObject

Defaults to ‘true`. When capturing a PaymentIntent, setting `final_capture` to `false` notifies Stripe to not release the remaining uncaptured funds to make sure that they’re captured in future requests. You can only use this setting when [multicapture](stripe.com/docs/payments/multicapture) is available for PaymentIntents.



9246
9247
9248
# File 'lib/stripe/resources/payment_intent.rb', line 9246

def final_capture
  @final_capture
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



9248
9249
9250
# File 'lib/stripe/resources/payment_intent.rb', line 9248

def 
  @metadata
end

#payment_detailsObject

Provides industry-specific information about the charge.



9250
9251
9252
# File 'lib/stripe/resources/payment_intent.rb', line 9250

def payment_details
  @payment_details
end

#statement_descriptorObject

Text that appears on the customer’s statement as the statement descriptor for a non-card charge. This value overrides the account’s default statement descriptor. For information about requirements, including the 22-character limit, see [the Statement Descriptor docs](docs.stripe.com/get-started/account/statement-descriptors).

Setting this value for a card charge returns an error. For card charges, set the [statement_descriptor_suffix](docs.stripe.com/get-started/account/statement-descriptors#dynamic) instead.



9254
9255
9256
# File 'lib/stripe/resources/payment_intent.rb', line 9254

def statement_descriptor
  @statement_descriptor
end

#statement_descriptor_suffixObject

Provides information about a card charge. Concatenated to the account’s [statement descriptor prefix](docs.stripe.com/get-started/account/statement-descriptors#static) to form the complete statement descriptor that appears on the customer’s statement.



9256
9257
9258
# File 'lib/stripe/resources/payment_intent.rb', line 9256

def statement_descriptor_suffix
  @statement_descriptor_suffix
end

#transfer_dataObject

The parameters that you can use to automatically create a transfer after the payment is captured. Learn more about the [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



9259
9260
9261
# File 'lib/stripe/resources/payment_intent.rb', line 9259

def transfer_data
  @transfer_data
end