Class: Stripe::PaymentIntent::CaptureParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



9693
9694
9695
9696
9697
9698
# File 'lib/stripe/resources/payment_intent.rb', line 9693

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



9685
9686
9687
# File 'lib/stripe/resources/payment_intent.rb', line 9685

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



9687
9688
9689
# File 'lib/stripe/resources/payment_intent.rb', line 9687

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



9689
9690
9691
# File 'lib/stripe/resources/payment_intent.rb', line 9689

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



9691
9692
9693
# File 'lib/stripe/resources/payment_intent.rb', line 9691

def tax
  @tax
end