Class: Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
11147 11148 11149 11150 11151 11152 11153 11154 11155 11156 11157 11158 11159 11160 11161 11162 11163 11164 11165 |
# File 'lib/stripe/resources/payment_intent.rb', line 11147 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
11131 11132 11133 |
# File 'lib/stripe/resources/payment_intent.rb', line 11131 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
11133 11134 11135 |
# File 'lib/stripe/resources/payment_intent.rb', line 11133 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
11135 11136 11137 |
# File 'lib/stripe/resources/payment_intent.rb', line 11135 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
11137 11138 11139 |
# File 'lib/stripe/resources/payment_intent.rb', line 11137 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
11139 11140 11141 |
# File 'lib/stripe/resources/payment_intent.rb', line 11139 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
11141 11142 11143 |
# File 'lib/stripe/resources/payment_intent.rb', line 11141 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
11143 11144 11145 |
# File 'lib/stripe/resources/payment_intent.rb', line 11143 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
11145 11146 11147 |
# File 'lib/stripe/resources/payment_intent.rb', line 11145 def unit_of_measure @unit_of_measure end |