Class: Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
9640 9641 9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 9654 9655 9656 9657 9658 |
# File 'lib/stripe/resources/payment_intent.rb', line 9640 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
9624 9625 9626 |
# File 'lib/stripe/resources/payment_intent.rb', line 9624 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
9626 9627 9628 |
# File 'lib/stripe/resources/payment_intent.rb', line 9626 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
9628 9629 9630 |
# File 'lib/stripe/resources/payment_intent.rb', line 9628 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
9630 9631 9632 |
# File 'lib/stripe/resources/payment_intent.rb', line 9630 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
9632 9633 9634 |
# File 'lib/stripe/resources/payment_intent.rb', line 9632 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
9634 9635 9636 |
# File 'lib/stripe/resources/payment_intent.rb', line 9634 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
9636 9637 9638 |
# File 'lib/stripe/resources/payment_intent.rb', line 9636 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
9638 9639 9640 |
# File 'lib/stripe/resources/payment_intent.rb', line 9638 def unit_of_measure @unit_of_measure end |