Class: Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::CardPresent
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::CardPresent
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#commodity_code ⇒ Object
Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, etc.
Instance Method Summary collapse
-
#initialize(commodity_code: nil) ⇒ CardPresent
constructor
A new instance of CardPresent.
Methods inherited from RequestParams
Constructor Details
#initialize(commodity_code: nil) ⇒ CardPresent
Returns a new instance of CardPresent.
9564 9565 9566 |
# File 'lib/stripe/resources/payment_intent.rb', line 9564 def initialize(commodity_code: nil) @commodity_code = commodity_code end |
Instance Attribute Details
#commodity_code ⇒ Object
Identifier that categorizes the items being purchased using a standardized commodity scheme such as (but not limited to) UNSPSC, NAICS, NAPCS, etc.
9562 9563 9564 |
# File 'lib/stripe/resources/payment_intent.rb', line 9562 def commodity_code @commodity_code end |