Class: Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
11099 11100 11101 11102 11103 |
# File 'lib/stripe/resources/payment_intent.rb', line 11099 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
11093 11094 11095 |
# File 'lib/stripe/resources/payment_intent.rb', line 11093 def category @category end |
#description ⇒ Object
Description of the line item.
11095 11096 11097 |
# File 'lib/stripe/resources/payment_intent.rb', line 11095 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
11097 11098 11099 |
# File 'lib/stripe/resources/payment_intent.rb', line 11097 def sold_by @sold_by end |