Class: Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
9592 9593 9594 9595 9596 |
# File 'lib/stripe/resources/payment_intent.rb', line 9592 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
9586 9587 9588 |
# File 'lib/stripe/resources/payment_intent.rb', line 9586 def category @category end |
#description ⇒ Object
Description of the line item.
9588 9589 9590 |
# File 'lib/stripe/resources/payment_intent.rb', line 9588 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
9590 9591 9592 |
# File 'lib/stripe/resources/payment_intent.rb', line 9590 def sold_by @sold_by end |