Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
11919 11920 11921 11922 11923 11924 11925 11926 11927 11928 11929 11930 11931 11932 11933 11934 11935 |
# File 'lib/stripe/resources/payment_intent.rb', line 11919 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
11905 11906 11907 |
# File 'lib/stripe/resources/payment_intent.rb', line 11905 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
11907 11908 11909 |
# File 'lib/stripe/resources/payment_intent.rb', line 11907 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
11909 11910 11911 |
# File 'lib/stripe/resources/payment_intent.rb', line 11909 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
11911 11912 11913 |
# File 'lib/stripe/resources/payment_intent.rb', line 11911 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
11913 11914 11915 |
# File 'lib/stripe/resources/payment_intent.rb', line 11913 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
11915 11916 11917 |
# File 'lib/stripe/resources/payment_intent.rb', line 11915 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
11917 11918 11919 |
# File 'lib/stripe/resources/payment_intent.rb', line 11917 def subscription @subscription end |