Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
10412 10413 10414 10415 10416 10417 10418 10419 10420 10421 10422 10423 10424 10425 10426 10427 10428 |
# File 'lib/stripe/resources/payment_intent.rb', line 10412 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
10398 10399 10400 |
# File 'lib/stripe/resources/payment_intent.rb', line 10398 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
10400 10401 10402 |
# File 'lib/stripe/resources/payment_intent.rb', line 10400 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
10402 10403 10404 |
# File 'lib/stripe/resources/payment_intent.rb', line 10402 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
10404 10405 10406 |
# File 'lib/stripe/resources/payment_intent.rb', line 10404 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
10406 10407 10408 |
# File 'lib/stripe/resources/payment_intent.rb', line 10406 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
10408 10409 10410 |
# File 'lib/stripe/resources/payment_intent.rb', line 10408 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
10410 10411 10412 |
# File 'lib/stripe/resources/payment_intent.rb', line 10410 def subscription @subscription end |