Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



9945
9946
9947
9948
9949
9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
# File 'lib/stripe/resources/payment_intent.rb', line 9945

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



9931
9932
9933
# File 'lib/stripe/resources/payment_intent.rb', line 9931

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



9933
9934
9935
# File 'lib/stripe/resources/payment_intent.rb', line 9933

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



9935
9936
9937
# File 'lib/stripe/resources/payment_intent.rb', line 9935

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



9937
9938
9939
# File 'lib/stripe/resources/payment_intent.rb', line 9937

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



9939
9940
9941
# File 'lib/stripe/resources/payment_intent.rb', line 9939

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



9941
9942
9943
# File 'lib/stripe/resources/payment_intent.rb', line 9941

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



9943
9944
9945
# File 'lib/stripe/resources/payment_intent.rb', line 9943

def subscription
  @subscription
end