Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
9728 9729 9730 9731 9732 9733 9734 9735 9736 9737 9738 9739 9740 9741 9742 9743 9744 |
# File 'lib/stripe/resources/payment_intent.rb', line 9728 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
9714 9715 9716 |
# File 'lib/stripe/resources/payment_intent.rb', line 9714 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
9716 9717 9718 |
# File 'lib/stripe/resources/payment_intent.rb', line 9716 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
9718 9719 9720 |
# File 'lib/stripe/resources/payment_intent.rb', line 9718 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
9720 9721 9722 |
# File 'lib/stripe/resources/payment_intent.rb', line 9720 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
9722 9723 9724 |
# File 'lib/stripe/resources/payment_intent.rb', line 9722 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
9724 9725 9726 |
# File 'lib/stripe/resources/payment_intent.rb', line 9724 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
9726 9727 9728 |
# File 'lib/stripe/resources/payment_intent.rb', line 9726 def subscription @subscription end |