Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



9688
9689
9690
9691
9692
9693
9694
9695
9696
9697
9698
9699
9700
9701
9702
9703
9704
# File 'lib/stripe/resources/payment_intent.rb', line 9688

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



9674
9675
9676
# File 'lib/stripe/resources/payment_intent.rb', line 9674

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



9676
9677
9678
# File 'lib/stripe/resources/payment_intent.rb', line 9676

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



9678
9679
9680
# File 'lib/stripe/resources/payment_intent.rb', line 9678

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



9680
9681
9682
# File 'lib/stripe/resources/payment_intent.rb', line 9680

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



9682
9683
9684
# File 'lib/stripe/resources/payment_intent.rb', line 9682

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



9684
9685
9686
# File 'lib/stripe/resources/payment_intent.rb', line 9684

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



9686
9687
9688
# File 'lib/stripe/resources/payment_intent.rb', line 9686

def subscription
  @subscription
end