Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



11407
11408
11409
11410
11411
11412
11413
11414
11415
11416
11417
11418
11419
11420
11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
11444
11445
11446
11447
11448
11449
11450
11451
11452
11453
11454
11455
11456
11457
# File 'lib/stripe/resources/payment_intent.rb', line 11407

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



11359
11360
11361
# File 'lib/stripe/resources/payment_intent.rb', line 11359

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



11361
11362
11363
# File 'lib/stripe/resources/payment_intent.rb', line 11361

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



11363
11364
11365
# File 'lib/stripe/resources/payment_intent.rb', line 11363

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



11365
11366
11367
# File 'lib/stripe/resources/payment_intent.rb', line 11365

def car_make
  @car_make
end

#car_modelObject

Model of the car.



11367
11368
11369
# File 'lib/stripe/resources/payment_intent.rb', line 11367

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



11369
11370
11371
# File 'lib/stripe/resources/payment_intent.rb', line 11369

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



11371
11372
11373
# File 'lib/stripe/resources/payment_intent.rb', line 11371

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



11373
11374
11375
# File 'lib/stripe/resources/payment_intent.rb', line 11373

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



11375
11376
11377
# File 'lib/stripe/resources/payment_intent.rb', line 11375

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



11377
11378
11379
# File 'lib/stripe/resources/payment_intent.rb', line 11377

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



11379
11380
11381
# File 'lib/stripe/resources/payment_intent.rb', line 11379

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



11381
11382
11383
# File 'lib/stripe/resources/payment_intent.rb', line 11381

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



11383
11384
11385
# File 'lib/stripe/resources/payment_intent.rb', line 11383

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



11385
11386
11387
# File 'lib/stripe/resources/payment_intent.rb', line 11385

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



11387
11388
11389
# File 'lib/stripe/resources/payment_intent.rb', line 11387

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



11389
11390
11391
# File 'lib/stripe/resources/payment_intent.rb', line 11389

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



11391
11392
11393
# File 'lib/stripe/resources/payment_intent.rb', line 11391

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



11393
11394
11395
# File 'lib/stripe/resources/payment_intent.rb', line 11393

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



11395
11396
11397
# File 'lib/stripe/resources/payment_intent.rb', line 11395

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



11397
11398
11399
# File 'lib/stripe/resources/payment_intent.rb', line 11397

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



11399
11400
11401
# File 'lib/stripe/resources/payment_intent.rb', line 11399

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



11401
11402
11403
# File 'lib/stripe/resources/payment_intent.rb', line 11401

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



11403
11404
11405
# File 'lib/stripe/resources/payment_intent.rb', line 11403

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



11405
11406
11407
# File 'lib/stripe/resources/payment_intent.rb', line 11405

def vehicle_identification_number
  @vehicle_identification_number
end