Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
10026 10027 10028 10029 10030 10031 10032 10033 10034 10035 10036 10037 10038 10039 10040 10041 10042 10043 10044 10045 10046 10047 10048 10049 10050 10051 10052 10053 10054 10055 10056 10057 10058 10059 10060 10061 10062 10063 10064 10065 10066 10067 10068 10069 10070 10071 10072 10073 10074 10075 10076 |
# File 'lib/stripe/resources/payment_intent.rb', line 10026 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9978 9979 9980 |
# File 'lib/stripe/resources/payment_intent.rb', line 9978 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
9980 9981 9982 |
# File 'lib/stripe/resources/payment_intent.rb', line 9980 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
9982 9983 9984 |
# File 'lib/stripe/resources/payment_intent.rb', line 9982 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
9984 9985 9986 |
# File 'lib/stripe/resources/payment_intent.rb', line 9984 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
9986 9987 9988 |
# File 'lib/stripe/resources/payment_intent.rb', line 9986 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
9988 9989 9990 |
# File 'lib/stripe/resources/payment_intent.rb', line 9988 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
9990 9991 9992 |
# File 'lib/stripe/resources/payment_intent.rb', line 9990 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
9992 9993 9994 |
# File 'lib/stripe/resources/payment_intent.rb', line 9992 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
9994 9995 9996 |
# File 'lib/stripe/resources/payment_intent.rb', line 9994 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
9996 9997 9998 |
# File 'lib/stripe/resources/payment_intent.rb', line 9996 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
9998 9999 10000 |
# File 'lib/stripe/resources/payment_intent.rb', line 9998 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
10000 10001 10002 |
# File 'lib/stripe/resources/payment_intent.rb', line 10000 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
10002 10003 10004 |
# File 'lib/stripe/resources/payment_intent.rb', line 10002 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
10004 10005 10006 |
# File 'lib/stripe/resources/payment_intent.rb', line 10004 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
10006 10007 10008 |
# File 'lib/stripe/resources/payment_intent.rb', line 10006 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
10008 10009 10010 |
# File 'lib/stripe/resources/payment_intent.rb', line 10008 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
10010 10011 10012 |
# File 'lib/stripe/resources/payment_intent.rb', line 10010 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
10012 10013 10014 |
# File 'lib/stripe/resources/payment_intent.rb', line 10012 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
10014 10015 10016 |
# File 'lib/stripe/resources/payment_intent.rb', line 10014 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
10016 10017 10018 |
# File 'lib/stripe/resources/payment_intent.rb', line 10016 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
10018 10019 10020 |
# File 'lib/stripe/resources/payment_intent.rb', line 10018 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
10020 10021 10022 |
# File 'lib/stripe/resources/payment_intent.rb', line 10020 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
10022 10023 10024 |
# File 'lib/stripe/resources/payment_intent.rb', line 10022 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
10024 10025 10026 |
# File 'lib/stripe/resources/payment_intent.rb', line 10024 def vehicle_identification_number @vehicle_identification_number end |