Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
9900 9901 9902 9903 9904 9905 9906 9907 9908 9909 9910 9911 9912 9913 9914 9915 9916 9917 9918 9919 9920 9921 9922 9923 9924 9925 9926 9927 9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 |
# File 'lib/stripe/resources/payment_intent.rb', line 9900 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9852 9853 9854 |
# File 'lib/stripe/resources/payment_intent.rb', line 9852 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
9854 9855 9856 |
# File 'lib/stripe/resources/payment_intent.rb', line 9854 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
9856 9857 9858 |
# File 'lib/stripe/resources/payment_intent.rb', line 9856 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
9858 9859 9860 |
# File 'lib/stripe/resources/payment_intent.rb', line 9858 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
9860 9861 9862 |
# File 'lib/stripe/resources/payment_intent.rb', line 9860 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
9862 9863 9864 |
# File 'lib/stripe/resources/payment_intent.rb', line 9862 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
9864 9865 9866 |
# File 'lib/stripe/resources/payment_intent.rb', line 9864 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
9866 9867 9868 |
# File 'lib/stripe/resources/payment_intent.rb', line 9866 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
9868 9869 9870 |
# File 'lib/stripe/resources/payment_intent.rb', line 9868 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
9870 9871 9872 |
# File 'lib/stripe/resources/payment_intent.rb', line 9870 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
9872 9873 9874 |
# File 'lib/stripe/resources/payment_intent.rb', line 9872 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
9874 9875 9876 |
# File 'lib/stripe/resources/payment_intent.rb', line 9874 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
9876 9877 9878 |
# File 'lib/stripe/resources/payment_intent.rb', line 9876 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
9878 9879 9880 |
# File 'lib/stripe/resources/payment_intent.rb', line 9878 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
9880 9881 9882 |
# File 'lib/stripe/resources/payment_intent.rb', line 9880 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
9882 9883 9884 |
# File 'lib/stripe/resources/payment_intent.rb', line 9882 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
9884 9885 9886 |
# File 'lib/stripe/resources/payment_intent.rb', line 9884 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
9886 9887 9888 |
# File 'lib/stripe/resources/payment_intent.rb', line 9886 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
9888 9889 9890 |
# File 'lib/stripe/resources/payment_intent.rb', line 9888 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
9890 9891 9892 |
# File 'lib/stripe/resources/payment_intent.rb', line 9890 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
9892 9893 9894 |
# File 'lib/stripe/resources/payment_intent.rb', line 9892 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
9894 9895 9896 |
# File 'lib/stripe/resources/payment_intent.rb', line 9894 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
9896 9897 9898 |
# File 'lib/stripe/resources/payment_intent.rb', line 9896 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
9898 9899 9900 |
# File 'lib/stripe/resources/payment_intent.rb', line 9898 def vehicle_identification_number @vehicle_identification_number end |