Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
9459
9460
9461
9462
9463
9464
9465
9466
9467
9468
9469
9470
9471
9472
9473
9474
9475
9476
9477
9478
9479
9480
9481
9482
9483
# File 'lib/stripe/resources/payment_intent.rb', line 9433

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



9385
9386
9387
# File 'lib/stripe/resources/payment_intent.rb', line 9385

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



9387
9388
9389
# File 'lib/stripe/resources/payment_intent.rb', line 9387

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



9389
9390
9391
# File 'lib/stripe/resources/payment_intent.rb', line 9389

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



9391
9392
9393
# File 'lib/stripe/resources/payment_intent.rb', line 9391

def car_make
  @car_make
end

#car_modelObject

Model of the car.



9393
9394
9395
# File 'lib/stripe/resources/payment_intent.rb', line 9393

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



9395
9396
9397
# File 'lib/stripe/resources/payment_intent.rb', line 9395

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



9397
9398
9399
# File 'lib/stripe/resources/payment_intent.rb', line 9397

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



9399
9400
9401
# File 'lib/stripe/resources/payment_intent.rb', line 9399

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



9401
9402
9403
# File 'lib/stripe/resources/payment_intent.rb', line 9401

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



9403
9404
9405
# File 'lib/stripe/resources/payment_intent.rb', line 9403

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



9405
9406
9407
# File 'lib/stripe/resources/payment_intent.rb', line 9405

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



9407
9408
9409
# File 'lib/stripe/resources/payment_intent.rb', line 9407

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



9409
9410
9411
# File 'lib/stripe/resources/payment_intent.rb', line 9409

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



9411
9412
9413
# File 'lib/stripe/resources/payment_intent.rb', line 9411

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



9413
9414
9415
# File 'lib/stripe/resources/payment_intent.rb', line 9413

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



9415
9416
9417
# File 'lib/stripe/resources/payment_intent.rb', line 9415

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



9417
9418
9419
# File 'lib/stripe/resources/payment_intent.rb', line 9417

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



9419
9420
9421
# File 'lib/stripe/resources/payment_intent.rb', line 9419

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



9421
9422
9423
# File 'lib/stripe/resources/payment_intent.rb', line 9421

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



9423
9424
9425
# File 'lib/stripe/resources/payment_intent.rb', line 9423

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



9425
9426
9427
# File 'lib/stripe/resources/payment_intent.rb', line 9425

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



9427
9428
9429
# File 'lib/stripe/resources/payment_intent.rb', line 9427

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



9429
9430
9431
# File 'lib/stripe/resources/payment_intent.rb', line 9429

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



9431
9432
9433
# File 'lib/stripe/resources/payment_intent.rb', line 9431

def vehicle_identification_number
  @vehicle_identification_number
end