Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



9216
9217
9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
9231
9232
9233
9234
9235
9236
9237
9238
9239
9240
9241
9242
9243
9244
9245
9246
9247
9248
9249
9250
9251
9252
9253
9254
9255
9256
9257
9258
9259
9260
9261
9262
9263
9264
9265
9266
# File 'lib/stripe/resources/payment_intent.rb', line 9216

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



9168
9169
9170
# File 'lib/stripe/resources/payment_intent.rb', line 9168

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



9170
9171
9172
# File 'lib/stripe/resources/payment_intent.rb', line 9170

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



9172
9173
9174
# File 'lib/stripe/resources/payment_intent.rb', line 9172

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



9174
9175
9176
# File 'lib/stripe/resources/payment_intent.rb', line 9174

def car_make
  @car_make
end

#car_modelObject

Model of the car.



9176
9177
9178
# File 'lib/stripe/resources/payment_intent.rb', line 9176

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



9178
9179
9180
# File 'lib/stripe/resources/payment_intent.rb', line 9178

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



9180
9181
9182
# File 'lib/stripe/resources/payment_intent.rb', line 9180

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



9182
9183
9184
# File 'lib/stripe/resources/payment_intent.rb', line 9182

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



9184
9185
9186
# File 'lib/stripe/resources/payment_intent.rb', line 9184

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



9186
9187
9188
# File 'lib/stripe/resources/payment_intent.rb', line 9186

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



9188
9189
9190
# File 'lib/stripe/resources/payment_intent.rb', line 9188

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



9190
9191
9192
# File 'lib/stripe/resources/payment_intent.rb', line 9190

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



9192
9193
9194
# File 'lib/stripe/resources/payment_intent.rb', line 9192

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



9194
9195
9196
# File 'lib/stripe/resources/payment_intent.rb', line 9194

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



9196
9197
9198
# File 'lib/stripe/resources/payment_intent.rb', line 9196

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



9198
9199
9200
# File 'lib/stripe/resources/payment_intent.rb', line 9198

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



9200
9201
9202
# File 'lib/stripe/resources/payment_intent.rb', line 9200

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



9202
9203
9204
# File 'lib/stripe/resources/payment_intent.rb', line 9202

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



9204
9205
9206
# File 'lib/stripe/resources/payment_intent.rb', line 9204

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



9206
9207
9208
# File 'lib/stripe/resources/payment_intent.rb', line 9206

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



9208
9209
9210
# File 'lib/stripe/resources/payment_intent.rb', line 9208

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



9210
9211
9212
# File 'lib/stripe/resources/payment_intent.rb', line 9210

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



9212
9213
9214
# File 'lib/stripe/resources/payment_intent.rb', line 9212

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



9214
9215
9216
# File 'lib/stripe/resources/payment_intent.rb', line 9214

def vehicle_identification_number
  @vehicle_identification_number
end