Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



9184
9185
9186
9187
9188
9189
9190
9191
9192
9193
9194
9195
9196
9197
9198
9199
9200
9201
9202
9203
9204
9205
9206
9207
9208
9209
9210
9211
9212
9213
9214
9215
9216
9217
9218
9219
9220
9221
9222
9223
9224
9225
9226
# File 'lib/stripe/resources/payment_intent.rb', line 9184

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



9144
9145
9146
# File 'lib/stripe/resources/payment_intent.rb', line 9144

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



9146
9147
9148
# File 'lib/stripe/resources/payment_intent.rb', line 9146

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



9148
9149
9150
# File 'lib/stripe/resources/payment_intent.rb', line 9148

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



9150
9151
9152
# File 'lib/stripe/resources/payment_intent.rb', line 9150

def car_make
  @car_make
end

#car_modelObject

Model of the car.



9152
9153
9154
# File 'lib/stripe/resources/payment_intent.rb', line 9152

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



9154
9155
9156
# File 'lib/stripe/resources/payment_intent.rb', line 9154

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



9156
9157
9158
# File 'lib/stripe/resources/payment_intent.rb', line 9156

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



9158
9159
9160
# File 'lib/stripe/resources/payment_intent.rb', line 9158

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



9160
9161
9162
# File 'lib/stripe/resources/payment_intent.rb', line 9160

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



9162
9163
9164
# File 'lib/stripe/resources/payment_intent.rb', line 9162

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



9164
9165
9166
# File 'lib/stripe/resources/payment_intent.rb', line 9164

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



9166
9167
9168
# File 'lib/stripe/resources/payment_intent.rb', line 9166

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



9168
9169
9170
# File 'lib/stripe/resources/payment_intent.rb', line 9168

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



9170
9171
9172
# File 'lib/stripe/resources/payment_intent.rb', line 9170

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



9172
9173
9174
# File 'lib/stripe/resources/payment_intent.rb', line 9172

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



9174
9175
9176
# File 'lib/stripe/resources/payment_intent.rb', line 9174

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



9176
9177
9178
# File 'lib/stripe/resources/payment_intent.rb', line 9176

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



9178
9179
9180
# File 'lib/stripe/resources/payment_intent.rb', line 9178

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



9180
9181
9182
# File 'lib/stripe/resources/payment_intent.rb', line 9180

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



9182
9183
9184
# File 'lib/stripe/resources/payment_intent.rb', line 9182

def tax_exempt
  @tax_exempt
end