Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
9125 9126 9127 9128 9129 9130 9131 9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 9146 9147 9148 9149 9150 9151 9152 9153 9154 9155 9156 9157 9158 9159 9160 9161 9162 9163 9164 9165 9166 9167 |
# File 'lib/stripe/resources/payment_intent.rb', line 9125 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9085 9086 9087 |
# File 'lib/stripe/resources/payment_intent.rb', line 9085 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
9087 9088 9089 |
# File 'lib/stripe/resources/payment_intent.rb', line 9087 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
9089 9090 9091 |
# File 'lib/stripe/resources/payment_intent.rb', line 9089 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
9091 9092 9093 |
# File 'lib/stripe/resources/payment_intent.rb', line 9091 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
9093 9094 9095 |
# File 'lib/stripe/resources/payment_intent.rb', line 9093 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
9095 9096 9097 |
# File 'lib/stripe/resources/payment_intent.rb', line 9095 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
9097 9098 9099 |
# File 'lib/stripe/resources/payment_intent.rb', line 9097 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
9099 9100 9101 |
# File 'lib/stripe/resources/payment_intent.rb', line 9099 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
9101 9102 9103 |
# File 'lib/stripe/resources/payment_intent.rb', line 9101 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
9103 9104 9105 |
# File 'lib/stripe/resources/payment_intent.rb', line 9103 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
9105 9106 9107 |
# File 'lib/stripe/resources/payment_intent.rb', line 9105 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
9107 9108 9109 |
# File 'lib/stripe/resources/payment_intent.rb', line 9107 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
9109 9110 9111 |
# File 'lib/stripe/resources/payment_intent.rb', line 9109 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
9111 9112 9113 |
# File 'lib/stripe/resources/payment_intent.rb', line 9111 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
9113 9114 9115 |
# File 'lib/stripe/resources/payment_intent.rb', line 9113 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
9115 9116 9117 |
# File 'lib/stripe/resources/payment_intent.rb', line 9115 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
9117 9118 9119 |
# File 'lib/stripe/resources/payment_intent.rb', line 9117 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
9119 9120 9121 |
# File 'lib/stripe/resources/payment_intent.rb', line 9119 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
9121 9122 9123 |
# File 'lib/stripe/resources/payment_intent.rb', line 9121 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
9123 9124 9125 |
# File 'lib/stripe/resources/payment_intent.rb', line 9123 def tax_exempt @tax_exempt end |