Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



8798
8799
8800
8801
8802
8803
8804
8805
8806
8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
8827
8828
8829
8830
8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
# File 'lib/stripe/resources/payment_intent.rb', line 8798

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



8758
8759
8760
# File 'lib/stripe/resources/payment_intent.rb', line 8758

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



8760
8761
8762
# File 'lib/stripe/resources/payment_intent.rb', line 8760

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



8762
8763
8764
# File 'lib/stripe/resources/payment_intent.rb', line 8762

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



8764
8765
8766
# File 'lib/stripe/resources/payment_intent.rb', line 8764

def car_make
  @car_make
end

#car_modelObject

Model of the car.



8766
8767
8768
# File 'lib/stripe/resources/payment_intent.rb', line 8766

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



8768
8769
8770
# File 'lib/stripe/resources/payment_intent.rb', line 8768

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



8770
8771
8772
# File 'lib/stripe/resources/payment_intent.rb', line 8770

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



8772
8773
8774
# File 'lib/stripe/resources/payment_intent.rb', line 8772

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



8774
8775
8776
# File 'lib/stripe/resources/payment_intent.rb', line 8774

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



8776
8777
8778
# File 'lib/stripe/resources/payment_intent.rb', line 8776

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



8778
8779
8780
# File 'lib/stripe/resources/payment_intent.rb', line 8778

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



8780
8781
8782
# File 'lib/stripe/resources/payment_intent.rb', line 8780

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



8782
8783
8784
# File 'lib/stripe/resources/payment_intent.rb', line 8782

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



8784
8785
8786
# File 'lib/stripe/resources/payment_intent.rb', line 8784

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



8786
8787
8788
# File 'lib/stripe/resources/payment_intent.rb', line 8786

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



8788
8789
8790
# File 'lib/stripe/resources/payment_intent.rb', line 8788

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



8790
8791
8792
# File 'lib/stripe/resources/payment_intent.rb', line 8790

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



8792
8793
8794
# File 'lib/stripe/resources/payment_intent.rb', line 8792

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



8794
8795
8796
# File 'lib/stripe/resources/payment_intent.rb', line 8794

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



8796
8797
8798
# File 'lib/stripe/resources/payment_intent.rb', line 8796

def tax_exempt
  @tax_exempt
end