Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
9969
9970
9971
9972
9973
9974
9975
9976
9977
9978
9979
9980
9981
9982
9983
9984
9985
9986
9987
9988
9989
9990
9991
9992
9993
9994
9995
9996
9997
9998
9999
10000
# File 'lib/stripe/resources/payment_intent.rb', line 9958

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



9899
9900
9901
# File 'lib/stripe/resources/payment_intent.rb', line 9899

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



9902
9903
9904
# File 'lib/stripe/resources/payment_intent.rb', line 9902

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



9905
9906
9907
# File 'lib/stripe/resources/payment_intent.rb', line 9905

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



9908
9909
9910
# File 'lib/stripe/resources/payment_intent.rb', line 9908

def car_make
  @car_make
end

#car_modelObject

Model of the car.



9911
9912
9913
# File 'lib/stripe/resources/payment_intent.rb', line 9911

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



9914
9915
9916
# File 'lib/stripe/resources/payment_intent.rb', line 9914

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



9917
9918
9919
# File 'lib/stripe/resources/payment_intent.rb', line 9917

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



9920
9921
9922
# File 'lib/stripe/resources/payment_intent.rb', line 9920

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



9923
9924
9925
# File 'lib/stripe/resources/payment_intent.rb', line 9923

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



9926
9927
9928
# File 'lib/stripe/resources/payment_intent.rb', line 9926

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



9929
9930
9931
# File 'lib/stripe/resources/payment_intent.rb', line 9929

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



9932
9933
9934
# File 'lib/stripe/resources/payment_intent.rb', line 9932

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



9935
9936
9937
# File 'lib/stripe/resources/payment_intent.rb', line 9935

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



9938
9939
9940
# File 'lib/stripe/resources/payment_intent.rb', line 9938

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



9941
9942
9943
# File 'lib/stripe/resources/payment_intent.rb', line 9941

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



9944
9945
9946
# File 'lib/stripe/resources/payment_intent.rb', line 9944

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



9947
9948
9949
# File 'lib/stripe/resources/payment_intent.rb', line 9947

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



9950
9951
9952
# File 'lib/stripe/resources/payment_intent.rb', line 9950

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



9953
9954
9955
# File 'lib/stripe/resources/payment_intent.rb', line 9953

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



9956
9957
9958
# File 'lib/stripe/resources/payment_intent.rb', line 9956

def tax_exempt
  @tax_exempt
end