Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 8760 8761 8762 8763 8764 8765 8766 8767 8768 8769 8770 8771 8772 8773 8774 8775 8776 8777 8778 8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 |
# File 'lib/stripe/resources/payment_intent.rb', line 8746 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8706 8707 8708 |
# File 'lib/stripe/resources/payment_intent.rb', line 8706 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
8708 8709 8710 |
# File 'lib/stripe/resources/payment_intent.rb', line 8708 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
8710 8711 8712 |
# File 'lib/stripe/resources/payment_intent.rb', line 8710 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
8712 8713 8714 |
# File 'lib/stripe/resources/payment_intent.rb', line 8712 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
8714 8715 8716 |
# File 'lib/stripe/resources/payment_intent.rb', line 8714 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
8716 8717 8718 |
# File 'lib/stripe/resources/payment_intent.rb', line 8716 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
8718 8719 8720 |
# File 'lib/stripe/resources/payment_intent.rb', line 8718 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
8720 8721 8722 |
# File 'lib/stripe/resources/payment_intent.rb', line 8720 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
8722 8723 8724 |
# File 'lib/stripe/resources/payment_intent.rb', line 8722 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
8724 8725 8726 |
# File 'lib/stripe/resources/payment_intent.rb', line 8724 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
8726 8727 8728 |
# File 'lib/stripe/resources/payment_intent.rb', line 8726 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
8728 8729 8730 |
# File 'lib/stripe/resources/payment_intent.rb', line 8728 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
8730 8731 8732 |
# File 'lib/stripe/resources/payment_intent.rb', line 8730 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
8732 8733 8734 |
# File 'lib/stripe/resources/payment_intent.rb', line 8732 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
8734 8735 8736 |
# File 'lib/stripe/resources/payment_intent.rb', line 8734 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
8736 8737 8738 |
# File 'lib/stripe/resources/payment_intent.rb', line 8736 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
8738 8739 8740 |
# File 'lib/stripe/resources/payment_intent.rb', line 8738 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
8740 8741 8742 |
# File 'lib/stripe/resources/payment_intent.rb', line 8740 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
8742 8743 8744 |
# File 'lib/stripe/resources/payment_intent.rb', line 8742 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
8744 8745 8746 |
# File 'lib/stripe/resources/payment_intent.rb', line 8744 def tax_exempt @tax_exempt end |