Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
8714 8715 8716 8717 8718 8719 8720 8721 8722 8723 8724 8725 8726 8727 8728 8729 8730 8731 8732 8733 8734 8735 8736 8737 8738 8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 8750 8751 8752 8753 8754 8755 8756 |
# File 'lib/stripe/resources/payment_intent.rb', line 8714 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8674 8675 8676 |
# File 'lib/stripe/resources/payment_intent.rb', line 8674 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
8676 8677 8678 |
# File 'lib/stripe/resources/payment_intent.rb', line 8676 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
8678 8679 8680 |
# File 'lib/stripe/resources/payment_intent.rb', line 8678 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
8680 8681 8682 |
# File 'lib/stripe/resources/payment_intent.rb', line 8680 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
8682 8683 8684 |
# File 'lib/stripe/resources/payment_intent.rb', line 8682 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
8684 8685 8686 |
# File 'lib/stripe/resources/payment_intent.rb', line 8684 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
8686 8687 8688 |
# File 'lib/stripe/resources/payment_intent.rb', line 8686 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
8688 8689 8690 |
# File 'lib/stripe/resources/payment_intent.rb', line 8688 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
8690 8691 8692 |
# File 'lib/stripe/resources/payment_intent.rb', line 8690 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
8692 8693 8694 |
# File 'lib/stripe/resources/payment_intent.rb', line 8692 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
8694 8695 8696 |
# File 'lib/stripe/resources/payment_intent.rb', line 8694 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
8696 8697 8698 |
# File 'lib/stripe/resources/payment_intent.rb', line 8696 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
8698 8699 8700 |
# File 'lib/stripe/resources/payment_intent.rb', line 8698 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
8700 8701 8702 |
# File 'lib/stripe/resources/payment_intent.rb', line 8700 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
8702 8703 8704 |
# File 'lib/stripe/resources/payment_intent.rb', line 8702 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
8704 8705 8706 |
# File 'lib/stripe/resources/payment_intent.rb', line 8704 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
8706 8707 8708 |
# File 'lib/stripe/resources/payment_intent.rb', line 8706 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
8708 8709 8710 |
# File 'lib/stripe/resources/payment_intent.rb', line 8708 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
8710 8711 8712 |
# File 'lib/stripe/resources/payment_intent.rb', line 8710 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
8712 8713 8714 |
# File 'lib/stripe/resources/payment_intent.rb', line 8712 def tax_exempt @tax_exempt end |