Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



11253
11254
11255
11256
11257
# File 'lib/stripe/resources/payment_intent.rb', line 11253

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



11247
11248
11249
# File 'lib/stripe/resources/payment_intent.rb', line 11247

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



11249
11250
11251
# File 'lib/stripe/resources/payment_intent.rb', line 11249

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



11251
11252
11253
# File 'lib/stripe/resources/payment_intent.rb', line 11251

def phone
  @phone
end