Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
11253 11254 11255 11256 11257 |
# File 'lib/stripe/resources/payment_intent.rb', line 11253 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
11247 11248 11249 |
# File 'lib/stripe/resources/payment_intent.rb', line 11247 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
11249 11250 11251 |
# File 'lib/stripe/resources/payment_intent.rb', line 11249 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
11251 11252 11253 |
# File 'lib/stripe/resources/payment_intent.rb', line 11251 def phone @phone end |