Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9746
9747
9748
9749
9750
# File 'lib/stripe/resources/payment_intent.rb', line 9746

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9740
9741
9742
# File 'lib/stripe/resources/payment_intent.rb', line 9740

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9742
9743
9744
# File 'lib/stripe/resources/payment_intent.rb', line 9742

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9744
9745
9746
# File 'lib/stripe/resources/payment_intent.rb', line 9744

def phone
  @phone
end