Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9279 9280 9281 9282 9283 |
# File 'lib/stripe/resources/payment_intent.rb', line 9279 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9273 9274 9275 |
# File 'lib/stripe/resources/payment_intent.rb', line 9273 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9275 9276 9277 |
# File 'lib/stripe/resources/payment_intent.rb', line 9275 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9277 9278 9279 |
# File 'lib/stripe/resources/payment_intent.rb', line 9277 def phone @phone end |