Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9062 9063 9064 9065 9066 |
# File 'lib/stripe/resources/payment_intent.rb', line 9062 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9056 9057 9058 |
# File 'lib/stripe/resources/payment_intent.rb', line 9056 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9058 9059 9060 |
# File 'lib/stripe/resources/payment_intent.rb', line 9058 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9060 9061 9062 |
# File 'lib/stripe/resources/payment_intent.rb', line 9060 def phone @phone end |