Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9056
9057
9058
9059
9060
# File 'lib/stripe/resources/payment_intent.rb', line 9056

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9050
9051
9052
# File 'lib/stripe/resources/payment_intent.rb', line 9050

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9052
9053
9054
# File 'lib/stripe/resources/payment_intent.rb', line 9052

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9054
9055
9056
# File 'lib/stripe/resources/payment_intent.rb', line 9054

def phone
  @phone
end