Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8670
8671
8672
8673
8674
# File 'lib/stripe/resources/payment_intent.rb', line 8670

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8664
8665
8666
# File 'lib/stripe/resources/payment_intent.rb', line 8664

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8666
8667
8668
# File 'lib/stripe/resources/payment_intent.rb', line 8666

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8668
8669
8670
# File 'lib/stripe/resources/payment_intent.rb', line 8668

def phone
  @phone
end