Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8670 8671 8672 8673 8674 |
# File 'lib/stripe/resources/payment_intent.rb', line 8670 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8664 8665 8666 |
# File 'lib/stripe/resources/payment_intent.rb', line 8664 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8666 8667 8668 |
# File 'lib/stripe/resources/payment_intent.rb', line 8666 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8668 8669 8670 |
# File 'lib/stripe/resources/payment_intent.rb', line 8668 def phone @phone end |