Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8586 8587 8588 8589 8590 |
# File 'lib/stripe/resources/payment_intent.rb', line 8586 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8580 8581 8582 |
# File 'lib/stripe/resources/payment_intent.rb', line 8580 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8582 8583 8584 |
# File 'lib/stripe/resources/payment_intent.rb', line 8582 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8584 8585 8586 |
# File 'lib/stripe/resources/payment_intent.rb', line 8584 def phone @phone end |