Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
10038 10039 10040 10041 10042 10043 10044 10045 10046 10047 10048 10049 10050 10051 10052 10053 10054 10055 10056 10057 10058 |
# File 'lib/stripe/resources/payment_intent.rb', line 10038 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
10020 10021 10022 |
# File 'lib/stripe/resources/payment_intent.rb', line 10020 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
10022 10023 10024 |
# File 'lib/stripe/resources/payment_intent.rb', line 10022 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
10024 10025 10026 |
# File 'lib/stripe/resources/payment_intent.rb', line 10024 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
10026 10027 10028 |
# File 'lib/stripe/resources/payment_intent.rb', line 10026 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
10028 10029 10030 |
# File 'lib/stripe/resources/payment_intent.rb', line 10028 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
10030 10031 10032 |
# File 'lib/stripe/resources/payment_intent.rb', line 10030 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
10032 10033 10034 |
# File 'lib/stripe/resources/payment_intent.rb', line 10032 def genre @genre end |
#name ⇒ Object
The name of the event.
10034 10035 10036 |
# File 'lib/stripe/resources/payment_intent.rb', line 10034 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
10036 10037 10038 |
# File 'lib/stripe/resources/payment_intent.rb', line 10036 def starts_at @starts_at end |