Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
9571 9572 9573 9574 9575 9576 9577 9578 9579 9580 9581 9582 9583 9584 9585 9586 9587 9588 9589 9590 9591 |
# File 'lib/stripe/resources/payment_intent.rb', line 9571 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
9553 9554 9555 |
# File 'lib/stripe/resources/payment_intent.rb', line 9553 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
9555 9556 9557 |
# File 'lib/stripe/resources/payment_intent.rb', line 9555 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9557 9558 9559 |
# File 'lib/stripe/resources/payment_intent.rb', line 9557 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
9559 9560 9561 |
# File 'lib/stripe/resources/payment_intent.rb', line 9559 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
9561 9562 9563 |
# File 'lib/stripe/resources/payment_intent.rb', line 9561 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
9563 9564 9565 |
# File 'lib/stripe/resources/payment_intent.rb', line 9563 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
9565 9566 9567 |
# File 'lib/stripe/resources/payment_intent.rb', line 9565 def genre @genre end |
#name ⇒ Object
The name of the event.
9567 9568 9569 |
# File 'lib/stripe/resources/payment_intent.rb', line 9567 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
9569 9570 9571 |
# File 'lib/stripe/resources/payment_intent.rb', line 9569 def starts_at @starts_at end |