Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
9354 9355 9356 9357 9358 9359 9360 9361 9362 9363 9364 9365 9366 9367 9368 9369 9370 9371 9372 9373 9374 |
# File 'lib/stripe/resources/payment_intent.rb', line 9354 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
9336 9337 9338 |
# File 'lib/stripe/resources/payment_intent.rb', line 9336 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
9338 9339 9340 |
# File 'lib/stripe/resources/payment_intent.rb', line 9338 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9340 9341 9342 |
# File 'lib/stripe/resources/payment_intent.rb', line 9340 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
9342 9343 9344 |
# File 'lib/stripe/resources/payment_intent.rb', line 9342 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
9344 9345 9346 |
# File 'lib/stripe/resources/payment_intent.rb', line 9344 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
9346 9347 9348 |
# File 'lib/stripe/resources/payment_intent.rb', line 9346 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
9348 9349 9350 |
# File 'lib/stripe/resources/payment_intent.rb', line 9348 def genre @genre end |
#name ⇒ Object
The name of the event.
9350 9351 9352 |
# File 'lib/stripe/resources/payment_intent.rb', line 9350 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
9352 9353 9354 |
# File 'lib/stripe/resources/payment_intent.rb', line 9352 def starts_at @starts_at end |