Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
9255 9256 9257 9258 9259 9260 9261 9262 9263 9264 9265 9266 9267 9268 9269 9270 9271 9272 9273 9274 9275 |
# File 'lib/stripe/resources/payment_intent.rb', line 9255 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
9237 9238 9239 |
# File 'lib/stripe/resources/payment_intent.rb', line 9237 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
9239 9240 9241 |
# File 'lib/stripe/resources/payment_intent.rb', line 9239 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9241 9242 9243 |
# File 'lib/stripe/resources/payment_intent.rb', line 9241 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
9243 9244 9245 |
# File 'lib/stripe/resources/payment_intent.rb', line 9243 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
9245 9246 9247 |
# File 'lib/stripe/resources/payment_intent.rb', line 9245 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
9247 9248 9249 |
# File 'lib/stripe/resources/payment_intent.rb', line 9247 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
9249 9250 9251 |
# File 'lib/stripe/resources/payment_intent.rb', line 9249 def genre @genre end |
#name ⇒ Object
The name of the event.
9251 9252 9253 |
# File 'lib/stripe/resources/payment_intent.rb', line 9251 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
9253 9254 9255 |
# File 'lib/stripe/resources/payment_intent.rb', line 9253 def starts_at @starts_at end |