Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
9314 9315 9316 9317 9318 9319 9320 9321 9322 9323 9324 9325 9326 9327 9328 9329 9330 9331 9332 9333 9334 |
# File 'lib/stripe/resources/payment_intent.rb', line 9314 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
9296 9297 9298 |
# File 'lib/stripe/resources/payment_intent.rb', line 9296 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
9298 9299 9300 |
# File 'lib/stripe/resources/payment_intent.rb', line 9298 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9300 9301 9302 |
# File 'lib/stripe/resources/payment_intent.rb', line 9300 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
9302 9303 9304 |
# File 'lib/stripe/resources/payment_intent.rb', line 9302 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
9304 9305 9306 |
# File 'lib/stripe/resources/payment_intent.rb', line 9304 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
9306 9307 9308 |
# File 'lib/stripe/resources/payment_intent.rb', line 9306 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
9308 9309 9310 |
# File 'lib/stripe/resources/payment_intent.rb', line 9308 def genre @genre end |
#name ⇒ Object
The name of the event.
9310 9311 9312 |
# File 'lib/stripe/resources/payment_intent.rb', line 9310 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
9312 9313 9314 |
# File 'lib/stripe/resources/payment_intent.rb', line 9312 def starts_at @starts_at end |