Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 |
# File 'lib/stripe/resources/payment_intent.rb', line 8844 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
8826 8827 8828 |
# File 'lib/stripe/resources/payment_intent.rb', line 8826 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
8828 8829 8830 |
# File 'lib/stripe/resources/payment_intent.rb', line 8828 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
8830 8831 8832 |
# File 'lib/stripe/resources/payment_intent.rb', line 8830 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
8832 8833 8834 |
# File 'lib/stripe/resources/payment_intent.rb', line 8832 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
8834 8835 8836 |
# File 'lib/stripe/resources/payment_intent.rb', line 8834 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
8836 8837 8838 |
# File 'lib/stripe/resources/payment_intent.rb', line 8836 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
8838 8839 8840 |
# File 'lib/stripe/resources/payment_intent.rb', line 8838 def genre @genre end |
#name ⇒ Object
The name of the event.
8840 8841 8842 |
# File 'lib/stripe/resources/payment_intent.rb', line 8840 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
8842 8843 8844 |
# File 'lib/stripe/resources/payment_intent.rb', line 8842 def starts_at @starts_at end |