Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



11510
11511
11512
11513
11514
# File 'lib/stripe/resources/payment_intent.rb', line 11510

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



11504
11505
11506
# File 'lib/stripe/resources/payment_intent.rb', line 11504

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



11506
11507
11508
# File 'lib/stripe/resources/payment_intent.rb', line 11506

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



11508
11509
11510
# File 'lib/stripe/resources/payment_intent.rb', line 11508

def phone
  @phone
end