Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10003
10004
10005
10006
10007
# File 'lib/stripe/resources/payment_intent.rb', line 10003

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9997
9998
9999
# File 'lib/stripe/resources/payment_intent.rb', line 9997

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9999
10000
10001
# File 'lib/stripe/resources/payment_intent.rb', line 9999

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10001
10002
10003
# File 'lib/stripe/resources/payment_intent.rb', line 10001

def phone
  @phone
end