Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9536
9537
9538
9539
9540
# File 'lib/stripe/resources/payment_intent.rb', line 9536

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9530
9531
9532
# File 'lib/stripe/resources/payment_intent.rb', line 9530

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9532
9533
9534
# File 'lib/stripe/resources/payment_intent.rb', line 9532

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9534
9535
9536
# File 'lib/stripe/resources/payment_intent.rb', line 9534

def phone
  @phone
end