Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9319 9320 9321 9322 9323 |
# File 'lib/stripe/resources/payment_intent.rb', line 9319 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9313 9314 9315 |
# File 'lib/stripe/resources/payment_intent.rb', line 9313 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9315 9316 9317 |
# File 'lib/stripe/resources/payment_intent.rb', line 9315 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9317 9318 9319 |
# File 'lib/stripe/resources/payment_intent.rb', line 9317 def phone @phone end |