Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9220 9221 9222 9223 9224 |
# File 'lib/stripe/resources/payment_intent.rb', line 9220 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9214 9215 9216 |
# File 'lib/stripe/resources/payment_intent.rb', line 9214 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9216 9217 9218 |
# File 'lib/stripe/resources/payment_intent.rb', line 9216 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9218 9219 9220 |
# File 'lib/stripe/resources/payment_intent.rb', line 9218 def phone @phone end |