Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8893
8894
8895
8896
8897
# File 'lib/stripe/resources/payment_intent.rb', line 8893

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8887
8888
8889
# File 'lib/stripe/resources/payment_intent.rb', line 8887

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8889
8890
8891
# File 'lib/stripe/resources/payment_intent.rb', line 8889

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8891
8892
8893
# File 'lib/stripe/resources/payment_intent.rb', line 8891

def phone
  @phone
end