Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8893 8894 8895 8896 8897 |
# File 'lib/stripe/resources/payment_intent.rb', line 8893 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8887 8888 8889 |
# File 'lib/stripe/resources/payment_intent.rb', line 8887 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8889 8890 8891 |
# File 'lib/stripe/resources/payment_intent.rb', line 8889 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8891 8892 8893 |
# File 'lib/stripe/resources/payment_intent.rb', line 8891 def phone @phone end |