Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8841
8842
8843
8844
8845
# File 'lib/stripe/resources/payment_intent.rb', line 8841

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8835
8836
8837
# File 'lib/stripe/resources/payment_intent.rb', line 8835

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8837
8838
8839
# File 'lib/stripe/resources/payment_intent.rb', line 8837

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8839
8840
8841
# File 'lib/stripe/resources/payment_intent.rb', line 8839

def phone
  @phone
end