Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8809
8810
8811
8812
8813
# File 'lib/stripe/resources/payment_intent.rb', line 8809

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8803
8804
8805
# File 'lib/stripe/resources/payment_intent.rb', line 8803

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8805
8806
8807
# File 'lib/stripe/resources/payment_intent.rb', line 8805

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8807
8808
8809
# File 'lib/stripe/resources/payment_intent.rb', line 8807

def phone
  @phone
end