Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10060 10061 10062 10063 10064 |
# File 'lib/stripe/resources/payment_intent.rb', line 10060 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10052 10053 10054 |
# File 'lib/stripe/resources/payment_intent.rb', line 10052 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10055 10056 10057 |
# File 'lib/stripe/resources/payment_intent.rb', line 10055 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10058 10059 10060 |
# File 'lib/stripe/resources/payment_intent.rb', line 10058 def phone @phone end |