Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
11668 11669 11670 11671 11672 11673 11674 11675 11676 11677 11678 11679 11680 11681 11682 11683 11684 11685 11686 |
# File 'lib/stripe/resources/payment_intent.rb', line 11668 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
11652 11653 11654 |
# File 'lib/stripe/resources/payment_intent.rb', line 11652 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
11654 11655 11656 |
# File 'lib/stripe/resources/payment_intent.rb', line 11654 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
11656 11657 11658 |
# File 'lib/stripe/resources/payment_intent.rb', line 11656 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
11658 11659 11660 |
# File 'lib/stripe/resources/payment_intent.rb', line 11658 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
11660 11661 11662 |
# File 'lib/stripe/resources/payment_intent.rb', line 11660 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
11662 11663 11664 |
# File 'lib/stripe/resources/payment_intent.rb', line 11662 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
11664 11665 11666 |
# File 'lib/stripe/resources/payment_intent.rb', line 11664 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
11666 11667 11668 |
# File 'lib/stripe/resources/payment_intent.rb', line 11666 def ticket_number @ticket_number end |