Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
9437 9438 9439 9440 9441 9442 9443 9444 9445 9446 9447 9448 9449 9450 9451 9452 9453 9454 9455 |
# File 'lib/stripe/resources/payment_intent.rb', line 9437 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9421 9422 9423 |
# File 'lib/stripe/resources/payment_intent.rb', line 9421 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
9423 9424 9425 |
# File 'lib/stripe/resources/payment_intent.rb', line 9423 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
9425 9426 9427 |
# File 'lib/stripe/resources/payment_intent.rb', line 9425 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
9427 9428 9429 |
# File 'lib/stripe/resources/payment_intent.rb', line 9427 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
9429 9430 9431 |
# File 'lib/stripe/resources/payment_intent.rb', line 9429 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
9431 9432 9433 |
# File 'lib/stripe/resources/payment_intent.rb', line 9431 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
9433 9434 9435 |
# File 'lib/stripe/resources/payment_intent.rb', line 9433 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
9435 9436 9437 |
# File 'lib/stripe/resources/payment_intent.rb', line 9435 def ticket_number @ticket_number end |