Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
9378 9379 9380 9381 9382 9383 9384 9385 9386 9387 9388 9389 9390 9391 9392 9393 9394 9395 9396 |
# File 'lib/stripe/resources/payment_intent.rb', line 9378 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9362 9363 9364 |
# File 'lib/stripe/resources/payment_intent.rb', line 9362 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
9364 9365 9366 |
# File 'lib/stripe/resources/payment_intent.rb', line 9364 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
9366 9367 9368 |
# File 'lib/stripe/resources/payment_intent.rb', line 9366 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
9368 9369 9370 |
# File 'lib/stripe/resources/payment_intent.rb', line 9368 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
9370 9371 9372 |
# File 'lib/stripe/resources/payment_intent.rb', line 9370 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
9372 9373 9374 |
# File 'lib/stripe/resources/payment_intent.rb', line 9372 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
9374 9375 9376 |
# File 'lib/stripe/resources/payment_intent.rb', line 9374 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
9376 9377 9378 |
# File 'lib/stripe/resources/payment_intent.rb', line 9376 def ticket_number @ticket_number end |