Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
9051 9052 9053 9054 9055 9056 9057 9058 9059 9060 9061 9062 9063 9064 9065 9066 9067 9068 9069 |
# File 'lib/stripe/resources/payment_intent.rb', line 9051 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9035 9036 9037 |
# File 'lib/stripe/resources/payment_intent.rb', line 9035 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
9037 9038 9039 |
# File 'lib/stripe/resources/payment_intent.rb', line 9037 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
9039 9040 9041 |
# File 'lib/stripe/resources/payment_intent.rb', line 9039 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
9041 9042 9043 |
# File 'lib/stripe/resources/payment_intent.rb', line 9041 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
9043 9044 9045 |
# File 'lib/stripe/resources/payment_intent.rb', line 9043 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
9045 9046 9047 |
# File 'lib/stripe/resources/payment_intent.rb', line 9045 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
9047 9048 9049 |
# File 'lib/stripe/resources/payment_intent.rb', line 9047 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
9049 9050 9051 |
# File 'lib/stripe/resources/payment_intent.rb', line 9049 def ticket_number @ticket_number end |