Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
8999 9000 9001 9002 9003 9004 9005 9006 9007 9008 9009 9010 9011 9012 9013 9014 9015 9016 9017 |
# File 'lib/stripe/resources/payment_intent.rb', line 8999 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8983 8984 8985 |
# File 'lib/stripe/resources/payment_intent.rb', line 8983 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
8985 8986 8987 |
# File 'lib/stripe/resources/payment_intent.rb', line 8985 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
8987 8988 8989 |
# File 'lib/stripe/resources/payment_intent.rb', line 8987 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
8989 8990 8991 |
# File 'lib/stripe/resources/payment_intent.rb', line 8989 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
8991 8992 8993 |
# File 'lib/stripe/resources/payment_intent.rb', line 8991 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
8993 8994 8995 |
# File 'lib/stripe/resources/payment_intent.rb', line 8993 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
8995 8996 8997 |
# File 'lib/stripe/resources/payment_intent.rb', line 8995 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
8997 8998 8999 |
# File 'lib/stripe/resources/payment_intent.rb', line 8997 def ticket_number @ticket_number end |