Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
8967 8968 8969 8970 8971 8972 8973 8974 8975 8976 8977 8978 8979 8980 8981 8982 8983 8984 8985 |
# File 'lib/stripe/resources/payment_intent.rb', line 8967 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
8951 8952 8953 |
# File 'lib/stripe/resources/payment_intent.rb', line 8951 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
8953 8954 8955 |
# File 'lib/stripe/resources/payment_intent.rb', line 8953 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
8955 8956 8957 |
# File 'lib/stripe/resources/payment_intent.rb', line 8955 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
8957 8958 8959 |
# File 'lib/stripe/resources/payment_intent.rb', line 8957 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
8959 8960 8961 |
# File 'lib/stripe/resources/payment_intent.rb', line 8959 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
8961 8962 8963 |
# File 'lib/stripe/resources/payment_intent.rb', line 8961 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
8963 8964 8965 |
# File 'lib/stripe/resources/payment_intent.rb', line 8963 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
8965 8966 8967 |
# File 'lib/stripe/resources/payment_intent.rb', line 8965 def ticket_number @ticket_number end |