Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Passenger, Segment
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#segments ⇒ Object
The individual flight segments associated with the trip.
-
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
Instance Method Summary collapse
-
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
constructor
A new instance of Flight.
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil) ⇒ Flight
Returns a new instance of Flight.
10244 10245 10246 10247 10248 10249 10250 10251 10252 10253 10254 10255 10256 10257 10258 10259 10260 10261 10262 |
# File 'lib/stripe/resources/payment_intent.rb', line 10244 def initialize( affiliate: nil, agency_number: nil, carrier: nil, delivery: nil, passenger_name: nil, passengers: nil, segments: nil, ticket_number: nil ) @affiliate = affiliate @agency_number = agency_number @carrier = carrier @delivery = delivery @passenger_name = passenger_name @passengers = passengers @segments = segments @ticket_number = ticket_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
10221 10222 10223 |
# File 'lib/stripe/resources/payment_intent.rb', line 10221 def affiliate @affiliate end |
#agency_number ⇒ Object
The agency number (i.e. International Air Transport Association (IATA) agency number) of the travel agency that made the booking.
10224 10225 10226 |
# File 'lib/stripe/resources/payment_intent.rb', line 10224 def agency_number @agency_number end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier that issued the ticket.
10227 10228 10229 |
# File 'lib/stripe/resources/payment_intent.rb', line 10227 def carrier @carrier end |
#delivery ⇒ Object
Delivery details for this purchase.
10230 10231 10232 |
# File 'lib/stripe/resources/payment_intent.rb', line 10230 def delivery @delivery end |
#passenger_name ⇒ Object
The name of the person or entity on the reservation.
10233 10234 10235 |
# File 'lib/stripe/resources/payment_intent.rb', line 10233 def passenger_name @passenger_name end |
#passengers ⇒ Object
The details of the passengers in the travel reservation.
10236 10237 10238 |
# File 'lib/stripe/resources/payment_intent.rb', line 10236 def passengers @passengers end |
#segments ⇒ Object
The individual flight segments associated with the trip.
10239 10240 10241 |
# File 'lib/stripe/resources/payment_intent.rb', line 10239 def segments @segments end |
#ticket_number ⇒ Object
The ticket number associated with the travel reservation.
10242 10243 10244 |
# File 'lib/stripe/resources/payment_intent.rb', line 10242 def ticket_number @ticket_number end |