Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
11587 11588 11589 11590 11591 |
# File 'lib/stripe/resources/payment_intent.rb', line 11587 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
11581 11582 11583 |
# File 'lib/stripe/resources/payment_intent.rb', line 11581 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
11583 11584 11585 |
# File 'lib/stripe/resources/payment_intent.rb', line 11583 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
11585 11586 11587 |
# File 'lib/stripe/resources/payment_intent.rb', line 11585 def phone @phone end |