Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10080 10081 10082 10083 10084 |
# File 'lib/stripe/resources/payment_intent.rb', line 10080 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10074 10075 10076 |
# File 'lib/stripe/resources/payment_intent.rb', line 10074 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10076 10077 10078 |
# File 'lib/stripe/resources/payment_intent.rb', line 10076 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10078 10079 10080 |
# File 'lib/stripe/resources/payment_intent.rb', line 10078 def phone @phone end |