Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9396 9397 9398 9399 9400 |
# File 'lib/stripe/resources/payment_intent.rb', line 9396 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9390 9391 9392 |
# File 'lib/stripe/resources/payment_intent.rb', line 9390 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9392 9393 9394 |
# File 'lib/stripe/resources/payment_intent.rb', line 9392 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9394 9395 9396 |
# File 'lib/stripe/resources/payment_intent.rb', line 9394 def phone @phone end |