Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9356
9357
9358
9359
9360
# File 'lib/stripe/resources/payment_intent.rb', line 9356

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9350
9351
9352
# File 'lib/stripe/resources/payment_intent.rb', line 9350

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9352
9353
9354
# File 'lib/stripe/resources/payment_intent.rb', line 9352

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9354
9355
9356
# File 'lib/stripe/resources/payment_intent.rb', line 9354

def phone
  @phone
end