Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9297
9298
9299
9300
9301
# File 'lib/stripe/resources/payment_intent.rb', line 9297

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9291
9292
9293
# File 'lib/stripe/resources/payment_intent.rb', line 9291

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9293
9294
9295
# File 'lib/stripe/resources/payment_intent.rb', line 9293

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9295
9296
9297
# File 'lib/stripe/resources/payment_intent.rb', line 9295

def phone
  @phone
end