Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8970 8971 8972 8973 8974 |
# File 'lib/stripe/resources/payment_intent.rb', line 8970 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8964 8965 8966 |
# File 'lib/stripe/resources/payment_intent.rb', line 8964 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8966 8967 8968 |
# File 'lib/stripe/resources/payment_intent.rb', line 8966 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8968 8969 8970 |
# File 'lib/stripe/resources/payment_intent.rb', line 8968 def phone @phone end |