Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



8886
8887
8888
8889
8890
# File 'lib/stripe/resources/payment_intent.rb', line 8886

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



8880
8881
8882
# File 'lib/stripe/resources/payment_intent.rb', line 8880

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



8882
8883
8884
# File 'lib/stripe/resources/payment_intent.rb', line 8882

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



8884
8885
8886
# File 'lib/stripe/resources/payment_intent.rb', line 8884

def phone
  @phone
end