Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10148
10149
10150
10151
10152
# File 'lib/stripe/resources/payment_intent.rb', line 10148

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



10140
10141
10142
# File 'lib/stripe/resources/payment_intent.rb', line 10140

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



10143
10144
10145
# File 'lib/stripe/resources/payment_intent.rb', line 10143

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10146
10147
10148
# File 'lib/stripe/resources/payment_intent.rb', line 10146

def phone
  @phone
end