Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
8918 8919 8920 8921 8922 |
# File 'lib/stripe/resources/payment_intent.rb', line 8918 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
8912 8913 8914 |
# File 'lib/stripe/resources/payment_intent.rb', line 8912 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
8914 8915 8916 |
# File 'lib/stripe/resources/payment_intent.rb', line 8914 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
8916 8917 8918 |
# File 'lib/stripe/resources/payment_intent.rb', line 8916 def phone @phone end |