Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



11807
11808
11809
11810
11811
11812
11813
11814
11815
11816
11817
11818
11819
11820
11821
11822
11823
11824
11825
11826
11827
11828
11829
11830
11831
11832
11833
11834
11835
11836
11837
11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
11848
11849
11850
11851
# File 'lib/stripe/resources/payment_intent.rb', line 11807

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



11765
11766
11767
# File 'lib/stripe/resources/payment_intent.rb', line 11765

def address
  @address
end

#adultsObject

The number of adults on the booking



11767
11768
11769
# File 'lib/stripe/resources/payment_intent.rb', line 11767

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



11769
11770
11771
# File 'lib/stripe/resources/payment_intent.rb', line 11769

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



11771
11772
11773
# File 'lib/stripe/resources/payment_intent.rb', line 11771

def booking_number
  @booking_number
end

#categoryObject

The lodging category



11773
11774
11775
# File 'lib/stripe/resources/payment_intent.rb', line 11773

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



11775
11776
11777
# File 'lib/stripe/resources/payment_intent.rb', line 11775

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



11777
11778
11779
# File 'lib/stripe/resources/payment_intent.rb', line 11777

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



11779
11780
11781
# File 'lib/stripe/resources/payment_intent.rb', line 11779

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



11781
11782
11783
# File 'lib/stripe/resources/payment_intent.rb', line 11781

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



11783
11784
11785
# File 'lib/stripe/resources/payment_intent.rb', line 11783

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



11785
11786
11787
# File 'lib/stripe/resources/payment_intent.rb', line 11785

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



11787
11788
11789
# File 'lib/stripe/resources/payment_intent.rb', line 11787

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



11789
11790
11791
# File 'lib/stripe/resources/payment_intent.rb', line 11789

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



11791
11792
11793
# File 'lib/stripe/resources/payment_intent.rb', line 11791

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



11793
11794
11795
# File 'lib/stripe/resources/payment_intent.rb', line 11793

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



11795
11796
11797
# File 'lib/stripe/resources/payment_intent.rb', line 11795

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



11797
11798
11799
# File 'lib/stripe/resources/payment_intent.rb', line 11797

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



11799
11800
11801
# File 'lib/stripe/resources/payment_intent.rb', line 11799

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



11801
11802
11803
# File 'lib/stripe/resources/payment_intent.rb', line 11801

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



11803
11804
11805
# File 'lib/stripe/resources/payment_intent.rb', line 11803

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



11805
11806
11807
# File 'lib/stripe/resources/payment_intent.rb', line 11805

def total_tax_amount
  @total_tax_amount
end