Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
10331
10332
10333
10334
10335
10336
10337
10338
10339
10340
10341
10342
10343
10344
# File 'lib/stripe/resources/payment_intent.rb', line 10300

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



10258
10259
10260
# File 'lib/stripe/resources/payment_intent.rb', line 10258

def address
  @address
end

#adultsObject

The number of adults on the booking



10260
10261
10262
# File 'lib/stripe/resources/payment_intent.rb', line 10260

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



10262
10263
10264
# File 'lib/stripe/resources/payment_intent.rb', line 10262

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



10264
10265
10266
# File 'lib/stripe/resources/payment_intent.rb', line 10264

def booking_number
  @booking_number
end

#categoryObject

The lodging category



10266
10267
10268
# File 'lib/stripe/resources/payment_intent.rb', line 10266

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



10268
10269
10270
# File 'lib/stripe/resources/payment_intent.rb', line 10268

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



10270
10271
10272
# File 'lib/stripe/resources/payment_intent.rb', line 10270

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



10272
10273
10274
# File 'lib/stripe/resources/payment_intent.rb', line 10272

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



10274
10275
10276
# File 'lib/stripe/resources/payment_intent.rb', line 10274

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



10276
10277
10278
# File 'lib/stripe/resources/payment_intent.rb', line 10276

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



10278
10279
10280
# File 'lib/stripe/resources/payment_intent.rb', line 10278

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



10280
10281
10282
# File 'lib/stripe/resources/payment_intent.rb', line 10280

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



10282
10283
10284
# File 'lib/stripe/resources/payment_intent.rb', line 10282

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



10284
10285
10286
# File 'lib/stripe/resources/payment_intent.rb', line 10284

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



10286
10287
10288
# File 'lib/stripe/resources/payment_intent.rb', line 10286

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



10288
10289
10290
# File 'lib/stripe/resources/payment_intent.rb', line 10288

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



10290
10291
10292
# File 'lib/stripe/resources/payment_intent.rb', line 10290

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



10292
10293
10294
# File 'lib/stripe/resources/payment_intent.rb', line 10292

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



10294
10295
10296
# File 'lib/stripe/resources/payment_intent.rb', line 10294

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



10296
10297
10298
# File 'lib/stripe/resources/payment_intent.rb', line 10296

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



10298
10299
10300
# File 'lib/stripe/resources/payment_intent.rb', line 10298

def total_tax_amount
  @total_tax_amount
end