Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Lodging check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
9833 9834 9835 9836 9837 9838 9839 9840 9841 9842 9843 9844 9845 9846 9847 9848 9849 9850 9851 9852 9853 9854 9855 9856 9857 9858 9859 9860 9861 9862 9863 9864 9865 9866 9867 9868 9869 9870 9871 9872 9873 9874 9875 9876 9877 |
# File 'lib/stripe/resources/payment_intent.rb', line 9833 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
9791 9792 9793 |
# File 'lib/stripe/resources/payment_intent.rb', line 9791 def address @address end |
#adults ⇒ Object
The number of adults on the booking
9793 9794 9795 |
# File 'lib/stripe/resources/payment_intent.rb', line 9793 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9795 9796 9797 |
# File 'lib/stripe/resources/payment_intent.rb', line 9795 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
9797 9798 9799 |
# File 'lib/stripe/resources/payment_intent.rb', line 9797 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
9799 9800 9801 |
# File 'lib/stripe/resources/payment_intent.rb', line 9799 def category @category end |
#checkin_at ⇒ Object
Lodging check-in time. Measured in seconds since the Unix epoch.
9801 9802 9803 |
# File 'lib/stripe/resources/payment_intent.rb', line 9801 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
9803 9804 9805 |
# File 'lib/stripe/resources/payment_intent.rb', line 9803 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
9805 9806 9807 |
# File 'lib/stripe/resources/payment_intent.rb', line 9805 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
9807 9808 9809 |
# File 'lib/stripe/resources/payment_intent.rb', line 9807 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
9809 9810 9811 |
# File 'lib/stripe/resources/payment_intent.rb', line 9809 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
9811 9812 9813 |
# File 'lib/stripe/resources/payment_intent.rb', line 9811 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
9813 9814 9815 |
# File 'lib/stripe/resources/payment_intent.rb', line 9813 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
9815 9816 9817 |
# File 'lib/stripe/resources/payment_intent.rb', line 9815 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
9817 9818 9819 |
# File 'lib/stripe/resources/payment_intent.rb', line 9817 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
9819 9820 9821 |
# File 'lib/stripe/resources/payment_intent.rb', line 9819 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
9821 9822 9823 |
# File 'lib/stripe/resources/payment_intent.rb', line 9821 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
9823 9824 9825 |
# File 'lib/stripe/resources/payment_intent.rb', line 9823 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
9825 9826 9827 |
# File 'lib/stripe/resources/payment_intent.rb', line 9825 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
9827 9828 9829 |
# File 'lib/stripe/resources/payment_intent.rb', line 9827 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
9829 9830 9831 |
# File 'lib/stripe/resources/payment_intent.rb', line 9829 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
9831 9832 9833 |
# File 'lib/stripe/resources/payment_intent.rb', line 9831 def total_tax_amount @total_tax_amount end |