Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



9576
9577
9578
9579
9580
9581
9582
9583
9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
9596
9597
9598
9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
9613
9614
9615
9616
9617
9618
9619
9620
# File 'lib/stripe/resources/payment_intent.rb', line 9576

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



9534
9535
9536
# File 'lib/stripe/resources/payment_intent.rb', line 9534

def address
  @address
end

#adultsObject

The number of adults on the booking



9536
9537
9538
# File 'lib/stripe/resources/payment_intent.rb', line 9536

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



9538
9539
9540
# File 'lib/stripe/resources/payment_intent.rb', line 9538

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



9540
9541
9542
# File 'lib/stripe/resources/payment_intent.rb', line 9540

def booking_number
  @booking_number
end

#categoryObject

The lodging category



9542
9543
9544
# File 'lib/stripe/resources/payment_intent.rb', line 9542

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



9544
9545
9546
# File 'lib/stripe/resources/payment_intent.rb', line 9544

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



9546
9547
9548
# File 'lib/stripe/resources/payment_intent.rb', line 9546

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



9548
9549
9550
# File 'lib/stripe/resources/payment_intent.rb', line 9548

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



9550
9551
9552
# File 'lib/stripe/resources/payment_intent.rb', line 9550

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



9552
9553
9554
# File 'lib/stripe/resources/payment_intent.rb', line 9552

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



9554
9555
9556
# File 'lib/stripe/resources/payment_intent.rb', line 9554

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



9556
9557
9558
# File 'lib/stripe/resources/payment_intent.rb', line 9556

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



9558
9559
9560
# File 'lib/stripe/resources/payment_intent.rb', line 9558

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



9560
9561
9562
# File 'lib/stripe/resources/payment_intent.rb', line 9560

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



9562
9563
9564
# File 'lib/stripe/resources/payment_intent.rb', line 9562

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



9564
9565
9566
# File 'lib/stripe/resources/payment_intent.rb', line 9564

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



9566
9567
9568
# File 'lib/stripe/resources/payment_intent.rb', line 9566

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



9568
9569
9570
# File 'lib/stripe/resources/payment_intent.rb', line 9568

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



9570
9571
9572
# File 'lib/stripe/resources/payment_intent.rb', line 9570

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



9572
9573
9574
# File 'lib/stripe/resources/payment_intent.rb', line 9572

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



9574
9575
9576
# File 'lib/stripe/resources/payment_intent.rb', line 9574

def total_tax_amount
  @total_tax_amount
end