Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



9517
9518
9519
9520
9521
9522
9523
9524
9525
9526
9527
9528
9529
9530
9531
9532
9533
9534
9535
9536
9537
9538
9539
9540
9541
9542
9543
9544
9545
9546
9547
9548
9549
9550
9551
9552
9553
9554
9555
9556
9557
9558
9559
9560
9561
# File 'lib/stripe/resources/payment_intent.rb', line 9517

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



9475
9476
9477
# File 'lib/stripe/resources/payment_intent.rb', line 9475

def address
  @address
end

#adultsObject

The number of adults on the booking



9477
9478
9479
# File 'lib/stripe/resources/payment_intent.rb', line 9477

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



9479
9480
9481
# File 'lib/stripe/resources/payment_intent.rb', line 9479

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



9481
9482
9483
# File 'lib/stripe/resources/payment_intent.rb', line 9481

def booking_number
  @booking_number
end

#categoryObject

The lodging category



9483
9484
9485
# File 'lib/stripe/resources/payment_intent.rb', line 9483

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



9485
9486
9487
# File 'lib/stripe/resources/payment_intent.rb', line 9485

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



9487
9488
9489
# File 'lib/stripe/resources/payment_intent.rb', line 9487

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



9489
9490
9491
# File 'lib/stripe/resources/payment_intent.rb', line 9489

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



9491
9492
9493
# File 'lib/stripe/resources/payment_intent.rb', line 9491

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



9493
9494
9495
# File 'lib/stripe/resources/payment_intent.rb', line 9493

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



9495
9496
9497
# File 'lib/stripe/resources/payment_intent.rb', line 9495

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



9497
9498
9499
# File 'lib/stripe/resources/payment_intent.rb', line 9497

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



9499
9500
9501
# File 'lib/stripe/resources/payment_intent.rb', line 9499

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



9501
9502
9503
# File 'lib/stripe/resources/payment_intent.rb', line 9501

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



9503
9504
9505
# File 'lib/stripe/resources/payment_intent.rb', line 9503

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



9505
9506
9507
# File 'lib/stripe/resources/payment_intent.rb', line 9505

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



9507
9508
9509
# File 'lib/stripe/resources/payment_intent.rb', line 9507

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



9509
9510
9511
# File 'lib/stripe/resources/payment_intent.rb', line 9509

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



9511
9512
9513
# File 'lib/stripe/resources/payment_intent.rb', line 9511

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



9513
9514
9515
# File 'lib/stripe/resources/payment_intent.rb', line 9513

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



9515
9516
9517
# File 'lib/stripe/resources/payment_intent.rb', line 9515

def total_tax_amount
  @total_tax_amount
end