Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



9190
9191
9192
9193
9194
9195
9196
9197
9198
9199
9200
9201
9202
9203
9204
9205
9206
9207
9208
9209
9210
9211
9212
9213
9214
9215
9216
9217
9218
9219
9220
9221
9222
9223
9224
9225
9226
9227
9228
9229
9230
9231
9232
9233
9234
# File 'lib/stripe/resources/payment_intent.rb', line 9190

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



9148
9149
9150
# File 'lib/stripe/resources/payment_intent.rb', line 9148

def address
  @address
end

#adultsObject

The number of adults on the booking



9150
9151
9152
# File 'lib/stripe/resources/payment_intent.rb', line 9150

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



9152
9153
9154
# File 'lib/stripe/resources/payment_intent.rb', line 9152

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



9154
9155
9156
# File 'lib/stripe/resources/payment_intent.rb', line 9154

def booking_number
  @booking_number
end

#categoryObject

The lodging category



9156
9157
9158
# File 'lib/stripe/resources/payment_intent.rb', line 9156

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



9158
9159
9160
# File 'lib/stripe/resources/payment_intent.rb', line 9158

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



9160
9161
9162
# File 'lib/stripe/resources/payment_intent.rb', line 9160

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



9162
9163
9164
# File 'lib/stripe/resources/payment_intent.rb', line 9162

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



9164
9165
9166
# File 'lib/stripe/resources/payment_intent.rb', line 9164

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



9166
9167
9168
# File 'lib/stripe/resources/payment_intent.rb', line 9166

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



9168
9169
9170
# File 'lib/stripe/resources/payment_intent.rb', line 9168

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



9170
9171
9172
# File 'lib/stripe/resources/payment_intent.rb', line 9170

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



9172
9173
9174
# File 'lib/stripe/resources/payment_intent.rb', line 9172

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



9174
9175
9176
# File 'lib/stripe/resources/payment_intent.rb', line 9174

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



9176
9177
9178
# File 'lib/stripe/resources/payment_intent.rb', line 9176

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



9178
9179
9180
# File 'lib/stripe/resources/payment_intent.rb', line 9178

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



9180
9181
9182
# File 'lib/stripe/resources/payment_intent.rb', line 9180

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



9182
9183
9184
# File 'lib/stripe/resources/payment_intent.rb', line 9182

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



9184
9185
9186
# File 'lib/stripe/resources/payment_intent.rb', line 9184

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



9186
9187
9188
# File 'lib/stripe/resources/payment_intent.rb', line 9186

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



9188
9189
9190
# File 'lib/stripe/resources/payment_intent.rb', line 9188

def total_tax_amount
  @total_tax_amount
end