Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
9106 9107 9108 9109 9110 9111 9112 9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 9130 9131 9132 9133 9134 9135 9136 9137 9138 9139 9140 9141 9142 9143 9144 9145 9146 9147 9148 9149 9150 |
# File 'lib/stripe/resources/payment_intent.rb', line 9106 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
9064 9065 9066 |
# File 'lib/stripe/resources/payment_intent.rb', line 9064 def address @address end |
#adults ⇒ Object
The number of adults on the booking
9066 9067 9068 |
# File 'lib/stripe/resources/payment_intent.rb', line 9066 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9068 9069 9070 |
# File 'lib/stripe/resources/payment_intent.rb', line 9068 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
9070 9071 9072 |
# File 'lib/stripe/resources/payment_intent.rb', line 9070 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
9072 9073 9074 |
# File 'lib/stripe/resources/payment_intent.rb', line 9072 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
9074 9075 9076 |
# File 'lib/stripe/resources/payment_intent.rb', line 9074 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
9076 9077 9078 |
# File 'lib/stripe/resources/payment_intent.rb', line 9076 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
9078 9079 9080 |
# File 'lib/stripe/resources/payment_intent.rb', line 9078 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
9080 9081 9082 |
# File 'lib/stripe/resources/payment_intent.rb', line 9080 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
9082 9083 9084 |
# File 'lib/stripe/resources/payment_intent.rb', line 9082 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
9084 9085 9086 |
# File 'lib/stripe/resources/payment_intent.rb', line 9084 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
9086 9087 9088 |
# File 'lib/stripe/resources/payment_intent.rb', line 9086 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
9088 9089 9090 |
# File 'lib/stripe/resources/payment_intent.rb', line 9088 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
9090 9091 9092 |
# File 'lib/stripe/resources/payment_intent.rb', line 9090 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
9092 9093 9094 |
# File 'lib/stripe/resources/payment_intent.rb', line 9092 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
9094 9095 9096 |
# File 'lib/stripe/resources/payment_intent.rb', line 9094 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
9096 9097 9098 |
# File 'lib/stripe/resources/payment_intent.rb', line 9096 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
9098 9099 9100 |
# File 'lib/stripe/resources/payment_intent.rb', line 9098 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
9100 9101 9102 |
# File 'lib/stripe/resources/payment_intent.rb', line 9100 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
9102 9103 9104 |
# File 'lib/stripe/resources/payment_intent.rb', line 9102 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
9104 9105 9106 |
# File 'lib/stripe/resources/payment_intent.rb', line 9104 def total_tax_amount @total_tax_amount end |