Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



11739
11740
11741
11742
11743
# File 'lib/stripe/resources/payment_intent.rb', line 11739

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



11733
11734
11735
# File 'lib/stripe/resources/payment_intent.rb', line 11733

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



11735
11736
11737
# File 'lib/stripe/resources/payment_intent.rb', line 11735

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



11737
11738
11739
# File 'lib/stripe/resources/payment_intent.rb', line 11737

def phone
  @phone
end