Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10232 10233 10234 10235 10236 |
# File 'lib/stripe/resources/payment_intent.rb', line 10232 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10226 10227 10228 |
# File 'lib/stripe/resources/payment_intent.rb', line 10226 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10228 10229 10230 |
# File 'lib/stripe/resources/payment_intent.rb', line 10228 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10230 10231 10232 |
# File 'lib/stripe/resources/payment_intent.rb', line 10230 def phone @phone end |