Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9548
9549
9550
9551
9552
# File 'lib/stripe/resources/payment_intent.rb', line 9548

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9542
9543
9544
# File 'lib/stripe/resources/payment_intent.rb', line 9542

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9544
9545
9546
# File 'lib/stripe/resources/payment_intent.rb', line 9544

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9546
9547
9548
# File 'lib/stripe/resources/payment_intent.rb', line 9546

def phone
  @phone
end