Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9508 9509 9510 9511 9512 |
# File 'lib/stripe/resources/payment_intent.rb', line 9508 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9502 9503 9504 |
# File 'lib/stripe/resources/payment_intent.rb', line 9502 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9504 9505 9506 |
# File 'lib/stripe/resources/payment_intent.rb', line 9504 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9506 9507 9508 |
# File 'lib/stripe/resources/payment_intent.rb', line 9506 def phone @phone end |