Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9449
9450
9451
9452
9453
# File 'lib/stripe/resources/payment_intent.rb', line 9449

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9443
9444
9445
# File 'lib/stripe/resources/payment_intent.rb', line 9443

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9445
9446
9447
# File 'lib/stripe/resources/payment_intent.rb', line 9445

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9447
9448
9449
# File 'lib/stripe/resources/payment_intent.rb', line 9447

def phone
  @phone
end