Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9449 9450 9451 9452 9453 |
# File 'lib/stripe/resources/payment_intent.rb', line 9449 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9443 9444 9445 |
# File 'lib/stripe/resources/payment_intent.rb', line 9443 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9445 9446 9447 |
# File 'lib/stripe/resources/payment_intent.rb', line 9445 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9447 9448 9449 |
# File 'lib/stripe/resources/payment_intent.rb', line 9447 def phone @phone end |