Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9038 9039 9040 9041 9042 |
# File 'lib/stripe/resources/payment_intent.rb', line 9038 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9032 9033 9034 |
# File 'lib/stripe/resources/payment_intent.rb', line 9032 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9034 9035 9036 |
# File 'lib/stripe/resources/payment_intent.rb', line 9034 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9036 9037 9038 |
# File 'lib/stripe/resources/payment_intent.rb', line 9036 def phone @phone end |