Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9070 9071 9072 9073 9074 |
# File 'lib/stripe/resources/payment_intent.rb', line 9070 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9064 9065 9066 |
# File 'lib/stripe/resources/payment_intent.rb', line 9064 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9066 9067 9068 |
# File 'lib/stripe/resources/payment_intent.rb', line 9066 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9068 9069 9070 |
# File 'lib/stripe/resources/payment_intent.rb', line 9068 def phone @phone end |