Class: Stripe::PaymentIntent::CaptureParams::PaymentDetails::Subscription::BillingInterval
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::PaymentDetails::Subscription::BillingInterval
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#count ⇒ Object
The number of intervals, as an whole number greater than 0.
-
#interval ⇒ Object
Specifies a type of interval unit.
Instance Method Summary collapse
-
#initialize(count: nil, interval: nil) ⇒ BillingInterval
constructor
A new instance of BillingInterval.
Methods inherited from RequestParams
Constructor Details
#initialize(count: nil, interval: nil) ⇒ BillingInterval
Returns a new instance of BillingInterval.
9639 9640 9641 9642 |
# File 'lib/stripe/resources/payment_intent.rb', line 9639 def initialize(count: nil, interval: nil) @count = count @interval = interval end |
Instance Attribute Details
#count ⇒ Object
The number of intervals, as an whole number greater than 0. Stripe multiplies this by the interval type to get the overall duration.
9635 9636 9637 |
# File 'lib/stripe/resources/payment_intent.rb', line 9635 def count @count end |
#interval ⇒ Object
Specifies a type of interval unit. Either ‘day`, `week`, `month` or `year`.
9637 9638 9639 |
# File 'lib/stripe/resources/payment_intent.rb', line 9637 def interval @interval end |