Class: Stripe::PaymentIntent::CaptureParams::TransferData
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CaptureParams::TransferData
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
Instance Method Summary collapse
-
#initialize(amount: nil) ⇒ TransferData
constructor
A new instance of TransferData.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil) ⇒ TransferData
Returns a new instance of TransferData.
9317 9318 9319 |
# File 'lib/stripe/resources/payment_intent.rb', line 9317 def initialize(amount: nil) @amount = amount end |
Instance Attribute Details
#amount ⇒ Object
The amount that will be transferred automatically when a charge succeeds.
9315 9316 9317 |
# File 'lib/stripe/resources/payment_intent.rb', line 9315 def amount @amount end |