Class: Stripe::PaymentIntent::ConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: AmountDetails, Hooks, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping
Instance Attribute Summary collapse
-
#amount_details ⇒ Object
Provides industry-specific information about the amount.
-
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account.
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
-
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
-
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle.
-
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate.
-
#payment_details ⇒ Object
Provides industry-specific information about the charge.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(amount_details: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ ConfirmParams
Returns a new instance of ConfirmParams.
14284 14285 14286 14287 14288 14289 14290 14291 14292 14293 14294 14295 14296 14297 14298 14299 14300 14301 14302 14303 14304 14305 14306 14307 14308 14309 14310 14311 14312 14313 14314 14315 14316 14317 14318 14319 14320 14321 14322 14323 14324 14325 14326 14327 14328 14329 14330 |
# File 'lib/stripe/resources/payment_intent.rb', line 14284 def initialize( amount_details: nil, application_fee_amount: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, fx_quote: nil, hooks: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil ) @amount_details = amount_details @application_fee_amount = application_fee_amount @capture_method = capture_method @confirmation_token = confirmation_token @error_on_requires_action = error_on_requires_action @expand = @fx_quote = fx_quote @hooks = hooks @mandate = mandate @mandate_data = mandate_data @off_session = off_session @payment_details = payment_details @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @radar_options = @receipt_email = receipt_email @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#amount_details ⇒ Object
Provides industry-specific information about the amount.
14225 14226 14227 |
# File 'lib/stripe/resources/payment_intent.rb', line 14225 def amount_details @amount_details end |
#application_fee_amount ⇒ Object
The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).
14227 14228 14229 |
# File 'lib/stripe/resources/payment_intent.rb', line 14227 def application_fee_amount @application_fee_amount end |
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
14229 14230 14231 |
# File 'lib/stripe/resources/payment_intent.rb', line 14229 def capture_method @capture_method end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
14233 14234 14235 |
# File 'lib/stripe/resources/payment_intent.rb', line 14233 def confirmation_token @confirmation_token end |
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](stripe.com/docs/payments/save-card-without-authentication).
14235 14236 14237 |
# File 'lib/stripe/resources/payment_intent.rb', line 14235 def error_on_requires_action @error_on_requires_action end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
14237 14238 14239 |
# File 'lib/stripe/resources/payment_intent.rb', line 14237 def @expand end |
#fx_quote ⇒ Object
The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.
14239 14240 14241 |
# File 'lib/stripe/resources/payment_intent.rb', line 14239 def fx_quote @fx_quote end |
#hooks ⇒ Object
Automations to be run during the PaymentIntent lifecycle
14241 14242 14243 |
# File 'lib/stripe/resources/payment_intent.rb', line 14241 def hooks @hooks end |
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
14243 14244 14245 |
# File 'lib/stripe/resources/payment_intent.rb', line 14243 def mandate @mandate end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
14245 14246 14247 |
# File 'lib/stripe/resources/payment_intent.rb', line 14245 def mandate_data @mandate_data end |
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](stripe.com/docs/payments/cards/charging-saved-cards).
14247 14248 14249 |
# File 'lib/stripe/resources/payment_intent.rb', line 14247 def off_session @off_session end |
#payment_details ⇒ Object
Provides industry-specific information about the charge.
14249 14250 14251 |
# File 'lib/stripe/resources/payment_intent.rb', line 14249 def payment_details @payment_details end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the [customer](stripe.com/docs/api#create_payment_intent-customer) that is set on this PaymentIntent.
14252 14253 14254 |
# File 'lib/stripe/resources/payment_intent.rb', line 14252 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.
14256 14257 14258 |
# File 'lib/stripe/resources/payment_intent.rb', line 14256 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
14258 14259 14260 |
# File 'lib/stripe/resources/payment_intent.rb', line 14258 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).
14260 14261 14262 |
# File 'lib/stripe/resources/payment_intent.rb', line 14260 def payment_method_types @payment_method_types end |
#radar_options ⇒ Object
Options to configure Radar. Learn more about [Radar Sessions](stripe.com/docs/radar/radar-session).
14262 14263 14264 |
# File 'lib/stripe/resources/payment_intent.rb', line 14262 def @radar_options end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
14264 14265 14266 |
# File 'lib/stripe/resources/payment_intent.rb', line 14264 def receipt_email @receipt_email end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
14268 14269 14270 |
# File 'lib/stripe/resources/payment_intent.rb', line 14268 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
14278 14279 14280 |
# File 'lib/stripe/resources/payment_intent.rb', line 14278 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
14280 14281 14282 |
# File 'lib/stripe/resources/payment_intent.rb', line 14280 def shipping @shipping end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
14282 14283 14284 |
# File 'lib/stripe/resources/payment_intent.rb', line 14282 def use_stripe_sdk @use_stripe_sdk end |