Class: Stripe::PaymentIntent::ConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



8790
8791
8792
8793
8794
8795
8796
8797
8798
8799
8800
8801
8802
8803
8804
8805
8806
8807
8808
8809
8810
8811
8812
8813
8814
8815
8816
8817
8818
8819
8820
8821
8822
8823
8824
8825
8826
# File 'lib/stripe/resources/payment_intent.rb', line 8790

def initialize(
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  expand: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @expand = expand
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



8741
8742
8743
# File 'lib/stripe/resources/payment_intent.rb', line 8741

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



8745
8746
8747
# File 'lib/stripe/resources/payment_intent.rb', line 8745

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](stripe.com/docs/payments/save-card-without-authentication).



8747
8748
8749
# File 'lib/stripe/resources/payment_intent.rb', line 8747

def error_on_requires_action
  @error_on_requires_action
end

#expandObject

Specifies which fields in the response should be expanded.



8749
8750
8751
# File 'lib/stripe/resources/payment_intent.rb', line 8749

def expand
  @expand
end

#mandateObject

ID of the mandate that’s used for this payment.



8751
8752
8753
# File 'lib/stripe/resources/payment_intent.rb', line 8751

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



8753
8754
8755
# File 'lib/stripe/resources/payment_intent.rb', line 8753

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](stripe.com/docs/payments/cards/charging-saved-cards).



8755
8756
8757
# File 'lib/stripe/resources/payment_intent.rb', line 8755

def off_session
  @off_session
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent. If the payment method is attached to a Customer, it must match the [customer](stripe.com/docs/api#create_payment_intent-customer) that is set on this PaymentIntent.



8758
8759
8760
# File 'lib/stripe/resources/payment_intent.rb', line 8758

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



8762
8763
8764
# File 'lib/stripe/resources/payment_intent.rb', line 8762

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



8764
8765
8766
# File 'lib/stripe/resources/payment_intent.rb', line 8764

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods). A list of valid payment method types can be found [here](docs.stripe.com/api/payment_methods/object#payment_method_object-type).



8766
8767
8768
# File 'lib/stripe/resources/payment_intent.rb', line 8766

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about [Radar Sessions](stripe.com/docs/radar/radar-session).



8768
8769
8770
# File 'lib/stripe/resources/payment_intent.rb', line 8768

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



8770
8771
8772
# File 'lib/stripe/resources/payment_intent.rb', line 8770

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



8774
8775
8776
# File 'lib/stripe/resources/payment_intent.rb', line 8774

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



8784
8785
8786
# File 'lib/stripe/resources/payment_intent.rb', line 8784

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



8786
8787
8788
# File 'lib/stripe/resources/payment_intent.rb', line 8786

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



8788
8789
8790
# File 'lib/stripe/resources/payment_intent.rb', line 8788

def use_stripe_sdk
  @use_stripe_sdk
end