Class: Stripe::PaymentIntent::ConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: MandateData, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



8547
8548
8549
8550
8551
8552
8553
8554
8555
8556
8557
8558
8559
8560
8561
8562
8563
8564
8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
# File 'lib/stripe/resources/payment_intent.rb', line 8547

def initialize(
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  expand: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @expand = expand
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



8499
8500
8501
# File 'lib/stripe/resources/payment_intent.rb', line 8499

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



8503
8504
8505
# File 'lib/stripe/resources/payment_intent.rb', line 8503

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](stripe.com/docs/payments/save-card-without-authentication).



8505
8506
8507
# File 'lib/stripe/resources/payment_intent.rb', line 8505

def error_on_requires_action
  @error_on_requires_action
end

#expandObject

Specifies which fields in the response should be expanded.



8507
8508
8509
# File 'lib/stripe/resources/payment_intent.rb', line 8507

def expand
  @expand
end

#mandateObject

ID of the mandate that’s used for this payment.



8509
8510
8511
# File 'lib/stripe/resources/payment_intent.rb', line 8509

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



8511
8512
8513
# File 'lib/stripe/resources/payment_intent.rb', line 8511

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](stripe.com/docs/payments/cards/charging-saved-cards).



8513
8514
8515
# File 'lib/stripe/resources/payment_intent.rb', line 8513

def off_session
  @off_session
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.



8515
8516
8517
# File 'lib/stripe/resources/payment_intent.rb', line 8515

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



8519
8520
8521
# File 'lib/stripe/resources/payment_intent.rb', line 8519

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



8521
8522
8523
# File 'lib/stripe/resources/payment_intent.rb', line 8521

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



8523
8524
8525
# File 'lib/stripe/resources/payment_intent.rb', line 8523

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about [Radar Sessions](stripe.com/docs/radar/radar-session).



8525
8526
8527
# File 'lib/stripe/resources/payment_intent.rb', line 8525

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



8527
8528
8529
# File 'lib/stripe/resources/payment_intent.rb', line 8527

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



8531
8532
8533
# File 'lib/stripe/resources/payment_intent.rb', line 8531

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



8541
8542
8543
# File 'lib/stripe/resources/payment_intent.rb', line 8541

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



8543
8544
8545
# File 'lib/stripe/resources/payment_intent.rb', line 8543

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



8545
8546
8547
# File 'lib/stripe/resources/payment_intent.rb', line 8545

def use_stripe_sdk
  @use_stripe_sdk
end