Class: Stripe::PaymentIntent::ConfirmParams

Inherits:
RequestParams show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AsyncWorkflows, MandateData, PaymentDetails, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(application_fee_amount: nil, async_workflows: nil, capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, fx_quote: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_details: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ ConfirmParams

Returns a new instance of ConfirmParams.



13135
13136
13137
13138
13139
13140
13141
13142
13143
13144
13145
13146
13147
13148
13149
13150
13151
13152
13153
13154
13155
13156
13157
13158
13159
13160
13161
13162
13163
13164
13165
13166
13167
13168
13169
13170
13171
13172
13173
13174
13175
13176
13177
13178
13179
# File 'lib/stripe/resources/payment_intent.rb', line 13135

def initialize(
  application_fee_amount: nil,
  async_workflows: nil,
  capture_method: nil,
  confirmation_token: nil,
  error_on_requires_action: nil,
  expand: nil,
  fx_quote: nil,
  mandate: nil,
  mandate_data: nil,
  off_session: nil,
  payment_details: nil,
  payment_method: nil,
  payment_method_data: nil,
  payment_method_options: nil,
  payment_method_types: nil,
  radar_options: nil,
  receipt_email: nil,
  return_url: nil,
  setup_future_usage: nil,
  shipping: nil,
  use_stripe_sdk: nil
)
  @application_fee_amount = application_fee_amount
  @async_workflows = async_workflows
  @capture_method = capture_method
  @confirmation_token = confirmation_token
  @error_on_requires_action = error_on_requires_action
  @expand = expand
  @fx_quote = fx_quote
  @mandate = mandate
  @mandate_data = mandate_data
  @off_session = off_session
  @payment_details = payment_details
  @payment_method = payment_method
  @payment_method_data = payment_method_data
  @payment_method_options = payment_method_options
  @payment_method_types = payment_method_types
  @radar_options = radar_options
  @receipt_email = receipt_email
  @return_url = return_url
  @setup_future_usage = setup_future_usage
  @shipping = shipping
  @use_stripe_sdk = use_stripe_sdk
end

Instance Attribute Details

#application_fee_amountObject

The amount of the application fee (if any) that will be requested to be applied to the payment and transferred to the application owner’s Stripe account. The amount of the application fee collected will be capped at the total amount captured. For more information, see the PaymentIntents [use case for connected accounts](stripe.com/docs/payments/connected-accounts).



13079
13080
13081
# File 'lib/stripe/resources/payment_intent.rb', line 13079

def application_fee_amount
  @application_fee_amount
end

#async_workflowsObject

Automations to be run during the PaymentIntent lifecycle



13081
13082
13083
# File 'lib/stripe/resources/payment_intent.rb', line 13081

def async_workflows
  @async_workflows
end

#capture_methodObject

Controls when the funds will be captured from the customer’s account.



13083
13084
13085
# File 'lib/stripe/resources/payment_intent.rb', line 13083

def capture_method
  @capture_method
end

#confirmation_tokenObject

ID of the ConfirmationToken used to confirm this PaymentIntent.

If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.



13087
13088
13089
# File 'lib/stripe/resources/payment_intent.rb', line 13087

def confirmation_token
  @confirmation_token
end

#error_on_requires_actionObject

Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](stripe.com/docs/payments/save-card-without-authentication).



13089
13090
13091
# File 'lib/stripe/resources/payment_intent.rb', line 13089

def error_on_requires_action
  @error_on_requires_action
end

#expandObject

Specifies which fields in the response should be expanded.



13091
13092
13093
# File 'lib/stripe/resources/payment_intent.rb', line 13091

def expand
  @expand
end

#fx_quoteObject

The FX rate in the quote is validated and used to convert the presentment amount to the settlement amount.



13093
13094
13095
# File 'lib/stripe/resources/payment_intent.rb', line 13093

def fx_quote
  @fx_quote
end

#mandateObject

ID of the mandate that’s used for this payment.



13095
13096
13097
# File 'lib/stripe/resources/payment_intent.rb', line 13095

def mandate
  @mandate
end

#mandate_dataObject

Attribute for param field mandate_data



13097
13098
13099
# File 'lib/stripe/resources/payment_intent.rb', line 13097

def mandate_data
  @mandate_data
end

#off_sessionObject

Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](stripe.com/docs/payments/cards/charging-saved-cards).



13099
13100
13101
# File 'lib/stripe/resources/payment_intent.rb', line 13099

def off_session
  @off_session
end

#payment_detailsObject

Provides industry-specific information about the charge.



13101
13102
13103
# File 'lib/stripe/resources/payment_intent.rb', line 13101

def payment_details
  @payment_details
end

#payment_methodObject

ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.



13103
13104
13105
# File 'lib/stripe/resources/payment_intent.rb', line 13103

def payment_method
  @payment_method
end

#payment_method_dataObject

If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.



13107
13108
13109
# File 'lib/stripe/resources/payment_intent.rb', line 13107

def payment_method_data
  @payment_method_data
end

#payment_method_optionsObject

Payment method-specific configuration for this PaymentIntent.



13109
13110
13111
# File 'lib/stripe/resources/payment_intent.rb', line 13109

def payment_method_options
  @payment_method_options
end

#payment_method_typesObject

The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).



13111
13112
13113
# File 'lib/stripe/resources/payment_intent.rb', line 13111

def payment_method_types
  @payment_method_types
end

#radar_optionsObject

Options to configure Radar. Learn more about [Radar Sessions](stripe.com/docs/radar/radar-session).



13113
13114
13115
# File 'lib/stripe/resources/payment_intent.rb', line 13113

def radar_options
  @radar_options
end

#receipt_emailObject

Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).



13115
13116
13117
# File 'lib/stripe/resources/payment_intent.rb', line 13115

def receipt_email
  @receipt_email
end

#return_urlObject

The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.



13119
13120
13121
# File 'lib/stripe/resources/payment_intent.rb', line 13119

def return_url
  @return_url
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



13129
13130
13131
# File 'lib/stripe/resources/payment_intent.rb', line 13129

def setup_future_usage
  @setup_future_usage
end

#shippingObject

Shipping information for this PaymentIntent.



13131
13132
13133
# File 'lib/stripe/resources/payment_intent.rb', line 13131

def shipping
  @shipping
end

#use_stripe_sdkObject

Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.



13133
13134
13135
# File 'lib/stripe/resources/payment_intent.rb', line 13133

def use_stripe_sdk
  @use_stripe_sdk
end