Class: Stripe::PaymentIntent::ConfirmParams
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: MandateData, PaymentMethodData, PaymentMethodOptions, RadarOptions, Shipping
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
-
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`.
-
#expand ⇒ Object
Specifies which fields in the response should be expanded.
-
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
-
#mandate_data ⇒ Object
Attribute for param field mandate_data.
-
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate.
-
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.
-
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod.
-
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
-
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use.
-
#radar_options ⇒ Object
Options to configure Radar.
-
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to.
-
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#shipping ⇒ Object
Shipping information for this PaymentIntent.
-
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
Instance Method Summary collapse
-
#initialize(capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ ConfirmParams
constructor
A new instance of ConfirmParams.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil) ⇒ ConfirmParams
Returns a new instance of ConfirmParams.
8483 8484 8485 8486 8487 8488 8489 8490 8491 8492 8493 8494 8495 8496 8497 8498 8499 8500 8501 8502 8503 8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 8519 |
# File 'lib/stripe/resources/payment_intent.rb', line 8483 def initialize( capture_method: nil, confirmation_token: nil, error_on_requires_action: nil, expand: nil, mandate: nil, mandate_data: nil, off_session: nil, payment_method: nil, payment_method_data: nil, payment_method_options: nil, payment_method_types: nil, radar_options: nil, receipt_email: nil, return_url: nil, setup_future_usage: nil, shipping: nil, use_stripe_sdk: nil ) @capture_method = capture_method @confirmation_token = confirmation_token @error_on_requires_action = error_on_requires_action @expand = @mandate = mandate @mandate_data = mandate_data @off_session = off_session @payment_method = payment_method @payment_method_data = payment_method_data @payment_method_options = @payment_method_types = payment_method_types @radar_options = @receipt_email = receipt_email @return_url = return_url @setup_future_usage = setup_future_usage @shipping = shipping @use_stripe_sdk = use_stripe_sdk end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
8435 8436 8437 |
# File 'lib/stripe/resources/payment_intent.rb', line 8435 def capture_method @capture_method end |
#confirmation_token ⇒ Object
ID of the ConfirmationToken used to confirm this PaymentIntent.
If the provided ConfirmationToken contains properties that are also being provided in this request, such as ‘payment_method`, then the values in this request will take precedence.
8439 8440 8441 |
# File 'lib/stripe/resources/payment_intent.rb', line 8439 def confirmation_token @confirmation_token end |
#error_on_requires_action ⇒ Object
Set to ‘true` to fail the payment attempt if the PaymentIntent transitions into `requires_action`. This parameter is intended for simpler integrations that do not handle customer actions, like [saving cards without authentication](stripe.com/docs/payments/save-card-without-authentication).
8441 8442 8443 |
# File 'lib/stripe/resources/payment_intent.rb', line 8441 def error_on_requires_action @error_on_requires_action end |
#expand ⇒ Object
Specifies which fields in the response should be expanded.
8443 8444 8445 |
# File 'lib/stripe/resources/payment_intent.rb', line 8443 def @expand end |
#mandate ⇒ Object
ID of the mandate that’s used for this payment.
8445 8446 8447 |
# File 'lib/stripe/resources/payment_intent.rb', line 8445 def mandate @mandate end |
#mandate_data ⇒ Object
Attribute for param field mandate_data
8447 8448 8449 |
# File 'lib/stripe/resources/payment_intent.rb', line 8447 def mandate_data @mandate_data end |
#off_session ⇒ Object
Set to ‘true` to indicate that the customer isn’t in your checkout flow during this payment attempt and can’t authenticate. Use this parameter in scenarios where you collect card details and [charge them later](stripe.com/docs/payments/cards/charging-saved-cards).
8449 8450 8451 |
# File 'lib/stripe/resources/payment_intent.rb', line 8449 def off_session @off_session end |
#payment_method ⇒ Object
ID of the payment method (a PaymentMethod, Card, or [compatible Source](stripe.com/docs/payments/payment-methods/transitioning#compatibility) object) to attach to this PaymentIntent.
8451 8452 8453 |
# File 'lib/stripe/resources/payment_intent.rb', line 8451 def payment_method @payment_method end |
#payment_method_data ⇒ Object
If provided, this hash will be used to create a PaymentMethod. The new PaymentMethod will appear in the [payment_method](stripe.com/docs/api/payment_intents/object#payment_intent_object-payment_method) property on the PaymentIntent.
8455 8456 8457 |
# File 'lib/stripe/resources/payment_intent.rb', line 8455 def payment_method_data @payment_method_data end |
#payment_method_options ⇒ Object
Payment method-specific configuration for this PaymentIntent.
8457 8458 8459 |
# File 'lib/stripe/resources/payment_intent.rb', line 8457 def @payment_method_options end |
#payment_method_types ⇒ Object
The list of payment method types (for example, a card) that this PaymentIntent can use. Use ‘automatic_payment_methods` to manage payment methods from the [Stripe Dashboard](dashboard.stripe.com/settings/payment_methods).
8459 8460 8461 |
# File 'lib/stripe/resources/payment_intent.rb', line 8459 def payment_method_types @payment_method_types end |
#radar_options ⇒ Object
Options to configure Radar. Learn more about [Radar Sessions](stripe.com/docs/radar/radar-session).
8461 8462 8463 |
# File 'lib/stripe/resources/payment_intent.rb', line 8461 def @radar_options end |
#receipt_email ⇒ Object
Email address that the receipt for the resulting payment will be sent to. If ‘receipt_email` is specified for a payment in live mode, a receipt will be sent regardless of your [email settings](dashboard.stripe.com/account/emails).
8463 8464 8465 |
# File 'lib/stripe/resources/payment_intent.rb', line 8463 def receipt_email @receipt_email end |
#return_url ⇒ Object
The URL to redirect your customer back to after they authenticate or cancel their payment on the payment method’s app or site. If you’d prefer to redirect to a mobile application, you can alternatively supply an application URI scheme. This parameter is only used for cards and other redirect-based payment methods.
8467 8468 8469 |
# File 'lib/stripe/resources/payment_intent.rb', line 8467 def return_url @return_url end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
8477 8478 8479 |
# File 'lib/stripe/resources/payment_intent.rb', line 8477 def setup_future_usage @setup_future_usage end |
#shipping ⇒ Object
Shipping information for this PaymentIntent.
8479 8480 8481 |
# File 'lib/stripe/resources/payment_intent.rb', line 8479 def shipping @shipping end |
#use_stripe_sdk ⇒ Object
Set to ‘true` when confirming server-side and using Stripe.js, iOS, or Android client-side SDKs to handle the next actions.
8481 8482 8483 |
# File 'lib/stripe/resources/payment_intent.rb', line 8481 def use_stripe_sdk @use_stripe_sdk end |