Class: Stripe::PaymentIntent::ConfirmParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



12145
12146
12147
12148
12149
12150
# File 'lib/stripe/resources/payment_intent.rb', line 12145

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



12137
12138
12139
# File 'lib/stripe/resources/payment_intent.rb', line 12137

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



12139
12140
12141
# File 'lib/stripe/resources/payment_intent.rb', line 12139

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



12141
12142
12143
# File 'lib/stripe/resources/payment_intent.rb', line 12141

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



12143
12144
12145
# File 'lib/stripe/resources/payment_intent.rb', line 12143

def tax
  @tax
end