Class: Stripe::PaymentIntent::ConfirmParams::AmountDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: LineItem, Shipping, Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil) ⇒ AmountDetails

Returns a new instance of AmountDetails.



10638
10639
10640
10641
10642
10643
# File 'lib/stripe/resources/payment_intent.rb', line 10638

def initialize(discount_amount: nil, line_items: nil, shipping: nil, tax: nil)
  @discount_amount = discount_amount
  @line_items = line_items
  @shipping = shipping
  @tax = tax
end

Instance Attribute Details

#discount_amountObject

The amount an item was discounted for.



10630
10631
10632
# File 'lib/stripe/resources/payment_intent.rb', line 10630

def discount_amount
  @discount_amount
end

#line_itemsObject

A list of line items, each containing information about a product in the PaymentIntent. There is a maximum of 100 line items.



10632
10633
10634
# File 'lib/stripe/resources/payment_intent.rb', line 10632

def line_items
  @line_items
end

#shippingObject

Contains information about the shipping portion of the amount.



10634
10635
10636
# File 'lib/stripe/resources/payment_intent.rb', line 10634

def shipping
  @shipping
end

#taxObject

Contains information about the tax portion of the amount.



10636
10637
10638
# File 'lib/stripe/resources/payment_intent.rb', line 10636

def tax
  @tax
end