Class: Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
10585 10586 10587 10588 10589 10590 10591 10592 10593 10594 10595 10596 10597 10598 10599 10600 10601 10602 10603 |
# File 'lib/stripe/resources/payment_intent.rb', line 10585 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
10569 10570 10571 |
# File 'lib/stripe/resources/payment_intent.rb', line 10569 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
10571 10572 10573 |
# File 'lib/stripe/resources/payment_intent.rb', line 10571 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
10573 10574 10575 |
# File 'lib/stripe/resources/payment_intent.rb', line 10573 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
10575 10576 10577 |
# File 'lib/stripe/resources/payment_intent.rb', line 10575 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
10577 10578 10579 |
# File 'lib/stripe/resources/payment_intent.rb', line 10577 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
10579 10580 10581 |
# File 'lib/stripe/resources/payment_intent.rb', line 10579 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
10581 10582 10583 |
# File 'lib/stripe/resources/payment_intent.rb', line 10581 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
10583 10584 10585 |
# File 'lib/stripe/resources/payment_intent.rb', line 10583 def unit_of_measure @unit_of_measure end |