Class: Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
12044 12045 12046 12047 12048 |
# File 'lib/stripe/resources/payment_intent.rb', line 12044 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
12038 12039 12040 |
# File 'lib/stripe/resources/payment_intent.rb', line 12038 def category @category end |
#description ⇒ Object
Description of the line item.
12040 12041 12042 |
# File 'lib/stripe/resources/payment_intent.rb', line 12040 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
12042 12043 12044 |
# File 'lib/stripe/resources/payment_intent.rb', line 12042 def sold_by @sold_by end |