Class: Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::AmountDetails::LineItem::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, sold_by: nil) ⇒ Paypal
Returns a new instance of Paypal.
10537 10538 10539 10540 10541 |
# File 'lib/stripe/resources/payment_intent.rb', line 10537 def initialize(category: nil, description: nil, sold_by: nil) @category = category @description = description @sold_by = sold_by end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
10531 10532 10533 |
# File 'lib/stripe/resources/payment_intent.rb', line 10531 def category @category end |
#description ⇒ Object
Description of the line item.
10533 10534 10535 |
# File 'lib/stripe/resources/payment_intent.rb', line 10533 def description @description end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
10535 10536 10537 |
# File 'lib/stripe/resources/payment_intent.rb', line 10535 def sold_by @sold_by end |