Class: Stripe::PaymentIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



10695
10696
10697
10698
10699
10700
# File 'lib/stripe/resources/payment_intent.rb', line 10695

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



10687
10688
10689
# File 'lib/stripe/resources/payment_intent.rb', line 10687

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



10689
10690
10691
# File 'lib/stripe/resources/payment_intent.rb', line 10689

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



10691
10692
10693
# File 'lib/stripe/resources/payment_intent.rb', line 10691

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



10693
10694
10695
# File 'lib/stripe/resources/payment_intent.rb', line 10693

def type
  @type
end