Class: Stripe::PaymentIntent::ConfirmParams::MandateData::CustomerAcceptance
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::MandateData::CustomerAcceptance
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#accepted_at ⇒ Object
The time at which the customer accepted the Mandate.
-
#offline ⇒ Object
If this is a Mandate accepted offline, this hash contains details about the offline acceptance.
-
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
-
#type ⇒ Object
The type of customer acceptance information included with the Mandate.
Instance Method Summary collapse
-
#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance
constructor
A new instance of CustomerAcceptance.
Methods inherited from RequestParams
Constructor Details
#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance
Returns a new instance of CustomerAcceptance.
9748 9749 9750 9751 9752 9753 |
# File 'lib/stripe/resources/payment_intent.rb', line 9748 def initialize(accepted_at: nil, offline: nil, online: nil, type: nil) @accepted_at = accepted_at @offline = offline @online = online @type = type end |
Instance Attribute Details
#accepted_at ⇒ Object
The time at which the customer accepted the Mandate.
9740 9741 9742 |
# File 'lib/stripe/resources/payment_intent.rb', line 9740 def accepted_at @accepted_at end |
#offline ⇒ Object
If this is a Mandate accepted offline, this hash contains details about the offline acceptance.
9742 9743 9744 |
# File 'lib/stripe/resources/payment_intent.rb', line 9742 def offline @offline end |
#online ⇒ Object
If this is a Mandate accepted online, this hash contains details about the online acceptance.
9744 9745 9746 |
# File 'lib/stripe/resources/payment_intent.rb', line 9744 def online @online end |
#type ⇒ Object
The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.
9746 9747 9748 |
# File 'lib/stripe/resources/payment_intent.rb', line 9746 def type @type end |