Class: Stripe::PaymentIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



9421
9422
9423
9424
9425
9426
# File 'lib/stripe/resources/payment_intent.rb', line 9421

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



9413
9414
9415
# File 'lib/stripe/resources/payment_intent.rb', line 9413

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



9415
9416
9417
# File 'lib/stripe/resources/payment_intent.rb', line 9415

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



9417
9418
9419
# File 'lib/stripe/resources/payment_intent.rb', line 9417

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



9419
9420
9421
# File 'lib/stripe/resources/payment_intent.rb', line 9419

def type
  @type
end