Class: Stripe::PaymentIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



9369
9370
9371
9372
9373
9374
# File 'lib/stripe/resources/payment_intent.rb', line 9369

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



9361
9362
9363
# File 'lib/stripe/resources/payment_intent.rb', line 9361

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



9363
9364
9365
# File 'lib/stripe/resources/payment_intent.rb', line 9363

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



9365
9366
9367
# File 'lib/stripe/resources/payment_intent.rb', line 9365

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



9367
9368
9369
# File 'lib/stripe/resources/payment_intent.rb', line 9367

def type
  @type
end