Class: Stripe::PaymentIntent::ConfirmParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



10665
10666
10667
10668
10669
10670
# File 'lib/stripe/resources/payment_intent.rb', line 10665

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



10654
10655
10656
# File 'lib/stripe/resources/payment_intent.rb', line 10654

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



10657
10658
10659
# File 'lib/stripe/resources/payment_intent.rb', line 10657

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



10660
10661
10662
# File 'lib/stripe/resources/payment_intent.rb', line 10660

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



10663
10664
10665
# File 'lib/stripe/resources/payment_intent.rb', line 10663

def type
  @type
end