Class: Stripe::PaymentIntent::ConfirmParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



6324
6325
6326
6327
# File 'lib/stripe/resources/payment_intent.rb', line 6324

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



6320
6321
6322
# File 'lib/stripe/resources/payment_intent.rb', line 6320

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



6322
6323
6324
# File 'lib/stripe/resources/payment_intent.rb', line 6322

def user_agent
  @user_agent
end