Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
12903 12904 12905 12906 12907 12908 12909 12910 12911 12912 12913 12914 12915 12916 12917 12918 12919 |
# File 'lib/stripe/resources/payment_intent.rb', line 12903 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
12889 12890 12891 |
# File 'lib/stripe/resources/payment_intent.rb', line 12889 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
12891 12892 12893 |
# File 'lib/stripe/resources/payment_intent.rb', line 12891 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
12893 12894 12895 |
# File 'lib/stripe/resources/payment_intent.rb', line 12893 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
12895 12896 12897 |
# File 'lib/stripe/resources/payment_intent.rb', line 12895 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
12897 12898 12899 |
# File 'lib/stripe/resources/payment_intent.rb', line 12897 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
12899 12900 12901 |
# File 'lib/stripe/resources/payment_intent.rb', line 12899 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
12901 12902 12903 |
# File 'lib/stripe/resources/payment_intent.rb', line 12901 def subscription @subscription end |