Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
11522 11523 11524 11525 11526 11527 11528 11529 11530 11531 11532 11533 11534 11535 11536 11537 11538 |
# File 'lib/stripe/resources/payment_intent.rb', line 11522 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
11508 11509 11510 |
# File 'lib/stripe/resources/payment_intent.rb', line 11508 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
11510 11511 11512 |
# File 'lib/stripe/resources/payment_intent.rb', line 11510 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
11512 11513 11514 |
# File 'lib/stripe/resources/payment_intent.rb', line 11512 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
11514 11515 11516 |
# File 'lib/stripe/resources/payment_intent.rb', line 11514 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
11516 11517 11518 |
# File 'lib/stripe/resources/payment_intent.rb', line 11516 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
11518 11519 11520 |
# File 'lib/stripe/resources/payment_intent.rb', line 11518 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
11520 11521 11522 |
# File 'lib/stripe/resources/payment_intent.rb', line 11520 def subscription @subscription end |