Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: CarRental, EventDetails, Flight, Lodging, Subscription
Instance Attribute Summary collapse
-
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
-
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information.
-
#event_details ⇒ Object
Event details for this PaymentIntent.
-
#flight ⇒ Object
Flight reservation details for this PaymentIntent.
-
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent.
-
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
-
#subscription ⇒ Object
Subscription details for this PaymentIntent.
Instance Method Summary collapse
-
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
constructor
A new instance of PaymentDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails
Returns a new instance of PaymentDetails.
10772 10773 10774 10775 10776 10777 10778 10779 10780 10781 10782 10783 10784 10785 10786 10787 10788 |
# File 'lib/stripe/resources/payment_intent.rb', line 10772 def initialize( car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil ) @car_rental = car_rental @customer_reference = customer_reference @event_details = event_details @flight = flight @lodging = lodging @order_reference = order_reference @subscription = subscription end |
Instance Attribute Details
#car_rental ⇒ Object
Car rental details for this PaymentIntent.
10758 10759 10760 |
# File 'lib/stripe/resources/payment_intent.rb', line 10758 def car_rental @car_rental end |
#customer_reference ⇒ Object
Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.
10760 10761 10762 |
# File 'lib/stripe/resources/payment_intent.rb', line 10760 def customer_reference @customer_reference end |
#event_details ⇒ Object
Event details for this PaymentIntent
10762 10763 10764 |
# File 'lib/stripe/resources/payment_intent.rb', line 10762 def event_details @event_details end |
#flight ⇒ Object
Flight reservation details for this PaymentIntent
10764 10765 10766 |
# File 'lib/stripe/resources/payment_intent.rb', line 10764 def flight @flight end |
#lodging ⇒ Object
Lodging reservation details for this PaymentIntent
10766 10767 10768 |
# File 'lib/stripe/resources/payment_intent.rb', line 10766 def lodging @lodging end |
#order_reference ⇒ Object
A unique value assigned by the business to identify the transaction.
10768 10769 10770 |
# File 'lib/stripe/resources/payment_intent.rb', line 10768 def order_reference @order_reference end |
#subscription ⇒ Object
Subscription details for this PaymentIntent
10770 10771 10772 |
# File 'lib/stripe/resources/payment_intent.rb', line 10770 def subscription @subscription end |