Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



10555
10556
10557
10558
10559
10560
10561
10562
10563
10564
10565
10566
10567
10568
10569
10570
10571
# File 'lib/stripe/resources/payment_intent.rb', line 10555

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



10541
10542
10543
# File 'lib/stripe/resources/payment_intent.rb', line 10541

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



10543
10544
10545
# File 'lib/stripe/resources/payment_intent.rb', line 10543

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



10545
10546
10547
# File 'lib/stripe/resources/payment_intent.rb', line 10545

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



10547
10548
10549
# File 'lib/stripe/resources/payment_intent.rb', line 10547

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



10549
10550
10551
# File 'lib/stripe/resources/payment_intent.rb', line 10549

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



10551
10552
10553
# File 'lib/stripe/resources/payment_intent.rb', line 10551

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



10553
10554
10555
# File 'lib/stripe/resources/payment_intent.rb', line 10553

def subscription
  @subscription
end