Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: CarRental, EventDetails, Flight, Lodging, Subscription

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(car_rental: nil, customer_reference: nil, event_details: nil, flight: nil, lodging: nil, order_reference: nil, subscription: nil) ⇒ PaymentDetails

Returns a new instance of PaymentDetails.



10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
# File 'lib/stripe/resources/payment_intent.rb', line 10482

def initialize(
  car_rental: nil,
  customer_reference: nil,
  event_details: nil,
  flight: nil,
  lodging: nil,
  order_reference: nil,
  subscription: nil
)
  @car_rental = car_rental
  @customer_reference = customer_reference
  @event_details = event_details
  @flight = flight
  @lodging = lodging
  @order_reference = order_reference
  @subscription = subscription
end

Instance Attribute Details

#car_rentalObject

Car rental details for this PaymentIntent.



10468
10469
10470
# File 'lib/stripe/resources/payment_intent.rb', line 10468

def car_rental
  @car_rental
end

#customer_referenceObject

Some customers might be required by their company or organization to provide this information. If so, provide this value. Otherwise you can ignore this field.



10470
10471
10472
# File 'lib/stripe/resources/payment_intent.rb', line 10470

def customer_reference
  @customer_reference
end

#event_detailsObject

Event details for this PaymentIntent



10472
10473
10474
# File 'lib/stripe/resources/payment_intent.rb', line 10472

def event_details
  @event_details
end

#flightObject

Flight reservation details for this PaymentIntent



10474
10475
10476
# File 'lib/stripe/resources/payment_intent.rb', line 10474

def flight
  @flight
end

#lodgingObject

Lodging reservation details for this PaymentIntent



10476
10477
10478
# File 'lib/stripe/resources/payment_intent.rb', line 10476

def lodging
  @lodging
end

#order_referenceObject

A unique value assigned by the business to identify the transaction.



10478
10479
10480
# File 'lib/stripe/resources/payment_intent.rb', line 10478

def order_reference
  @order_reference
end

#subscriptionObject

Subscription details for this PaymentIntent



10480
10481
10482
# File 'lib/stripe/resources/payment_intent.rb', line 10480

def subscription
  @subscription
end