Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
11010 11011 11012 11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 11032 11033 11034 11035 11036 11037 11038 11039 11040 11041 11042 11043 11044 11045 11046 11047 11048 11049 11050 11051 11052 11053 11054 11055 11056 11057 11058 11059 11060 |
# File 'lib/stripe/resources/payment_intent.rb', line 11010 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
10962 10963 10964 |
# File 'lib/stripe/resources/payment_intent.rb', line 10962 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
10964 10965 10966 |
# File 'lib/stripe/resources/payment_intent.rb', line 10964 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
10966 10967 10968 |
# File 'lib/stripe/resources/payment_intent.rb', line 10966 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
10968 10969 10970 |
# File 'lib/stripe/resources/payment_intent.rb', line 10968 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
10970 10971 10972 |
# File 'lib/stripe/resources/payment_intent.rb', line 10970 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
10972 10973 10974 |
# File 'lib/stripe/resources/payment_intent.rb', line 10972 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
10974 10975 10976 |
# File 'lib/stripe/resources/payment_intent.rb', line 10974 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
10976 10977 10978 |
# File 'lib/stripe/resources/payment_intent.rb', line 10976 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
10978 10979 10980 |
# File 'lib/stripe/resources/payment_intent.rb', line 10978 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
10980 10981 10982 |
# File 'lib/stripe/resources/payment_intent.rb', line 10980 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
10982 10983 10984 |
# File 'lib/stripe/resources/payment_intent.rb', line 10982 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
10984 10985 10986 |
# File 'lib/stripe/resources/payment_intent.rb', line 10984 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
10986 10987 10988 |
# File 'lib/stripe/resources/payment_intent.rb', line 10986 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
10988 10989 10990 |
# File 'lib/stripe/resources/payment_intent.rb', line 10988 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
10990 10991 10992 |
# File 'lib/stripe/resources/payment_intent.rb', line 10990 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
10992 10993 10994 |
# File 'lib/stripe/resources/payment_intent.rb', line 10992 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
10994 10995 10996 |
# File 'lib/stripe/resources/payment_intent.rb', line 10994 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
10996 10997 10998 |
# File 'lib/stripe/resources/payment_intent.rb', line 10996 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
10998 10999 11000 |
# File 'lib/stripe/resources/payment_intent.rb', line 10998 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
11000 11001 11002 |
# File 'lib/stripe/resources/payment_intent.rb', line 11000 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
11002 11003 11004 |
# File 'lib/stripe/resources/payment_intent.rb', line 11002 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
11004 11005 11006 |
# File 'lib/stripe/resources/payment_intent.rb', line 11004 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
11006 11007 11008 |
# File 'lib/stripe/resources/payment_intent.rb', line 11006 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
11008 11009 11010 |
# File 'lib/stripe/resources/payment_intent.rb', line 11008 def vehicle_identification_number @vehicle_identification_number end |