Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#distance ⇒ Object
The details of the distance traveled during the rental period.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#pickup_location_name ⇒ Object
Name of the pickup location.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#return_location_name ⇒ Object
Name of the return location.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
-
#vehicle_identification_number ⇒ Object
The vehicle identification number.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental
Returns a new instance of CarRental.
10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 10896 10897 10898 10899 10900 10901 10902 10903 10904 10905 10906 10907 10908 10909 10910 10911 10912 10913 10914 10915 10916 10917 10918 10919 10920 10921 10922 10923 10924 10925 10926 10927 10928 10929 10930 10931 10932 10933 10934 |
# File 'lib/stripe/resources/payment_intent.rb', line 10884 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @distance = distance @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @pickup_location_name = pickup_location_name @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @return_location_name = return_location_name @tax_exempt = tax_exempt @vehicle_identification_number = vehicle_identification_number end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
10836 10837 10838 |
# File 'lib/stripe/resources/payment_intent.rb', line 10836 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
10838 10839 10840 |
# File 'lib/stripe/resources/payment_intent.rb', line 10838 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
10840 10841 10842 |
# File 'lib/stripe/resources/payment_intent.rb', line 10840 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
10842 10843 10844 |
# File 'lib/stripe/resources/payment_intent.rb', line 10842 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
10844 10845 10846 |
# File 'lib/stripe/resources/payment_intent.rb', line 10844 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
10846 10847 10848 |
# File 'lib/stripe/resources/payment_intent.rb', line 10846 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
10848 10849 10850 |
# File 'lib/stripe/resources/payment_intent.rb', line 10848 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
10850 10851 10852 |
# File 'lib/stripe/resources/payment_intent.rb', line 10850 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
10852 10853 10854 |
# File 'lib/stripe/resources/payment_intent.rb', line 10852 def delivery @delivery end |
#distance ⇒ Object
The details of the distance traveled during the rental period.
10854 10855 10856 |
# File 'lib/stripe/resources/payment_intent.rb', line 10854 def distance @distance end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
10856 10857 10858 |
# File 'lib/stripe/resources/payment_intent.rb', line 10856 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
10858 10859 10860 |
# File 'lib/stripe/resources/payment_intent.rb', line 10858 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
10860 10861 10862 |
# File 'lib/stripe/resources/payment_intent.rb', line 10860 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
10862 10863 10864 |
# File 'lib/stripe/resources/payment_intent.rb', line 10862 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
10864 10865 10866 |
# File 'lib/stripe/resources/payment_intent.rb', line 10864 def pickup_at @pickup_at end |
#pickup_location_name ⇒ Object
Name of the pickup location.
10866 10867 10868 |
# File 'lib/stripe/resources/payment_intent.rb', line 10866 def pickup_location_name @pickup_location_name end |
#rate_amount ⇒ Object
Rental rate.
10868 10869 10870 |
# File 'lib/stripe/resources/payment_intent.rb', line 10868 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
10870 10871 10872 |
# File 'lib/stripe/resources/payment_intent.rb', line 10870 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
10872 10873 10874 |
# File 'lib/stripe/resources/payment_intent.rb', line 10872 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
10874 10875 10876 |
# File 'lib/stripe/resources/payment_intent.rb', line 10874 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
10876 10877 10878 |
# File 'lib/stripe/resources/payment_intent.rb', line 10876 def return_at @return_at end |
#return_location_name ⇒ Object
Name of the return location.
10878 10879 10880 |
# File 'lib/stripe/resources/payment_intent.rb', line 10878 def return_location_name @return_location_name end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
10880 10881 10882 |
# File 'lib/stripe/resources/payment_intent.rb', line 10880 def tax_exempt @tax_exempt end |
#vehicle_identification_number ⇒ Object
The vehicle identification number.
10882 10883 10884 |
# File 'lib/stripe/resources/payment_intent.rb', line 10882 def vehicle_identification_number @vehicle_identification_number end |