Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Distance, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, distance: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, pickup_location_name: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, return_location_name: nil, tax_exempt: nil, vehicle_identification_number: nil) ⇒ CarRental

Returns a new instance of CarRental.



10260
10261
10262
10263
10264
10265
10266
10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
10281
10282
10283
10284
10285
10286
10287
10288
10289
10290
10291
10292
10293
10294
10295
10296
10297
10298
10299
10300
10301
10302
10303
10304
10305
10306
10307
10308
10309
10310
# File 'lib/stripe/resources/payment_intent.rb', line 10260

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  distance: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  pickup_location_name: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  return_location_name: nil,
  tax_exempt: nil,
  vehicle_identification_number: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @distance = distance
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @pickup_location_name = pickup_location_name
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @return_location_name = return_location_name
  @tax_exempt = tax_exempt
  @vehicle_identification_number = vehicle_identification_number
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



10212
10213
10214
# File 'lib/stripe/resources/payment_intent.rb', line 10212

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



10214
10215
10216
# File 'lib/stripe/resources/payment_intent.rb', line 10214

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



10216
10217
10218
# File 'lib/stripe/resources/payment_intent.rb', line 10216

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



10218
10219
10220
# File 'lib/stripe/resources/payment_intent.rb', line 10218

def car_make
  @car_make
end

#car_modelObject

Model of the car.



10220
10221
10222
# File 'lib/stripe/resources/payment_intent.rb', line 10220

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



10222
10223
10224
# File 'lib/stripe/resources/payment_intent.rb', line 10222

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



10224
10225
10226
# File 'lib/stripe/resources/payment_intent.rb', line 10224

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



10226
10227
10228
# File 'lib/stripe/resources/payment_intent.rb', line 10226

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



10228
10229
10230
# File 'lib/stripe/resources/payment_intent.rb', line 10228

def delivery
  @delivery
end

#distanceObject

The details of the distance traveled during the rental period.



10230
10231
10232
# File 'lib/stripe/resources/payment_intent.rb', line 10230

def distance
  @distance
end

#driversObject

The details of the passengers in the travel reservation



10232
10233
10234
# File 'lib/stripe/resources/payment_intent.rb', line 10232

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



10234
10235
10236
# File 'lib/stripe/resources/payment_intent.rb', line 10234

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



10236
10237
10238
# File 'lib/stripe/resources/payment_intent.rb', line 10236

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



10238
10239
10240
# File 'lib/stripe/resources/payment_intent.rb', line 10238

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



10240
10241
10242
# File 'lib/stripe/resources/payment_intent.rb', line 10240

def pickup_at
  @pickup_at
end

#pickup_location_nameObject

Name of the pickup location.



10242
10243
10244
# File 'lib/stripe/resources/payment_intent.rb', line 10242

def pickup_location_name
  @pickup_location_name
end

#rate_amountObject

Rental rate.



10244
10245
10246
# File 'lib/stripe/resources/payment_intent.rb', line 10244

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



10246
10247
10248
# File 'lib/stripe/resources/payment_intent.rb', line 10246

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



10248
10249
10250
# File 'lib/stripe/resources/payment_intent.rb', line 10248

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



10250
10251
10252
# File 'lib/stripe/resources/payment_intent.rb', line 10250

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



10252
10253
10254
# File 'lib/stripe/resources/payment_intent.rb', line 10252

def return_at
  @return_at
end

#return_location_nameObject

Name of the return location.



10254
10255
10256
# File 'lib/stripe/resources/payment_intent.rb', line 10254

def return_location_name
  @return_location_name
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



10256
10257
10258
# File 'lib/stripe/resources/payment_intent.rb', line 10256

def tax_exempt
  @tax_exempt
end

#vehicle_identification_numberObject

The vehicle identification number.



10258
10259
10260
# File 'lib/stripe/resources/payment_intent.rb', line 10258

def vehicle_identification_number
  @vehicle_identification_number
end