Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
9911 9912 9913 9914 9915 9916 9917 9918 9919 9920 9921 9922 9923 9924 9925 9926 9927 9928 9929 9930 9931 9932 9933 9934 9935 9936 9937 9938 9939 9940 9941 9942 9943 9944 9945 9946 9947 9948 9949 9950 9951 9952 9953 |
# File 'lib/stripe/resources/payment_intent.rb', line 9911 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9871 9872 9873 |
# File 'lib/stripe/resources/payment_intent.rb', line 9871 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
9873 9874 9875 |
# File 'lib/stripe/resources/payment_intent.rb', line 9873 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
9875 9876 9877 |
# File 'lib/stripe/resources/payment_intent.rb', line 9875 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
9877 9878 9879 |
# File 'lib/stripe/resources/payment_intent.rb', line 9877 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
9879 9880 9881 |
# File 'lib/stripe/resources/payment_intent.rb', line 9879 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
9881 9882 9883 |
# File 'lib/stripe/resources/payment_intent.rb', line 9881 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
9883 9884 9885 |
# File 'lib/stripe/resources/payment_intent.rb', line 9883 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
9885 9886 9887 |
# File 'lib/stripe/resources/payment_intent.rb', line 9885 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
9887 9888 9889 |
# File 'lib/stripe/resources/payment_intent.rb', line 9887 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
9889 9890 9891 |
# File 'lib/stripe/resources/payment_intent.rb', line 9889 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
9891 9892 9893 |
# File 'lib/stripe/resources/payment_intent.rb', line 9891 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
9893 9894 9895 |
# File 'lib/stripe/resources/payment_intent.rb', line 9893 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
9895 9896 9897 |
# File 'lib/stripe/resources/payment_intent.rb', line 9895 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
9897 9898 9899 |
# File 'lib/stripe/resources/payment_intent.rb', line 9897 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
9899 9900 9901 |
# File 'lib/stripe/resources/payment_intent.rb', line 9899 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
9901 9902 9903 |
# File 'lib/stripe/resources/payment_intent.rb', line 9901 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
9903 9904 9905 |
# File 'lib/stripe/resources/payment_intent.rb', line 9903 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
9905 9906 9907 |
# File 'lib/stripe/resources/payment_intent.rb', line 9905 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
9907 9908 9909 |
# File 'lib/stripe/resources/payment_intent.rb', line 9907 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
9909 9910 9911 |
# File 'lib/stripe/resources/payment_intent.rb', line 9909 def tax_exempt @tax_exempt end |