Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental

Returns a new instance of CarRental.



9584
9585
9586
9587
9588
9589
9590
9591
9592
9593
9594
9595
9596
9597
9598
9599
9600
9601
9602
9603
9604
9605
9606
9607
9608
9609
9610
9611
9612
9613
9614
9615
9616
9617
9618
9619
9620
9621
9622
9623
9624
9625
9626
# File 'lib/stripe/resources/payment_intent.rb', line 9584

def initialize(
  affiliate: nil,
  booking_number: nil,
  car_class_code: nil,
  car_make: nil,
  car_model: nil,
  company: nil,
  customer_service_phone_number: nil,
  days_rented: nil,
  delivery: nil,
  drivers: nil,
  extra_charges: nil,
  no_show: nil,
  pickup_address: nil,
  pickup_at: nil,
  rate_amount: nil,
  rate_interval: nil,
  renter_name: nil,
  return_address: nil,
  return_at: nil,
  tax_exempt: nil
)
  @affiliate = affiliate
  @booking_number = booking_number
  @car_class_code = car_class_code
  @car_make = car_make
  @car_model = car_model
  @company = company
  @customer_service_phone_number = customer_service_phone_number
  @days_rented = days_rented
  @delivery = delivery
  @drivers = drivers
  @extra_charges = extra_charges
  @no_show = no_show
  @pickup_address = pickup_address
  @pickup_at = pickup_at
  @rate_amount = rate_amount
  @rate_interval = rate_interval
  @renter_name = renter_name
  @return_address = return_address
  @return_at = return_at
  @tax_exempt = tax_exempt
end

Instance Attribute Details

#affiliateObject

Affiliate details for this purchase.



9544
9545
9546
# File 'lib/stripe/resources/payment_intent.rb', line 9544

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the car rental.



9546
9547
9548
# File 'lib/stripe/resources/payment_intent.rb', line 9546

def booking_number
  @booking_number
end

#car_class_codeObject

Class code of the car.



9548
9549
9550
# File 'lib/stripe/resources/payment_intent.rb', line 9548

def car_class_code
  @car_class_code
end

#car_makeObject

Make of the car.



9550
9551
9552
# File 'lib/stripe/resources/payment_intent.rb', line 9550

def car_make
  @car_make
end

#car_modelObject

Model of the car.



9552
9553
9554
# File 'lib/stripe/resources/payment_intent.rb', line 9552

def car_model
  @car_model
end

#companyObject

The name of the rental car company.



9554
9555
9556
# File 'lib/stripe/resources/payment_intent.rb', line 9554

def company
  @company
end

#customer_service_phone_numberObject

The customer service phone number of the car rental company.



9556
9557
9558
# File 'lib/stripe/resources/payment_intent.rb', line 9556

def customer_service_phone_number
  @customer_service_phone_number
end

#days_rentedObject

Number of days the car is being rented.



9558
9559
9560
# File 'lib/stripe/resources/payment_intent.rb', line 9558

def days_rented
  @days_rented
end

#deliveryObject

Delivery details for this purchase.



9560
9561
9562
# File 'lib/stripe/resources/payment_intent.rb', line 9560

def delivery
  @delivery
end

#driversObject

The details of the passengers in the travel reservation



9562
9563
9564
# File 'lib/stripe/resources/payment_intent.rb', line 9562

def drivers
  @drivers
end

#extra_chargesObject

List of additional charges being billed.



9564
9565
9566
# File 'lib/stripe/resources/payment_intent.rb', line 9564

def extra_charges
  @extra_charges
end

#no_showObject

Indicates if the customer did not keep nor cancel their booking.



9566
9567
9568
# File 'lib/stripe/resources/payment_intent.rb', line 9566

def no_show
  @no_show
end

#pickup_addressObject

Car pick-up address.



9568
9569
9570
# File 'lib/stripe/resources/payment_intent.rb', line 9568

def pickup_address
  @pickup_address
end

#pickup_atObject

Car pick-up time. Measured in seconds since the Unix epoch.



9570
9571
9572
# File 'lib/stripe/resources/payment_intent.rb', line 9570

def pickup_at
  @pickup_at
end

#rate_amountObject

Rental rate.



9572
9573
9574
# File 'lib/stripe/resources/payment_intent.rb', line 9572

def rate_amount
  @rate_amount
end

#rate_intervalObject

The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`



9574
9575
9576
# File 'lib/stripe/resources/payment_intent.rb', line 9574

def rate_interval
  @rate_interval
end

#renter_nameObject

The name of the person or entity renting the car.



9576
9577
9578
# File 'lib/stripe/resources/payment_intent.rb', line 9576

def renter_name
  @renter_name
end

#return_addressObject

Car return address.



9578
9579
9580
# File 'lib/stripe/resources/payment_intent.rb', line 9578

def return_address
  @return_address
end

#return_atObject

Car return time. Measured in seconds since the Unix epoch.



9580
9581
9582
# File 'lib/stripe/resources/payment_intent.rb', line 9580

def return_at
  @return_at
end

#tax_exemptObject

Indicates whether the goods or services are tax-exempt or tax is not collected.



9582
9583
9584
# File 'lib/stripe/resources/payment_intent.rb', line 9582

def tax_exempt
  @tax_exempt
end