Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
10860 10861 10862 10863 10864 10865 10866 10867 10868 10869 10870 10871 10872 10873 10874 10875 10876 10877 10878 10879 10880 10881 10882 10883 10884 10885 10886 10887 10888 10889 10890 10891 10892 10893 10894 10895 10896 10897 10898 10899 10900 10901 10902 |
# File 'lib/stripe/resources/payment_intent.rb', line 10860 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
10801 10802 10803 |
# File 'lib/stripe/resources/payment_intent.rb', line 10801 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
10804 10805 10806 |
# File 'lib/stripe/resources/payment_intent.rb', line 10804 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
10807 10808 10809 |
# File 'lib/stripe/resources/payment_intent.rb', line 10807 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
10810 10811 10812 |
# File 'lib/stripe/resources/payment_intent.rb', line 10810 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
10813 10814 10815 |
# File 'lib/stripe/resources/payment_intent.rb', line 10813 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
10816 10817 10818 |
# File 'lib/stripe/resources/payment_intent.rb', line 10816 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
10819 10820 10821 |
# File 'lib/stripe/resources/payment_intent.rb', line 10819 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
10822 10823 10824 |
# File 'lib/stripe/resources/payment_intent.rb', line 10822 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
10825 10826 10827 |
# File 'lib/stripe/resources/payment_intent.rb', line 10825 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
10828 10829 10830 |
# File 'lib/stripe/resources/payment_intent.rb', line 10828 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
10831 10832 10833 |
# File 'lib/stripe/resources/payment_intent.rb', line 10831 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
10834 10835 10836 |
# File 'lib/stripe/resources/payment_intent.rb', line 10834 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
10837 10838 10839 |
# File 'lib/stripe/resources/payment_intent.rb', line 10837 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
10840 10841 10842 |
# File 'lib/stripe/resources/payment_intent.rb', line 10840 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
10843 10844 10845 |
# File 'lib/stripe/resources/payment_intent.rb', line 10843 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
10846 10847 10848 |
# File 'lib/stripe/resources/payment_intent.rb', line 10846 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
10849 10850 10851 |
# File 'lib/stripe/resources/payment_intent.rb', line 10849 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
10852 10853 10854 |
# File 'lib/stripe/resources/payment_intent.rb', line 10852 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
10855 10856 10857 |
# File 'lib/stripe/resources/payment_intent.rb', line 10855 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
10858 10859 10860 |
# File 'lib/stripe/resources/payment_intent.rb', line 10858 def tax_exempt @tax_exempt end |