Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Affiliate, Delivery, Driver, PickupAddress, ReturnAddress
Instance Attribute Summary collapse
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the car rental.
-
#car_class_code ⇒ Object
Class code of the car.
-
#car_make ⇒ Object
Make of the car.
-
#car_model ⇒ Object
Model of the car.
-
#company ⇒ Object
The name of the rental car company.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
-
#days_rented ⇒ Object
Number of days the car is being rented.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#drivers ⇒ Object
The details of the passengers in the travel reservation.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
-
#pickup_address ⇒ Object
Car pick-up address.
-
#pickup_at ⇒ Object
Car pick-up time.
-
#rate_amount ⇒ Object
Rental rate.
-
#rate_interval ⇒ Object
The frequency at which the rate amount is applied.
-
#renter_name ⇒ Object
The name of the person or entity renting the car.
-
#return_address ⇒ Object
Car return address.
-
#return_at ⇒ Object
Car return time.
-
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil) ⇒ CarRental
Returns a new instance of CarRental.
9532 9533 9534 9535 9536 9537 9538 9539 9540 9541 9542 9543 9544 9545 9546 9547 9548 9549 9550 9551 9552 9553 9554 9555 9556 9557 9558 9559 9560 9561 9562 9563 9564 9565 9566 9567 9568 9569 9570 9571 9572 9573 9574 |
# File 'lib/stripe/resources/payment_intent.rb', line 9532 def initialize( affiliate: nil, booking_number: nil, car_class_code: nil, car_make: nil, car_model: nil, company: nil, customer_service_phone_number: nil, days_rented: nil, delivery: nil, drivers: nil, extra_charges: nil, no_show: nil, pickup_address: nil, pickup_at: nil, rate_amount: nil, rate_interval: nil, renter_name: nil, return_address: nil, return_at: nil, tax_exempt: nil ) @affiliate = affiliate @booking_number = booking_number @car_class_code = car_class_code @car_make = car_make @car_model = car_model @company = company @customer_service_phone_number = customer_service_phone_number @days_rented = days_rented @delivery = delivery @drivers = drivers @extra_charges = extra_charges @no_show = no_show @pickup_address = pickup_address @pickup_at = pickup_at @rate_amount = rate_amount @rate_interval = rate_interval @renter_name = renter_name @return_address = return_address @return_at = return_at @tax_exempt = tax_exempt end |
Instance Attribute Details
#affiliate ⇒ Object
Affiliate details for this purchase.
9492 9493 9494 |
# File 'lib/stripe/resources/payment_intent.rb', line 9492 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the car rental.
9494 9495 9496 |
# File 'lib/stripe/resources/payment_intent.rb', line 9494 def booking_number @booking_number end |
#car_class_code ⇒ Object
Class code of the car.
9496 9497 9498 |
# File 'lib/stripe/resources/payment_intent.rb', line 9496 def car_class_code @car_class_code end |
#car_make ⇒ Object
Make of the car.
9498 9499 9500 |
# File 'lib/stripe/resources/payment_intent.rb', line 9498 def car_make @car_make end |
#car_model ⇒ Object
Model of the car.
9500 9501 9502 |
# File 'lib/stripe/resources/payment_intent.rb', line 9500 def car_model @car_model end |
#company ⇒ Object
The name of the rental car company.
9502 9503 9504 |
# File 'lib/stripe/resources/payment_intent.rb', line 9502 def company @company end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the car rental company.
9504 9505 9506 |
# File 'lib/stripe/resources/payment_intent.rb', line 9504 def customer_service_phone_number @customer_service_phone_number end |
#days_rented ⇒ Object
Number of days the car is being rented.
9506 9507 9508 |
# File 'lib/stripe/resources/payment_intent.rb', line 9506 def days_rented @days_rented end |
#delivery ⇒ Object
Delivery details for this purchase.
9508 9509 9510 |
# File 'lib/stripe/resources/payment_intent.rb', line 9508 def delivery @delivery end |
#drivers ⇒ Object
The details of the passengers in the travel reservation
9510 9511 9512 |
# File 'lib/stripe/resources/payment_intent.rb', line 9510 def drivers @drivers end |
#extra_charges ⇒ Object
List of additional charges being billed.
9512 9513 9514 |
# File 'lib/stripe/resources/payment_intent.rb', line 9512 def extra_charges @extra_charges end |
#no_show ⇒ Object
Indicates if the customer did not keep nor cancel their booking.
9514 9515 9516 |
# File 'lib/stripe/resources/payment_intent.rb', line 9514 def no_show @no_show end |
#pickup_address ⇒ Object
Car pick-up address.
9516 9517 9518 |
# File 'lib/stripe/resources/payment_intent.rb', line 9516 def pickup_address @pickup_address end |
#pickup_at ⇒ Object
Car pick-up time. Measured in seconds since the Unix epoch.
9518 9519 9520 |
# File 'lib/stripe/resources/payment_intent.rb', line 9518 def pickup_at @pickup_at end |
#rate_amount ⇒ Object
Rental rate.
9520 9521 9522 |
# File 'lib/stripe/resources/payment_intent.rb', line 9520 def rate_amount @rate_amount end |
#rate_interval ⇒ Object
The frequency at which the rate amount is applied. One of ‘day`, `week` or `month`
9522 9523 9524 |
# File 'lib/stripe/resources/payment_intent.rb', line 9522 def rate_interval @rate_interval end |
#renter_name ⇒ Object
The name of the person or entity renting the car.
9524 9525 9526 |
# File 'lib/stripe/resources/payment_intent.rb', line 9524 def renter_name @renter_name end |
#return_address ⇒ Object
Car return address.
9526 9527 9528 |
# File 'lib/stripe/resources/payment_intent.rb', line 9526 def return_address @return_address end |
#return_at ⇒ Object
Car return time. Measured in seconds since the Unix epoch.
9528 9529 9530 |
# File 'lib/stripe/resources/payment_intent.rb', line 9528 def return_at @return_at end |
#tax_exempt ⇒ Object
Indicates whether the goods or services are tax-exempt or tax is not collected.
9530 9531 9532 |
# File 'lib/stripe/resources/payment_intent.rb', line 9530 def tax_exempt @tax_exempt end |