Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
12237 12238 12239 12240 12241 |
# File 'lib/stripe/resources/payment_intent.rb', line 12237 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
12231 12232 12233 |
# File 'lib/stripe/resources/payment_intent.rb', line 12231 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
12233 12234 12235 |
# File 'lib/stripe/resources/payment_intent.rb', line 12233 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
12235 12236 12237 |
# File 'lib/stripe/resources/payment_intent.rb', line 12235 def phone @phone end |