Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10730 10731 10732 10733 10734 |
# File 'lib/stripe/resources/payment_intent.rb', line 10730 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10724 10725 10726 |
# File 'lib/stripe/resources/payment_intent.rb', line 10724 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10726 10727 10728 |
# File 'lib/stripe/resources/payment_intent.rb', line 10726 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10728 10729 10730 |
# File 'lib/stripe/resources/payment_intent.rb', line 10728 def phone @phone end |