Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10106
10107
10108
10109
10110
# File 'lib/stripe/resources/payment_intent.rb', line 10106

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



10100
10101
10102
# File 'lib/stripe/resources/payment_intent.rb', line 10100

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



10102
10103
10104
# File 'lib/stripe/resources/payment_intent.rb', line 10102

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10104
10105
10106
# File 'lib/stripe/resources/payment_intent.rb', line 10104

def phone
  @phone
end