Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9889
9890
9891
9892
9893
# File 'lib/stripe/resources/payment_intent.rb', line 9889

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9883
9884
9885
# File 'lib/stripe/resources/payment_intent.rb', line 9883

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9885
9886
9887
# File 'lib/stripe/resources/payment_intent.rb', line 9885

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9887
9888
9889
# File 'lib/stripe/resources/payment_intent.rb', line 9887

def phone
  @phone
end