Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9850 9851 9852 9853 9854 |
# File 'lib/stripe/resources/payment_intent.rb', line 9850 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9844 9845 9846 |
# File 'lib/stripe/resources/payment_intent.rb', line 9844 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9846 9847 9848 |
# File 'lib/stripe/resources/payment_intent.rb', line 9846 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9848 9849 9850 |
# File 'lib/stripe/resources/payment_intent.rb', line 9848 def phone @phone end |