Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9783 9784 9785 9786 9787 |
# File 'lib/stripe/resources/payment_intent.rb', line 9783 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9777 9778 9779 |
# File 'lib/stripe/resources/payment_intent.rb', line 9777 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9779 9780 9781 |
# File 'lib/stripe/resources/payment_intent.rb', line 9779 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9781 9782 9783 |
# File 'lib/stripe/resources/payment_intent.rb', line 9781 def phone @phone end |