Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9456
9457
9458
9459
9460
# File 'lib/stripe/resources/payment_intent.rb', line 9456

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9450
9451
9452
# File 'lib/stripe/resources/payment_intent.rb', line 9450

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9452
9453
9454
# File 'lib/stripe/resources/payment_intent.rb', line 9452

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9454
9455
9456
# File 'lib/stripe/resources/payment_intent.rb', line 9454

def phone
  @phone
end