Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9404
9405
9406
9407
9408
# File 'lib/stripe/resources/payment_intent.rb', line 9404

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9398
9399
9400
# File 'lib/stripe/resources/payment_intent.rb', line 9398

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9400
9401
9402
# File 'lib/stripe/resources/payment_intent.rb', line 9400

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9402
9403
9404
# File 'lib/stripe/resources/payment_intent.rb', line 9402

def phone
  @phone
end