Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10702 10703 10704 10705 10706 |
# File 'lib/stripe/resources/payment_intent.rb', line 10702 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10694 10695 10696 |
# File 'lib/stripe/resources/payment_intent.rb', line 10694 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10697 10698 10699 |
# File 'lib/stripe/resources/payment_intent.rb', line 10697 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10700 10701 10702 |
# File 'lib/stripe/resources/payment_intent.rb', line 10700 def phone @phone end |