Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::CarRental::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9372 9373 9374 9375 9376 |
# File 'lib/stripe/resources/payment_intent.rb', line 9372 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9366 9367 9368 |
# File 'lib/stripe/resources/payment_intent.rb', line 9366 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9368 9369 9370 |
# File 'lib/stripe/resources/payment_intent.rb', line 9368 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9370 9371 9372 |
# File 'lib/stripe/resources/payment_intent.rb', line 9370 def phone @phone end |