Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
12529 12530 12531 12532 12533 12534 12535 12536 12537 12538 12539 12540 12541 12542 12543 12544 12545 12546 12547 12548 12549 |
# File 'lib/stripe/resources/payment_intent.rb', line 12529 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
12511 12512 12513 |
# File 'lib/stripe/resources/payment_intent.rb', line 12511 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
12513 12514 12515 |
# File 'lib/stripe/resources/payment_intent.rb', line 12513 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
12515 12516 12517 |
# File 'lib/stripe/resources/payment_intent.rb', line 12515 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
12517 12518 12519 |
# File 'lib/stripe/resources/payment_intent.rb', line 12517 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
12519 12520 12521 |
# File 'lib/stripe/resources/payment_intent.rb', line 12519 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
12521 12522 12523 |
# File 'lib/stripe/resources/payment_intent.rb', line 12521 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
12523 12524 12525 |
# File 'lib/stripe/resources/payment_intent.rb', line 12523 def genre @genre end |
#name ⇒ Object
The name of the event.
12525 12526 12527 |
# File 'lib/stripe/resources/payment_intent.rb', line 12525 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
12527 12528 12529 |
# File 'lib/stripe/resources/payment_intent.rb', line 12527 def starts_at @starts_at end |