Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
11022 11023 11024 11025 11026 11027 11028 11029 11030 11031 11032 11033 11034 11035 11036 11037 11038 11039 11040 11041 11042 |
# File 'lib/stripe/resources/payment_intent.rb', line 11022 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
11004 11005 11006 |
# File 'lib/stripe/resources/payment_intent.rb', line 11004 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
11006 11007 11008 |
# File 'lib/stripe/resources/payment_intent.rb', line 11006 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
11008 11009 11010 |
# File 'lib/stripe/resources/payment_intent.rb', line 11008 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
11010 11011 11012 |
# File 'lib/stripe/resources/payment_intent.rb', line 11010 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
11012 11013 11014 |
# File 'lib/stripe/resources/payment_intent.rb', line 11012 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
11014 11015 11016 |
# File 'lib/stripe/resources/payment_intent.rb', line 11014 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
11016 11017 11018 |
# File 'lib/stripe/resources/payment_intent.rb', line 11016 def genre @genre end |
#name ⇒ Object
The name of the event.
11018 11019 11020 |
# File 'lib/stripe/resources/payment_intent.rb', line 11018 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
11020 11021 11022 |
# File 'lib/stripe/resources/payment_intent.rb', line 11020 def starts_at @starts_at end |