Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
10398 10399 10400 10401 10402 10403 10404 10405 10406 10407 10408 10409 10410 10411 10412 10413 10414 10415 10416 10417 10418 |
# File 'lib/stripe/resources/payment_intent.rb', line 10398 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
10380 10381 10382 |
# File 'lib/stripe/resources/payment_intent.rb', line 10380 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
10382 10383 10384 |
# File 'lib/stripe/resources/payment_intent.rb', line 10382 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
10384 10385 10386 |
# File 'lib/stripe/resources/payment_intent.rb', line 10384 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
10386 10387 10388 |
# File 'lib/stripe/resources/payment_intent.rb', line 10386 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
10388 10389 10390 |
# File 'lib/stripe/resources/payment_intent.rb', line 10388 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
10390 10391 10392 |
# File 'lib/stripe/resources/payment_intent.rb', line 10390 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
10392 10393 10394 |
# File 'lib/stripe/resources/payment_intent.rb', line 10392 def genre @genre end |
#name ⇒ Object
The name of the event.
10394 10395 10396 |
# File 'lib/stripe/resources/payment_intent.rb', line 10394 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
10396 10397 10398 |
# File 'lib/stripe/resources/payment_intent.rb', line 10396 def starts_at @starts_at end |