Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
10181 10182 10183 10184 10185 10186 10187 10188 10189 10190 10191 10192 10193 10194 10195 10196 10197 10198 10199 10200 10201 |
# File 'lib/stripe/resources/payment_intent.rb', line 10181 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
10163 10164 10165 |
# File 'lib/stripe/resources/payment_intent.rb', line 10163 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
10165 10166 10167 |
# File 'lib/stripe/resources/payment_intent.rb', line 10165 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
10167 10168 10169 |
# File 'lib/stripe/resources/payment_intent.rb', line 10167 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
10169 10170 10171 |
# File 'lib/stripe/resources/payment_intent.rb', line 10169 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
10171 10172 10173 |
# File 'lib/stripe/resources/payment_intent.rb', line 10171 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
10173 10174 10175 |
# File 'lib/stripe/resources/payment_intent.rb', line 10173 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
10175 10176 10177 |
# File 'lib/stripe/resources/payment_intent.rb', line 10175 def genre @genre end |
#name ⇒ Object
The name of the event.
10177 10178 10179 |
# File 'lib/stripe/resources/payment_intent.rb', line 10177 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
10179 10180 10181 |
# File 'lib/stripe/resources/payment_intent.rb', line 10179 def starts_at @starts_at end |