Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
10108 10109 10110 10111 10112 10113 10114 10115 10116 10117 10118 10119 10120 10121 10122 10123 10124 10125 10126 10127 10128 |
# File 'lib/stripe/resources/payment_intent.rb', line 10108 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
10090 10091 10092 |
# File 'lib/stripe/resources/payment_intent.rb', line 10090 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
10092 10093 10094 |
# File 'lib/stripe/resources/payment_intent.rb', line 10092 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
10094 10095 10096 |
# File 'lib/stripe/resources/payment_intent.rb', line 10094 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
10096 10097 10098 |
# File 'lib/stripe/resources/payment_intent.rb', line 10096 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
10098 10099 10100 |
# File 'lib/stripe/resources/payment_intent.rb', line 10098 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
10100 10101 10102 |
# File 'lib/stripe/resources/payment_intent.rb', line 10100 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
10102 10103 10104 |
# File 'lib/stripe/resources/payment_intent.rb', line 10102 def genre @genre end |
#name ⇒ Object
The name of the event.
10104 10105 10106 |
# File 'lib/stripe/resources/payment_intent.rb', line 10104 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
10106 10107 10108 |
# File 'lib/stripe/resources/payment_intent.rb', line 10106 def starts_at @starts_at end |