Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
10041 10042 10043 10044 10045 10046 10047 10048 10049 10050 10051 10052 10053 10054 10055 10056 10057 10058 10059 10060 10061 |
# File 'lib/stripe/resources/payment_intent.rb', line 10041 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
10023 10024 10025 |
# File 'lib/stripe/resources/payment_intent.rb', line 10023 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
10025 10026 10027 |
# File 'lib/stripe/resources/payment_intent.rb', line 10025 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
10027 10028 10029 |
# File 'lib/stripe/resources/payment_intent.rb', line 10027 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
10029 10030 10031 |
# File 'lib/stripe/resources/payment_intent.rb', line 10029 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
10031 10032 10033 |
# File 'lib/stripe/resources/payment_intent.rb', line 10031 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
10033 10034 10035 |
# File 'lib/stripe/resources/payment_intent.rb', line 10033 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
10035 10036 10037 |
# File 'lib/stripe/resources/payment_intent.rb', line 10035 def genre @genre end |
#name ⇒ Object
The name of the event.
10037 10038 10039 |
# File 'lib/stripe/resources/payment_intent.rb', line 10037 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
10039 10040 10041 |
# File 'lib/stripe/resources/payment_intent.rb', line 10039 def starts_at @starts_at end |