Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
11006 11007 11008 11009 11010 11011 11012 11013 11014 11015 11016 11017 11018 11019 11020 11021 11022 11023 11024 11025 11026 |
# File 'lib/stripe/resources/payment_intent.rb', line 11006 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
10980 10981 10982 |
# File 'lib/stripe/resources/payment_intent.rb', line 10980 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
10983 10984 10985 |
# File 'lib/stripe/resources/payment_intent.rb', line 10983 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
10986 10987 10988 |
# File 'lib/stripe/resources/payment_intent.rb', line 10986 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
10989 10990 10991 |
# File 'lib/stripe/resources/payment_intent.rb', line 10989 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
10992 10993 10994 |
# File 'lib/stripe/resources/payment_intent.rb', line 10992 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
10995 10996 10997 |
# File 'lib/stripe/resources/payment_intent.rb', line 10995 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
10998 10999 11000 |
# File 'lib/stripe/resources/payment_intent.rb', line 10998 def genre @genre end |
#name ⇒ Object
The name of the event.
11001 11002 11003 |
# File 'lib/stripe/resources/payment_intent.rb', line 11001 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
11004 11005 11006 |
# File 'lib/stripe/resources/payment_intent.rb', line 11004 def starts_at @starts_at end |