Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
9630 9631 9632 9633 9634 9635 9636 9637 9638 9639 9640 9641 9642 9643 9644 9645 9646 9647 9648 9649 9650 |
# File 'lib/stripe/resources/payment_intent.rb', line 9630 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
9612 9613 9614 |
# File 'lib/stripe/resources/payment_intent.rb', line 9612 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
9614 9615 9616 |
# File 'lib/stripe/resources/payment_intent.rb', line 9614 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9616 9617 9618 |
# File 'lib/stripe/resources/payment_intent.rb', line 9616 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
9618 9619 9620 |
# File 'lib/stripe/resources/payment_intent.rb', line 9618 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
9620 9621 9622 |
# File 'lib/stripe/resources/payment_intent.rb', line 9620 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
9622 9623 9624 |
# File 'lib/stripe/resources/payment_intent.rb', line 9622 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
9624 9625 9626 |
# File 'lib/stripe/resources/payment_intent.rb', line 9624 def genre @genre end |
#name ⇒ Object
The name of the event.
9626 9627 9628 |
# File 'lib/stripe/resources/payment_intent.rb', line 9626 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
9628 9629 9630 |
# File 'lib/stripe/resources/payment_intent.rb', line 9628 def starts_at @starts_at end |