Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery
Instance Attribute Summary collapse
-
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
-
#address ⇒ Object
The event location’s address.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#company ⇒ Object
The name of the company.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#ends_at ⇒ Object
Event end time.
-
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc).
-
#name ⇒ Object
The name of the event.
-
#starts_at ⇒ Object
Event start time.
Instance Method Summary collapse
-
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
constructor
A new instance of EventDetails.
Methods inherited from RequestParams
Constructor Details
#initialize(access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil) ⇒ EventDetails
Returns a new instance of EventDetails.
9662 9663 9664 9665 9666 9667 9668 9669 9670 9671 9672 9673 9674 9675 9676 9677 9678 9679 9680 9681 9682 |
# File 'lib/stripe/resources/payment_intent.rb', line 9662 def initialize( access_controlled_venue: nil, address: nil, affiliate: nil, company: nil, delivery: nil, ends_at: nil, genre: nil, name: nil, starts_at: nil ) @access_controlled_venue = access_controlled_venue @address = address @affiliate = affiliate @company = company @delivery = delivery @ends_at = ends_at @genre = genre @name = name @starts_at = starts_at end |
Instance Attribute Details
#access_controlled_venue ⇒ Object
Indicates if the tickets are digitally checked when entering the venue.
9644 9645 9646 |
# File 'lib/stripe/resources/payment_intent.rb', line 9644 def access_controlled_venue @access_controlled_venue end |
#address ⇒ Object
The event location’s address.
9646 9647 9648 |
# File 'lib/stripe/resources/payment_intent.rb', line 9646 def address @address end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9648 9649 9650 |
# File 'lib/stripe/resources/payment_intent.rb', line 9648 def affiliate @affiliate end |
#company ⇒ Object
The name of the company
9650 9651 9652 |
# File 'lib/stripe/resources/payment_intent.rb', line 9650 def company @company end |
#delivery ⇒ Object
Delivery details for this purchase.
9652 9653 9654 |
# File 'lib/stripe/resources/payment_intent.rb', line 9652 def delivery @delivery end |
#ends_at ⇒ Object
Event end time. Measured in seconds since the Unix epoch.
9654 9655 9656 |
# File 'lib/stripe/resources/payment_intent.rb', line 9654 def ends_at @ends_at end |
#genre ⇒ Object
Type of the event entertainment (concert, sports event etc)
9656 9657 9658 |
# File 'lib/stripe/resources/payment_intent.rb', line 9656 def genre @genre end |
#name ⇒ Object
The name of the event.
9658 9659 9660 |
# File 'lib/stripe/resources/payment_intent.rb', line 9658 def name @name end |
#starts_at ⇒ Object
Event start time. Measured in seconds since the Unix epoch.
9660 9661 9662 |
# File 'lib/stripe/resources/payment_intent.rb', line 9660 def starts_at @starts_at end |