Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
11113 11114 11115 11116 11117 |
# File 'lib/stripe/resources/payment_intent.rb', line 11113 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
11107 11108 11109 |
# File 'lib/stripe/resources/payment_intent.rb', line 11107 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
11109 11110 11111 |
# File 'lib/stripe/resources/payment_intent.rb', line 11109 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
11111 11112 11113 |
# File 'lib/stripe/resources/payment_intent.rb', line 11111 def phone @phone end |