Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10987 10988 10989 10990 10991 |
# File 'lib/stripe/resources/payment_intent.rb', line 10987 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10981 10982 10983 |
# File 'lib/stripe/resources/payment_intent.rb', line 10981 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10983 10984 10985 |
# File 'lib/stripe/resources/payment_intent.rb', line 10983 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10985 10986 10987 |
# File 'lib/stripe/resources/payment_intent.rb', line 10985 def phone @phone end |