Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10146 10147 10148 10149 10150 |
# File 'lib/stripe/resources/payment_intent.rb', line 10146 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10140 10141 10142 |
# File 'lib/stripe/resources/payment_intent.rb', line 10140 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10142 10143 10144 |
# File 'lib/stripe/resources/payment_intent.rb', line 10142 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10144 10145 10146 |
# File 'lib/stripe/resources/payment_intent.rb', line 10144 def phone @phone end |