Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10006
10007
10008
10009
10010
# File 'lib/stripe/resources/payment_intent.rb', line 10006

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



10000
10001
10002
# File 'lib/stripe/resources/payment_intent.rb', line 10000

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



10002
10003
10004
# File 'lib/stripe/resources/payment_intent.rb', line 10002

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10004
10005
10006
# File 'lib/stripe/resources/payment_intent.rb', line 10004

def phone
  @phone
end