Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10962
10963
10964
10965
10966
# File 'lib/stripe/resources/payment_intent.rb', line 10962

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



10954
10955
10956
# File 'lib/stripe/resources/payment_intent.rb', line 10954

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



10957
10958
10959
# File 'lib/stripe/resources/payment_intent.rb', line 10957

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10960
10961
10962
# File 'lib/stripe/resources/payment_intent.rb', line 10960

def phone
  @phone
end