Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9595
9596
9597
9598
9599
# File 'lib/stripe/resources/payment_intent.rb', line 9595

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9589
9590
9591
# File 'lib/stripe/resources/payment_intent.rb', line 9589

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9591
9592
9593
# File 'lib/stripe/resources/payment_intent.rb', line 9591

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9593
9594
9595
# File 'lib/stripe/resources/payment_intent.rb', line 9593

def phone
  @phone
end