Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::EventDetails::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9627 9628 9629 9630 9631 |
# File 'lib/stripe/resources/payment_intent.rb', line 9627 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9621 9622 9623 |
# File 'lib/stripe/resources/payment_intent.rb', line 9621 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9623 9624 9625 |
# File 'lib/stripe/resources/payment_intent.rb', line 9623 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9625 9626 9627 |
# File 'lib/stripe/resources/payment_intent.rb', line 9625 def phone @phone end |