Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



12571
12572
12573
12574
12575
# File 'lib/stripe/resources/payment_intent.rb', line 12571

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



12565
12566
12567
# File 'lib/stripe/resources/payment_intent.rb', line 12565

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



12567
12568
12569
# File 'lib/stripe/resources/payment_intent.rb', line 12567

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



12569
12570
12571
# File 'lib/stripe/resources/payment_intent.rb', line 12569

def phone
  @phone
end