Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



10440
10441
10442
10443
10444
# File 'lib/stripe/resources/payment_intent.rb', line 10440

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



10434
10435
10436
# File 'lib/stripe/resources/payment_intent.rb', line 10434

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



10436
10437
10438
# File 'lib/stripe/resources/payment_intent.rb', line 10436

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



10438
10439
10440
# File 'lib/stripe/resources/payment_intent.rb', line 10438

def phone
  @phone
end