Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10223 10224 10225 10226 10227 |
# File 'lib/stripe/resources/payment_intent.rb', line 10223 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10217 10218 10219 |
# File 'lib/stripe/resources/payment_intent.rb', line 10217 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10219 10220 10221 |
# File 'lib/stripe/resources/payment_intent.rb', line 10219 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10221 10222 10223 |
# File 'lib/stripe/resources/payment_intent.rb', line 10221 def phone @phone end |