Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10083 10084 10085 10086 10087 |
# File 'lib/stripe/resources/payment_intent.rb', line 10083 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10077 10078 10079 |
# File 'lib/stripe/resources/payment_intent.rb', line 10077 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10079 10080 10081 |
# File 'lib/stripe/resources/payment_intent.rb', line 10079 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10081 10082 10083 |
# File 'lib/stripe/resources/payment_intent.rb', line 10081 def phone @phone end |