Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9756
9757
9758
9759
9760
# File 'lib/stripe/resources/payment_intent.rb', line 9756

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9750
9751
9752
# File 'lib/stripe/resources/payment_intent.rb', line 9750

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9752
9753
9754
# File 'lib/stripe/resources/payment_intent.rb', line 9752

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9754
9755
9756
# File 'lib/stripe/resources/payment_intent.rb', line 9754

def phone
  @phone
end