Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9704
9705
9706
9707
9708
# File 'lib/stripe/resources/payment_intent.rb', line 9704

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9698
9699
9700
# File 'lib/stripe/resources/payment_intent.rb', line 9698

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9700
9701
9702
# File 'lib/stripe/resources/payment_intent.rb', line 9700

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9702
9703
9704
# File 'lib/stripe/resources/payment_intent.rb', line 9702

def phone
  @phone
end