Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



11050
11051
11052
11053
11054
# File 'lib/stripe/resources/payment_intent.rb', line 11050

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



11042
11043
11044
# File 'lib/stripe/resources/payment_intent.rb', line 11042

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



11045
11046
11047
# File 'lib/stripe/resources/payment_intent.rb', line 11045

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



11048
11049
11050
# File 'lib/stripe/resources/payment_intent.rb', line 11048

def phone
  @phone
end