Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9672
9673
9674
9675
9676
# File 'lib/stripe/resources/payment_intent.rb', line 9672

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9666
9667
9668
# File 'lib/stripe/resources/payment_intent.rb', line 9666

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9668
9669
9670
# File 'lib/stripe/resources/payment_intent.rb', line 9668

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9670
9671
9672
# File 'lib/stripe/resources/payment_intent.rb', line 9670

def phone
  @phone
end