Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Segment
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Flight::Segment
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The flight segment amount.
-
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
-
#arrives_at ⇒ Object
The arrival time for the flight segment.
-
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
-
#departs_at ⇒ Object
The departure time for the flight segment.
-
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
-
#flight_number ⇒ Object
The flight number associated with the segment.
-
#service_class ⇒ Object
The fare class for the segment.
Instance Method Summary collapse
-
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
constructor
A new instance of Segment.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil) ⇒ Segment
Returns a new instance of Segment.
11108 11109 11110 11111 11112 11113 11114 11115 11116 11117 11118 11119 11120 11121 11122 11123 11124 11125 11126 |
# File 'lib/stripe/resources/payment_intent.rb', line 11108 def initialize( amount: nil, arrival_airport: nil, arrives_at: nil, carrier: nil, departs_at: nil, departure_airport: nil, flight_number: nil, service_class: nil ) @amount = amount @arrival_airport = arrival_airport @arrives_at = arrives_at @carrier = carrier @departs_at = departs_at @departure_airport = departure_airport @flight_number = flight_number @service_class = service_class end |
Instance Attribute Details
#amount ⇒ Object
The flight segment amount.
11092 11093 11094 |
# File 'lib/stripe/resources/payment_intent.rb', line 11092 def amount @amount end |
#arrival_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the arrival airport.
11094 11095 11096 |
# File 'lib/stripe/resources/payment_intent.rb', line 11094 def arrival_airport @arrival_airport end |
#arrives_at ⇒ Object
The arrival time for the flight segment. Measured in seconds since the Unix epoch.
11096 11097 11098 |
# File 'lib/stripe/resources/payment_intent.rb', line 11096 def arrives_at @arrives_at end |
#carrier ⇒ Object
The International Air Transport Association (IATA) carrier code of the carrier operating the flight segment.
11098 11099 11100 |
# File 'lib/stripe/resources/payment_intent.rb', line 11098 def carrier @carrier end |
#departs_at ⇒ Object
The departure time for the flight segment. Measured in seconds since the Unix epoch.
11100 11101 11102 |
# File 'lib/stripe/resources/payment_intent.rb', line 11100 def departs_at @departs_at end |
#departure_airport ⇒ Object
The International Air Transport Association (IATA) airport code for the departure airport.
11102 11103 11104 |
# File 'lib/stripe/resources/payment_intent.rb', line 11102 def departure_airport @departure_airport end |
#flight_number ⇒ Object
The flight number associated with the segment
11104 11105 11106 |
# File 'lib/stripe/resources/payment_intent.rb', line 11104 def flight_number @flight_number end |
#service_class ⇒ Object
The fare class for the segment.
11106 11107 11108 |
# File 'lib/stripe/resources/payment_intent.rb', line 11106 def service_class @service_class end |