Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



11410
11411
11412
11413
11414
11415
11416
11417
11418
11419
11420
11421
11422
11423
11424
11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
11444
11445
11446
11447
11448
11449
11450
11451
11452
11453
11454
# File 'lib/stripe/resources/payment_intent.rb', line 11410

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



11368
11369
11370
# File 'lib/stripe/resources/payment_intent.rb', line 11368

def address
  @address
end

#adultsObject

The number of adults on the booking



11370
11371
11372
# File 'lib/stripe/resources/payment_intent.rb', line 11370

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



11372
11373
11374
# File 'lib/stripe/resources/payment_intent.rb', line 11372

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



11374
11375
11376
# File 'lib/stripe/resources/payment_intent.rb', line 11374

def booking_number
  @booking_number
end

#categoryObject

The lodging category



11376
11377
11378
# File 'lib/stripe/resources/payment_intent.rb', line 11376

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



11378
11379
11380
# File 'lib/stripe/resources/payment_intent.rb', line 11378

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



11380
11381
11382
# File 'lib/stripe/resources/payment_intent.rb', line 11380

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



11382
11383
11384
# File 'lib/stripe/resources/payment_intent.rb', line 11382

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



11384
11385
11386
# File 'lib/stripe/resources/payment_intent.rb', line 11384

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



11386
11387
11388
# File 'lib/stripe/resources/payment_intent.rb', line 11386

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



11388
11389
11390
# File 'lib/stripe/resources/payment_intent.rb', line 11388

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



11390
11391
11392
# File 'lib/stripe/resources/payment_intent.rb', line 11390

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



11392
11393
11394
# File 'lib/stripe/resources/payment_intent.rb', line 11392

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



11394
11395
11396
# File 'lib/stripe/resources/payment_intent.rb', line 11394

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



11396
11397
11398
# File 'lib/stripe/resources/payment_intent.rb', line 11396

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



11398
11399
11400
# File 'lib/stripe/resources/payment_intent.rb', line 11398

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



11400
11401
11402
# File 'lib/stripe/resources/payment_intent.rb', line 11400

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



11402
11403
11404
# File 'lib/stripe/resources/payment_intent.rb', line 11402

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



11404
11405
11406
# File 'lib/stripe/resources/payment_intent.rb', line 11404

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



11406
11407
11408
# File 'lib/stripe/resources/payment_intent.rb', line 11406

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



11408
11409
11410
# File 'lib/stripe/resources/payment_intent.rb', line 11408

def total_tax_amount
  @total_tax_amount
end