Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



10660
10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
10693
10694
10695
10696
10697
10698
10699
10700
10701
10702
10703
10704
# File 'lib/stripe/resources/payment_intent.rb', line 10660

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



10618
10619
10620
# File 'lib/stripe/resources/payment_intent.rb', line 10618

def address
  @address
end

#adultsObject

The number of adults on the booking



10620
10621
10622
# File 'lib/stripe/resources/payment_intent.rb', line 10620

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



10622
10623
10624
# File 'lib/stripe/resources/payment_intent.rb', line 10622

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



10624
10625
10626
# File 'lib/stripe/resources/payment_intent.rb', line 10624

def booking_number
  @booking_number
end

#categoryObject

The lodging category



10626
10627
10628
# File 'lib/stripe/resources/payment_intent.rb', line 10626

def category
  @category
end

#checkin_atObject

Lodging check-in time. Measured in seconds since the Unix epoch.



10628
10629
10630
# File 'lib/stripe/resources/payment_intent.rb', line 10628

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



10630
10631
10632
# File 'lib/stripe/resources/payment_intent.rb', line 10630

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



10632
10633
10634
# File 'lib/stripe/resources/payment_intent.rb', line 10632

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



10634
10635
10636
# File 'lib/stripe/resources/payment_intent.rb', line 10634

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



10636
10637
10638
# File 'lib/stripe/resources/payment_intent.rb', line 10636

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



10638
10639
10640
# File 'lib/stripe/resources/payment_intent.rb', line 10638

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



10640
10641
10642
# File 'lib/stripe/resources/payment_intent.rb', line 10640

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



10642
10643
10644
# File 'lib/stripe/resources/payment_intent.rb', line 10642

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



10644
10645
10646
# File 'lib/stripe/resources/payment_intent.rb', line 10644

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



10646
10647
10648
# File 'lib/stripe/resources/payment_intent.rb', line 10646

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



10648
10649
10650
# File 'lib/stripe/resources/payment_intent.rb', line 10648

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



10650
10651
10652
# File 'lib/stripe/resources/payment_intent.rb', line 10650

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



10652
10653
10654
# File 'lib/stripe/resources/payment_intent.rb', line 10652

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



10654
10655
10656
# File 'lib/stripe/resources/payment_intent.rb', line 10654

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



10656
10657
10658
# File 'lib/stripe/resources/payment_intent.rb', line 10656

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



10658
10659
10660
# File 'lib/stripe/resources/payment_intent.rb', line 10658

def total_tax_amount
  @total_tax_amount
end