Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



10303
10304
10305
10306
10307
10308
10309
10310
10311
10312
10313
10314
10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
10326
10327
10328
10329
10330
10331
10332
10333
10334
10335
10336
10337
10338
10339
10340
10341
10342
10343
10344
10345
10346
10347
# File 'lib/stripe/resources/payment_intent.rb', line 10303

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



10261
10262
10263
# File 'lib/stripe/resources/payment_intent.rb', line 10261

def address
  @address
end

#adultsObject

The number of adults on the booking



10263
10264
10265
# File 'lib/stripe/resources/payment_intent.rb', line 10263

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



10265
10266
10267
# File 'lib/stripe/resources/payment_intent.rb', line 10265

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



10267
10268
10269
# File 'lib/stripe/resources/payment_intent.rb', line 10267

def booking_number
  @booking_number
end

#categoryObject

The lodging category



10269
10270
10271
# File 'lib/stripe/resources/payment_intent.rb', line 10269

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



10271
10272
10273
# File 'lib/stripe/resources/payment_intent.rb', line 10271

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



10273
10274
10275
# File 'lib/stripe/resources/payment_intent.rb', line 10273

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



10275
10276
10277
# File 'lib/stripe/resources/payment_intent.rb', line 10275

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



10277
10278
10279
# File 'lib/stripe/resources/payment_intent.rb', line 10277

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



10279
10280
10281
# File 'lib/stripe/resources/payment_intent.rb', line 10279

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



10281
10282
10283
# File 'lib/stripe/resources/payment_intent.rb', line 10281

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



10283
10284
10285
# File 'lib/stripe/resources/payment_intent.rb', line 10283

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



10285
10286
10287
# File 'lib/stripe/resources/payment_intent.rb', line 10285

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



10287
10288
10289
# File 'lib/stripe/resources/payment_intent.rb', line 10287

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



10289
10290
10291
# File 'lib/stripe/resources/payment_intent.rb', line 10289

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



10291
10292
10293
# File 'lib/stripe/resources/payment_intent.rb', line 10291

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



10293
10294
10295
# File 'lib/stripe/resources/payment_intent.rb', line 10293

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



10295
10296
10297
# File 'lib/stripe/resources/payment_intent.rb', line 10295

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



10297
10298
10299
# File 'lib/stripe/resources/payment_intent.rb', line 10297

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



10299
10300
10301
# File 'lib/stripe/resources/payment_intent.rb', line 10299

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



10301
10302
10303
# File 'lib/stripe/resources/payment_intent.rb', line 10301

def total_tax_amount
  @total_tax_amount
end