Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 10390 10391 10392 10393 10394 10395 10396 10397 10398 10399 10400 10401 10402 10403 10404 10405 10406 10407 10408 10409 10410 10411 10412 10413 10414 |
# File 'lib/stripe/resources/payment_intent.rb', line 10370 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
10328 10329 10330 |
# File 'lib/stripe/resources/payment_intent.rb', line 10328 def address @address end |
#adults ⇒ Object
The number of adults on the booking
10330 10331 10332 |
# File 'lib/stripe/resources/payment_intent.rb', line 10330 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
10332 10333 10334 |
# File 'lib/stripe/resources/payment_intent.rb', line 10332 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
10334 10335 10336 |
# File 'lib/stripe/resources/payment_intent.rb', line 10334 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
10336 10337 10338 |
# File 'lib/stripe/resources/payment_intent.rb', line 10336 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
10338 10339 10340 |
# File 'lib/stripe/resources/payment_intent.rb', line 10338 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
10340 10341 10342 |
# File 'lib/stripe/resources/payment_intent.rb', line 10340 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
10342 10343 10344 |
# File 'lib/stripe/resources/payment_intent.rb', line 10342 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
10344 10345 10346 |
# File 'lib/stripe/resources/payment_intent.rb', line 10344 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
10346 10347 10348 |
# File 'lib/stripe/resources/payment_intent.rb', line 10346 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
10348 10349 10350 |
# File 'lib/stripe/resources/payment_intent.rb', line 10348 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
10350 10351 10352 |
# File 'lib/stripe/resources/payment_intent.rb', line 10350 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
10352 10353 10354 |
# File 'lib/stripe/resources/payment_intent.rb', line 10352 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
10354 10355 10356 |
# File 'lib/stripe/resources/payment_intent.rb', line 10354 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
10356 10357 10358 |
# File 'lib/stripe/resources/payment_intent.rb', line 10356 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
10358 10359 10360 |
# File 'lib/stripe/resources/payment_intent.rb', line 10358 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
10360 10361 10362 |
# File 'lib/stripe/resources/payment_intent.rb', line 10360 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
10362 10363 10364 |
# File 'lib/stripe/resources/payment_intent.rb', line 10362 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
10364 10365 10366 |
# File 'lib/stripe/resources/payment_intent.rb', line 10364 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
10366 10367 10368 |
# File 'lib/stripe/resources/payment_intent.rb', line 10366 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
10368 10369 10370 |
# File 'lib/stripe/resources/payment_intent.rb', line 10368 def total_tax_amount @total_tax_amount end |