Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 9986 9987 9988 9989 9990 9991 9992 9993 9994 9995 9996 9997 9998 9999 10000 10001 10002 10003 10004 10005 10006 10007 10008 10009 10010 10011 10012 10013 10014 10015 10016 10017 10018 10019 10020 |
# File 'lib/stripe/resources/payment_intent.rb', line 9976 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
9934 9935 9936 |
# File 'lib/stripe/resources/payment_intent.rb', line 9934 def address @address end |
#adults ⇒ Object
The number of adults on the booking
9936 9937 9938 |
# File 'lib/stripe/resources/payment_intent.rb', line 9936 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
9938 9939 9940 |
# File 'lib/stripe/resources/payment_intent.rb', line 9938 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
9940 9941 9942 |
# File 'lib/stripe/resources/payment_intent.rb', line 9940 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
9942 9943 9944 |
# File 'lib/stripe/resources/payment_intent.rb', line 9942 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
9944 9945 9946 |
# File 'lib/stripe/resources/payment_intent.rb', line 9944 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
9946 9947 9948 |
# File 'lib/stripe/resources/payment_intent.rb', line 9946 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
9948 9949 9950 |
# File 'lib/stripe/resources/payment_intent.rb', line 9948 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
9950 9951 9952 |
# File 'lib/stripe/resources/payment_intent.rb', line 9950 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
9952 9953 9954 |
# File 'lib/stripe/resources/payment_intent.rb', line 9952 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
9954 9955 9956 |
# File 'lib/stripe/resources/payment_intent.rb', line 9954 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
9956 9957 9958 |
# File 'lib/stripe/resources/payment_intent.rb', line 9956 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
9958 9959 9960 |
# File 'lib/stripe/resources/payment_intent.rb', line 9958 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
9960 9961 9962 |
# File 'lib/stripe/resources/payment_intent.rb', line 9960 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
9962 9963 9964 |
# File 'lib/stripe/resources/payment_intent.rb', line 9962 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
9964 9965 9966 |
# File 'lib/stripe/resources/payment_intent.rb', line 9964 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
9966 9967 9968 |
# File 'lib/stripe/resources/payment_intent.rb', line 9966 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
9968 9969 9970 |
# File 'lib/stripe/resources/payment_intent.rb', line 9968 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
9970 9971 9972 |
# File 'lib/stripe/resources/payment_intent.rb', line 9970 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
9972 9973 9974 |
# File 'lib/stripe/resources/payment_intent.rb', line 9972 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
9974 9975 9976 |
# File 'lib/stripe/resources/payment_intent.rb', line 9974 def total_tax_amount @total_tax_amount end |