Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



9924
9925
9926
9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
9937
9938
9939
9940
9941
9942
9943
9944
9945
9946
9947
9948
9949
9950
9951
9952
9953
9954
9955
9956
9957
9958
9959
9960
9961
9962
9963
9964
9965
9966
9967
9968
# File 'lib/stripe/resources/payment_intent.rb', line 9924

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



9882
9883
9884
# File 'lib/stripe/resources/payment_intent.rb', line 9882

def address
  @address
end

#adultsObject

The number of adults on the booking



9884
9885
9886
# File 'lib/stripe/resources/payment_intent.rb', line 9884

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



9886
9887
9888
# File 'lib/stripe/resources/payment_intent.rb', line 9886

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



9888
9889
9890
# File 'lib/stripe/resources/payment_intent.rb', line 9888

def booking_number
  @booking_number
end

#categoryObject

The lodging category



9890
9891
9892
# File 'lib/stripe/resources/payment_intent.rb', line 9890

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



9892
9893
9894
# File 'lib/stripe/resources/payment_intent.rb', line 9892

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



9894
9895
9896
# File 'lib/stripe/resources/payment_intent.rb', line 9894

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



9896
9897
9898
# File 'lib/stripe/resources/payment_intent.rb', line 9896

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



9898
9899
9900
# File 'lib/stripe/resources/payment_intent.rb', line 9898

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



9900
9901
9902
# File 'lib/stripe/resources/payment_intent.rb', line 9900

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



9902
9903
9904
# File 'lib/stripe/resources/payment_intent.rb', line 9902

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



9904
9905
9906
# File 'lib/stripe/resources/payment_intent.rb', line 9904

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



9906
9907
9908
# File 'lib/stripe/resources/payment_intent.rb', line 9906

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



9908
9909
9910
# File 'lib/stripe/resources/payment_intent.rb', line 9908

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



9910
9911
9912
# File 'lib/stripe/resources/payment_intent.rb', line 9910

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



9912
9913
9914
# File 'lib/stripe/resources/payment_intent.rb', line 9912

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



9914
9915
9916
# File 'lib/stripe/resources/payment_intent.rb', line 9914

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



9916
9917
9918
# File 'lib/stripe/resources/payment_intent.rb', line 9916

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



9918
9919
9920
# File 'lib/stripe/resources/payment_intent.rb', line 9918

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



9920
9921
9922
# File 'lib/stripe/resources/payment_intent.rb', line 9920

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



9922
9923
9924
# File 'lib/stripe/resources/payment_intent.rb', line 9922

def total_tax_amount
  @total_tax_amount
end