Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address, Affiliate, Delivery, Passenger

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging

Returns a new instance of Lodging.



9892
9893
9894
9895
9896
9897
9898
9899
9900
9901
9902
9903
9904
9905
9906
9907
9908
9909
9910
9911
9912
9913
9914
9915
9916
9917
9918
9919
9920
9921
9922
9923
9924
9925
9926
9927
9928
9929
9930
9931
9932
9933
9934
9935
9936
# File 'lib/stripe/resources/payment_intent.rb', line 9892

def initialize(
  address: nil,
  adults: nil,
  affiliate: nil,
  booking_number: nil,
  category: nil,
  checkin_at: nil,
  checkout_at: nil,
  customer_service_phone_number: nil,
  daily_room_rate_amount: nil,
  delivery: nil,
  extra_charges: nil,
  fire_safety_act_compliance: nil,
  name: nil,
  no_show: nil,
  number_of_rooms: nil,
  passengers: nil,
  property_phone_number: nil,
  room_class: nil,
  room_nights: nil,
  total_room_tax_amount: nil,
  total_tax_amount: nil
)
  @address = address
  @adults = adults
  @affiliate = affiliate
  @booking_number = booking_number
  @category = category
  @checkin_at = checkin_at
  @checkout_at = checkout_at
  @customer_service_phone_number = customer_service_phone_number
  @daily_room_rate_amount = daily_room_rate_amount
  @delivery = delivery
  @extra_charges = extra_charges
  @fire_safety_act_compliance = fire_safety_act_compliance
  @name = name
  @no_show = no_show
  @number_of_rooms = number_of_rooms
  @passengers = passengers
  @property_phone_number = property_phone_number
  @room_class = room_class
  @room_nights = room_nights
  @total_room_tax_amount = total_room_tax_amount
  @total_tax_amount = total_tax_amount
end

Instance Attribute Details

#addressObject

The lodging location’s address.



9850
9851
9852
# File 'lib/stripe/resources/payment_intent.rb', line 9850

def address
  @address
end

#adultsObject

The number of adults on the booking



9852
9853
9854
# File 'lib/stripe/resources/payment_intent.rb', line 9852

def adults
  @adults
end

#affiliateObject

Affiliate details for this purchase.



9854
9855
9856
# File 'lib/stripe/resources/payment_intent.rb', line 9854

def affiliate
  @affiliate
end

#booking_numberObject

The booking number associated with the lodging reservation.



9856
9857
9858
# File 'lib/stripe/resources/payment_intent.rb', line 9856

def booking_number
  @booking_number
end

#categoryObject

The lodging category



9858
9859
9860
# File 'lib/stripe/resources/payment_intent.rb', line 9858

def category
  @category
end

#checkin_atObject

Loding check-in time. Measured in seconds since the Unix epoch.



9860
9861
9862
# File 'lib/stripe/resources/payment_intent.rb', line 9860

def checkin_at
  @checkin_at
end

#checkout_atObject

Lodging check-out time. Measured in seconds since the Unix epoch.



9862
9863
9864
# File 'lib/stripe/resources/payment_intent.rb', line 9862

def checkout_at
  @checkout_at
end

#customer_service_phone_numberObject

The customer service phone number of the lodging company.



9864
9865
9866
# File 'lib/stripe/resources/payment_intent.rb', line 9864

def customer_service_phone_number
  @customer_service_phone_number
end

#daily_room_rate_amountObject

The daily lodging room rate.



9866
9867
9868
# File 'lib/stripe/resources/payment_intent.rb', line 9866

def daily_room_rate_amount
  @daily_room_rate_amount
end

#deliveryObject

Delivery details for this purchase.



9868
9869
9870
# File 'lib/stripe/resources/payment_intent.rb', line 9868

def delivery
  @delivery
end

#extra_chargesObject

List of additional charges being billed.



9870
9871
9872
# File 'lib/stripe/resources/payment_intent.rb', line 9870

def extra_charges
  @extra_charges
end

#fire_safety_act_complianceObject

Indicates whether the lodging location is compliant with the Fire Safety Act.



9872
9873
9874
# File 'lib/stripe/resources/payment_intent.rb', line 9872

def fire_safety_act_compliance
  @fire_safety_act_compliance
end

#nameObject

The name of the lodging location.



9874
9875
9876
# File 'lib/stripe/resources/payment_intent.rb', line 9874

def name
  @name
end

#no_showObject

Indicates if the customer did not keep their booking while failing to cancel the reservation.



9876
9877
9878
# File 'lib/stripe/resources/payment_intent.rb', line 9876

def no_show
  @no_show
end

#number_of_roomsObject

The number of rooms on the booking



9878
9879
9880
# File 'lib/stripe/resources/payment_intent.rb', line 9878

def number_of_rooms
  @number_of_rooms
end

#passengersObject

The details of the passengers in the travel reservation



9880
9881
9882
# File 'lib/stripe/resources/payment_intent.rb', line 9880

def passengers
  @passengers
end

#property_phone_numberObject

The phone number of the lodging location.



9882
9883
9884
# File 'lib/stripe/resources/payment_intent.rb', line 9882

def property_phone_number
  @property_phone_number
end

#room_classObject

The room class for this purchase.



9884
9885
9886
# File 'lib/stripe/resources/payment_intent.rb', line 9884

def room_class
  @room_class
end

#room_nightsObject

The number of room nights



9886
9887
9888
# File 'lib/stripe/resources/payment_intent.rb', line 9886

def room_nights
  @room_nights
end

#total_room_tax_amountObject

The total tax amount associating with the room reservation.



9888
9889
9890
# File 'lib/stripe/resources/payment_intent.rb', line 9888

def total_room_tax_amount
  @total_room_tax_amount
end

#total_tax_amountObject

The total tax amount



9890
9891
9892
# File 'lib/stripe/resources/payment_intent.rb', line 9890

def total_tax_amount
  @total_tax_amount
end