Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address, Affiliate, Delivery, Passenger
Instance Attribute Summary collapse
-
#address ⇒ Object
The lodging location’s address.
-
#adults ⇒ Object
The number of adults on the booking.
-
#affiliate ⇒ Object
Affiliate details for this purchase.
-
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
-
#category ⇒ Object
The lodging category.
-
#checkin_at ⇒ Object
Loding check-in time.
-
#checkout_at ⇒ Object
Lodging check-out time.
-
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
-
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
-
#delivery ⇒ Object
Delivery details for this purchase.
-
#extra_charges ⇒ Object
List of additional charges being billed.
-
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
-
#name ⇒ Object
The name of the lodging location.
-
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
-
#number_of_rooms ⇒ Object
The number of rooms on the booking.
-
#passengers ⇒ Object
The details of the passengers in the travel reservation.
-
#property_phone_number ⇒ Object
The phone number of the lodging location.
-
#room_class ⇒ Object
The room class for this purchase.
-
#room_nights ⇒ Object
The number of room nights.
-
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
-
#total_tax_amount ⇒ Object
The total tax amount.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil) ⇒ Lodging
Returns a new instance of Lodging.
11313 11314 11315 11316 11317 11318 11319 11320 11321 11322 11323 11324 11325 11326 11327 11328 11329 11330 11331 11332 11333 11334 11335 11336 11337 11338 11339 11340 11341 11342 11343 11344 11345 11346 11347 11348 11349 11350 11351 11352 11353 11354 11355 11356 11357 |
# File 'lib/stripe/resources/payment_intent.rb', line 11313 def initialize( address: nil, adults: nil, affiliate: nil, booking_number: nil, category: nil, checkin_at: nil, checkout_at: nil, customer_service_phone_number: nil, daily_room_rate_amount: nil, delivery: nil, extra_charges: nil, fire_safety_act_compliance: nil, name: nil, no_show: nil, number_of_rooms: nil, passengers: nil, property_phone_number: nil, room_class: nil, room_nights: nil, total_room_tax_amount: nil, total_tax_amount: nil ) @address = address @adults = adults @affiliate = affiliate @booking_number = booking_number @category = category @checkin_at = checkin_at @checkout_at = checkout_at @customer_service_phone_number = customer_service_phone_number @daily_room_rate_amount = daily_room_rate_amount @delivery = delivery @extra_charges = extra_charges @fire_safety_act_compliance = fire_safety_act_compliance @name = name @no_show = no_show @number_of_rooms = number_of_rooms @passengers = passengers @property_phone_number = property_phone_number @room_class = room_class @room_nights = room_nights @total_room_tax_amount = total_room_tax_amount @total_tax_amount = total_tax_amount end |
Instance Attribute Details
#address ⇒ Object
The lodging location’s address.
11251 11252 11253 |
# File 'lib/stripe/resources/payment_intent.rb', line 11251 def address @address end |
#adults ⇒ Object
The number of adults on the booking
11254 11255 11256 |
# File 'lib/stripe/resources/payment_intent.rb', line 11254 def adults @adults end |
#affiliate ⇒ Object
Affiliate details for this purchase.
11257 11258 11259 |
# File 'lib/stripe/resources/payment_intent.rb', line 11257 def affiliate @affiliate end |
#booking_number ⇒ Object
The booking number associated with the lodging reservation.
11260 11261 11262 |
# File 'lib/stripe/resources/payment_intent.rb', line 11260 def booking_number @booking_number end |
#category ⇒ Object
The lodging category
11263 11264 11265 |
# File 'lib/stripe/resources/payment_intent.rb', line 11263 def category @category end |
#checkin_at ⇒ Object
Loding check-in time. Measured in seconds since the Unix epoch.
11266 11267 11268 |
# File 'lib/stripe/resources/payment_intent.rb', line 11266 def checkin_at @checkin_at end |
#checkout_at ⇒ Object
Lodging check-out time. Measured in seconds since the Unix epoch.
11269 11270 11271 |
# File 'lib/stripe/resources/payment_intent.rb', line 11269 def checkout_at @checkout_at end |
#customer_service_phone_number ⇒ Object
The customer service phone number of the lodging company.
11272 11273 11274 |
# File 'lib/stripe/resources/payment_intent.rb', line 11272 def customer_service_phone_number @customer_service_phone_number end |
#daily_room_rate_amount ⇒ Object
The daily lodging room rate.
11275 11276 11277 |
# File 'lib/stripe/resources/payment_intent.rb', line 11275 def daily_room_rate_amount @daily_room_rate_amount end |
#delivery ⇒ Object
Delivery details for this purchase.
11278 11279 11280 |
# File 'lib/stripe/resources/payment_intent.rb', line 11278 def delivery @delivery end |
#extra_charges ⇒ Object
List of additional charges being billed.
11281 11282 11283 |
# File 'lib/stripe/resources/payment_intent.rb', line 11281 def extra_charges @extra_charges end |
#fire_safety_act_compliance ⇒ Object
Indicates whether the lodging location is compliant with the Fire Safety Act.
11284 11285 11286 |
# File 'lib/stripe/resources/payment_intent.rb', line 11284 def fire_safety_act_compliance @fire_safety_act_compliance end |
#name ⇒ Object
The name of the lodging location.
11287 11288 11289 |
# File 'lib/stripe/resources/payment_intent.rb', line 11287 def name @name end |
#no_show ⇒ Object
Indicates if the customer did not keep their booking while failing to cancel the reservation.
11290 11291 11292 |
# File 'lib/stripe/resources/payment_intent.rb', line 11290 def no_show @no_show end |
#number_of_rooms ⇒ Object
The number of rooms on the booking
11293 11294 11295 |
# File 'lib/stripe/resources/payment_intent.rb', line 11293 def number_of_rooms @number_of_rooms end |
#passengers ⇒ Object
The details of the passengers in the travel reservation
11296 11297 11298 |
# File 'lib/stripe/resources/payment_intent.rb', line 11296 def passengers @passengers end |
#property_phone_number ⇒ Object
The phone number of the lodging location.
11299 11300 11301 |
# File 'lib/stripe/resources/payment_intent.rb', line 11299 def property_phone_number @property_phone_number end |
#room_class ⇒ Object
The room class for this purchase.
11302 11303 11304 |
# File 'lib/stripe/resources/payment_intent.rb', line 11302 def room_class @room_class end |
#room_nights ⇒ Object
The number of room nights
11305 11306 11307 |
# File 'lib/stripe/resources/payment_intent.rb', line 11305 def room_nights @room_nights end |
#total_room_tax_amount ⇒ Object
The total tax amount associating with the room reservation.
11308 11309 11310 |
# File 'lib/stripe/resources/payment_intent.rb', line 11308 def total_room_tax_amount @total_room_tax_amount end |
#total_tax_amount ⇒ Object
The total tax amount
11311 11312 11313 |
# File 'lib/stripe/resources/payment_intent.rb', line 11311 def total_tax_amount @total_tax_amount end |