Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
11216 11217 11218 11219 11220 |
# File 'lib/stripe/resources/payment_intent.rb', line 11216 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
11210 11211 11212 |
# File 'lib/stripe/resources/payment_intent.rb', line 11210 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
11212 11213 11214 |
# File 'lib/stripe/resources/payment_intent.rb', line 11212 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
11214 11215 11216 |
# File 'lib/stripe/resources/payment_intent.rb', line 11214 def phone @phone end |