Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
10302 10303 10304 10305 10306 |
# File 'lib/stripe/resources/payment_intent.rb', line 10302 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
10296 10297 10298 |
# File 'lib/stripe/resources/payment_intent.rb', line 10296 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
10298 10299 10300 |
# File 'lib/stripe/resources/payment_intent.rb', line 10298 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
10300 10301 10302 |
# File 'lib/stripe/resources/payment_intent.rb', line 10300 def phone @phone end |