Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



9908
9909
9910
9911
9912
# File 'lib/stripe/resources/payment_intent.rb', line 9908

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



9902
9903
9904
# File 'lib/stripe/resources/payment_intent.rb', line 9902

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



9904
9905
9906
# File 'lib/stripe/resources/payment_intent.rb', line 9904

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



9906
9907
9908
# File 'lib/stripe/resources/payment_intent.rb', line 9906

def phone
  @phone
end