Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9908 9909 9910 9911 9912 |
# File 'lib/stripe/resources/payment_intent.rb', line 9908 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9902 9903 9904 |
# File 'lib/stripe/resources/payment_intent.rb', line 9902 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9904 9905 9906 |
# File 'lib/stripe/resources/payment_intent.rb', line 9904 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9906 9907 9908 |
# File 'lib/stripe/resources/payment_intent.rb', line 9906 def phone @phone end |