Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient

Returns a new instance of Recipient.



11224
11225
11226
11227
11228
# File 'lib/stripe/resources/payment_intent.rb', line 11224

def initialize(email: nil, name: nil, phone: nil)
  @email = email
  @name = name
  @phone = phone
end

Instance Attribute Details

#emailObject

The email of the recipient the ticket is delivered to.



11216
11217
11218
# File 'lib/stripe/resources/payment_intent.rb', line 11216

def email
  @email
end

#nameObject

The name of the recipient the ticket is delivered to.



11219
11220
11221
# File 'lib/stripe/resources/payment_intent.rb', line 11219

def name
  @name
end

#phoneObject

The phone number of the recipient the ticket is delivered to.



11222
11223
11224
# File 'lib/stripe/resources/payment_intent.rb', line 11222

def phone
  @phone
end