Class: Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentDetails::Lodging::Delivery::Recipient
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#email ⇒ Object
The email of the recipient the ticket is delivered to.
-
#name ⇒ Object
The name of the recipient the ticket is delivered to.
-
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
Instance Method Summary collapse
-
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
constructor
A new instance of Recipient.
Methods inherited from RequestParams
Constructor Details
#initialize(email: nil, name: nil, phone: nil) ⇒ Recipient
Returns a new instance of Recipient.
9824 9825 9826 9827 9828 |
# File 'lib/stripe/resources/payment_intent.rb', line 9824 def initialize(email: nil, name: nil, phone: nil) @email = email @name = name @phone = phone end |
Instance Attribute Details
#email ⇒ Object
The email of the recipient the ticket is delivered to.
9818 9819 9820 |
# File 'lib/stripe/resources/payment_intent.rb', line 9818 def email @email end |
#name ⇒ Object
The name of the recipient the ticket is delivered to.
9820 9821 9822 |
# File 'lib/stripe/resources/payment_intent.rb', line 9820 def name @name end |
#phone ⇒ Object
The phone number of the recipient the ticket is delivered to.
9822 9823 9824 |
# File 'lib/stripe/resources/payment_intent.rb', line 9822 def phone @phone end |