Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, Billie, BillingDetails, Blik, Boleto, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Grabpay, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, Mobilepay, Multibanco, NaverPay, NzBankAccount, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Pix, Promptpay, RadarOptions, RevolutPay, SamsungPay, Satispay, SepaDebit, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billie: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, grabpay: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, nz_bank_account: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, pix: nil, promptpay: nil, radar_options: nil, revolut_pay: nil, samsung_pay: nil, satispay: nil, sepa_debit: nil, sofort: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



6812
6813
6814
6815
6816
6817
6818
6819
6820
6821
6822
6823
6824
6825
6826
6827
6828
6829
6830
6831
6832
6833
6834
6835
6836
6837
6838
6839
6840
6841
6842
6843
6844
6845
6846
6847
6848
6849
6850
6851
6852
6853
6854
6855
6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
6866
6867
6868
6869
6870
6871
6872
6873
6874
6875
6876
6877
6878
6879
6880
6881
6882
6883
6884
6885
6886
6887
6888
6889
6890
6891
6892
6893
6894
6895
6896
6897
6898
6899
6900
6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
6911
6912
6913
6914
6915
6916
6917
6918
# File 'lib/stripe/resources/payment_intent.rb', line 6812

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billie: nil,
  billing_details: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  grabpay: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  nz_bank_account: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  pix: nil,
  promptpay: nil,
  radar_options: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  satispay: nil,
  sepa_debit: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  type: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billie = billie
  @billing_details = billing_details
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @grabpay = grabpay
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @nz_bank_account = 
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @pix = pix
  @promptpay = promptpay
  @radar_options = radar_options
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @satispay = satispay
  @sepa_debit = sepa_debit
  @sofort = sofort
  @swish = swish
  @twint = twint
  @type = type
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



6708
6709
6710
# File 'lib/stripe/resources/payment_intent.rb', line 6708

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



6710
6711
6712
# File 'lib/stripe/resources/payment_intent.rb', line 6710

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



6712
6713
6714
# File 'lib/stripe/resources/payment_intent.rb', line 6712

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



6714
6715
6716
# File 'lib/stripe/resources/payment_intent.rb', line 6714

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



6716
6717
6718
# File 'lib/stripe/resources/payment_intent.rb', line 6716

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



6718
6719
6720
# File 'lib/stripe/resources/payment_intent.rb', line 6718

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



6720
6721
6722
# File 'lib/stripe/resources/payment_intent.rb', line 6720

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



6722
6723
6724
# File 'lib/stripe/resources/payment_intent.rb', line 6722

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



6724
6725
6726
# File 'lib/stripe/resources/payment_intent.rb', line 6724

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



6726
6727
6728
# File 'lib/stripe/resources/payment_intent.rb', line 6726

def bancontact
  @bancontact
end

#billieObject

If this is a ‘billie` PaymentMethod, this hash contains details about the Billie payment method.



6728
6729
6730
# File 'lib/stripe/resources/payment_intent.rb', line 6728

def billie
  @billie
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



6730
6731
6732
# File 'lib/stripe/resources/payment_intent.rb', line 6730

def billing_details
  @billing_details
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



6732
6733
6734
# File 'lib/stripe/resources/payment_intent.rb', line 6732

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



6734
6735
6736
# File 'lib/stripe/resources/payment_intent.rb', line 6734

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



6736
6737
6738
# File 'lib/stripe/resources/payment_intent.rb', line 6736

def cashapp
  @cashapp
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



6738
6739
6740
# File 'lib/stripe/resources/payment_intent.rb', line 6738

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



6740
6741
6742
# File 'lib/stripe/resources/payment_intent.rb', line 6740

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



6742
6743
6744
# File 'lib/stripe/resources/payment_intent.rb', line 6742

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



6744
6745
6746
# File 'lib/stripe/resources/payment_intent.rb', line 6744

def giropay
  @giropay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



6746
6747
6748
# File 'lib/stripe/resources/payment_intent.rb', line 6746

def grabpay
  @grabpay
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



6748
6749
6750
# File 'lib/stripe/resources/payment_intent.rb', line 6748

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



6750
6751
6752
# File 'lib/stripe/resources/payment_intent.rb', line 6750

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



6752
6753
6754
# File 'lib/stripe/resources/payment_intent.rb', line 6752

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



6754
6755
6756
# File 'lib/stripe/resources/payment_intent.rb', line 6754

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



6756
6757
6758
# File 'lib/stripe/resources/payment_intent.rb', line 6756

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



6758
6759
6760
# File 'lib/stripe/resources/payment_intent.rb', line 6758

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



6760
6761
6762
# File 'lib/stripe/resources/payment_intent.rb', line 6760

def link
  @link
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



6762
6763
6764
# File 'lib/stripe/resources/payment_intent.rb', line 6762

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



6764
6765
6766
# File 'lib/stripe/resources/payment_intent.rb', line 6764

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



6766
6767
6768
# File 'lib/stripe/resources/payment_intent.rb', line 6766

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



6768
6769
6770
# File 'lib/stripe/resources/payment_intent.rb', line 6768

def naver_pay
  @naver_pay
end

#nz_bank_accountObject

If this is an nz_bank_account PaymentMethod, this hash contains details about the nz_bank_account payment method.



6770
6771
6772
# File 'lib/stripe/resources/payment_intent.rb', line 6770

def 
  @nz_bank_account
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



6772
6773
6774
# File 'lib/stripe/resources/payment_intent.rb', line 6772

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



6774
6775
6776
# File 'lib/stripe/resources/payment_intent.rb', line 6774

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



6776
6777
6778
# File 'lib/stripe/resources/payment_intent.rb', line 6776

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



6778
6779
6780
# File 'lib/stripe/resources/payment_intent.rb', line 6778

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



6780
6781
6782
# File 'lib/stripe/resources/payment_intent.rb', line 6780

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



6782
6783
6784
# File 'lib/stripe/resources/payment_intent.rb', line 6782

def paypal
  @paypal
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



6784
6785
6786
# File 'lib/stripe/resources/payment_intent.rb', line 6784

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



6786
6787
6788
# File 'lib/stripe/resources/payment_intent.rb', line 6786

def promptpay
  @promptpay
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



6788
6789
6790
# File 'lib/stripe/resources/payment_intent.rb', line 6788

def radar_options
  @radar_options
end

#revolut_payObject

If this is a ‘revolut_pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



6790
6791
6792
# File 'lib/stripe/resources/payment_intent.rb', line 6790

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



6792
6793
6794
# File 'lib/stripe/resources/payment_intent.rb', line 6792

def samsung_pay
  @samsung_pay
end

#satispayObject

If this is a ‘satispay` PaymentMethod, this hash contains details about the Satispay payment method.



6794
6795
6796
# File 'lib/stripe/resources/payment_intent.rb', line 6794

def satispay
  @satispay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



6796
6797
6798
# File 'lib/stripe/resources/payment_intent.rb', line 6796

def sepa_debit
  @sepa_debit
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



6798
6799
6800
# File 'lib/stripe/resources/payment_intent.rb', line 6798

def sofort
  @sofort
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



6800
6801
6802
# File 'lib/stripe/resources/payment_intent.rb', line 6800

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



6802
6803
6804
# File 'lib/stripe/resources/payment_intent.rb', line 6802

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



6804
6805
6806
# File 'lib/stripe/resources/payment_intent.rb', line 6804

def type
  @type
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



6806
6807
6808
# File 'lib/stripe/resources/payment_intent.rb', line 6806

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



6808
6809
6810
# File 'lib/stripe/resources/payment_intent.rb', line 6808

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



6810
6811
6812
# File 'lib/stripe/resources/payment_intent.rb', line 6810

def zip
  @zip
end