Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: AcssDebit, Affirm, AfterpayClearpay, Alipay, Alma, AmazonPay, AuBecsDebit, BacsDebit, Bancontact, BillingDetails, Blik, Boleto, Cashapp, CustomerBalance, Eps, Fpx, Giropay, Gopay, Grabpay, IdBankTransfer, Ideal, InteracPresent, KakaoPay, Klarna, Konbini, KrCard, Link, MbWay, Mobilepay, Multibanco, NaverPay, Oxxo, P24, PayByBank, Payco, Paynow, Paypal, Payto, Pix, Promptpay, Qris, RadarOptions, Rechnung, RevolutPay, SamsungPay, SepaDebit, Shopeepay, Sofort, Swish, Twint, UsBankAccount, WechatPay, Zip

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(acss_debit: nil, affirm: nil, afterpay_clearpay: nil, alipay: nil, allow_redisplay: nil, alma: nil, amazon_pay: nil, au_becs_debit: nil, bacs_debit: nil, bancontact: nil, billing_details: nil, blik: nil, boleto: nil, cashapp: nil, customer_balance: nil, eps: nil, fpx: nil, giropay: nil, gopay: nil, grabpay: nil, id_bank_transfer: nil, ideal: nil, interac_present: nil, kakao_pay: nil, klarna: nil, konbini: nil, kr_card: nil, link: nil, mb_way: nil, metadata: nil, mobilepay: nil, multibanco: nil, naver_pay: nil, oxxo: nil, p24: nil, pay_by_bank: nil, payco: nil, paynow: nil, paypal: nil, payto: nil, pix: nil, promptpay: nil, qris: nil, radar_options: nil, rechnung: nil, revolut_pay: nil, samsung_pay: nil, sepa_debit: nil, shopeepay: nil, sofort: nil, swish: nil, twint: nil, type: nil, us_bank_account: nil, wechat_pay: nil, zip: nil) ⇒ PaymentMethodData

Returns a new instance of PaymentMethodData.



10585
10586
10587
10588
10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
10602
10603
10604
10605
10606
10607
10608
10609
10610
10611
10612
10613
10614
10615
10616
10617
10618
10619
10620
10621
10622
10623
10624
10625
10626
10627
10628
10629
10630
10631
10632
10633
10634
10635
10636
10637
10638
10639
10640
10641
10642
10643
10644
10645
10646
10647
10648
10649
10650
10651
10652
10653
10654
10655
10656
10657
10658
10659
10660
10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
10693
10694
10695
10696
10697
10698
10699
# File 'lib/stripe/resources/payment_intent.rb', line 10585

def initialize(
  acss_debit: nil,
  affirm: nil,
  afterpay_clearpay: nil,
  alipay: nil,
  allow_redisplay: nil,
  alma: nil,
  amazon_pay: nil,
  au_becs_debit: nil,
  bacs_debit: nil,
  bancontact: nil,
  billing_details: nil,
  blik: nil,
  boleto: nil,
  cashapp: nil,
  customer_balance: nil,
  eps: nil,
  fpx: nil,
  giropay: nil,
  gopay: nil,
  grabpay: nil,
  id_bank_transfer: nil,
  ideal: nil,
  interac_present: nil,
  kakao_pay: nil,
  klarna: nil,
  konbini: nil,
  kr_card: nil,
  link: nil,
  mb_way: nil,
  metadata: nil,
  mobilepay: nil,
  multibanco: nil,
  naver_pay: nil,
  oxxo: nil,
  p24: nil,
  pay_by_bank: nil,
  payco: nil,
  paynow: nil,
  paypal: nil,
  payto: nil,
  pix: nil,
  promptpay: nil,
  qris: nil,
  radar_options: nil,
  rechnung: nil,
  revolut_pay: nil,
  samsung_pay: nil,
  sepa_debit: nil,
  shopeepay: nil,
  sofort: nil,
  swish: nil,
  twint: nil,
  type: nil,
  us_bank_account: nil,
  wechat_pay: nil,
  zip: nil
)
  @acss_debit = acss_debit
  @affirm = affirm
  @afterpay_clearpay = afterpay_clearpay
  @alipay = alipay
  @allow_redisplay = allow_redisplay
  @alma = alma
  @amazon_pay = amazon_pay
  @au_becs_debit = au_becs_debit
  @bacs_debit = bacs_debit
  @bancontact = bancontact
  @billing_details = billing_details
  @blik = blik
  @boleto = boleto
  @cashapp = cashapp
  @customer_balance = customer_balance
  @eps = eps
  @fpx = fpx
  @giropay = giropay
  @gopay = gopay
  @grabpay = grabpay
  @id_bank_transfer = id_bank_transfer
  @ideal = ideal
  @interac_present = interac_present
  @kakao_pay = kakao_pay
  @klarna = klarna
  @konbini = konbini
  @kr_card = kr_card
  @link = link
  @mb_way = mb_way
  @metadata = 
  @mobilepay = mobilepay
  @multibanco = multibanco
  @naver_pay = naver_pay
  @oxxo = oxxo
  @p24 = p24
  @pay_by_bank = pay_by_bank
  @payco = payco
  @paynow = paynow
  @paypal = paypal
  @payto = payto
  @pix = pix
  @promptpay = promptpay
  @qris = qris
  @radar_options = radar_options
  @rechnung = rechnung
  @revolut_pay = revolut_pay
  @samsung_pay = samsung_pay
  @sepa_debit = sepa_debit
  @shopeepay = shopeepay
  @sofort = sofort
  @swish = swish
  @twint = twint
  @type = type
  @us_bank_account = 
  @wechat_pay = wechat_pay
  @zip = zip
end

Instance Attribute Details

#acss_debitObject

If this is an ‘acss_debit` PaymentMethod, this hash contains details about the ACSS Debit payment method.



10473
10474
10475
# File 'lib/stripe/resources/payment_intent.rb', line 10473

def acss_debit
  @acss_debit
end

#affirmObject

If this is an ‘affirm` PaymentMethod, this hash contains details about the Affirm payment method.



10475
10476
10477
# File 'lib/stripe/resources/payment_intent.rb', line 10475

def affirm
  @affirm
end

#afterpay_clearpayObject

If this is an ‘AfterpayClearpay` PaymentMethod, this hash contains details about the AfterpayClearpay payment method.



10477
10478
10479
# File 'lib/stripe/resources/payment_intent.rb', line 10477

def afterpay_clearpay
  @afterpay_clearpay
end

#alipayObject

If this is an ‘Alipay` PaymentMethod, this hash contains details about the Alipay payment method.



10479
10480
10481
# File 'lib/stripe/resources/payment_intent.rb', line 10479

def alipay
  @alipay
end

#allow_redisplayObject

This field indicates whether this payment method can be shown again to its customer in a checkout flow. Stripe products such as Checkout and Elements use this field to determine whether a payment method can be shown as a saved payment method in a checkout flow. The field defaults to ‘unspecified`.



10481
10482
10483
# File 'lib/stripe/resources/payment_intent.rb', line 10481

def allow_redisplay
  @allow_redisplay
end

#almaObject

If this is a Alma PaymentMethod, this hash contains details about the Alma payment method.



10483
10484
10485
# File 'lib/stripe/resources/payment_intent.rb', line 10483

def alma
  @alma
end

#amazon_payObject

If this is a AmazonPay PaymentMethod, this hash contains details about the AmazonPay payment method.



10485
10486
10487
# File 'lib/stripe/resources/payment_intent.rb', line 10485

def amazon_pay
  @amazon_pay
end

#au_becs_debitObject

If this is an ‘au_becs_debit` PaymentMethod, this hash contains details about the bank account.



10487
10488
10489
# File 'lib/stripe/resources/payment_intent.rb', line 10487

def au_becs_debit
  @au_becs_debit
end

#bacs_debitObject

If this is a ‘bacs_debit` PaymentMethod, this hash contains details about the Bacs Direct Debit bank account.



10489
10490
10491
# File 'lib/stripe/resources/payment_intent.rb', line 10489

def bacs_debit
  @bacs_debit
end

#bancontactObject

If this is a ‘bancontact` PaymentMethod, this hash contains details about the Bancontact payment method.



10491
10492
10493
# File 'lib/stripe/resources/payment_intent.rb', line 10491

def bancontact
  @bancontact
end

#billing_detailsObject

Billing information associated with the PaymentMethod that may be used or required by particular types of payment methods.



10493
10494
10495
# File 'lib/stripe/resources/payment_intent.rb', line 10493

def billing_details
  @billing_details
end

#blikObject

If this is a ‘blik` PaymentMethod, this hash contains details about the BLIK payment method.



10495
10496
10497
# File 'lib/stripe/resources/payment_intent.rb', line 10495

def blik
  @blik
end

#boletoObject

If this is a ‘boleto` PaymentMethod, this hash contains details about the Boleto payment method.



10497
10498
10499
# File 'lib/stripe/resources/payment_intent.rb', line 10497

def boleto
  @boleto
end

#cashappObject

If this is a ‘cashapp` PaymentMethod, this hash contains details about the Cash App Pay payment method.



10499
10500
10501
# File 'lib/stripe/resources/payment_intent.rb', line 10499

def cashapp
  @cashapp
end

#customer_balanceObject

If this is a ‘customer_balance` PaymentMethod, this hash contains details about the CustomerBalance payment method.



10501
10502
10503
# File 'lib/stripe/resources/payment_intent.rb', line 10501

def customer_balance
  @customer_balance
end

#epsObject

If this is an ‘eps` PaymentMethod, this hash contains details about the EPS payment method.



10503
10504
10505
# File 'lib/stripe/resources/payment_intent.rb', line 10503

def eps
  @eps
end

#fpxObject

If this is an ‘fpx` PaymentMethod, this hash contains details about the FPX payment method.



10505
10506
10507
# File 'lib/stripe/resources/payment_intent.rb', line 10505

def fpx
  @fpx
end

#giropayObject

If this is a ‘giropay` PaymentMethod, this hash contains details about the Giropay payment method.



10507
10508
10509
# File 'lib/stripe/resources/payment_intent.rb', line 10507

def giropay
  @giropay
end

#gopayObject

If this is a Gopay PaymentMethod, this hash contains details about the Gopay payment method.



10509
10510
10511
# File 'lib/stripe/resources/payment_intent.rb', line 10509

def gopay
  @gopay
end

#grabpayObject

If this is a ‘grabpay` PaymentMethod, this hash contains details about the GrabPay payment method.



10511
10512
10513
# File 'lib/stripe/resources/payment_intent.rb', line 10511

def grabpay
  @grabpay
end

#id_bank_transferObject

If this is an ‘IdBankTransfer` PaymentMethod, this hash contains details about the IdBankTransfer payment method.



10513
10514
10515
# File 'lib/stripe/resources/payment_intent.rb', line 10513

def id_bank_transfer
  @id_bank_transfer
end

#idealObject

If this is an ‘ideal` PaymentMethod, this hash contains details about the iDEAL payment method.



10515
10516
10517
# File 'lib/stripe/resources/payment_intent.rb', line 10515

def ideal
  @ideal
end

#interac_presentObject

If this is an ‘interac_present` PaymentMethod, this hash contains details about the Interac Present payment method.



10517
10518
10519
# File 'lib/stripe/resources/payment_intent.rb', line 10517

def interac_present
  @interac_present
end

#kakao_payObject

If this is a ‘kakao_pay` PaymentMethod, this hash contains details about the Kakao Pay payment method.



10519
10520
10521
# File 'lib/stripe/resources/payment_intent.rb', line 10519

def kakao_pay
  @kakao_pay
end

#klarnaObject

If this is a ‘klarna` PaymentMethod, this hash contains details about the Klarna payment method.



10521
10522
10523
# File 'lib/stripe/resources/payment_intent.rb', line 10521

def klarna
  @klarna
end

#konbiniObject

If this is a ‘konbini` PaymentMethod, this hash contains details about the Konbini payment method.



10523
10524
10525
# File 'lib/stripe/resources/payment_intent.rb', line 10523

def konbini
  @konbini
end

#kr_cardObject

If this is a ‘kr_card` PaymentMethod, this hash contains details about the Korean Card payment method.



10525
10526
10527
# File 'lib/stripe/resources/payment_intent.rb', line 10525

def kr_card
  @kr_card
end

If this is an ‘Link` PaymentMethod, this hash contains details about the Link payment method.



10527
10528
10529
# File 'lib/stripe/resources/payment_intent.rb', line 10527

def link
  @link
end

#mb_wayObject

If this is a MB WAY PaymentMethod, this hash contains details about the MB WAY payment method.



10529
10530
10531
# File 'lib/stripe/resources/payment_intent.rb', line 10529

def mb_way
  @mb_way
end

#metadataObject

Set of [key-value pairs](stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to ‘metadata`.



10531
10532
10533
# File 'lib/stripe/resources/payment_intent.rb', line 10531

def 
  @metadata
end

#mobilepayObject

If this is a ‘mobilepay` PaymentMethod, this hash contains details about the MobilePay payment method.



10533
10534
10535
# File 'lib/stripe/resources/payment_intent.rb', line 10533

def mobilepay
  @mobilepay
end

#multibancoObject

If this is a ‘multibanco` PaymentMethod, this hash contains details about the Multibanco payment method.



10535
10536
10537
# File 'lib/stripe/resources/payment_intent.rb', line 10535

def multibanco
  @multibanco
end

If this is a ‘naver_pay` PaymentMethod, this hash contains details about the Naver Pay payment method.



10537
10538
10539
# File 'lib/stripe/resources/payment_intent.rb', line 10537

def naver_pay
  @naver_pay
end

#oxxoObject

If this is an ‘oxxo` PaymentMethod, this hash contains details about the OXXO payment method.



10539
10540
10541
# File 'lib/stripe/resources/payment_intent.rb', line 10539

def oxxo
  @oxxo
end

#p24Object

If this is a ‘p24` PaymentMethod, this hash contains details about the P24 payment method.



10541
10542
10543
# File 'lib/stripe/resources/payment_intent.rb', line 10541

def p24
  @p24
end

#pay_by_bankObject

If this is a ‘pay_by_bank` PaymentMethod, this hash contains details about the PayByBank payment method.



10543
10544
10545
# File 'lib/stripe/resources/payment_intent.rb', line 10543

def pay_by_bank
  @pay_by_bank
end

#paycoObject

If this is a ‘payco` PaymentMethod, this hash contains details about the PAYCO payment method.



10545
10546
10547
# File 'lib/stripe/resources/payment_intent.rb', line 10545

def payco
  @payco
end

#paynowObject

If this is a ‘paynow` PaymentMethod, this hash contains details about the PayNow payment method.



10547
10548
10549
# File 'lib/stripe/resources/payment_intent.rb', line 10547

def paynow
  @paynow
end

#paypalObject

If this is a ‘paypal` PaymentMethod, this hash contains details about the PayPal payment method.



10549
10550
10551
# File 'lib/stripe/resources/payment_intent.rb', line 10549

def paypal
  @paypal
end

#paytoObject

If this is a ‘payto` PaymentMethod, this hash contains details about the PayTo payment method.



10551
10552
10553
# File 'lib/stripe/resources/payment_intent.rb', line 10551

def payto
  @payto
end

#pixObject

If this is a ‘pix` PaymentMethod, this hash contains details about the Pix payment method.



10553
10554
10555
# File 'lib/stripe/resources/payment_intent.rb', line 10553

def pix
  @pix
end

#promptpayObject

If this is a ‘promptpay` PaymentMethod, this hash contains details about the PromptPay payment method.



10555
10556
10557
# File 'lib/stripe/resources/payment_intent.rb', line 10555

def promptpay
  @promptpay
end

#qrisObject

If this is a ‘qris` PaymentMethod, this hash contains details about the QRIS payment method.



10557
10558
10559
# File 'lib/stripe/resources/payment_intent.rb', line 10557

def qris
  @qris
end

#radar_optionsObject

Options to configure Radar. See [Radar Session](stripe.com/docs/radar/radar-session) for more information.



10559
10560
10561
# File 'lib/stripe/resources/payment_intent.rb', line 10559

def radar_options
  @radar_options
end

#rechnungObject

If this is a ‘rechnung` PaymentMethod, this hash contains details about the Rechnung payment method.



10561
10562
10563
# File 'lib/stripe/resources/payment_intent.rb', line 10561

def rechnung
  @rechnung
end

#revolut_payObject

If this is a ‘Revolut Pay` PaymentMethod, this hash contains details about the Revolut Pay payment method.



10563
10564
10565
# File 'lib/stripe/resources/payment_intent.rb', line 10563

def revolut_pay
  @revolut_pay
end

#samsung_payObject

If this is a ‘samsung_pay` PaymentMethod, this hash contains details about the SamsungPay payment method.



10565
10566
10567
# File 'lib/stripe/resources/payment_intent.rb', line 10565

def samsung_pay
  @samsung_pay
end

#sepa_debitObject

If this is a ‘sepa_debit` PaymentMethod, this hash contains details about the SEPA debit bank account.



10567
10568
10569
# File 'lib/stripe/resources/payment_intent.rb', line 10567

def sepa_debit
  @sepa_debit
end

#shopeepayObject

If this is a Shopeepay PaymentMethod, this hash contains details about the Shopeepay payment method.



10569
10570
10571
# File 'lib/stripe/resources/payment_intent.rb', line 10569

def shopeepay
  @shopeepay
end

#sofortObject

If this is a ‘sofort` PaymentMethod, this hash contains details about the SOFORT payment method.



10571
10572
10573
# File 'lib/stripe/resources/payment_intent.rb', line 10571

def sofort
  @sofort
end

#swishObject

If this is a ‘swish` PaymentMethod, this hash contains details about the Swish payment method.



10573
10574
10575
# File 'lib/stripe/resources/payment_intent.rb', line 10573

def swish
  @swish
end

#twintObject

If this is a TWINT PaymentMethod, this hash contains details about the TWINT payment method.



10575
10576
10577
# File 'lib/stripe/resources/payment_intent.rb', line 10575

def twint
  @twint
end

#typeObject

The type of the PaymentMethod. An additional hash is included on the PaymentMethod with a name matching this value. It contains additional information specific to the PaymentMethod type.



10577
10578
10579
# File 'lib/stripe/resources/payment_intent.rb', line 10577

def type
  @type
end

#us_bank_accountObject

If this is an ‘us_bank_account` PaymentMethod, this hash contains details about the US bank account payment method.



10579
10580
10581
# File 'lib/stripe/resources/payment_intent.rb', line 10579

def 
  @us_bank_account
end

#wechat_payObject

If this is an ‘wechat_pay` PaymentMethod, this hash contains details about the wechat_pay payment method.



10581
10582
10583
# File 'lib/stripe/resources/payment_intent.rb', line 10581

def wechat_pay
  @wechat_pay
end

#zipObject

If this is a ‘zip` PaymentMethod, this hash contains details about the Zip payment method.



10583
10584
10585
# File 'lib/stripe/resources/payment_intent.rb', line 10583

def zip
  @zip
end