Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::BacsDebit
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::BacsDebit
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
-
#sort_code ⇒ Object
Sort code of the bank account.
Instance Method Summary collapse
-
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
constructor
A new instance of BacsDebit.
Methods inherited from RequestParams
Constructor Details
#initialize(account_number: nil, sort_code: nil) ⇒ BacsDebit
Returns a new instance of BacsDebit.
6325 6326 6327 6328 |
# File 'lib/stripe/resources/payment_intent.rb', line 6325 def initialize(account_number: nil, sort_code: nil) @account_number = account_number @sort_code = sort_code end |
Instance Attribute Details
#account_number ⇒ Object
Account number of the bank account that the funds will be debited from.
6321 6322 6323 |
# File 'lib/stripe/resources/payment_intent.rb', line 6321 def account_number @account_number end |
#sort_code ⇒ Object
Sort code of the bank account. (e.g., ‘10-20-30`)
6323 6324 6325 |
# File 'lib/stripe/resources/payment_intent.rb', line 6323 def sort_code @sort_code end |