Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
11755 11756 11757 11758 11759 11760 11761 11762 11763 11764 11765 11766 11767 11768 11769 |
# File 'lib/stripe/resources/payment_intent.rb', line 11755 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
11743 11744 11745 |
# File 'lib/stripe/resources/payment_intent.rb', line 11743 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
11745 11746 11747 |
# File 'lib/stripe/resources/payment_intent.rb', line 11745 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
11747 11748 11749 |
# File 'lib/stripe/resources/payment_intent.rb', line 11747 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
11749 11750 11751 |
# File 'lib/stripe/resources/payment_intent.rb', line 11749 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
11751 11752 11753 |
# File 'lib/stripe/resources/payment_intent.rb', line 11751 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
11753 11754 11755 |
# File 'lib/stripe/resources/payment_intent.rb', line 11753 def suffix @suffix end |