Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
13136 13137 13138 13139 13140 13141 13142 13143 13144 13145 13146 13147 13148 13149 13150 |
# File 'lib/stripe/resources/payment_intent.rb', line 13136 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
13124 13125 13126 |
# File 'lib/stripe/resources/payment_intent.rb', line 13124 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
13126 13127 13128 |
# File 'lib/stripe/resources/payment_intent.rb', line 13126 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
13128 13129 13130 |
# File 'lib/stripe/resources/payment_intent.rb', line 13128 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
13130 13131 13132 |
# File 'lib/stripe/resources/payment_intent.rb', line 13130 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
13132 13133 13134 |
# File 'lib/stripe/resources/payment_intent.rb', line 13132 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
13134 13135 13136 |
# File 'lib/stripe/resources/payment_intent.rb', line 13134 def suffix @suffix end |