Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



6727
6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
6741
# File 'lib/stripe/resources/payment_intent.rb', line 6727

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



6715
6716
6717
# File 'lib/stripe/resources/payment_intent.rb', line 6715

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



6717
6718
6719
# File 'lib/stripe/resources/payment_intent.rb', line 6717

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



6719
6720
6721
# File 'lib/stripe/resources/payment_intent.rb', line 6719

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



6721
6722
6723
# File 'lib/stripe/resources/payment_intent.rb', line 6721

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



6723
6724
6725
# File 'lib/stripe/resources/payment_intent.rb', line 6723

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



6725
6726
6727
# File 'lib/stripe/resources/payment_intent.rb', line 6725

def suffix
  @suffix
end