Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
6727 6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 6741 |
# File 'lib/stripe/resources/payment_intent.rb', line 6727 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
6715 6716 6717 |
# File 'lib/stripe/resources/payment_intent.rb', line 6715 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
6717 6718 6719 |
# File 'lib/stripe/resources/payment_intent.rb', line 6717 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
6719 6720 6721 |
# File 'lib/stripe/resources/payment_intent.rb', line 6719 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
6721 6722 6723 |
# File 'lib/stripe/resources/payment_intent.rb', line 6721 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
6723 6724 6725 |
# File 'lib/stripe/resources/payment_intent.rb', line 6723 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
6725 6726 6727 |
# File 'lib/stripe/resources/payment_intent.rb', line 6725 def suffix @suffix end |