Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



11629
11630
11631
11632
11633
11634
11635
11636
11637
11638
11639
11640
11641
11642
11643
# File 'lib/stripe/resources/payment_intent.rb', line 11629

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



11617
11618
11619
# File 'lib/stripe/resources/payment_intent.rb', line 11617

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



11619
11620
11621
# File 'lib/stripe/resources/payment_intent.rb', line 11619

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



11621
11622
11623
# File 'lib/stripe/resources/payment_intent.rb', line 11621

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



11623
11624
11625
# File 'lib/stripe/resources/payment_intent.rb', line 11623

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



11625
11626
11627
# File 'lib/stripe/resources/payment_intent.rb', line 11625

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



11627
11628
11629
# File 'lib/stripe/resources/payment_intent.rb', line 11627

def suffix
  @suffix
end