Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
6705 6706 6707 6708 6709 6710 6711 6712 6713 6714 6715 6716 6717 6718 6719 |
# File 'lib/stripe/resources/payment_intent.rb', line 6705 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
6693 6694 6695 |
# File 'lib/stripe/resources/payment_intent.rb', line 6693 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
6695 6696 6697 |
# File 'lib/stripe/resources/payment_intent.rb', line 6695 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
6697 6698 6699 |
# File 'lib/stripe/resources/payment_intent.rb', line 6697 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
6699 6700 6701 |
# File 'lib/stripe/resources/payment_intent.rb', line 6699 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
6701 6702 6703 |
# File 'lib/stripe/resources/payment_intent.rb', line 6701 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
6703 6704 6705 |
# File 'lib/stripe/resources/payment_intent.rb', line 6703 def suffix @suffix end |