Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
11005 11006 11007 11008 11009 11010 11011 11012 11013 11014 11015 11016 11017 11018 11019 |
# File 'lib/stripe/resources/payment_intent.rb', line 11005 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
10993 10994 10995 |
# File 'lib/stripe/resources/payment_intent.rb', line 10993 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
10995 10996 10997 |
# File 'lib/stripe/resources/payment_intent.rb', line 10995 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
10997 10998 10999 |
# File 'lib/stripe/resources/payment_intent.rb', line 10997 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
10999 11000 11001 |
# File 'lib/stripe/resources/payment_intent.rb', line 10999 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
11001 11002 11003 |
# File 'lib/stripe/resources/payment_intent.rb', line 11001 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
11003 11004 11005 |
# File 'lib/stripe/resources/payment_intent.rb', line 11003 def suffix @suffix end |