Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



6705
6706
6707
6708
6709
6710
6711
6712
6713
6714
6715
6716
6717
6718
6719
# File 'lib/stripe/resources/payment_intent.rb', line 6705

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



6693
6694
6695
# File 'lib/stripe/resources/payment_intent.rb', line 6693

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



6695
6696
6697
# File 'lib/stripe/resources/payment_intent.rb', line 6695

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



6697
6698
6699
# File 'lib/stripe/resources/payment_intent.rb', line 6697

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



6699
6700
6701
# File 'lib/stripe/resources/payment_intent.rb', line 6699

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



6701
6702
6703
# File 'lib/stripe/resources/payment_intent.rb', line 6701

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



6703
6704
6705
# File 'lib/stripe/resources/payment_intent.rb', line 6703

def suffix
  @suffix
end