Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



10787
10788
10789
10790
10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
# File 'lib/stripe/resources/payment_intent.rb', line 10787

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



10775
10776
10777
# File 'lib/stripe/resources/payment_intent.rb', line 10775

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



10777
10778
10779
# File 'lib/stripe/resources/payment_intent.rb', line 10777

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



10779
10780
10781
# File 'lib/stripe/resources/payment_intent.rb', line 10779

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



10781
10782
10783
# File 'lib/stripe/resources/payment_intent.rb', line 10781

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



10783
10784
10785
# File 'lib/stripe/resources/payment_intent.rb', line 10783

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



10785
10786
10787
# File 'lib/stripe/resources/payment_intent.rb', line 10785

def suffix
  @suffix
end