Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
10787 10788 10789 10790 10791 10792 10793 10794 10795 10796 10797 10798 10799 10800 10801 |
# File 'lib/stripe/resources/payment_intent.rb', line 10787 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
10775 10776 10777 |
# File 'lib/stripe/resources/payment_intent.rb', line 10775 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
10777 10778 10779 |
# File 'lib/stripe/resources/payment_intent.rb', line 10777 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
10779 10780 10781 |
# File 'lib/stripe/resources/payment_intent.rb', line 10779 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
10781 10782 10783 |
# File 'lib/stripe/resources/payment_intent.rb', line 10781 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
10783 10784 10785 |
# File 'lib/stripe/resources/payment_intent.rb', line 10783 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
10785 10786 10787 |
# File 'lib/stripe/resources/payment_intent.rb', line 10785 def suffix @suffix end |