Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
6487 6488 6489 6490 6491 6492 6493 6494 6495 6496 6497 6498 6499 6500 6501 |
# File 'lib/stripe/resources/payment_intent.rb', line 6487 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
6475 6476 6477 |
# File 'lib/stripe/resources/payment_intent.rb', line 6475 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
6477 6478 6479 |
# File 'lib/stripe/resources/payment_intent.rb', line 6477 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
6479 6480 6481 |
# File 'lib/stripe/resources/payment_intent.rb', line 6479 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
6481 6482 6483 |
# File 'lib/stripe/resources/payment_intent.rb', line 6481 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
6483 6484 6485 |
# File 'lib/stripe/resources/payment_intent.rb', line 6483 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
6485 6486 6487 |
# File 'lib/stripe/resources/payment_intent.rb', line 6485 def suffix @suffix end |