Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



6586
6587
6588
6589
6590
6591
6592
6593
6594
6595
6596
6597
6598
6599
6600
# File 'lib/stripe/resources/payment_intent.rb', line 6586

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



6574
6575
6576
# File 'lib/stripe/resources/payment_intent.rb', line 6574

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



6576
6577
6578
# File 'lib/stripe/resources/payment_intent.rb', line 6576

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



6578
6579
6580
# File 'lib/stripe/resources/payment_intent.rb', line 6578

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



6580
6581
6582
# File 'lib/stripe/resources/payment_intent.rb', line 6580

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



6582
6583
6584
# File 'lib/stripe/resources/payment_intent.rb', line 6582

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



6584
6585
6586
# File 'lib/stripe/resources/payment_intent.rb', line 6584

def suffix
  @suffix
end