Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
# File 'lib/stripe/resources/payment_intent.rb', line 10671

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



10659
10660
10661
# File 'lib/stripe/resources/payment_intent.rb', line 10659

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



10661
10662
10663
# File 'lib/stripe/resources/payment_intent.rb', line 10661

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



10663
10664
10665
# File 'lib/stripe/resources/payment_intent.rb', line 10663

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



10665
10666
10667
# File 'lib/stripe/resources/payment_intent.rb', line 10665

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



10667
10668
10669
# File 'lib/stripe/resources/payment_intent.rb', line 10667

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



10669
10670
10671
# File 'lib/stripe/resources/payment_intent.rb', line 10669

def suffix
  @suffix
end