Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
10759
10760
10761
10762
10763
# File 'lib/stripe/resources/payment_intent.rb', line 10749

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



10737
10738
10739
# File 'lib/stripe/resources/payment_intent.rb', line 10737

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



10739
10740
10741
# File 'lib/stripe/resources/payment_intent.rb', line 10739

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



10741
10742
10743
# File 'lib/stripe/resources/payment_intent.rb', line 10741

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



10743
10744
10745
# File 'lib/stripe/resources/payment_intent.rb', line 10743

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



10745
10746
10747
# File 'lib/stripe/resources/payment_intent.rb', line 10745

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



10747
10748
10749
# File 'lib/stripe/resources/payment_intent.rb', line 10747

def suffix
  @suffix
end