Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_name ⇒ Object
The name on the bank account.
-
#account_number ⇒ Object
The account number for the bank account.
-
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
-
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
-
#reference ⇒ Object
Attribute for param field reference.
-
#suffix ⇒ Object
The suffix of the bank account number.
Instance Method Summary collapse
-
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
constructor
A new instance of NzBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount
Returns a new instance of NzBankAccount.
6539 6540 6541 6542 6543 6544 6545 6546 6547 6548 6549 6550 6551 6552 6553 |
# File 'lib/stripe/resources/payment_intent.rb', line 6539 def initialize( account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil ) @account_holder_name = account_holder_name @account_number = account_number @bank_code = bank_code @branch_code = branch_code @reference = reference @suffix = suffix end |
Instance Attribute Details
#account_holder_name ⇒ Object
The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.
6527 6528 6529 |
# File 'lib/stripe/resources/payment_intent.rb', line 6527 def account_holder_name @account_holder_name end |
#account_number ⇒ Object
The account number for the bank account.
6529 6530 6531 |
# File 'lib/stripe/resources/payment_intent.rb', line 6529 def account_number @account_number end |
#bank_code ⇒ Object
The numeric code for the bank account’s bank.
6531 6532 6533 |
# File 'lib/stripe/resources/payment_intent.rb', line 6531 def bank_code @bank_code end |
#branch_code ⇒ Object
The numeric code for the bank account’s bank branch.
6533 6534 6535 |
# File 'lib/stripe/resources/payment_intent.rb', line 6533 def branch_code @branch_code end |
#reference ⇒ Object
Attribute for param field reference
6535 6536 6537 |
# File 'lib/stripe/resources/payment_intent.rb', line 6535 def reference @reference end |
#suffix ⇒ Object
The suffix of the bank account number.
6537 6538 6539 |
# File 'lib/stripe/resources/payment_intent.rb', line 6537 def suffix @suffix end |