Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::NzBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(account_holder_name: nil, account_number: nil, bank_code: nil, branch_code: nil, reference: nil, suffix: nil) ⇒ NzBankAccount

Returns a new instance of NzBankAccount.



6539
6540
6541
6542
6543
6544
6545
6546
6547
6548
6549
6550
6551
6552
6553
# File 'lib/stripe/resources/payment_intent.rb', line 6539

def initialize(
  account_holder_name: nil,
  account_number: nil,
  bank_code: nil,
  branch_code: nil,
  reference: nil,
  suffix: nil
)
  @account_holder_name = 
  @account_number = 
  @bank_code = bank_code
  @branch_code = branch_code
  @reference = reference
  @suffix = suffix
end

Instance Attribute Details

#account_holder_nameObject

The name on the bank account. Only required if the account holder name is different from the name of the authorized signatory collected in the PaymentMethod’s billing details.



6527
6528
6529
# File 'lib/stripe/resources/payment_intent.rb', line 6527

def 
  @account_holder_name
end

#account_numberObject

The account number for the bank account.



6529
6530
6531
# File 'lib/stripe/resources/payment_intent.rb', line 6529

def 
  @account_number
end

#bank_codeObject

The numeric code for the bank account’s bank.



6531
6532
6533
# File 'lib/stripe/resources/payment_intent.rb', line 6531

def bank_code
  @bank_code
end

#branch_codeObject

The numeric code for the bank account’s bank branch.



6533
6534
6535
# File 'lib/stripe/resources/payment_intent.rb', line 6533

def branch_code
  @branch_code
end

#referenceObject

Attribute for param field reference



6535
6536
6537
# File 'lib/stripe/resources/payment_intent.rb', line 6535

def reference
  @reference
end

#suffixObject

The suffix of the bank account number.



6537
6538
6539
# File 'lib/stripe/resources/payment_intent.rb', line 6537

def suffix
  @suffix
end