Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
11140 11141 11142 11143 11144 11145 11146 11147 11148 11149 11150 11151 11152 |
# File 'lib/stripe/resources/payment_intent.rb', line 11140 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
11130 11131 11132 |
# File 'lib/stripe/resources/payment_intent.rb', line 11130 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
11132 11133 11134 |
# File 'lib/stripe/resources/payment_intent.rb', line 11132 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
11134 11135 11136 |
# File 'lib/stripe/resources/payment_intent.rb', line 11134 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
11136 11137 11138 |
# File 'lib/stripe/resources/payment_intent.rb', line 11136 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
11138 11139 11140 |
# File 'lib/stripe/resources/payment_intent.rb', line 11138 def routing_number @routing_number end |