Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
6786 6787 6788 6789 6790 6791 6792 6793 6794 6795 6796 6797 6798 |
# File 'lib/stripe/resources/payment_intent.rb', line 6786 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
6776 6777 6778 |
# File 'lib/stripe/resources/payment_intent.rb', line 6776 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
6778 6779 6780 |
# File 'lib/stripe/resources/payment_intent.rb', line 6778 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
6780 6781 6782 |
# File 'lib/stripe/resources/payment_intent.rb', line 6780 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
6782 6783 6784 |
# File 'lib/stripe/resources/payment_intent.rb', line 6782 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
6784 6785 6786 |
# File 'lib/stripe/resources/payment_intent.rb', line 6784 def routing_number @routing_number end |