Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
6687 6688 6689 6690 6691 6692 6693 6694 6695 6696 6697 6698 6699 |
# File 'lib/stripe/resources/payment_intent.rb', line 6687 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
6677 6678 6679 |
# File 'lib/stripe/resources/payment_intent.rb', line 6677 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
6679 6680 6681 |
# File 'lib/stripe/resources/payment_intent.rb', line 6679 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
6681 6682 6683 |
# File 'lib/stripe/resources/payment_intent.rb', line 6681 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
6683 6684 6685 |
# File 'lib/stripe/resources/payment_intent.rb', line 6683 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
6685 6686 6687 |
# File 'lib/stripe/resources/payment_intent.rb', line 6685 def routing_number @routing_number end |