Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
10828 10829 10830 10831 10832 10833 10834 10835 10836 10837 10838 10839 10840 |
# File 'lib/stripe/resources/payment_intent.rb', line 10828 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
10818 10819 10820 |
# File 'lib/stripe/resources/payment_intent.rb', line 10818 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
10820 10821 10822 |
# File 'lib/stripe/resources/payment_intent.rb', line 10820 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
10822 10823 10824 |
# File 'lib/stripe/resources/payment_intent.rb', line 10822 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
10824 10825 10826 |
# File 'lib/stripe/resources/payment_intent.rb', line 10824 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
10826 10827 10828 |
# File 'lib/stripe/resources/payment_intent.rb', line 10826 def routing_number @routing_number end |