Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
10452 10453 10454 10455 10456 10457 10458 10459 10460 10461 10462 10463 10464 |
# File 'lib/stripe/resources/payment_intent.rb', line 10452 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
10442 10443 10444 |
# File 'lib/stripe/resources/payment_intent.rb', line 10442 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
10444 10445 10446 |
# File 'lib/stripe/resources/payment_intent.rb', line 10444 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
10446 10447 10448 |
# File 'lib/stripe/resources/payment_intent.rb', line 10446 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
10448 10449 10450 |
# File 'lib/stripe/resources/payment_intent.rb', line 10448 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
10450 10451 10452 |
# File 'lib/stripe/resources/payment_intent.rb', line 10450 def routing_number @routing_number end |