Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodData::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#account_holder_type ⇒ Object
Account holder type: individual or company.
-
#account_number ⇒ Object
Account number of the bank account.
-
#account_type ⇒ Object
Account type: checkings or savings.
-
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
-
#routing_number ⇒ Object
Routing number of the bank account.
Instance Method Summary collapse
-
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
10365 10366 10367 10368 10369 10370 10371 10372 10373 10374 10375 10376 10377 |
# File 'lib/stripe/resources/payment_intent.rb', line 10365 def initialize( account_holder_type: nil, account_number: nil, account_type: nil, financial_connections_account: nil, routing_number: nil ) @account_holder_type = account_holder_type @account_number = account_number @account_type = account_type @financial_connections_account = financial_connections_account @routing_number = routing_number end |
Instance Attribute Details
#account_holder_type ⇒ Object
Account holder type: individual or company.
10355 10356 10357 |
# File 'lib/stripe/resources/payment_intent.rb', line 10355 def account_holder_type @account_holder_type end |
#account_number ⇒ Object
Account number of the bank account.
10357 10358 10359 |
# File 'lib/stripe/resources/payment_intent.rb', line 10357 def account_number @account_number end |
#account_type ⇒ Object
Account type: checkings or savings. Defaults to checking if omitted.
10359 10360 10361 |
# File 'lib/stripe/resources/payment_intent.rb', line 10359 def account_type @account_type end |
#financial_connections_account ⇒ Object
The ID of a Financial Connections Account to use as a payment method.
10361 10362 10363 |
# File 'lib/stripe/resources/payment_intent.rb', line 10361 def financial_connections_account @financial_connections_account end |
#routing_number ⇒ Object
Routing number of the bank account.
10363 10364 10365 |
# File 'lib/stripe/resources/payment_intent.rb', line 10363 def routing_number @routing_number end |