Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::AcssDebit

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: MandateOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(mandate_options: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ AcssDebit

Returns a new instance of AcssDebit.



11215
11216
11217
11218
11219
11220
11221
11222
11223
11224
11225
# File 'lib/stripe/resources/payment_intent.rb', line 11215

def initialize(
  mandate_options: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @mandate_options = mandate_options
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#mandate_optionsObject

Additional fields for Mandate creation



11199
11200
11201
# File 'lib/stripe/resources/payment_intent.rb', line 11199

def mandate_options
  @mandate_options
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



11209
11210
11211
# File 'lib/stripe/resources/payment_intent.rb', line 11209

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



11211
11212
11213
# File 'lib/stripe/resources/payment_intent.rb', line 11211

def target_date
  @target_date
end

#verification_methodObject

Bank account verification method.



11213
11214
11215
# File 'lib/stripe/resources/payment_intent.rb', line 11213

def verification_method
  @verification_method
end