Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Installments, MandateOptions, StatementDetails, ThreeDSecure
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#cvc_token ⇒ Object
A single-use ‘cvc_update` Token that represents a card CVC value.
-
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent (Mexico Only).
-
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
-
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA.
-
#network ⇒ Object
Selected network to process this PaymentIntent on.
-
#request_decremental_authorization ⇒ Object
Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.
-
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
-
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
-
#request_multicapture ⇒ Object
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
-
#request_overcapture ⇒ Object
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
-
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
-
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication).
-
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements.
-
#statement_details ⇒ Object
Statement details for this payment intent.
-
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
Instance Method Summary collapse
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil) ⇒ Card
Returns a new instance of Card.
11940 11941 11942 11943 11944 11945 11946 11947 11948 11949 11950 11951 11952 11953 11954 11955 11956 11957 11958 11959 11960 11961 11962 11963 11964 11965 11966 11967 11968 11969 11970 11971 11972 11973 11974 11975 11976 11977 11978 11979 11980 |
# File 'lib/stripe/resources/payment_intent.rb', line 11940 def initialize( capture_method: nil, cvc_token: nil, installments: nil, mandate_options: nil, moto: nil, network: nil, request_decremental_authorization: nil, request_extended_authorization: nil, request_incremental_authorization: nil, request_multicapture: nil, request_overcapture: nil, request_partial_authorization: nil, request_three_d_secure: nil, require_cvc_recollection: nil, setup_future_usage: nil, statement_descriptor_suffix_kana: nil, statement_descriptor_suffix_kanji: nil, statement_details: nil, three_d_secure: nil ) @capture_method = capture_method @cvc_token = cvc_token @installments = installments @mandate_options = @moto = moto @network = network @request_decremental_authorization = @request_extended_authorization = @request_incremental_authorization = @request_multicapture = request_multicapture @request_overcapture = request_overcapture @request_partial_authorization = @request_three_d_secure = request_three_d_secure @require_cvc_recollection = require_cvc_recollection @setup_future_usage = setup_future_usage @statement_descriptor_suffix_kana = statement_descriptor_suffix_kana @statement_descriptor_suffix_kanji = statement_descriptor_suffix_kanji @statement_details = statement_details @three_d_secure = three_d_secure end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
11889 11890 11891 |
# File 'lib/stripe/resources/payment_intent.rb', line 11889 def capture_method @capture_method end |
#cvc_token ⇒ Object
A single-use ‘cvc_update` Token that represents a card CVC value. When provided, the CVC value will be verified during the card payment attempt. This parameter can only be provided during confirmation.
11891 11892 11893 |
# File 'lib/stripe/resources/payment_intent.rb', line 11891 def cvc_token @cvc_token end |
#installments ⇒ Object
Installment configuration for payments attempted on this PaymentIntent (Mexico Only).
For more information, see the [installments integration guide](stripe.com/docs/payments/installments).
11895 11896 11897 |
# File 'lib/stripe/resources/payment_intent.rb', line 11895 def installments @installments end |
#mandate_options ⇒ Object
Configuration options for setting up an eMandate for cards issued in India.
11897 11898 11899 |
# File 'lib/stripe/resources/payment_intent.rb', line 11897 def @mandate_options end |
#moto ⇒ Object
When specified, this parameter indicates that a transaction will be marked as MOTO (Mail Order Telephone Order) and thus out of scope for SCA. This parameter can only be provided during confirmation.
11901 11902 11903 |
# File 'lib/stripe/resources/payment_intent.rb', line 11901 def moto @moto end |
#network ⇒ Object
Selected network to process this PaymentIntent on. Depends on the available networks of the card attached to the PaymentIntent. Can be only set confirm-time.
11903 11904 11905 |
# File 'lib/stripe/resources/payment_intent.rb', line 11903 def network @network end |
#request_decremental_authorization ⇒ Object
Request ability to [decrement the authorization](stripe.com/docs/payments/decremental-authorization) for this PaymentIntent.
11905 11906 11907 |
# File 'lib/stripe/resources/payment_intent.rb', line 11905 def @request_decremental_authorization end |
#request_extended_authorization ⇒ Object
Request ability to [capture beyond the standard authorization validity window](stripe.com/docs/payments/extended-authorization) for this PaymentIntent.
11907 11908 11909 |
# File 'lib/stripe/resources/payment_intent.rb', line 11907 def @request_extended_authorization end |
#request_incremental_authorization ⇒ Object
Request ability to [increment the authorization](stripe.com/docs/payments/incremental-authorization) for this PaymentIntent.
11909 11910 11911 |
# File 'lib/stripe/resources/payment_intent.rb', line 11909 def @request_incremental_authorization end |
#request_multicapture ⇒ Object
Request ability to make [multiple captures](stripe.com/docs/payments/multicapture) for this PaymentIntent.
11911 11912 11913 |
# File 'lib/stripe/resources/payment_intent.rb', line 11911 def request_multicapture @request_multicapture end |
#request_overcapture ⇒ Object
Request ability to [overcapture](stripe.com/docs/payments/overcapture) for this PaymentIntent.
11913 11914 11915 |
# File 'lib/stripe/resources/payment_intent.rb', line 11913 def request_overcapture @request_overcapture end |
#request_partial_authorization ⇒ Object
Request partial authorization on this PaymentIntent.
11915 11916 11917 |
# File 'lib/stripe/resources/payment_intent.rb', line 11915 def @request_partial_authorization end |
#request_three_d_secure ⇒ Object
We strongly recommend that you rely on our SCA Engine to automatically prompt your customers for authentication based on risk level and [other requirements](stripe.com/docs/strong-customer-authentication). However, if you wish to request 3D Secure based on logic from your own fraud engine, provide this option. If not provided, this value defaults to ‘automatic`. Read our guide on [manually requesting 3D Secure](stripe.com/docs/payments/3d-secure/authentication-flow#manual-three-ds) for more information on how this configuration interacts with Radar and our SCA Engine.
11917 11918 11919 |
# File 'lib/stripe/resources/payment_intent.rb', line 11917 def request_three_d_secure @request_three_d_secure end |
#require_cvc_recollection ⇒ Object
When enabled, using a card that is attached to a customer will require the CVC to be provided again (i.e. using the cvc_token parameter).
11919 11920 11921 |
# File 'lib/stripe/resources/payment_intent.rb', line 11919 def require_cvc_recollection @require_cvc_recollection end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
11929 11930 11931 |
# File 'lib/stripe/resources/payment_intent.rb', line 11929 def setup_future_usage @setup_future_usage end |
#statement_descriptor_suffix_kana ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kana prefix (shortened Kana descriptor) or Kana statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 22 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 22 characters.
11931 11932 11933 |
# File 'lib/stripe/resources/payment_intent.rb', line 11931 def statement_descriptor_suffix_kana @statement_descriptor_suffix_kana end |
#statement_descriptor_suffix_kanji ⇒ Object
Provides information about a card payment that customers see on their statements. Concatenated with the Kanji prefix (shortened Kanji descriptor) or Kanji statement descriptor that’s set on the account to form the complete statement descriptor. Maximum 17 characters. On card statements, the concatenation of both prefix and suffix (including separators) will appear truncated to 17 characters.
11933 11934 11935 |
# File 'lib/stripe/resources/payment_intent.rb', line 11933 def statement_descriptor_suffix_kanji @statement_descriptor_suffix_kanji end |
#statement_details ⇒ Object
Statement details for this payment intent. You can use this to override the merchant details shown on your customers’ statements.
11935 11936 11937 |
# File 'lib/stripe/resources/payment_intent.rb', line 11935 def statement_details @statement_details end |
#three_d_secure ⇒ Object
If 3D Secure authentication was performed with a third-party provider, the authentication details to use for this payment.
11938 11939 11940 |
# File 'lib/stripe/resources/payment_intent.rb', line 11938 def three_d_secure @three_d_secure end |