Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



7341
7342
7343
7344
7345
# File 'lib/stripe/resources/payment_intent.rb', line 7341

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



7334
7335
7336
# File 'lib/stripe/resources/payment_intent.rb', line 7334

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



7337
7338
7339
# File 'lib/stripe/resources/payment_intent.rb', line 7337

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



7339
7340
7341
# File 'lib/stripe/resources/payment_intent.rb', line 7339

def type
  @type
end