Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



7319
7320
7321
7322
7323
# File 'lib/stripe/resources/payment_intent.rb', line 7319

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



7312
7313
7314
# File 'lib/stripe/resources/payment_intent.rb', line 7312

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



7315
7316
7317
# File 'lib/stripe/resources/payment_intent.rb', line 7315

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`, `bonus`, or `revolving`.



7317
7318
7319
# File 'lib/stripe/resources/payment_intent.rb', line 7317

def type
  @type
end