Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



7219
7220
7221
7222
7223
# File 'lib/stripe/resources/payment_intent.rb', line 7219

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



7212
7213
7214
# File 'lib/stripe/resources/payment_intent.rb', line 7212

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



7215
7216
7217
# File 'lib/stripe/resources/payment_intent.rb', line 7215

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



7217
7218
7219
# File 'lib/stripe/resources/payment_intent.rb', line 7217

def type
  @type
end