Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



11392
11393
11394
11395
11396
# File 'lib/stripe/resources/payment_intent.rb', line 11392

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



11385
11386
11387
# File 'lib/stripe/resources/payment_intent.rb', line 11385

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



11388
11389
11390
# File 'lib/stripe/resources/payment_intent.rb', line 11388

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



11390
11391
11392
# File 'lib/stripe/resources/payment_intent.rb', line 11390

def type
  @type
end