Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::Installments::Plan

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(count: nil, interval: nil, type: nil) ⇒ Plan

Returns a new instance of Plan.



10921
10922
10923
10924
10925
# File 'lib/stripe/resources/payment_intent.rb', line 10921

def initialize(count: nil, interval: nil, type: nil)
  @count = count
  @interval = interval
  @type = type
end

Instance Attribute Details

#countObject

For ‘fixed_count` installment plans, this is required. It represents the number of installment payments your customer will make to their credit card.



10914
10915
10916
# File 'lib/stripe/resources/payment_intent.rb', line 10914

def count
  @count
end

#intervalObject

For ‘fixed_count` installment plans, this is required. It represents the interval between installment payments your customer will make to their credit card. One of `month`.



10917
10918
10919
# File 'lib/stripe/resources/payment_intent.rb', line 10917

def interval
  @interval
end

#typeObject

Type of installment plan, one of ‘fixed_count`.



10919
10920
10921
# File 'lib/stripe/resources/payment_intent.rb', line 10919

def type
  @type
end