Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



7199
7200
7201
7202
7203
7204
7205
7206
7207
7208
7209
7210
7211
7212
7213
7214
7215
7216
7217
7218
7219
# File 'lib/stripe/resources/payment_intent.rb', line 7199

def initialize(
  amount: nil,
  amount_type: nil,
  description: nil,
  end_date: nil,
  interval: nil,
  interval_count: nil,
  reference: nil,
  start_date: nil,
  supported_types: nil
)
  @amount = amount
  @amount_type = amount_type
  @description = description
  @end_date = end_date
  @interval = interval
  @interval_count = interval_count
  @reference = reference
  @start_date = start_date
  @supported_types = supported_types
end

Instance Attribute Details

#amountObject

Amount to be charged for future payments.



7181
7182
7183
# File 'lib/stripe/resources/payment_intent.rb', line 7181

def amount
  @amount
end

#amount_typeObject

One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.



7183
7184
7185
# File 'lib/stripe/resources/payment_intent.rb', line 7183

def amount_type
  @amount_type
end

#descriptionObject

A description of the mandate or subscription that is meant to be displayed to the customer.



7185
7186
7187
# File 'lib/stripe/resources/payment_intent.rb', line 7185

def description
  @description
end

#end_dateObject

End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.



7187
7188
7189
# File 'lib/stripe/resources/payment_intent.rb', line 7187

def end_date
  @end_date
end

#intervalObject

Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.



7189
7190
7191
# File 'lib/stripe/resources/payment_intent.rb', line 7189

def interval
  @interval
end

#interval_countObject

The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.



7191
7192
7193
# File 'lib/stripe/resources/payment_intent.rb', line 7191

def interval_count
  @interval_count
end

#referenceObject

Unique identifier for the mandate or subscription.



7193
7194
7195
# File 'lib/stripe/resources/payment_intent.rb', line 7193

def reference
  @reference
end

#start_dateObject

Start date of the mandate or subscription. Start date should not be lesser than yesterday.



7195
7196
7197
# File 'lib/stripe/resources/payment_intent.rb', line 7195

def start_date
  @start_date
end

#supported_typesObject

Specifies the type of mandates supported. Possible values are ‘india`.



7197
7198
7199
# File 'lib/stripe/resources/payment_intent.rb', line 7197

def supported_types
  @supported_types
end