Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount to be charged for future payments.
-
#amount_type ⇒ Object
One of ‘fixed` or `maximum`.
-
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
-
#end_date ⇒ Object
End date of the mandate or subscription.
-
#interval ⇒ Object
Specifies payment frequency.
-
#interval_count ⇒ Object
The number of intervals between payments.
-
#reference ⇒ Object
Unique identifier for the mandate or subscription.
-
#start_date ⇒ Object
Start date of the mandate or subscription.
-
#supported_types ⇒ Object
Specifies the type of mandates supported.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
12455 12456 12457 12458 12459 12460 12461 12462 12463 12464 12465 12466 12467 12468 12469 12470 12471 12472 12473 12474 12475 |
# File 'lib/stripe/resources/payment_intent.rb', line 12455 def initialize( amount: nil, amount_type: nil, description: nil, end_date: nil, interval: nil, interval_count: nil, reference: nil, start_date: nil, supported_types: nil ) @amount = amount @amount_type = amount_type @description = description @end_date = end_date @interval = interval @interval_count = interval_count @reference = reference @start_date = start_date @supported_types = supported_types end |
Instance Attribute Details
#amount ⇒ Object
Amount to be charged for future payments.
12429 12430 12431 |
# File 'lib/stripe/resources/payment_intent.rb', line 12429 def amount @amount end |
#amount_type ⇒ Object
One of ‘fixed` or `maximum`. If `fixed`, the `amount` param refers to the exact amount to be charged in future payments. If `maximum`, the amount charged can be up to the value passed for the `amount` param.
12432 12433 12434 |
# File 'lib/stripe/resources/payment_intent.rb', line 12432 def amount_type @amount_type end |
#description ⇒ Object
A description of the mandate or subscription that is meant to be displayed to the customer.
12435 12436 12437 |
# File 'lib/stripe/resources/payment_intent.rb', line 12435 def description @description end |
#end_date ⇒ Object
End date of the mandate or subscription. If not provided, the mandate will be active until canceled. If provided, end date should be after start date.
12438 12439 12440 |
# File 'lib/stripe/resources/payment_intent.rb', line 12438 def end_date @end_date end |
#interval ⇒ Object
Specifies payment frequency. One of ‘day`, `week`, `month`, `year`, or `sporadic`.
12441 12442 12443 |
# File 'lib/stripe/resources/payment_intent.rb', line 12441 def interval @interval end |
#interval_count ⇒ Object
The number of intervals between payments. For example, ‘interval=month` and `interval_count=3` indicates one payment every three months. Maximum of one year interval allowed (1 year, 12 months, or 52 weeks). This parameter is optional when `interval=sporadic`.
12444 12445 12446 |
# File 'lib/stripe/resources/payment_intent.rb', line 12444 def interval_count @interval_count end |
#reference ⇒ Object
Unique identifier for the mandate or subscription.
12447 12448 12449 |
# File 'lib/stripe/resources/payment_intent.rb', line 12447 def reference @reference end |
#start_date ⇒ Object
Start date of the mandate or subscription. Start date should not be lesser than yesterday.
12450 12451 12452 |
# File 'lib/stripe/resources/payment_intent.rb', line 12450 def start_date @start_date end |
#supported_types ⇒ Object
Specifies the type of mandates supported. Possible values are ‘india`.
12453 12454 12455 |
# File 'lib/stripe/resources/payment_intent.rb', line 12453 def supported_types @supported_types end |