Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: NetworkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure

Returns a new instance of ThreeDSecure.



11864
11865
11866
11867
11868
11869
11870
11871
11872
11873
11874
11875
11876
11877
11878
11879
11880
11881
11882
# File 'lib/stripe/resources/payment_intent.rb', line 11864

def initialize(
  ares_trans_status: nil,
  cryptogram: nil,
  electronic_commerce_indicator: nil,
  exemption_indicator: nil,
  network_options: nil,
  requestor_challenge_indicator: nil,
  transaction_id: nil,
  version: nil
)
  @ares_trans_status = ares_trans_status
  @cryptogram = cryptogram
  @electronic_commerce_indicator = electronic_commerce_indicator
  @exemption_indicator = exemption_indicator
  @network_options = network_options
  @requestor_challenge_indicator = requestor_challenge_indicator
  @transaction_id = transaction_id
  @version = version
end

Instance Attribute Details

#ares_trans_statusObject

The ‘transStatus` returned from the card Issuer’s ACS in the ARes.



11840
11841
11842
# File 'lib/stripe/resources/payment_intent.rb', line 11840

def ares_trans_status
  @ares_trans_status
end

#cryptogramObject

The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)



11845
11846
11847
# File 'lib/stripe/resources/payment_intent.rb', line 11845

def cryptogram
  @cryptogram
end

#electronic_commerce_indicatorObject

The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.



11848
11849
11850
# File 'lib/stripe/resources/payment_intent.rb', line 11848

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#exemption_indicatorObject

The exemption requested via 3DS and accepted by the issuer at authentication time.



11850
11851
11852
# File 'lib/stripe/resources/payment_intent.rb', line 11850

def exemption_indicator
  @exemption_indicator
end

#network_optionsObject

Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly



11854
11855
11856
# File 'lib/stripe/resources/payment_intent.rb', line 11854

def network_options
  @network_options
end

#requestor_challenge_indicatorObject

The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.



11857
11858
11859
# File 'lib/stripe/resources/payment_intent.rb', line 11857

def requestor_challenge_indicator
  @requestor_challenge_indicator
end

#transaction_idObject

For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).



11860
11861
11862
# File 'lib/stripe/resources/payment_intent.rb', line 11860

def transaction_id
  @transaction_id
end

#versionObject

The version of 3D Secure that was performed.



11862
11863
11864
# File 'lib/stripe/resources/payment_intent.rb', line 11862

def version
  @version
end