Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: NetworkOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ares_trans_status: nil, cryptogram: nil, electronic_commerce_indicator: nil, exemption_indicator: nil, network_options: nil, requestor_challenge_indicator: nil, transaction_id: nil, version: nil) ⇒ ThreeDSecure

Returns a new instance of ThreeDSecure.



11146
11147
11148
11149
11150
11151
11152
11153
11154
11155
11156
11157
11158
11159
11160
11161
11162
11163
11164
# File 'lib/stripe/resources/payment_intent.rb', line 11146

def initialize(
  ares_trans_status: nil,
  cryptogram: nil,
  electronic_commerce_indicator: nil,
  exemption_indicator: nil,
  network_options: nil,
  requestor_challenge_indicator: nil,
  transaction_id: nil,
  version: nil
)
  @ares_trans_status = ares_trans_status
  @cryptogram = cryptogram
  @electronic_commerce_indicator = electronic_commerce_indicator
  @exemption_indicator = exemption_indicator
  @network_options = network_options
  @requestor_challenge_indicator = requestor_challenge_indicator
  @transaction_id = transaction_id
  @version = version
end

Instance Attribute Details

#ares_trans_statusObject

The ‘transStatus` returned from the card Issuer’s ACS in the ARes.



11122
11123
11124
# File 'lib/stripe/resources/payment_intent.rb', line 11122

def ares_trans_status
  @ares_trans_status
end

#cryptogramObject

The cryptogram, also known as the “authentication value” (AAV, CAVV or AEVV). This value is 20 bytes, base64-encoded into a 28-character string. (Most 3D Secure providers will return the base64-encoded version, which is what you should specify here.)



11127
11128
11129
# File 'lib/stripe/resources/payment_intent.rb', line 11127

def cryptogram
  @cryptogram
end

#electronic_commerce_indicatorObject

The Electronic Commerce Indicator (ECI) is returned by your 3D Secure provider and indicates what degree of authentication was performed.



11130
11131
11132
# File 'lib/stripe/resources/payment_intent.rb', line 11130

def electronic_commerce_indicator
  @electronic_commerce_indicator
end

#exemption_indicatorObject

The exemption requested via 3DS and accepted by the issuer at authentication time.



11132
11133
11134
# File 'lib/stripe/resources/payment_intent.rb', line 11132

def exemption_indicator
  @exemption_indicator
end

#network_optionsObject

Network specific 3DS fields. Network specific arguments require an explicit card brand choice. The parameter ‘payment_method_options.card.network“ must be populated accordingly



11136
11137
11138
# File 'lib/stripe/resources/payment_intent.rb', line 11136

def network_options
  @network_options
end

#requestor_challenge_indicatorObject

The challenge indicator (‘threeDSRequestorChallengeInd`) which was requested in the AReq sent to the card Issuer’s ACS. A string containing 2 digits from 01-99.



11139
11140
11141
# File 'lib/stripe/resources/payment_intent.rb', line 11139

def requestor_challenge_indicator
  @requestor_challenge_indicator
end

#transaction_idObject

For 3D Secure 1, the XID. For 3D Secure 2, the Directory Server Transaction ID (dsTransID).



11142
11143
11144
# File 'lib/stripe/resources/payment_intent.rb', line 11142

def transaction_id
  @transaction_id
end

#versionObject

The version of 3D Secure that was performed.



11144
11145
11146
# File 'lib/stripe/resources/payment_intent.rb', line 11144

def version
  @version
end