Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Card::ThreeDSecure::NetworkOptions::CartesBancaires

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil) ⇒ CartesBancaires

Returns a new instance of CartesBancaires.



11513
11514
11515
11516
11517
# File 'lib/stripe/resources/payment_intent.rb', line 11513

def initialize(cb_avalgo: nil, cb_exemption: nil, cb_score: nil)
  @cb_avalgo = cb_avalgo
  @cb_exemption = cb_exemption
  @cb_score = cb_score
end

Instance Attribute Details

#cb_avalgoObject

The cryptogram calculation algorithm used by the card Issuer’s ACS to calculate the Authentication cryptogram. Also known as ‘cavvAlgorithm`. messageExtension: CB-AVALGO



11503
11504
11505
# File 'lib/stripe/resources/payment_intent.rb', line 11503

def cb_avalgo
  @cb_avalgo
end

#cb_exemptionObject

The exemption indicator returned from Cartes Bancaires in the ARes. message extension: CB-EXEMPTION; string (4 characters) This is a 3 byte bitmap (low significant byte first and most significant bit first) that has been Base64 encoded



11508
11509
11510
# File 'lib/stripe/resources/payment_intent.rb', line 11508

def cb_exemption
  @cb_exemption
end

#cb_scoreObject

The risk score returned from Cartes Bancaires in the ARes. message extension: CB-SCORE; numeric value 0-99



11511
11512
11513
# File 'lib/stripe/resources/payment_intent.rb', line 11511

def cb_score
  @cb_score
end