Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



14391
14392
14393
14394
14395
14396
14397
14398
14399
14400
14401
14402
14403
# File 'lib/stripe/resources/payment_intent.rb', line 14391

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



14381
14382
14383
# File 'lib/stripe/resources/payment_intent.rb', line 14381

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



14383
14384
14385
# File 'lib/stripe/resources/payment_intent.rb', line 14383

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



14385
14386
14387
# File 'lib/stripe/resources/payment_intent.rb', line 14385

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



14387
14388
14389
# File 'lib/stripe/resources/payment_intent.rb', line 14387

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



14389
14390
14391
# File 'lib/stripe/resources/payment_intent.rb', line 14389

def purchase_interval_count
  @purchase_interval_count
end