Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



7802
7803
7804
7805
7806
7807
7808
7809
7810
7811
7812
7813
7814
# File 'lib/stripe/resources/payment_intent.rb', line 7802

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



7792
7793
7794
# File 'lib/stripe/resources/payment_intent.rb', line 7792

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



7794
7795
7796
# File 'lib/stripe/resources/payment_intent.rb', line 7794

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



7796
7797
7798
# File 'lib/stripe/resources/payment_intent.rb', line 7796

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



7798
7799
7800
# File 'lib/stripe/resources/payment_intent.rb', line 7798

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



7800
7801
7802
# File 'lib/stripe/resources/payment_intent.rb', line 7800

def purchase_interval_count
  @purchase_interval_count
end