Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::OnDemand

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(average_amount: nil, maximum_amount: nil, minimum_amount: nil, purchase_interval: nil, purchase_interval_count: nil) ⇒ OnDemand

Returns a new instance of OnDemand.



12260
12261
12262
12263
12264
12265
12266
12267
12268
12269
12270
12271
12272
# File 'lib/stripe/resources/payment_intent.rb', line 12260

def initialize(
  average_amount: nil,
  maximum_amount: nil,
  minimum_amount: nil,
  purchase_interval: nil,
  purchase_interval_count: nil
)
  @average_amount = average_amount
  @maximum_amount = maximum_amount
  @minimum_amount = minimum_amount
  @purchase_interval = purchase_interval
  @purchase_interval_count = purchase_interval_count
end

Instance Attribute Details

#average_amountObject

Your average amount value. You can use a value across your customer base, or segment based on customer type, country, etc.



12250
12251
12252
# File 'lib/stripe/resources/payment_intent.rb', line 12250

def average_amount
  @average_amount
end

#maximum_amountObject

The maximum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



12252
12253
12254
# File 'lib/stripe/resources/payment_intent.rb', line 12252

def maximum_amount
  @maximum_amount
end

#minimum_amountObject

The lowest or minimum value you may charge a customer per purchase. You can use a value across your customer base, or segment based on customer type, country, etc.



12254
12255
12256
# File 'lib/stripe/resources/payment_intent.rb', line 12254

def minimum_amount
  @minimum_amount
end

#purchase_intervalObject

Interval at which the customer is making purchases



12256
12257
12258
# File 'lib/stripe/resources/payment_intent.rb', line 12256

def purchase_interval
  @purchase_interval
end

#purchase_interval_countObject

The number of ‘purchase_interval` between charges



12258
12259
12260
# File 'lib/stripe/resources/payment_intent.rb', line 12258

def purchase_interval_count
  @purchase_interval_count
end