Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
12922 12923 12924 12925 12926 12927 12928 12929 12930 12931 12932 12933 12934 |
# File 'lib/stripe/resources/payment_intent.rb', line 12922 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
12912 12913 12914 |
# File 'lib/stripe/resources/payment_intent.rb', line 12912 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
12914 12915 12916 |
# File 'lib/stripe/resources/payment_intent.rb', line 12914 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
12916 12917 12918 |
# File 'lib/stripe/resources/payment_intent.rb', line 12916 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
12918 12919 12920 |
# File 'lib/stripe/resources/payment_intent.rb', line 12918 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
12920 12921 12922 |
# File 'lib/stripe/resources/payment_intent.rb', line 12920 def reference @reference end |