Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: NextBilling
Instance Attribute Summary collapse
-
#interval ⇒ Object
Unit of time between subscription charges.
-
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges.
-
#name ⇒ Object
Name for subscription.
-
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
-
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app.
Instance Method Summary collapse
-
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
constructor
A new instance of Subscription.
Methods inherited from RequestParams
Constructor Details
#initialize(interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil) ⇒ Subscription
Returns a new instance of Subscription.
12298 12299 12300 12301 12302 12303 12304 12305 12306 12307 12308 12309 12310 |
# File 'lib/stripe/resources/payment_intent.rb', line 12298 def initialize( interval: nil, interval_count: nil, name: nil, next_billing: nil, reference: nil ) @interval = interval @interval_count = interval_count @name = name @next_billing = next_billing @reference = reference end |
Instance Attribute Details
#interval ⇒ Object
Unit of time between subscription charges.
12288 12289 12290 |
# File 'lib/stripe/resources/payment_intent.rb', line 12288 def interval @interval end |
#interval_count ⇒ Object
The number of intervals (specified in the ‘interval` attribute) between subscription charges. For example, `interval=month` and `interval_count=3` charges every 3 months.
12290 12291 12292 |
# File 'lib/stripe/resources/payment_intent.rb', line 12290 def interval_count @interval_count end |
#name ⇒ Object
Name for subscription.
12292 12293 12294 |
# File 'lib/stripe/resources/payment_intent.rb', line 12292 def name @name end |
#next_billing ⇒ Object
Describes the upcoming charge for this subscription.
12294 12295 12296 |
# File 'lib/stripe/resources/payment_intent.rb', line 12294 def next_billing @next_billing end |
#reference ⇒ Object
A non-customer-facing reference to correlate subscription charges in the Klarna app. Use a value that persists across subscription charges.
12296 12297 12298 |
# File 'lib/stripe/resources/payment_intent.rb', line 12296 def reference @reference end |