Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



13032
13033
13034
13035
# File 'lib/stripe/resources/payment_intent.rb', line 13032

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



13028
13029
13030
# File 'lib/stripe/resources/payment_intent.rb', line 13028

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



13030
13031
13032
# File 'lib/stripe/resources/payment_intent.rb', line 13030

def date
  @date
end