Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, date: nil) ⇒ NextBilling

Returns a new instance of NextBilling.



7824
7825
7826
7827
# File 'lib/stripe/resources/payment_intent.rb', line 7824

def initialize(amount: nil, date: nil)
  @amount = amount
  @date = date
end

Instance Attribute Details

#amountObject

The amount of the next charge for the subscription.



7820
7821
7822
# File 'lib/stripe/resources/payment_intent.rb', line 7820

def amount
  @amount
end

#dateObject

The date of the next charge for the subscription in YYYY-MM-DD format.



7822
7823
7824
# File 'lib/stripe/resources/payment_intent.rb', line 7822

def date
  @date
end