Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Klarna::Subscription::NextBilling
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
The amount of the next charge for the subscription.
-
#date ⇒ Object
The date of the next charge for the subscription in YYYY-MM-DD format.
Instance Method Summary collapse
-
#initialize(amount: nil, date: nil) ⇒ NextBilling
constructor
A new instance of NextBilling.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, date: nil) ⇒ NextBilling
Returns a new instance of NextBilling.
7824 7825 7826 7827 |
# File 'lib/stripe/resources/payment_intent.rb', line 7824 def initialize(amount: nil, date: nil) @amount = amount @date = date end |
Instance Attribute Details
#amount ⇒ Object
The amount of the next charge for the subscription.
7820 7821 7822 |
# File 'lib/stripe/resources/payment_intent.rb', line 7820 def amount @amount end |
#date ⇒ Object
The date of the next charge for the subscription in YYYY-MM-DD format.
7822 7823 7824 |
# File 'lib/stripe/resources/payment_intent.rb', line 7822 def date @date end |