Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Konbini

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(confirmation_number: nil, expires_after_days: nil, expires_at: nil, product_description: nil, setup_future_usage: nil) ⇒ Konbini

Returns a new instance of Konbini.



7890
7891
7892
7893
7894
7895
7896
7897
7898
7899
7900
7901
7902
# File 'lib/stripe/resources/payment_intent.rb', line 7890

def initialize(
  confirmation_number: nil,
  expires_after_days: nil,
  expires_at: nil,
  product_description: nil,
  setup_future_usage: nil
)
  @confirmation_number = confirmation_number
  @expires_after_days = expires_after_days
  @expires_at = expires_at
  @product_description = product_description
  @setup_future_usage = setup_future_usage
end

Instance Attribute Details

#confirmation_numberObject

An optional 10 to 11 digit numeric-only string determining the confirmation code at applicable convenience stores. Must not consist of only zeroes and could be rejected in case of insufficient uniqueness. We recommend to use the customer’s phone number.



7872
7873
7874
# File 'lib/stripe/resources/payment_intent.rb', line 7872

def confirmation_number
  @confirmation_number
end

#expires_after_daysObject

The number of calendar days (between 1 and 60) after which Konbini payment instructions will expire. For example, if a PaymentIntent is confirmed with Konbini and ‘expires_after_days` set to 2 on Monday JST, the instructions will expire on Wednesday 23:59:59 JST. Defaults to 3 days.



7874
7875
7876
# File 'lib/stripe/resources/payment_intent.rb', line 7874

def expires_after_days
  @expires_after_days
end

#expires_atObject

The timestamp at which the Konbini payment instructions will expire. Only one of ‘expires_after_days` or `expires_at` may be set.



7876
7877
7878
# File 'lib/stripe/resources/payment_intent.rb', line 7876

def expires_at
  @expires_at
end

#product_descriptionObject

A product descriptor of up to 22 characters, which will appear to customers at the convenience store.



7878
7879
7880
# File 'lib/stripe/resources/payment_intent.rb', line 7878

def product_description
  @product_description
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



7888
7889
7890
# File 'lib/stripe/resources/payment_intent.rb', line 7888

def setup_future_usage
  @setup_future_usage
end