Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Link
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Link
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
-
#persistent_token ⇒ Object
- Deprecated
-
This is a legacy parameter that no longer has any function.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
Instance Method Summary collapse
-
#initialize(capture_method: nil, persistent_token: nil, setup_future_usage: nil) ⇒ Link
constructor
A new instance of Link.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, persistent_token: nil, setup_future_usage: nil) ⇒ Link
Returns a new instance of Link.
13051 13052 13053 13054 13055 |
# File 'lib/stripe/resources/payment_intent.rb', line 13051 def initialize(capture_method: nil, persistent_token: nil, setup_future_usage: nil) @capture_method = capture_method @persistent_token = persistent_token @setup_future_usage = setup_future_usage end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds are captured from the customer’s account.
If provided, this parameter overrides the behavior of the top-level [capture_method](/api/payment_intents/update#update_payment_intent-capture_method) for this payment method type when finalizing the payment with this payment method type.
If ‘capture_method` is already set on the PaymentIntent, providing an empty value for this parameter unsets the stored value for this payment method type.
13037 13038 13039 |
# File 'lib/stripe/resources/payment_intent.rb', line 13037 def capture_method @capture_method end |
#persistent_token ⇒ Object
- Deprecated
-
This is a legacy parameter that no longer has any function.
13039 13040 13041 |
# File 'lib/stripe/resources/payment_intent.rb', line 13039 def persistent_token @persistent_token end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
13049 13050 13051 |
# File 'lib/stripe/resources/payment_intent.rb', line 13049 def setup_future_usage @setup_future_usage end |