Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: LineItem
Instance Attribute Summary collapse
-
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
-
#line_items ⇒ Object
The line items purchased by the customer.
-
#preferred_locale ⇒ Object
[Preferred locale](stripe.com/docs/payments/paypal/supported-locales) of the PayPal checkout page that the customer is redirected to.
-
#reference ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID.
-
#reference_id ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID.
-
#risk_correlation_id ⇒ Object
The risk correlation ID for an on-session payment using a saved PayPal payment method.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#subsellers ⇒ Object
The Stripe connected account IDs of the sellers on the platform for this transaction (optional).
Instance Method Summary collapse
-
#initialize(capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil) ⇒ Paypal
constructor
A new instance of Paypal.
Methods inherited from RequestParams
Constructor Details
#initialize(capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil) ⇒ Paypal
Returns a new instance of Paypal.
12681 12682 12683 12684 12685 12686 12687 12688 12689 12690 12691 12692 12693 12694 12695 12696 12697 12698 12699 |
# File 'lib/stripe/resources/payment_intent.rb', line 12681 def initialize( capture_method: nil, line_items: nil, preferred_locale: nil, reference: nil, reference_id: nil, risk_correlation_id: nil, setup_future_usage: nil, subsellers: nil ) @capture_method = capture_method @line_items = line_items @preferred_locale = preferred_locale @reference = reference @reference_id = reference_id @risk_correlation_id = risk_correlation_id @setup_future_usage = setup_future_usage @subsellers = subsellers end |
Instance Attribute Details
#capture_method ⇒ Object
Controls when the funds will be captured from the customer’s account.
12657 12658 12659 |
# File 'lib/stripe/resources/payment_intent.rb', line 12657 def capture_method @capture_method end |
#line_items ⇒ Object
The line items purchased by the customer.
12659 12660 12661 |
# File 'lib/stripe/resources/payment_intent.rb', line 12659 def line_items @line_items end |
#preferred_locale ⇒ Object
[Preferred locale](stripe.com/docs/payments/paypal/supported-locales) of the PayPal checkout page that the customer is redirected to.
12661 12662 12663 |
# File 'lib/stripe/resources/payment_intent.rb', line 12661 def preferred_locale @preferred_locale end |
#reference ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
12663 12664 12665 |
# File 'lib/stripe/resources/payment_intent.rb', line 12663 def reference @reference end |
#reference_id ⇒ Object
A reference of the PayPal transaction visible to customer which is mapped to PayPal’s invoice ID. This must be a globally unique ID if you have configured in your PayPal settings to block multiple payments per invoice ID.
12665 12666 12667 |
# File 'lib/stripe/resources/payment_intent.rb', line 12665 def reference_id @reference_id end |
#risk_correlation_id ⇒ Object
The risk correlation ID for an on-session payment using a saved PayPal payment method.
12667 12668 12669 |
# File 'lib/stripe/resources/payment_intent.rb', line 12667 def risk_correlation_id @risk_correlation_id end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
12677 12678 12679 |
# File 'lib/stripe/resources/payment_intent.rb', line 12677 def setup_future_usage @setup_future_usage end |
#subsellers ⇒ Object
The Stripe connected account IDs of the sellers on the platform for this transaction (optional). Only allowed when [separate charges and transfers](stripe.com/docs/connect/separate-charges-and-transfers) are used.
12679 12680 12681 |
# File 'lib/stripe/resources/payment_intent.rb', line 12679 def subsellers @subsellers end |