Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
14767 14768 14769 14770 14771 14772 14773 14774 14775 14776 14777 14778 14779 14780 14781 14782 14783 14784 14785 |
# File 'lib/stripe/resources/payment_intent.rb', line 14767 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
14751 14752 14753 |
# File 'lib/stripe/resources/payment_intent.rb', line 14751 def category @category end |
#description ⇒ Object
Description of the line item.
14753 14754 14755 |
# File 'lib/stripe/resources/payment_intent.rb', line 14753 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
14755 14756 14757 |
# File 'lib/stripe/resources/payment_intent.rb', line 14755 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
14757 14758 14759 |
# File 'lib/stripe/resources/payment_intent.rb', line 14757 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
14759 14760 14761 |
# File 'lib/stripe/resources/payment_intent.rb', line 14759 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
14761 14762 14763 |
# File 'lib/stripe/resources/payment_intent.rb', line 14761 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
14763 14764 14765 |
# File 'lib/stripe/resources/payment_intent.rb', line 14763 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
14765 14766 14767 |
# File 'lib/stripe/resources/payment_intent.rb', line 14765 def unit_amount @unit_amount end |