Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



13260
13261
13262
13263
13264
13265
13266
13267
13268
13269
13270
13271
13272
13273
13274
13275
13276
13277
13278
# File 'lib/stripe/resources/payment_intent.rb', line 13260

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



13244
13245
13246
# File 'lib/stripe/resources/payment_intent.rb', line 13244

def category
  @category
end

#descriptionObject

Description of the line item.



13246
13247
13248
# File 'lib/stripe/resources/payment_intent.rb', line 13246

def description
  @description
end

#nameObject

Descriptive name of the line item.



13248
13249
13250
# File 'lib/stripe/resources/payment_intent.rb', line 13248

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



13250
13251
13252
# File 'lib/stripe/resources/payment_intent.rb', line 13250

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



13252
13253
13254
# File 'lib/stripe/resources/payment_intent.rb', line 13252

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



13254
13255
13256
# File 'lib/stripe/resources/payment_intent.rb', line 13254

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



13256
13257
13258
# File 'lib/stripe/resources/payment_intent.rb', line 13256

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



13258
13259
13260
# File 'lib/stripe/resources/payment_intent.rb', line 13258

def unit_amount
  @unit_amount
end