Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



12321
12322
12323
12324
12325
12326
12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
# File 'lib/stripe/resources/payment_intent.rb', line 12321

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



12305
12306
12307
# File 'lib/stripe/resources/payment_intent.rb', line 12305

def category
  @category
end

#descriptionObject

Description of the line item.



12307
12308
12309
# File 'lib/stripe/resources/payment_intent.rb', line 12307

def description
  @description
end

#nameObject

Descriptive name of the line item.



12309
12310
12311
# File 'lib/stripe/resources/payment_intent.rb', line 12309

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



12311
12312
12313
# File 'lib/stripe/resources/payment_intent.rb', line 12311

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



12313
12314
12315
# File 'lib/stripe/resources/payment_intent.rb', line 12313

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



12315
12316
12317
# File 'lib/stripe/resources/payment_intent.rb', line 12315

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



12317
12318
12319
# File 'lib/stripe/resources/payment_intent.rb', line 12317

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



12319
12320
12321
# File 'lib/stripe/resources/payment_intent.rb', line 12319

def unit_amount
  @unit_amount
end