Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
12321 12322 12323 12324 12325 12326 12327 12328 12329 12330 12331 12332 12333 12334 12335 12336 12337 12338 12339 |
# File 'lib/stripe/resources/payment_intent.rb', line 12321 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
12305 12306 12307 |
# File 'lib/stripe/resources/payment_intent.rb', line 12305 def category @category end |
#description ⇒ Object
Description of the line item.
12307 12308 12309 |
# File 'lib/stripe/resources/payment_intent.rb', line 12307 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
12309 12310 12311 |
# File 'lib/stripe/resources/payment_intent.rb', line 12309 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
12311 12312 12313 |
# File 'lib/stripe/resources/payment_intent.rb', line 12311 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
12313 12314 12315 |
# File 'lib/stripe/resources/payment_intent.rb', line 12313 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
12315 12316 12317 |
# File 'lib/stripe/resources/payment_intent.rb', line 12315 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
12317 12318 12319 |
# File 'lib/stripe/resources/payment_intent.rb', line 12317 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
12319 12320 12321 |
# File 'lib/stripe/resources/payment_intent.rb', line 12319 def unit_amount @unit_amount end |