Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



12310
12311
12312
12313
12314
12315
12316
12317
12318
12319
12320
12321
12322
12323
12324
12325
12326
12327
12328
# File 'lib/stripe/resources/payment_intent.rb', line 12310

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



12294
12295
12296
# File 'lib/stripe/resources/payment_intent.rb', line 12294

def category
  @category
end

#descriptionObject

Description of the line item.



12296
12297
12298
# File 'lib/stripe/resources/payment_intent.rb', line 12296

def description
  @description
end

#nameObject

Descriptive name of the line item.



12298
12299
12300
# File 'lib/stripe/resources/payment_intent.rb', line 12298

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



12300
12301
12302
# File 'lib/stripe/resources/payment_intent.rb', line 12300

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



12302
12303
12304
# File 'lib/stripe/resources/payment_intent.rb', line 12302

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



12304
12305
12306
# File 'lib/stripe/resources/payment_intent.rb', line 12304

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



12306
12307
12308
# File 'lib/stripe/resources/payment_intent.rb', line 12306

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



12308
12309
12310
# File 'lib/stripe/resources/payment_intent.rb', line 12308

def unit_amount
  @unit_amount
end