Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



12232
12233
12234
12235
12236
12237
12238
12239
12240
12241
12242
12243
12244
12245
12246
12247
12248
12249
12250
# File 'lib/stripe/resources/payment_intent.rb', line 12232

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



12216
12217
12218
# File 'lib/stripe/resources/payment_intent.rb', line 12216

def category
  @category
end

#descriptionObject

Description of the line item.



12218
12219
12220
# File 'lib/stripe/resources/payment_intent.rb', line 12218

def description
  @description
end

#nameObject

Descriptive name of the line item.



12220
12221
12222
# File 'lib/stripe/resources/payment_intent.rb', line 12220

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



12222
12223
12224
# File 'lib/stripe/resources/payment_intent.rb', line 12222

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



12224
12225
12226
# File 'lib/stripe/resources/payment_intent.rb', line 12224

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



12226
12227
12228
# File 'lib/stripe/resources/payment_intent.rb', line 12226

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



12228
12229
12230
# File 'lib/stripe/resources/payment_intent.rb', line 12228

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



12230
12231
12232
# File 'lib/stripe/resources/payment_intent.rb', line 12230

def unit_amount
  @unit_amount
end