Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 11808 11809 11810 11811 11812 11813 11814 11815 11816 |
# File 'lib/stripe/resources/payment_intent.rb', line 11798 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
11782 11783 11784 |
# File 'lib/stripe/resources/payment_intent.rb', line 11782 def category @category end |
#description ⇒ Object
Description of the line item.
11784 11785 11786 |
# File 'lib/stripe/resources/payment_intent.rb', line 11784 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
11786 11787 11788 |
# File 'lib/stripe/resources/payment_intent.rb', line 11786 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
11788 11789 11790 |
# File 'lib/stripe/resources/payment_intent.rb', line 11788 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
11790 11791 11792 |
# File 'lib/stripe/resources/payment_intent.rb', line 11790 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
11792 11793 11794 |
# File 'lib/stripe/resources/payment_intent.rb', line 11792 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
11794 11795 11796 |
# File 'lib/stripe/resources/payment_intent.rb', line 11794 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
11796 11797 11798 |
# File 'lib/stripe/resources/payment_intent.rb', line 11796 def unit_amount @unit_amount end |