Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



13286
13287
13288
13289
13290
13291
13292
13293
13294
13295
13296
13297
13298
13299
13300
13301
13302
13303
13304
# File 'lib/stripe/resources/payment_intent.rb', line 13286

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



13263
13264
13265
# File 'lib/stripe/resources/payment_intent.rb', line 13263

def category
  @category
end

#descriptionObject

Description of the line item.



13266
13267
13268
# File 'lib/stripe/resources/payment_intent.rb', line 13266

def description
  @description
end

#nameObject

Descriptive name of the line item.



13269
13270
13271
# File 'lib/stripe/resources/payment_intent.rb', line 13269

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



13272
13273
13274
# File 'lib/stripe/resources/payment_intent.rb', line 13272

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



13275
13276
13277
# File 'lib/stripe/resources/payment_intent.rb', line 13275

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



13278
13279
13280
# File 'lib/stripe/resources/payment_intent.rb', line 13278

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



13281
13282
13283
# File 'lib/stripe/resources/payment_intent.rb', line 13281

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



13284
13285
13286
# File 'lib/stripe/resources/payment_intent.rb', line 13284

def unit_amount
  @unit_amount
end