Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Tax

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem

Returns a new instance of LineItem.



11690
11691
11692
11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
11703
11704
11705
11706
11707
11708
# File 'lib/stripe/resources/payment_intent.rb', line 11690

def initialize(
  category: nil,
  description: nil,
  name: nil,
  quantity: nil,
  sku: nil,
  sold_by: nil,
  tax: nil,
  unit_amount: nil
)
  @category = category
  @description = description
  @name = name
  @quantity = quantity
  @sku = sku
  @sold_by = sold_by
  @tax = tax
  @unit_amount = unit_amount
end

Instance Attribute Details

#categoryObject

Type of the line item.



11674
11675
11676
# File 'lib/stripe/resources/payment_intent.rb', line 11674

def category
  @category
end

#descriptionObject

Description of the line item.



11676
11677
11678
# File 'lib/stripe/resources/payment_intent.rb', line 11676

def description
  @description
end

#nameObject

Descriptive name of the line item.



11678
11679
11680
# File 'lib/stripe/resources/payment_intent.rb', line 11678

def name
  @name
end

#quantityObject

Quantity of the line item. Must be a positive number.



11680
11681
11682
# File 'lib/stripe/resources/payment_intent.rb', line 11680

def quantity
  @quantity
end

#skuObject

Client facing stock keeping unit, article number or similar.



11682
11683
11684
# File 'lib/stripe/resources/payment_intent.rb', line 11682

def sku
  @sku
end

#sold_byObject

The Stripe account ID of the connected account that sells the item.



11684
11685
11686
# File 'lib/stripe/resources/payment_intent.rb', line 11684

def sold_by
  @sold_by
end

#taxObject

The tax information for the line item.



11686
11687
11688
# File 'lib/stripe/resources/payment_intent.rb', line 11686

def tax
  @tax
end

#unit_amountObject

Price for a single unit of the line item in minor units. Cannot be a negative number.



11688
11689
11690
# File 'lib/stripe/resources/payment_intent.rb', line 11688

def unit_amount
  @unit_amount
end