Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Paypal::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Tax
Instance Attribute Summary collapse
-
#category ⇒ Object
Type of the line item.
-
#description ⇒ Object
Description of the line item.
-
#name ⇒ Object
Descriptive name of the line item.
-
#quantity ⇒ Object
Quantity of the line item.
-
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
-
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
-
#tax ⇒ Object
The tax information for the line item.
-
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units.
Instance Method Summary collapse
-
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil) ⇒ LineItem
Returns a new instance of LineItem.
11732 11733 11734 11735 11736 11737 11738 11739 11740 11741 11742 11743 11744 11745 11746 11747 11748 11749 11750 |
# File 'lib/stripe/resources/payment_intent.rb', line 11732 def initialize( category: nil, description: nil, name: nil, quantity: nil, sku: nil, sold_by: nil, tax: nil, unit_amount: nil ) @category = category @description = description @name = name @quantity = quantity @sku = sku @sold_by = sold_by @tax = tax @unit_amount = unit_amount end |
Instance Attribute Details
#category ⇒ Object
Type of the line item.
11716 11717 11718 |
# File 'lib/stripe/resources/payment_intent.rb', line 11716 def category @category end |
#description ⇒ Object
Description of the line item.
11718 11719 11720 |
# File 'lib/stripe/resources/payment_intent.rb', line 11718 def description @description end |
#name ⇒ Object
Descriptive name of the line item.
11720 11721 11722 |
# File 'lib/stripe/resources/payment_intent.rb', line 11720 def name @name end |
#quantity ⇒ Object
Quantity of the line item. Must be a positive number.
11722 11723 11724 |
# File 'lib/stripe/resources/payment_intent.rb', line 11722 def quantity @quantity end |
#sku ⇒ Object
Client facing stock keeping unit, article number or similar.
11724 11725 11726 |
# File 'lib/stripe/resources/payment_intent.rb', line 11724 def sku @sku end |
#sold_by ⇒ Object
The Stripe account ID of the connected account that sells the item.
11726 11727 11728 |
# File 'lib/stripe/resources/payment_intent.rb', line 11726 def sold_by @sold_by end |
#tax ⇒ Object
The tax information for the line item.
11728 11729 11730 |
# File 'lib/stripe/resources/payment_intent.rb', line 11728 def tax @tax end |
#unit_amount ⇒ Object
Price for a single unit of the line item in minor units. Cannot be a negative number.
11730 11731 11732 |
# File 'lib/stripe/resources/payment_intent.rb', line 11730 def unit_amount @unit_amount end |