Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



14848
14849
14850
14851
14852
14853
14854
14855
14856
14857
14858
14859
14860
14861
14862
# File 'lib/stripe/resources/payment_intent.rb', line 14848

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



14836
14837
14838
# File 'lib/stripe/resources/payment_intent.rb', line 14836

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



14838
14839
14840
# File 'lib/stripe/resources/payment_intent.rb', line 14838

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



14840
14841
14842
# File 'lib/stripe/resources/payment_intent.rb', line 14840

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



14842
14843
14844
# File 'lib/stripe/resources/payment_intent.rb', line 14842

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



14844
14845
14846
# File 'lib/stripe/resources/payment_intent.rb', line 14844

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



14846
14847
14848
# File 'lib/stripe/resources/payment_intent.rb', line 14846

def purpose
  @purpose
end