Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



12402
12403
12404
12405
12406
12407
12408
12409
12410
12411
12412
12413
12414
12415
12416
# File 'lib/stripe/resources/payment_intent.rb', line 12402

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



12390
12391
12392
# File 'lib/stripe/resources/payment_intent.rb', line 12390

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



12392
12393
12394
# File 'lib/stripe/resources/payment_intent.rb', line 12392

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



12394
12395
12396
# File 'lib/stripe/resources/payment_intent.rb', line 12394

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



12396
12397
12398
# File 'lib/stripe/resources/payment_intent.rb', line 12396

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



12398
12399
12400
# File 'lib/stripe/resources/payment_intent.rb', line 12398

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



12400
12401
12402
# File 'lib/stripe/resources/payment_intent.rb', line 12400

def purpose
  @purpose
end