Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount that will be collected.
-
#amount_type ⇒ Object
The type of amount that will be collected.
-
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected.
-
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
-
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period.
-
#purpose ⇒ Object
The purpose for which payments are made.
Instance Method Summary collapse
-
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions
constructor
A new instance of MandateOptions.
Methods inherited from RequestParams
Constructor Details
#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions
Returns a new instance of MandateOptions.
12391 12392 12393 12394 12395 12396 12397 12398 12399 12400 12401 12402 12403 12404 12405 |
# File 'lib/stripe/resources/payment_intent.rb', line 12391 def initialize( amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil ) @amount = amount @amount_type = amount_type @end_date = end_date @payment_schedule = payment_schedule @payments_per_period = payments_per_period @purpose = purpose end |
Instance Attribute Details
#amount ⇒ Object
Amount that will be collected. It is required when ‘amount_type` is `fixed`.
12379 12380 12381 |
# File 'lib/stripe/resources/payment_intent.rb', line 12379 def amount @amount end |
#amount_type ⇒ Object
The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.
12381 12382 12383 |
# File 'lib/stripe/resources/payment_intent.rb', line 12381 def amount_type @amount_type end |
#end_date ⇒ Object
Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.
12383 12384 12385 |
# File 'lib/stripe/resources/payment_intent.rb', line 12383 def end_date @end_date end |
#payment_schedule ⇒ Object
The periodicity at which payments will be collected.
12385 12386 12387 |
# File 'lib/stripe/resources/payment_intent.rb', line 12385 def payment_schedule @payment_schedule end |
#payments_per_period ⇒ Object
The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.
12387 12388 12389 |
# File 'lib/stripe/resources/payment_intent.rb', line 12387 def payments_per_period @payments_per_period end |
#purpose ⇒ Object
The purpose for which payments are made. Defaults to retail.
12389 12390 12391 |
# File 'lib/stripe/resources/payment_intent.rb', line 12389 def purpose @purpose end |