Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::Payto::MandateOptions

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(amount: nil, amount_type: nil, end_date: nil, payment_schedule: nil, payments_per_period: nil, purpose: nil) ⇒ MandateOptions

Returns a new instance of MandateOptions.



11771
11772
11773
11774
11775
11776
11777
11778
11779
11780
11781
11782
11783
11784
11785
# File 'lib/stripe/resources/payment_intent.rb', line 11771

def initialize(
  amount: nil,
  amount_type: nil,
  end_date: nil,
  payment_schedule: nil,
  payments_per_period: nil,
  purpose: nil
)
  @amount = amount
  @amount_type = amount_type
  @end_date = end_date
  @payment_schedule = payment_schedule
  @payments_per_period = payments_per_period
  @purpose = purpose
end

Instance Attribute Details

#amountObject

Amount that will be collected. It is required when ‘amount_type` is `fixed`.



11759
11760
11761
# File 'lib/stripe/resources/payment_intent.rb', line 11759

def amount
  @amount
end

#amount_typeObject

The type of amount that will be collected. The amount charged must be exact or up to the value of ‘amount` param for `fixed` or `maximum` type respectively.



11761
11762
11763
# File 'lib/stripe/resources/payment_intent.rb', line 11761

def amount_type
  @amount_type
end

#end_dateObject

Date, in YYYY-MM-DD format, after which payments will not be collected. Defaults to no end date.



11763
11764
11765
# File 'lib/stripe/resources/payment_intent.rb', line 11763

def end_date
  @end_date
end

#payment_scheduleObject

The periodicity at which payments will be collected.



11765
11766
11767
# File 'lib/stripe/resources/payment_intent.rb', line 11765

def payment_schedule
  @payment_schedule
end

#payments_per_periodObject

The number of payments that will be made during a payment period. Defaults to 1 except for when ‘payment_schedule` is `adhoc`. In that case, it defaults to no limit.



11767
11768
11769
# File 'lib/stripe/resources/payment_intent.rb', line 11767

def payments_per_period
  @payments_per_period
end

#purposeObject

The purpose for which payments are made. Defaults to retail.



11769
11770
11771
# File 'lib/stripe/resources/payment_intent.rb', line 11769

def purpose
  @purpose
end