Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



8417
8418
8419
8420
8421
8422
8423
8424
8425
8426
8427
8428
8429
8430
8431
8432
8433
# File 'lib/stripe/resources/payment_intent.rb', line 8417

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  preferred_settlement_speed: nil,
  setup_future_usage: nil,
  target_date: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @preferred_settlement_speed = preferred_settlement_speed
  @setup_future_usage = setup_future_usage
  @target_date = target_date
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



8395
8396
8397
# File 'lib/stripe/resources/payment_intent.rb', line 8395

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



8397
8398
8399
# File 'lib/stripe/resources/payment_intent.rb', line 8397

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



8399
8400
8401
# File 'lib/stripe/resources/payment_intent.rb', line 8399

def networks
  @networks
end

#preferred_settlement_speedObject

Preferred transaction settlement speed



8401
8402
8403
# File 'lib/stripe/resources/payment_intent.rb', line 8401

def preferred_settlement_speed
  @preferred_settlement_speed
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



8411
8412
8413
# File 'lib/stripe/resources/payment_intent.rb', line 8411

def setup_future_usage
  @setup_future_usage
end

#target_dateObject

Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.



8413
8414
8415
# File 'lib/stripe/resources/payment_intent.rb', line 8413

def target_date
  @target_date
end

#verification_methodObject

Bank account verification method.



8415
8416
8417
# File 'lib/stripe/resources/payment_intent.rb', line 8415

def verification_method
  @verification_method
end