Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: FinancialConnections, MandateOptions, Networks
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#networks ⇒ Object
Additional fields for network related functions.
-
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account.
-
#verification_method ⇒ Object
Bank account verification method.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
13693 13694 13695 13696 13697 13698 13699 13700 13701 13702 13703 13704 13705 13706 13707 13708 13709 |
# File 'lib/stripe/resources/payment_intent.rb', line 13693 def initialize( financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, target_date: nil, verification_method: nil ) @financial_connections = financial_connections @mandate_options = @networks = networks @preferred_settlement_speed = preferred_settlement_speed @setup_future_usage = setup_future_usage @target_date = target_date @verification_method = verification_method end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
13671 13672 13673 |
# File 'lib/stripe/resources/payment_intent.rb', line 13671 def financial_connections @financial_connections end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
13673 13674 13675 |
# File 'lib/stripe/resources/payment_intent.rb', line 13673 def @mandate_options end |
#networks ⇒ Object
Additional fields for network related functions
13675 13676 13677 |
# File 'lib/stripe/resources/payment_intent.rb', line 13675 def networks @networks end |
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed
13677 13678 13679 |
# File 'lib/stripe/resources/payment_intent.rb', line 13677 def preferred_settlement_speed @preferred_settlement_speed end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
13687 13688 13689 |
# File 'lib/stripe/resources/payment_intent.rb', line 13687 def setup_future_usage @setup_future_usage end |
#target_date ⇒ Object
Controls when Stripe will attempt to debit the funds from the customer’s account. The date must be a string in YYYY-MM-DD format. The date must be in the future and between 3 and 15 calendar days from now.
13689 13690 13691 |
# File 'lib/stripe/resources/payment_intent.rb', line 13689 def target_date @target_date end |
#verification_method ⇒ Object
Bank account verification method.
13691 13692 13693 |
# File 'lib/stripe/resources/payment_intent.rb', line 13691 def verification_method @verification_method end |