Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: FinancialConnections, MandateOptions, Networks
Instance Attribute Summary collapse
-
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation.
-
#mandate_options ⇒ Object
Additional fields for Mandate creation.
-
#networks ⇒ Object
Additional fields for network related functions.
-
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed.
-
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
-
#verification_method ⇒ Object
Bank account verification method.
Instance Method Summary collapse
-
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, verification_method: nil) ⇒ UsBankAccount
constructor
A new instance of UsBankAccount.
Methods inherited from RequestParams
Constructor Details
#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, verification_method: nil) ⇒ UsBankAccount
Returns a new instance of UsBankAccount.
12131 12132 12133 12134 12135 12136 12137 12138 12139 12140 12141 12142 12143 12144 12145 |
# File 'lib/stripe/resources/payment_intent.rb', line 12131 def initialize( financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, verification_method: nil ) @financial_connections = financial_connections @mandate_options = @networks = networks @preferred_settlement_speed = preferred_settlement_speed @setup_future_usage = setup_future_usage @verification_method = verification_method end |
Instance Attribute Details
#financial_connections ⇒ Object
Additional fields for Financial Connections Session creation
12111 12112 12113 |
# File 'lib/stripe/resources/payment_intent.rb', line 12111 def financial_connections @financial_connections end |
#mandate_options ⇒ Object
Additional fields for Mandate creation
12113 12114 12115 |
# File 'lib/stripe/resources/payment_intent.rb', line 12113 def @mandate_options end |
#networks ⇒ Object
Additional fields for network related functions
12115 12116 12117 |
# File 'lib/stripe/resources/payment_intent.rb', line 12115 def networks @networks end |
#preferred_settlement_speed ⇒ Object
Preferred transaction settlement speed
12117 12118 12119 |
# File 'lib/stripe/resources/payment_intent.rb', line 12117 def preferred_settlement_speed @preferred_settlement_speed end |
#setup_future_usage ⇒ Object
Indicates that you intend to make future payments with this PaymentIntent’s payment method.
If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.
If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.
When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).
If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.
12127 12128 12129 |
# File 'lib/stripe/resources/payment_intent.rb', line 12127 def setup_future_usage @setup_future_usage end |
#verification_method ⇒ Object
Bank account verification method.
12129 12130 12131 |
# File 'lib/stripe/resources/payment_intent.rb', line 12129 def verification_method @verification_method end |