Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: FinancialConnections, MandateOptions, Networks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(financial_connections: nil, mandate_options: nil, networks: nil, preferred_settlement_speed: nil, setup_future_usage: nil, verification_method: nil) ⇒ UsBankAccount

Returns a new instance of UsBankAccount.



13714
13715
13716
13717
13718
13719
13720
13721
13722
13723
13724
13725
13726
13727
13728
# File 'lib/stripe/resources/payment_intent.rb', line 13714

def initialize(
  financial_connections: nil,
  mandate_options: nil,
  networks: nil,
  preferred_settlement_speed: nil,
  setup_future_usage: nil,
  verification_method: nil
)
  @financial_connections = financial_connections
  @mandate_options = mandate_options
  @networks = networks
  @preferred_settlement_speed = preferred_settlement_speed
  @setup_future_usage = setup_future_usage
  @verification_method = verification_method
end

Instance Attribute Details

#financial_connectionsObject

Additional fields for Financial Connections Session creation



13689
13690
13691
# File 'lib/stripe/resources/payment_intent.rb', line 13689

def financial_connections
  @financial_connections
end

#mandate_optionsObject

Additional fields for Mandate creation



13692
13693
13694
# File 'lib/stripe/resources/payment_intent.rb', line 13692

def mandate_options
  @mandate_options
end

#networksObject

Additional fields for network related functions



13695
13696
13697
# File 'lib/stripe/resources/payment_intent.rb', line 13695

def networks
  @networks
end

#preferred_settlement_speedObject

Preferred transaction settlement speed



13698
13699
13700
# File 'lib/stripe/resources/payment_intent.rb', line 13698

def preferred_settlement_speed
  @preferred_settlement_speed
end

#setup_future_usageObject

Indicates that you intend to make future payments with this PaymentIntent’s payment method.

If you provide a Customer with the PaymentIntent, you can use this parameter to [attach the payment method](/payments/save-during-payment) to the Customer after the PaymentIntent is confirmed and the customer completes any required actions. If you don’t provide a Customer, you can still [attach](/api/payment_methods/attach) the payment method to a Customer after the transaction completes.

If the payment method is ‘card_present` and isn’t a digital wallet, Stripe creates and attaches a [generated_card](/api/charges/object#charge_object-payment_method_details-card_present-generated_card) payment method representing the card to the Customer instead.

When processing card payments, Stripe uses ‘setup_future_usage` to help you comply with regional legislation and network rules, such as [SCA](/strong-customer-authentication).

If you’ve already set ‘setup_future_usage` and you’re performing a request using a publishable key, you can only update the value from ‘on_session` to `off_session`.



13709
13710
13711
# File 'lib/stripe/resources/payment_intent.rb', line 13709

def setup_future_usage
  @setup_future_usage
end

#verification_methodObject

Bank account verification method.



13712
13713
13714
# File 'lib/stripe/resources/payment_intent.rb', line 13712

def verification_method
  @verification_method
end