Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



13638
13639
13640
13641
13642
13643
13644
13645
13646
13647
13648
13649
13650
# File 'lib/stripe/resources/payment_intent.rb', line 13638

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



13628
13629
13630
# File 'lib/stripe/resources/payment_intent.rb', line 13628

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



13630
13631
13632
# File 'lib/stripe/resources/payment_intent.rb', line 13630

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



13632
13633
13634
# File 'lib/stripe/resources/payment_intent.rb', line 13632

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



13634
13635
13636
# File 'lib/stripe/resources/payment_intent.rb', line 13634

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



13636
13637
13638
# File 'lib/stripe/resources/payment_intent.rb', line 13636

def return_url
  @return_url
end