Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



12147
12148
12149
12150
12151
12152
12153
12154
12155
12156
12157
12158
12159
# File 'lib/stripe/resources/payment_intent.rb', line 12147

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method.



12137
12138
12139
# File 'lib/stripe/resources/payment_intent.rb', line 12137

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



12139
12140
12141
# File 'lib/stripe/resources/payment_intent.rb', line 12139

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



12141
12142
12143
# File 'lib/stripe/resources/payment_intent.rb', line 12141

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



12143
12144
12145
# File 'lib/stripe/resources/payment_intent.rb', line 12143

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



12145
12146
12147
# File 'lib/stripe/resources/payment_intent.rb', line 12145

def return_url
  @return_url
end