Class: Stripe::PaymentIntent::ConfirmParams::PaymentMethodOptions::UsBankAccount::FinancialConnections

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Filters, ManualEntry

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(filters: nil, manual_entry: nil, permissions: nil, prefetch: nil, return_url: nil) ⇒ FinancialConnections

Returns a new instance of FinancialConnections.



12078
12079
12080
12081
12082
12083
12084
12085
12086
12087
12088
12089
12090
# File 'lib/stripe/resources/payment_intent.rb', line 12078

def initialize(
  filters: nil,
  manual_entry: nil,
  permissions: nil,
  prefetch: nil,
  return_url: nil
)
  @filters = filters
  @manual_entry = manual_entry
  @permissions = permissions
  @prefetch = prefetch
  @return_url = return_url
end

Instance Attribute Details

#filtersObject

Provide filters for the linked accounts that the customer can select for the payment method



12068
12069
12070
# File 'lib/stripe/resources/payment_intent.rb', line 12068

def filters
  @filters
end

#manual_entryObject

Customize manual entry behavior



12070
12071
12072
# File 'lib/stripe/resources/payment_intent.rb', line 12070

def manual_entry
  @manual_entry
end

#permissionsObject

The list of permissions to request. If this parameter is passed, the ‘payment_method` permission must be included. Valid permissions include: `balances`, `ownership`, `payment_method`, and `transactions`.



12072
12073
12074
# File 'lib/stripe/resources/payment_intent.rb', line 12072

def permissions
  @permissions
end

#prefetchObject

List of data features that you would like to retrieve upon account creation.



12074
12075
12076
# File 'lib/stripe/resources/payment_intent.rb', line 12074

def prefetch
  @prefetch
end

#return_urlObject

For webview integrations only. Upon completing OAuth login in the native browser, the user will be redirected to this URL to return to your app.



12076
12077
12078
# File 'lib/stripe/resources/payment_intent.rb', line 12076

def return_url
  @return_url
end