Class: Stripe::PaymentIntent::ConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



8732
8733
8734
8735
8736
8737
8738
# File 'lib/stripe/resources/payment_intent.rb', line 8732

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



8722
8723
8724
# File 'lib/stripe/resources/payment_intent.rb', line 8722

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



8724
8725
8726
# File 'lib/stripe/resources/payment_intent.rb', line 8724

def carrier
  @carrier
end

#nameObject

Recipient name.



8726
8727
8728
# File 'lib/stripe/resources/payment_intent.rb', line 8726

def name
  @name
end

#phoneObject

Recipient phone (including extension).



8728
8729
8730
# File 'lib/stripe/resources/payment_intent.rb', line 8728

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



8730
8731
8732
# File 'lib/stripe/resources/payment_intent.rb', line 8730

def tracking_number
  @tracking_number
end