Class: Stripe::PaymentIntent::ConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
14040 14041 14042 14043 14044 14045 14046 |
# File 'lib/stripe/resources/payment_intent.rb', line 14040 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
14030 14031 14032 |
# File 'lib/stripe/resources/payment_intent.rb', line 14030 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
14032 14033 14034 |
# File 'lib/stripe/resources/payment_intent.rb', line 14032 def carrier @carrier end |
#name ⇒ Object
Recipient name.
14034 14035 14036 |
# File 'lib/stripe/resources/payment_intent.rb', line 14034 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
14036 14037 14038 |
# File 'lib/stripe/resources/payment_intent.rb', line 14036 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
14038 14039 14040 |
# File 'lib/stripe/resources/payment_intent.rb', line 14038 def tracking_number @tracking_number end |