Class: Stripe::PaymentIntent::ConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



8702
8703
8704
8705
8706
8707
8708
# File 'lib/stripe/resources/payment_intent.rb', line 8702

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



8692
8693
8694
# File 'lib/stripe/resources/payment_intent.rb', line 8692

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



8694
8695
8696
# File 'lib/stripe/resources/payment_intent.rb', line 8694

def carrier
  @carrier
end

#nameObject

Recipient name.



8696
8697
8698
# File 'lib/stripe/resources/payment_intent.rb', line 8696

def name
  @name
end

#phoneObject

Recipient phone (including extension).



8698
8699
8700
# File 'lib/stripe/resources/payment_intent.rb', line 8698

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



8700
8701
8702
# File 'lib/stripe/resources/payment_intent.rb', line 8700

def tracking_number
  @tracking_number
end