Class: Stripe::PaymentIntent::ConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
13416 13417 13418 13419 13420 13421 13422 |
# File 'lib/stripe/resources/payment_intent.rb', line 13416 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
13406 13407 13408 |
# File 'lib/stripe/resources/payment_intent.rb', line 13406 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
13408 13409 13410 |
# File 'lib/stripe/resources/payment_intent.rb', line 13408 def carrier @carrier end |
#name ⇒ Object
Recipient name.
13410 13411 13412 |
# File 'lib/stripe/resources/payment_intent.rb', line 13410 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
13412 13413 13414 |
# File 'lib/stripe/resources/payment_intent.rb', line 13412 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
13414 13415 13416 |
# File 'lib/stripe/resources/payment_intent.rb', line 13414 def tracking_number @tracking_number end |