Class: Stripe::PaymentIntent::ConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



13097
13098
13099
13100
13101
13102
13103
# File 'lib/stripe/resources/payment_intent.rb', line 13097

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



13087
13088
13089
# File 'lib/stripe/resources/payment_intent.rb', line 13087

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



13089
13090
13091
# File 'lib/stripe/resources/payment_intent.rb', line 13089

def carrier
  @carrier
end

#nameObject

Recipient name.



13091
13092
13093
# File 'lib/stripe/resources/payment_intent.rb', line 13091

def name
  @name
end

#phoneObject

Recipient phone (including extension).



13093
13094
13095
# File 'lib/stripe/resources/payment_intent.rb', line 13093

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



13095
13096
13097
# File 'lib/stripe/resources/payment_intent.rb', line 13095

def tracking_number
  @tracking_number
end