Class: Stripe::PaymentIntent::ConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
13070 13071 13072 13073 13074 13075 13076 |
# File 'lib/stripe/resources/payment_intent.rb', line 13070 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
13060 13061 13062 |
# File 'lib/stripe/resources/payment_intent.rb', line 13060 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
13062 13063 13064 |
# File 'lib/stripe/resources/payment_intent.rb', line 13062 def carrier @carrier end |
#name ⇒ Object
Recipient name.
13064 13065 13066 |
# File 'lib/stripe/resources/payment_intent.rb', line 13064 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
13066 13067 13068 |
# File 'lib/stripe/resources/payment_intent.rb', line 13066 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
13068 13069 13070 |
# File 'lib/stripe/resources/payment_intent.rb', line 13068 def tracking_number @tracking_number end |