Class: Stripe::PaymentIntent::ConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



8490
8491
8492
8493
8494
8495
8496
# File 'lib/stripe/resources/payment_intent.rb', line 8490

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



8480
8481
8482
# File 'lib/stripe/resources/payment_intent.rb', line 8480

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



8482
8483
8484
# File 'lib/stripe/resources/payment_intent.rb', line 8482

def carrier
  @carrier
end

#nameObject

Recipient name.



8484
8485
8486
# File 'lib/stripe/resources/payment_intent.rb', line 8484

def name
  @name
end

#phoneObject

Recipient phone (including extension).



8486
8487
8488
# File 'lib/stripe/resources/payment_intent.rb', line 8486

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



8488
8489
8490
# File 'lib/stripe/resources/payment_intent.rb', line 8488

def tracking_number
  @tracking_number
end