Class: Stripe::PaymentIntent::ConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



12992
12993
12994
12995
12996
12997
12998
# File 'lib/stripe/resources/payment_intent.rb', line 12992

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



12982
12983
12984
# File 'lib/stripe/resources/payment_intent.rb', line 12982

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



12984
12985
12986
# File 'lib/stripe/resources/payment_intent.rb', line 12984

def carrier
  @carrier
end

#nameObject

Recipient name.



12986
12987
12988
# File 'lib/stripe/resources/payment_intent.rb', line 12986

def name
  @name
end

#phoneObject

Recipient phone (including extension).



12988
12989
12990
# File 'lib/stripe/resources/payment_intent.rb', line 12988

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



12990
12991
12992
# File 'lib/stripe/resources/payment_intent.rb', line 12990

def tracking_number
  @tracking_number
end