Class: Stripe::PaymentIntent::ConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
12529 12530 12531 12532 12533 12534 12535 |
# File 'lib/stripe/resources/payment_intent.rb', line 12529 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
12519 12520 12521 |
# File 'lib/stripe/resources/payment_intent.rb', line 12519 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
12521 12522 12523 |
# File 'lib/stripe/resources/payment_intent.rb', line 12521 def carrier @carrier end |
#name ⇒ Object
Recipient name.
12523 12524 12525 |
# File 'lib/stripe/resources/payment_intent.rb', line 12523 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
12525 12526 12527 |
# File 'lib/stripe/resources/payment_intent.rb', line 12525 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
12527 12528 12529 |
# File 'lib/stripe/resources/payment_intent.rb', line 12527 def tracking_number @tracking_number end |