Class: Stripe::PaymentIntent::ConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



12456
12457
12458
12459
12460
12461
12462
# File 'lib/stripe/resources/payment_intent.rb', line 12456

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



12446
12447
12448
# File 'lib/stripe/resources/payment_intent.rb', line 12446

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



12448
12449
12450
# File 'lib/stripe/resources/payment_intent.rb', line 12448

def carrier
  @carrier
end

#nameObject

Recipient name.



12450
12451
12452
# File 'lib/stripe/resources/payment_intent.rb', line 12450

def name
  @name
end

#phoneObject

Recipient phone (including extension).



12452
12453
12454
# File 'lib/stripe/resources/payment_intent.rb', line 12452

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



12454
12455
12456
# File 'lib/stripe/resources/payment_intent.rb', line 12454

def tracking_number
  @tracking_number
end