Class: Stripe::PaymentIntent::ConfirmParams::Shipping

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Address

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping

Returns a new instance of Shipping.



12410
12411
12412
12413
12414
12415
12416
# File 'lib/stripe/resources/payment_intent.rb', line 12410

def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil)
  @address = address
  @carrier = carrier
  @name = name
  @phone = phone
  @tracking_number = tracking_number
end

Instance Attribute Details

#addressObject

Shipping address.



12400
12401
12402
# File 'lib/stripe/resources/payment_intent.rb', line 12400

def address
  @address
end

#carrierObject

The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.



12402
12403
12404
# File 'lib/stripe/resources/payment_intent.rb', line 12402

def carrier
  @carrier
end

#nameObject

Recipient name.



12404
12405
12406
# File 'lib/stripe/resources/payment_intent.rb', line 12404

def name
  @name
end

#phoneObject

Recipient phone (including extension).



12406
12407
12408
# File 'lib/stripe/resources/payment_intent.rb', line 12406

def phone
  @phone
end

#tracking_numberObject

The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.



12408
12409
12410
# File 'lib/stripe/resources/payment_intent.rb', line 12408

def tracking_number
  @tracking_number
end