Class: Stripe::PaymentIntent::ConfirmParams::Shipping
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::ConfirmParams::Shipping
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: Address
Instance Attribute Summary collapse
-
#address ⇒ Object
Shipping address.
-
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
-
#name ⇒ Object
Recipient name.
-
#phone ⇒ Object
Recipient phone (including extension).
-
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service.
Instance Method Summary collapse
-
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
constructor
A new instance of Shipping.
Methods inherited from RequestParams
Constructor Details
#initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) ⇒ Shipping
Returns a new instance of Shipping.
14097 14098 14099 14100 14101 14102 14103 |
# File 'lib/stripe/resources/payment_intent.rb', line 14097 def initialize(address: nil, carrier: nil, name: nil, phone: nil, tracking_number: nil) @address = address @carrier = carrier @name = name @phone = phone @tracking_number = tracking_number end |
Instance Attribute Details
#address ⇒ Object
Shipping address.
14083 14084 14085 |
# File 'lib/stripe/resources/payment_intent.rb', line 14083 def address @address end |
#carrier ⇒ Object
The delivery service that shipped a physical product, such as Fedex, UPS, USPS, etc.
14086 14087 14088 |
# File 'lib/stripe/resources/payment_intent.rb', line 14086 def carrier @carrier end |
#name ⇒ Object
Recipient name.
14089 14090 14091 |
# File 'lib/stripe/resources/payment_intent.rb', line 14089 def name @name end |
#phone ⇒ Object
Recipient phone (including extension).
14092 14093 14094 |
# File 'lib/stripe/resources/payment_intent.rb', line 14092 def phone @phone end |
#tracking_number ⇒ Object
The tracking number for a physical product, obtained from the delivery service. If multiple tracking numbers were generated for this purchase, please separate them with commas.
14095 14096 14097 |
# File 'lib/stripe/resources/payment_intent.rb', line 14095 def tracking_number @tracking_number end |