Class: Stripe::PaymentIntent::CreateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
3542 3543 3544 3545 3546 3547 3548 3549 3550 3551 3552 3553 3554 3555 3556 3557 3558 3559 3560 |
# File 'lib/stripe/resources/payment_intent.rb', line 3542 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
3526 3527 3528 |
# File 'lib/stripe/resources/payment_intent.rb', line 3526 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
3528 3529 3530 |
# File 'lib/stripe/resources/payment_intent.rb', line 3528 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
3530 3531 3532 |
# File 'lib/stripe/resources/payment_intent.rb', line 3530 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
3532 3533 3534 |
# File 'lib/stripe/resources/payment_intent.rb', line 3532 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
3534 3535 3536 |
# File 'lib/stripe/resources/payment_intent.rb', line 3534 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
3536 3537 3538 |
# File 'lib/stripe/resources/payment_intent.rb', line 3536 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
3538 3539 3540 |
# File 'lib/stripe/resources/payment_intent.rb', line 3538 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
3540 3541 3542 |
# File 'lib/stripe/resources/payment_intent.rb', line 3540 def unit_of_measure @unit_of_measure end |