Class: Stripe::PaymentIntent::CreateParams::AmountDetails::LineItem
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::AmountDetails::LineItem
- Defined in:
- lib/stripe/resources/payment_intent.rb
Defined Under Namespace
Classes: PaymentMethodOptions, Tax
Instance Attribute Summary collapse
-
#discount_amount ⇒ Object
The amount an item was discounted for.
-
#payment_method_options ⇒ Object
Payment method-specific information for line items.
-
#product_code ⇒ Object
Unique identifier of the product.
-
#product_name ⇒ Object
Name of the product.
-
#quantity ⇒ Object
Number of items of the product.
-
#tax ⇒ Object
Contains information about the tax on the item.
-
#unit_cost ⇒ Object
Cost of the product.
-
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
Instance Method Summary collapse
-
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
constructor
A new instance of LineItem.
Methods inherited from RequestParams
Constructor Details
#initialize(discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil) ⇒ LineItem
Returns a new instance of LineItem.
2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 |
# File 'lib/stripe/resources/payment_intent.rb', line 2139 def initialize( discount_amount: nil, payment_method_options: nil, product_code: nil, product_name: nil, quantity: nil, tax: nil, unit_cost: nil, unit_of_measure: nil ) @discount_amount = discount_amount @payment_method_options = @product_code = product_code @product_name = product_name @quantity = quantity @tax = tax @unit_cost = unit_cost @unit_of_measure = unit_of_measure end |
Instance Attribute Details
#discount_amount ⇒ Object
The amount an item was discounted for. Positive integer.
2123 2124 2125 |
# File 'lib/stripe/resources/payment_intent.rb', line 2123 def discount_amount @discount_amount end |
#payment_method_options ⇒ Object
Payment method-specific information for line items.
2125 2126 2127 |
# File 'lib/stripe/resources/payment_intent.rb', line 2125 def @payment_method_options end |
#product_code ⇒ Object
Unique identifier of the product. At most 12 characters long.
2127 2128 2129 |
# File 'lib/stripe/resources/payment_intent.rb', line 2127 def product_code @product_code end |
#product_name ⇒ Object
Name of the product. At most 100 characters long.
2129 2130 2131 |
# File 'lib/stripe/resources/payment_intent.rb', line 2129 def product_name @product_name end |
#quantity ⇒ Object
Number of items of the product. Positive integer.
2131 2132 2133 |
# File 'lib/stripe/resources/payment_intent.rb', line 2131 def quantity @quantity end |
#tax ⇒ Object
Contains information about the tax on the item.
2133 2134 2135 |
# File 'lib/stripe/resources/payment_intent.rb', line 2133 def tax @tax end |
#unit_cost ⇒ Object
Cost of the product. Non-negative integer.
2135 2136 2137 |
# File 'lib/stripe/resources/payment_intent.rb', line 2135 def unit_cost @unit_cost end |
#unit_of_measure ⇒ Object
A unit of measure for the line item, such as gallons, feet, meters, etc.
2137 2138 2139 |
# File 'lib/stripe/resources/payment_intent.rb', line 2137 def unit_of_measure @unit_of_measure end |