Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



1653
1654
1655
1656
1657
1658
# File 'lib/stripe/resources/payment_intent.rb', line 1653

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



1645
1646
1647
# File 'lib/stripe/resources/payment_intent.rb', line 1645

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



1647
1648
1649
# File 'lib/stripe/resources/payment_intent.rb', line 1647

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



1649
1650
1651
# File 'lib/stripe/resources/payment_intent.rb', line 1649

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



1651
1652
1653
# File 'lib/stripe/resources/payment_intent.rb', line 1651

def type
  @type
end