Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2097
2098
2099
2100
2101
2102
# File 'lib/stripe/resources/payment_intent.rb', line 2097

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2089
2090
2091
# File 'lib/stripe/resources/payment_intent.rb', line 2089

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2091
2092
2093
# File 'lib/stripe/resources/payment_intent.rb', line 2091

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2093
2094
2095
# File 'lib/stripe/resources/payment_intent.rb', line 2093

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2095
2096
2097
# File 'lib/stripe/resources/payment_intent.rb', line 2095

def type
  @type
end