Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



2040
2041
2042
2043
2044
2045
# File 'lib/stripe/resources/payment_intent.rb', line 2040

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



2032
2033
2034
# File 'lib/stripe/resources/payment_intent.rb', line 2032

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



2034
2035
2036
# File 'lib/stripe/resources/payment_intent.rb', line 2034

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



2036
2037
2038
# File 'lib/stripe/resources/payment_intent.rb', line 2036

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



2038
2039
2040
# File 'lib/stripe/resources/payment_intent.rb', line 2038

def type
  @type
end