Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Defined Under Namespace

Classes: Offline, Online

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(accepted_at: nil, offline: nil, online: nil, type: nil) ⇒ CustomerAcceptance

Returns a new instance of CustomerAcceptance.



1975
1976
1977
1978
1979
1980
# File 'lib/stripe/resources/payment_intent.rb', line 1975

def initialize(accepted_at: nil, offline: nil, online: nil, type: nil)
  @accepted_at = accepted_at
  @offline = offline
  @online = online
  @type = type
end

Instance Attribute Details

#accepted_atObject

The time at which the customer accepted the Mandate.



1967
1968
1969
# File 'lib/stripe/resources/payment_intent.rb', line 1967

def accepted_at
  @accepted_at
end

#offlineObject

If this is a Mandate accepted offline, this hash contains details about the offline acceptance.



1969
1970
1971
# File 'lib/stripe/resources/payment_intent.rb', line 1969

def offline
  @offline
end

#onlineObject

If this is a Mandate accepted online, this hash contains details about the online acceptance.



1971
1972
1973
# File 'lib/stripe/resources/payment_intent.rb', line 1971

def online
  @online
end

#typeObject

The type of customer acceptance information included with the Mandate. One of ‘online` or `offline`.



1973
1974
1975
# File 'lib/stripe/resources/payment_intent.rb', line 1973

def type
  @type
end