Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



2249
2250
2251
2252
# File 'lib/stripe/resources/payment_intent.rb', line 2249

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



2245
2246
2247
# File 'lib/stripe/resources/payment_intent.rb', line 2245

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



2247
2248
2249
# File 'lib/stripe/resources/payment_intent.rb', line 2247

def user_agent
  @user_agent
end