Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



1975
1976
1977
1978
# File 'lib/stripe/resources/payment_intent.rb', line 1975

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



1971
1972
1973
# File 'lib/stripe/resources/payment_intent.rb', line 1971

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



1973
1974
1975
# File 'lib/stripe/resources/payment_intent.rb', line 1973

def user_agent
  @user_agent
end