Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance::Online

Inherits:
RequestParams
  • Object
show all
Defined in:
lib/stripe/resources/payment_intent.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from RequestParams

#to_h

Constructor Details

#initialize(ip_address: nil, user_agent: nil) ⇒ Online

Returns a new instance of Online.



1961
1962
1963
1964
# File 'lib/stripe/resources/payment_intent.rb', line 1961

def initialize(ip_address: nil, user_agent: nil)
  @ip_address = ip_address
  @user_agent = user_agent
end

Instance Attribute Details

#ip_addressObject

The IP address from which the Mandate was accepted by the customer.



1957
1958
1959
# File 'lib/stripe/resources/payment_intent.rb', line 1957

def ip_address
  @ip_address
end

#user_agentObject

The user agent of the browser from which the Mandate was accepted by the customer.



1959
1960
1961
# File 'lib/stripe/resources/payment_intent.rb', line 1959

def user_agent
  @user_agent
end