Class: Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance::Online
- Inherits:
-
RequestParams
- Object
- RequestParams
- Stripe::PaymentIntent::CreateParams::MandateData::CustomerAcceptance::Online
- Defined in:
- lib/stripe/resources/payment_intent.rb
Instance Attribute Summary collapse
-
#ip_address ⇒ Object
The IP address from which the Mandate was accepted by the customer.
-
#user_agent ⇒ Object
The user agent of the browser from which the Mandate was accepted by the customer.
Instance Method Summary collapse
-
#initialize(ip_address: nil, user_agent: nil) ⇒ Online
constructor
A new instance of Online.
Methods inherited from RequestParams
Constructor Details
#initialize(ip_address: nil, user_agent: nil) ⇒ Online
Returns a new instance of Online.
1961 1962 1963 1964 |
# File 'lib/stripe/resources/payment_intent.rb', line 1961 def initialize(ip_address: nil, user_agent: nil) @ip_address = ip_address @user_agent = user_agent end |
Instance Attribute Details
#ip_address ⇒ Object
The IP address from which the Mandate was accepted by the customer.
1957 1958 1959 |
# File 'lib/stripe/resources/payment_intent.rb', line 1957 def ip_address @ip_address end |
#user_agent ⇒ Object
The user agent of the browser from which the Mandate was accepted by the customer.
1959 1960 1961 |
# File 'lib/stripe/resources/payment_intent.rb', line 1959 def user_agent @user_agent end |